from mhcgnomes import Pair, parse


def test_DRB1_0101():
    result = parse("DRB1_0101", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0101") to be Pair but got {result}'


def test_DRB1_0102():
    result = parse("DRB1_0102", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0102") to be Pair but got {result}'


def test_DRB1_0103():
    result = parse("DRB1_0103", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0103") to be Pair but got {result}'


def test_DRB1_0104():
    result = parse("DRB1_0104", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0104") to be Pair but got {result}'


def test_DRB1_0105():
    result = parse("DRB1_0105", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0105") to be Pair but got {result}'


def test_DRB1_0106():
    result = parse("DRB1_0106", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0106") to be Pair but got {result}'


def test_DRB1_0107():
    result = parse("DRB1_0107", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0107") to be Pair but got {result}'


def test_DRB1_0108():
    result = parse("DRB1_0108", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0108") to be Pair but got {result}'


def test_DRB1_0109():
    result = parse("DRB1_0109", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0109") to be Pair but got {result}'


def test_DRB1_0110():
    result = parse("DRB1_0110", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0110") to be Pair but got {result}'


def test_DRB1_0111():
    result = parse("DRB1_0111", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0111") to be Pair but got {result}'


def test_DRB1_0112():
    result = parse("DRB1_0112", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0112") to be Pair but got {result}'


def test_DRB1_0113():
    result = parse("DRB1_0113", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0113") to be Pair but got {result}'


def test_DRB1_0114():
    result = parse("DRB1_0114", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0114") to be Pair but got {result}'


def test_DRB1_0115():
    result = parse("DRB1_0115", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0115") to be Pair but got {result}'


def test_DRB1_0116():
    result = parse("DRB1_0116", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0116") to be Pair but got {result}'


def test_DRB1_0117():
    result = parse("DRB1_0117", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0117") to be Pair but got {result}'


def test_DRB1_0118():
    result = parse("DRB1_0118", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0118") to be Pair but got {result}'


def test_DRB1_0119():
    result = parse("DRB1_0119", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0119") to be Pair but got {result}'


def test_DRB1_0120():
    result = parse("DRB1_0120", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0120") to be Pair but got {result}'


def test_DRB1_0121():
    result = parse("DRB1_0121", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0121") to be Pair but got {result}'


def test_DRB1_0122():
    result = parse("DRB1_0122", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0122") to be Pair but got {result}'


def test_DRB1_0123():
    result = parse("DRB1_0123", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0123") to be Pair but got {result}'


def test_DRB1_0124():
    result = parse("DRB1_0124", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0124") to be Pair but got {result}'


def test_DRB1_0125():
    result = parse("DRB1_0125", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0125") to be Pair but got {result}'


def test_DRB1_0126():
    result = parse("DRB1_0126", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0126") to be Pair but got {result}'


def test_DRB1_0127():
    result = parse("DRB1_0127", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0127") to be Pair but got {result}'


def test_DRB1_0128():
    result = parse("DRB1_0128", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0128") to be Pair but got {result}'


def test_DRB1_0129():
    result = parse("DRB1_0129", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0129") to be Pair but got {result}'


def test_DRB1_0130():
    result = parse("DRB1_0130", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0130") to be Pair but got {result}'


def test_DRB1_0131():
    result = parse("DRB1_0131", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0131") to be Pair but got {result}'


def test_DRB1_0132():
    result = parse("DRB1_0132", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0132") to be Pair but got {result}'


def test_DRB1_0301():
    result = parse("DRB1_0301", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0301") to be Pair but got {result}'


def test_DRB1_0302():
    result = parse("DRB1_0302", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0302") to be Pair but got {result}'


def test_DRB1_0303():
    result = parse("DRB1_0303", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0303") to be Pair but got {result}'


def test_DRB1_0304():
    result = parse("DRB1_0304", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0304") to be Pair but got {result}'


def test_DRB1_0305():
    result = parse("DRB1_0305", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0305") to be Pair but got {result}'


def test_DRB1_0306():
    result = parse("DRB1_0306", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0306") to be Pair but got {result}'


def test_DRB1_0307():
    result = parse("DRB1_0307", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0307") to be Pair but got {result}'


def test_DRB1_0308():
    result = parse("DRB1_0308", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0308") to be Pair but got {result}'


def test_DRB1_0310():
    result = parse("DRB1_0310", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0310") to be Pair but got {result}'


def test_DRB1_0311():
    result = parse("DRB1_0311", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0311") to be Pair but got {result}'


def test_DRB1_0313():
    result = parse("DRB1_0313", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0313") to be Pair but got {result}'


def test_DRB1_0314():
    result = parse("DRB1_0314", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0314") to be Pair but got {result}'


def test_DRB1_0315():
    result = parse("DRB1_0315", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0315") to be Pair but got {result}'


def test_DRB1_0317():
    result = parse("DRB1_0317", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0317") to be Pair but got {result}'


def test_DRB1_0318():
    result = parse("DRB1_0318", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0318") to be Pair but got {result}'


def test_DRB1_0319():
    result = parse("DRB1_0319", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0319") to be Pair but got {result}'


def test_DRB1_0320():
    result = parse("DRB1_0320", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0320") to be Pair but got {result}'


def test_DRB1_0321():
    result = parse("DRB1_0321", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0321") to be Pair but got {result}'


def test_DRB1_0322():
    result = parse("DRB1_0322", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0322") to be Pair but got {result}'


def test_DRB1_0323():
    result = parse("DRB1_0323", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0323") to be Pair but got {result}'


def test_DRB1_0324():
    result = parse("DRB1_0324", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0324") to be Pair but got {result}'


def test_DRB1_0325():
    result = parse("DRB1_0325", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0325") to be Pair but got {result}'


def test_DRB1_0326():
    result = parse("DRB1_0326", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0326") to be Pair but got {result}'


def test_DRB1_0327():
    result = parse("DRB1_0327", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0327") to be Pair but got {result}'


def test_DRB1_0328():
    result = parse("DRB1_0328", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0328") to be Pair but got {result}'


def test_DRB1_0329():
    result = parse("DRB1_0329", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0329") to be Pair but got {result}'


def test_DRB1_0330():
    result = parse("DRB1_0330", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0330") to be Pair but got {result}'


def test_DRB1_0331():
    result = parse("DRB1_0331", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0331") to be Pair but got {result}'


def test_DRB1_0332():
    result = parse("DRB1_0332", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0332") to be Pair but got {result}'


def test_DRB1_0333():
    result = parse("DRB1_0333", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0333") to be Pair but got {result}'


def test_DRB1_0334():
    result = parse("DRB1_0334", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0334") to be Pair but got {result}'


def test_DRB1_0335():
    result = parse("DRB1_0335", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0335") to be Pair but got {result}'


def test_DRB1_0336():
    result = parse("DRB1_0336", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0336") to be Pair but got {result}'


def test_DRB1_0337():
    result = parse("DRB1_0337", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0337") to be Pair but got {result}'


def test_DRB1_0338():
    result = parse("DRB1_0338", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0338") to be Pair but got {result}'


def test_DRB1_0339():
    result = parse("DRB1_0339", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0339") to be Pair but got {result}'


def test_DRB1_0340():
    result = parse("DRB1_0340", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0340") to be Pair but got {result}'


def test_DRB1_0341():
    result = parse("DRB1_0341", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0341") to be Pair but got {result}'


def test_DRB1_0342():
    result = parse("DRB1_0342", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0342") to be Pair but got {result}'


def test_DRB1_0343():
    result = parse("DRB1_0343", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0343") to be Pair but got {result}'


def test_DRB1_0344():
    result = parse("DRB1_0344", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0344") to be Pair but got {result}'


def test_DRB1_0345():
    result = parse("DRB1_0345", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0345") to be Pair but got {result}'


def test_DRB1_0346():
    result = parse("DRB1_0346", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0346") to be Pair but got {result}'


def test_DRB1_0347():
    result = parse("DRB1_0347", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0347") to be Pair but got {result}'


def test_DRB1_0348():
    result = parse("DRB1_0348", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0348") to be Pair but got {result}'


def test_DRB1_0349():
    result = parse("DRB1_0349", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0349") to be Pair but got {result}'


def test_DRB1_0350():
    result = parse("DRB1_0350", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0350") to be Pair but got {result}'


def test_DRB1_0351():
    result = parse("DRB1_0351", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0351") to be Pair but got {result}'


def test_DRB1_0352():
    result = parse("DRB1_0352", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0352") to be Pair but got {result}'


def test_DRB1_0353():
    result = parse("DRB1_0353", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0353") to be Pair but got {result}'


def test_DRB1_0354():
    result = parse("DRB1_0354", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0354") to be Pair but got {result}'


def test_DRB1_0355():
    result = parse("DRB1_0355", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0355") to be Pair but got {result}'


def test_DRB1_0401():
    result = parse("DRB1_0401", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0401") to be Pair but got {result}'


def test_DRB1_0402():
    result = parse("DRB1_0402", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0402") to be Pair but got {result}'


def test_DRB1_0403():
    result = parse("DRB1_0403", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0403") to be Pair but got {result}'


def test_DRB1_0404():
    result = parse("DRB1_0404", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0404") to be Pair but got {result}'


def test_DRB1_0405():
    result = parse("DRB1_0405", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0405") to be Pair but got {result}'


def test_DRB1_0406():
    result = parse("DRB1_0406", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0406") to be Pair but got {result}'


def test_DRB1_0407():
    result = parse("DRB1_0407", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0407") to be Pair but got {result}'


def test_DRB1_0408():
    result = parse("DRB1_0408", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0408") to be Pair but got {result}'


def test_DRB1_0409():
    result = parse("DRB1_0409", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0409") to be Pair but got {result}'


def test_DRB1_0410():
    result = parse("DRB1_0410", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0410") to be Pair but got {result}'


def test_DRB1_0411():
    result = parse("DRB1_0411", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0411") to be Pair but got {result}'


def test_DRB1_0412():
    result = parse("DRB1_0412", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0412") to be Pair but got {result}'


def test_DRB1_0413():
    result = parse("DRB1_0413", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0413") to be Pair but got {result}'


def test_DRB1_0414():
    result = parse("DRB1_0414", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0414") to be Pair but got {result}'


def test_DRB1_0415():
    result = parse("DRB1_0415", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0415") to be Pair but got {result}'


def test_DRB1_0416():
    result = parse("DRB1_0416", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0416") to be Pair but got {result}'


def test_DRB1_0417():
    result = parse("DRB1_0417", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0417") to be Pair but got {result}'


def test_DRB1_0418():
    result = parse("DRB1_0418", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0418") to be Pair but got {result}'


def test_DRB1_0419():
    result = parse("DRB1_0419", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0419") to be Pair but got {result}'


def test_DRB1_0421():
    result = parse("DRB1_0421", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0421") to be Pair but got {result}'


def test_DRB1_0422():
    result = parse("DRB1_0422", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0422") to be Pair but got {result}'


def test_DRB1_0423():
    result = parse("DRB1_0423", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0423") to be Pair but got {result}'


def test_DRB1_0424():
    result = parse("DRB1_0424", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0424") to be Pair but got {result}'


def test_DRB1_0426():
    result = parse("DRB1_0426", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0426") to be Pair but got {result}'


def test_DRB1_0427():
    result = parse("DRB1_0427", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0427") to be Pair but got {result}'


def test_DRB1_0428():
    result = parse("DRB1_0428", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0428") to be Pair but got {result}'


def test_DRB1_0429():
    result = parse("DRB1_0429", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0429") to be Pair but got {result}'


def test_DRB1_0430():
    result = parse("DRB1_0430", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0430") to be Pair but got {result}'


def test_DRB1_0431():
    result = parse("DRB1_0431", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0431") to be Pair but got {result}'


def test_DRB1_0433():
    result = parse("DRB1_0433", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0433") to be Pair but got {result}'


def test_DRB1_0434():
    result = parse("DRB1_0434", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0434") to be Pair but got {result}'


def test_DRB1_0435():
    result = parse("DRB1_0435", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0435") to be Pair but got {result}'


def test_DRB1_0436():
    result = parse("DRB1_0436", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0436") to be Pair but got {result}'


def test_DRB1_0437():
    result = parse("DRB1_0437", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0437") to be Pair but got {result}'


def test_DRB1_0438():
    result = parse("DRB1_0438", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0438") to be Pair but got {result}'


def test_DRB1_0439():
    result = parse("DRB1_0439", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0439") to be Pair but got {result}'


def test_DRB1_0440():
    result = parse("DRB1_0440", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0440") to be Pair but got {result}'


def test_DRB1_0441():
    result = parse("DRB1_0441", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0441") to be Pair but got {result}'


def test_DRB1_0442():
    result = parse("DRB1_0442", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0442") to be Pair but got {result}'


def test_DRB1_0443():
    result = parse("DRB1_0443", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0443") to be Pair but got {result}'


def test_DRB1_0444():
    result = parse("DRB1_0444", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0444") to be Pair but got {result}'


def test_DRB1_0445():
    result = parse("DRB1_0445", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0445") to be Pair but got {result}'


def test_DRB1_0446():
    result = parse("DRB1_0446", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0446") to be Pair but got {result}'


def test_DRB1_0447():
    result = parse("DRB1_0447", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0447") to be Pair but got {result}'


def test_DRB1_0448():
    result = parse("DRB1_0448", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0448") to be Pair but got {result}'


def test_DRB1_0449():
    result = parse("DRB1_0449", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0449") to be Pair but got {result}'


def test_DRB1_0450():
    result = parse("DRB1_0450", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0450") to be Pair but got {result}'


def test_DRB1_0451():
    result = parse("DRB1_0451", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0451") to be Pair but got {result}'


def test_DRB1_0452():
    result = parse("DRB1_0452", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0452") to be Pair but got {result}'


def test_DRB1_0453():
    result = parse("DRB1_0453", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0453") to be Pair but got {result}'


def test_DRB1_0454():
    result = parse("DRB1_0454", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0454") to be Pair but got {result}'


def test_DRB1_0455():
    result = parse("DRB1_0455", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0455") to be Pair but got {result}'


def test_DRB1_0456():
    result = parse("DRB1_0456", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0456") to be Pair but got {result}'


def test_DRB1_0457():
    result = parse("DRB1_0457", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0457") to be Pair but got {result}'


def test_DRB1_0458():
    result = parse("DRB1_0458", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0458") to be Pair but got {result}'


def test_DRB1_0459():
    result = parse("DRB1_0459", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0459") to be Pair but got {result}'


def test_DRB1_0460():
    result = parse("DRB1_0460", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0460") to be Pair but got {result}'


def test_DRB1_0461():
    result = parse("DRB1_0461", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0461") to be Pair but got {result}'


def test_DRB1_0462():
    result = parse("DRB1_0462", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0462") to be Pair but got {result}'


def test_DRB1_0463():
    result = parse("DRB1_0463", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0463") to be Pair but got {result}'


def test_DRB1_0464():
    result = parse("DRB1_0464", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0464") to be Pair but got {result}'


def test_DRB1_0465():
    result = parse("DRB1_0465", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0465") to be Pair but got {result}'


def test_DRB1_0466():
    result = parse("DRB1_0466", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0466") to be Pair but got {result}'


def test_DRB1_0467():
    result = parse("DRB1_0467", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0467") to be Pair but got {result}'


def test_DRB1_0468():
    result = parse("DRB1_0468", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0468") to be Pair but got {result}'


def test_DRB1_0469():
    result = parse("DRB1_0469", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0469") to be Pair but got {result}'


def test_DRB1_0470():
    result = parse("DRB1_0470", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0470") to be Pair but got {result}'


def test_DRB1_0471():
    result = parse("DRB1_0471", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0471") to be Pair but got {result}'


def test_DRB1_0472():
    result = parse("DRB1_0472", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0472") to be Pair but got {result}'


def test_DRB1_0473():
    result = parse("DRB1_0473", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0473") to be Pair but got {result}'


def test_DRB1_0474():
    result = parse("DRB1_0474", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0474") to be Pair but got {result}'


def test_DRB1_0475():
    result = parse("DRB1_0475", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0475") to be Pair but got {result}'


def test_DRB1_0476():
    result = parse("DRB1_0476", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0476") to be Pair but got {result}'


def test_DRB1_0477():
    result = parse("DRB1_0477", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0477") to be Pair but got {result}'


def test_DRB1_0478():
    result = parse("DRB1_0478", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0478") to be Pair but got {result}'


def test_DRB1_0479():
    result = parse("DRB1_0479", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0479") to be Pair but got {result}'


def test_DRB1_0480():
    result = parse("DRB1_0480", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0480") to be Pair but got {result}'


def test_DRB1_0482():
    result = parse("DRB1_0482", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0482") to be Pair but got {result}'


def test_DRB1_0483():
    result = parse("DRB1_0483", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0483") to be Pair but got {result}'


def test_DRB1_0484():
    result = parse("DRB1_0484", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0484") to be Pair but got {result}'


def test_DRB1_0485():
    result = parse("DRB1_0485", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0485") to be Pair but got {result}'


def test_DRB1_0486():
    result = parse("DRB1_0486", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0486") to be Pair but got {result}'


def test_DRB1_0487():
    result = parse("DRB1_0487", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0487") to be Pair but got {result}'


def test_DRB1_0488():
    result = parse("DRB1_0488", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0488") to be Pair but got {result}'


def test_DRB1_0489():
    result = parse("DRB1_0489", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0489") to be Pair but got {result}'


def test_DRB1_0491():
    result = parse("DRB1_0491", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0491") to be Pair but got {result}'


def test_DRB1_0701():
    result = parse("DRB1_0701", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0701") to be Pair but got {result}'


def test_DRB1_0703():
    result = parse("DRB1_0703", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0703") to be Pair but got {result}'


def test_DRB1_0704():
    result = parse("DRB1_0704", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0704") to be Pair but got {result}'


def test_DRB1_0705():
    result = parse("DRB1_0705", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0705") to be Pair but got {result}'


def test_DRB1_0706():
    result = parse("DRB1_0706", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0706") to be Pair but got {result}'


def test_DRB1_0707():
    result = parse("DRB1_0707", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0707") to be Pair but got {result}'


def test_DRB1_0708():
    result = parse("DRB1_0708", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0708") to be Pair but got {result}'


def test_DRB1_0709():
    result = parse("DRB1_0709", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0709") to be Pair but got {result}'


def test_DRB1_0711():
    result = parse("DRB1_0711", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0711") to be Pair but got {result}'


def test_DRB1_0712():
    result = parse("DRB1_0712", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0712") to be Pair but got {result}'


def test_DRB1_0713():
    result = parse("DRB1_0713", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0713") to be Pair but got {result}'


def test_DRB1_0714():
    result = parse("DRB1_0714", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0714") to be Pair but got {result}'


def test_DRB1_0715():
    result = parse("DRB1_0715", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0715") to be Pair but got {result}'


def test_DRB1_0716():
    result = parse("DRB1_0716", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0716") to be Pair but got {result}'


def test_DRB1_0717():
    result = parse("DRB1_0717", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0717") to be Pair but got {result}'


def test_DRB1_0719():
    result = parse("DRB1_0719", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0719") to be Pair but got {result}'


def test_DRB1_0801():
    result = parse("DRB1_0801", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0801") to be Pair but got {result}'


def test_DRB1_0802():
    result = parse("DRB1_0802", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0802") to be Pair but got {result}'


def test_DRB1_0803():
    result = parse("DRB1_0803", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0803") to be Pair but got {result}'


def test_DRB1_0804():
    result = parse("DRB1_0804", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0804") to be Pair but got {result}'


def test_DRB1_0805():
    result = parse("DRB1_0805", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0805") to be Pair but got {result}'


def test_DRB1_0806():
    result = parse("DRB1_0806", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0806") to be Pair but got {result}'


def test_DRB1_0807():
    result = parse("DRB1_0807", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0807") to be Pair but got {result}'


def test_DRB1_0808():
    result = parse("DRB1_0808", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0808") to be Pair but got {result}'


def test_DRB1_0809():
    result = parse("DRB1_0809", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0809") to be Pair but got {result}'


def test_DRB1_0810():
    result = parse("DRB1_0810", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0810") to be Pair but got {result}'


def test_DRB1_0811():
    result = parse("DRB1_0811", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0811") to be Pair but got {result}'


def test_DRB1_0812():
    result = parse("DRB1_0812", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0812") to be Pair but got {result}'


def test_DRB1_0813():
    result = parse("DRB1_0813", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0813") to be Pair but got {result}'


def test_DRB1_0814():
    result = parse("DRB1_0814", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0814") to be Pair but got {result}'


def test_DRB1_0815():
    result = parse("DRB1_0815", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0815") to be Pair but got {result}'


def test_DRB1_0816():
    result = parse("DRB1_0816", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0816") to be Pair but got {result}'


def test_DRB1_0818():
    result = parse("DRB1_0818", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0818") to be Pair but got {result}'


def test_DRB1_0819():
    result = parse("DRB1_0819", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0819") to be Pair but got {result}'


def test_DRB1_0820():
    result = parse("DRB1_0820", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0820") to be Pair but got {result}'


def test_DRB1_0821():
    result = parse("DRB1_0821", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0821") to be Pair but got {result}'


def test_DRB1_0822():
    result = parse("DRB1_0822", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0822") to be Pair but got {result}'


def test_DRB1_0823():
    result = parse("DRB1_0823", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0823") to be Pair but got {result}'


def test_DRB1_0824():
    result = parse("DRB1_0824", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0824") to be Pair but got {result}'


def test_DRB1_0825():
    result = parse("DRB1_0825", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0825") to be Pair but got {result}'


def test_DRB1_0826():
    result = parse("DRB1_0826", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0826") to be Pair but got {result}'


def test_DRB1_0827():
    result = parse("DRB1_0827", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0827") to be Pair but got {result}'


def test_DRB1_0828():
    result = parse("DRB1_0828", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0828") to be Pair but got {result}'


def test_DRB1_0829():
    result = parse("DRB1_0829", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0829") to be Pair but got {result}'


def test_DRB1_0830():
    result = parse("DRB1_0830", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0830") to be Pair but got {result}'


def test_DRB1_0831():
    result = parse("DRB1_0831", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0831") to be Pair but got {result}'


def test_DRB1_0832():
    result = parse("DRB1_0832", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0832") to be Pair but got {result}'


def test_DRB1_0833():
    result = parse("DRB1_0833", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0833") to be Pair but got {result}'


def test_DRB1_0834():
    result = parse("DRB1_0834", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0834") to be Pair but got {result}'


def test_DRB1_0835():
    result = parse("DRB1_0835", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0835") to be Pair but got {result}'


def test_DRB1_0836():
    result = parse("DRB1_0836", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0836") to be Pair but got {result}'


def test_DRB1_0837():
    result = parse("DRB1_0837", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0837") to be Pair but got {result}'


def test_DRB1_0838():
    result = parse("DRB1_0838", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0838") to be Pair but got {result}'


def test_DRB1_0839():
    result = parse("DRB1_0839", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0839") to be Pair but got {result}'


def test_DRB1_0840():
    result = parse("DRB1_0840", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0840") to be Pair but got {result}'


def test_DRB1_0901():
    result = parse("DRB1_0901", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0901") to be Pair but got {result}'


def test_DRB1_0902():
    result = parse("DRB1_0902", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0902") to be Pair but got {result}'


def test_DRB1_0903():
    result = parse("DRB1_0903", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0903") to be Pair but got {result}'


def test_DRB1_0904():
    result = parse("DRB1_0904", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0904") to be Pair but got {result}'


def test_DRB1_0905():
    result = parse("DRB1_0905", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0905") to be Pair but got {result}'


def test_DRB1_0906():
    result = parse("DRB1_0906", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0906") to be Pair but got {result}'


def test_DRB1_0907():
    result = parse("DRB1_0907", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0907") to be Pair but got {result}'


def test_DRB1_0908():
    result = parse("DRB1_0908", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0908") to be Pair but got {result}'


def test_DRB1_0909():
    result = parse("DRB1_0909", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_0909") to be Pair but got {result}'


def test_DRB1_1001():
    result = parse("DRB1_1001", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1001") to be Pair but got {result}'


def test_DRB1_1002():
    result = parse("DRB1_1002", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1002") to be Pair but got {result}'


def test_DRB1_1003():
    result = parse("DRB1_1003", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1003") to be Pair but got {result}'


def test_DRB1_1101():
    result = parse("DRB1_1101", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1101") to be Pair but got {result}'


def test_DRB1_1102():
    result = parse("DRB1_1102", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1102") to be Pair but got {result}'


def test_DRB1_1103():
    result = parse("DRB1_1103", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1103") to be Pair but got {result}'


def test_DRB1_1104():
    result = parse("DRB1_1104", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1104") to be Pair but got {result}'


def test_DRB1_1105():
    result = parse("DRB1_1105", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1105") to be Pair but got {result}'


def test_DRB1_1106():
    result = parse("DRB1_1106", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1106") to be Pair but got {result}'


def test_DRB1_1107():
    result = parse("DRB1_1107", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1107") to be Pair but got {result}'


def test_DRB1_1108():
    result = parse("DRB1_1108", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1108") to be Pair but got {result}'


def test_DRB1_1109():
    result = parse("DRB1_1109", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1109") to be Pair but got {result}'


def test_DRB1_1110():
    result = parse("DRB1_1110", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1110") to be Pair but got {result}'


def test_DRB1_1111():
    result = parse("DRB1_1111", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1111") to be Pair but got {result}'


def test_DRB1_1112():
    result = parse("DRB1_1112", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1112") to be Pair but got {result}'


def test_DRB1_1113():
    result = parse("DRB1_1113", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1113") to be Pair but got {result}'


def test_DRB1_1114():
    result = parse("DRB1_1114", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1114") to be Pair but got {result}'


def test_DRB1_1115():
    result = parse("DRB1_1115", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1115") to be Pair but got {result}'


def test_DRB1_1116():
    result = parse("DRB1_1116", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1116") to be Pair but got {result}'


def test_DRB1_1117():
    result = parse("DRB1_1117", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1117") to be Pair but got {result}'


def test_DRB1_1118():
    result = parse("DRB1_1118", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1118") to be Pair but got {result}'


def test_DRB1_1119():
    result = parse("DRB1_1119", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1119") to be Pair but got {result}'


def test_DRB1_1120():
    result = parse("DRB1_1120", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1120") to be Pair but got {result}'


def test_DRB1_1121():
    result = parse("DRB1_1121", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1121") to be Pair but got {result}'


def test_DRB1_1124():
    result = parse("DRB1_1124", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1124") to be Pair but got {result}'


def test_DRB1_1125():
    result = parse("DRB1_1125", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1125") to be Pair but got {result}'


def test_DRB1_1127():
    result = parse("DRB1_1127", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1127") to be Pair but got {result}'


def test_DRB1_1128():
    result = parse("DRB1_1128", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1128") to be Pair but got {result}'


def test_DRB1_1129():
    result = parse("DRB1_1129", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1129") to be Pair but got {result}'


def test_DRB1_1130():
    result = parse("DRB1_1130", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1130") to be Pair but got {result}'


def test_DRB1_1131():
    result = parse("DRB1_1131", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1131") to be Pair but got {result}'


def test_DRB1_1132():
    result = parse("DRB1_1132", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1132") to be Pair but got {result}'


def test_DRB1_1133():
    result = parse("DRB1_1133", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1133") to be Pair but got {result}'


def test_DRB1_1134():
    result = parse("DRB1_1134", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1134") to be Pair but got {result}'


def test_DRB1_1135():
    result = parse("DRB1_1135", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1135") to be Pair but got {result}'


def test_DRB1_1136():
    result = parse("DRB1_1136", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1136") to be Pair but got {result}'


def test_DRB1_1137():
    result = parse("DRB1_1137", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1137") to be Pair but got {result}'


def test_DRB1_1138():
    result = parse("DRB1_1138", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1138") to be Pair but got {result}'


def test_DRB1_1139():
    result = parse("DRB1_1139", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1139") to be Pair but got {result}'


def test_DRB1_1141():
    result = parse("DRB1_1141", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1141") to be Pair but got {result}'


def test_DRB1_1142():
    result = parse("DRB1_1142", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1142") to be Pair but got {result}'


def test_DRB1_1143():
    result = parse("DRB1_1143", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1143") to be Pair but got {result}'


def test_DRB1_1144():
    result = parse("DRB1_1144", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1144") to be Pair but got {result}'


def test_DRB1_1145():
    result = parse("DRB1_1145", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1145") to be Pair but got {result}'


def test_DRB1_1146():
    result = parse("DRB1_1146", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1146") to be Pair but got {result}'


def test_DRB1_1147():
    result = parse("DRB1_1147", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1147") to be Pair but got {result}'


def test_DRB1_1148():
    result = parse("DRB1_1148", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1148") to be Pair but got {result}'


def test_DRB1_1149():
    result = parse("DRB1_1149", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1149") to be Pair but got {result}'


def test_DRB1_1150():
    result = parse("DRB1_1150", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1150") to be Pair but got {result}'


def test_DRB1_1151():
    result = parse("DRB1_1151", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1151") to be Pair but got {result}'


def test_DRB1_1152():
    result = parse("DRB1_1152", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1152") to be Pair but got {result}'


def test_DRB1_1153():
    result = parse("DRB1_1153", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1153") to be Pair but got {result}'


def test_DRB1_1154():
    result = parse("DRB1_1154", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1154") to be Pair but got {result}'


def test_DRB1_1155():
    result = parse("DRB1_1155", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1155") to be Pair but got {result}'


def test_DRB1_1156():
    result = parse("DRB1_1156", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1156") to be Pair but got {result}'


def test_DRB1_1157():
    result = parse("DRB1_1157", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1157") to be Pair but got {result}'


def test_DRB1_1158():
    result = parse("DRB1_1158", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1158") to be Pair but got {result}'


def test_DRB1_1159():
    result = parse("DRB1_1159", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1159") to be Pair but got {result}'


def test_DRB1_1160():
    result = parse("DRB1_1160", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1160") to be Pair but got {result}'


def test_DRB1_1161():
    result = parse("DRB1_1161", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1161") to be Pair but got {result}'


def test_DRB1_1162():
    result = parse("DRB1_1162", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1162") to be Pair but got {result}'


def test_DRB1_1163():
    result = parse("DRB1_1163", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1163") to be Pair but got {result}'


def test_DRB1_1164():
    result = parse("DRB1_1164", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1164") to be Pair but got {result}'


def test_DRB1_1165():
    result = parse("DRB1_1165", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1165") to be Pair but got {result}'


def test_DRB1_1166():
    result = parse("DRB1_1166", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1166") to be Pair but got {result}'


def test_DRB1_1167():
    result = parse("DRB1_1167", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1167") to be Pair but got {result}'


def test_DRB1_1168():
    result = parse("DRB1_1168", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1168") to be Pair but got {result}'


def test_DRB1_1169():
    result = parse("DRB1_1169", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1169") to be Pair but got {result}'


def test_DRB1_1170():
    result = parse("DRB1_1170", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1170") to be Pair but got {result}'


def test_DRB1_1172():
    result = parse("DRB1_1172", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1172") to be Pair but got {result}'


def test_DRB1_1173():
    result = parse("DRB1_1173", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1173") to be Pair but got {result}'


def test_DRB1_1174():
    result = parse("DRB1_1174", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1174") to be Pair but got {result}'


def test_DRB1_1175():
    result = parse("DRB1_1175", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1175") to be Pair but got {result}'


def test_DRB1_1176():
    result = parse("DRB1_1176", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1176") to be Pair but got {result}'


def test_DRB1_1177():
    result = parse("DRB1_1177", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1177") to be Pair but got {result}'


def test_DRB1_1178():
    result = parse("DRB1_1178", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1178") to be Pair but got {result}'


def test_DRB1_1179():
    result = parse("DRB1_1179", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1179") to be Pair but got {result}'


def test_DRB1_1180():
    result = parse("DRB1_1180", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1180") to be Pair but got {result}'


def test_DRB1_1181():
    result = parse("DRB1_1181", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1181") to be Pair but got {result}'


def test_DRB1_1182():
    result = parse("DRB1_1182", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1182") to be Pair but got {result}'


def test_DRB1_1183():
    result = parse("DRB1_1183", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1183") to be Pair but got {result}'


def test_DRB1_1184():
    result = parse("DRB1_1184", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1184") to be Pair but got {result}'


def test_DRB1_1185():
    result = parse("DRB1_1185", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1185") to be Pair but got {result}'


def test_DRB1_1186():
    result = parse("DRB1_1186", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1186") to be Pair but got {result}'


def test_DRB1_1187():
    result = parse("DRB1_1187", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1187") to be Pair but got {result}'


def test_DRB1_1188():
    result = parse("DRB1_1188", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1188") to be Pair but got {result}'


def test_DRB1_1189():
    result = parse("DRB1_1189", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1189") to be Pair but got {result}'


def test_DRB1_1190():
    result = parse("DRB1_1190", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1190") to be Pair but got {result}'


def test_DRB1_1191():
    result = parse("DRB1_1191", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1191") to be Pair but got {result}'


def test_DRB1_1192():
    result = parse("DRB1_1192", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1192") to be Pair but got {result}'


def test_DRB1_1193():
    result = parse("DRB1_1193", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1193") to be Pair but got {result}'


def test_DRB1_1194():
    result = parse("DRB1_1194", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1194") to be Pair but got {result}'


def test_DRB1_1195():
    result = parse("DRB1_1195", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1195") to be Pair but got {result}'


def test_DRB1_1196():
    result = parse("DRB1_1196", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1196") to be Pair but got {result}'


def test_DRB1_1201():
    result = parse("DRB1_1201", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1201") to be Pair but got {result}'


def test_DRB1_1202():
    result = parse("DRB1_1202", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1202") to be Pair but got {result}'


def test_DRB1_1203():
    result = parse("DRB1_1203", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1203") to be Pair but got {result}'


def test_DRB1_1204():
    result = parse("DRB1_1204", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1204") to be Pair but got {result}'


def test_DRB1_1205():
    result = parse("DRB1_1205", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1205") to be Pair but got {result}'


def test_DRB1_1206():
    result = parse("DRB1_1206", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1206") to be Pair but got {result}'


def test_DRB1_1207():
    result = parse("DRB1_1207", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1207") to be Pair but got {result}'


def test_DRB1_1208():
    result = parse("DRB1_1208", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1208") to be Pair but got {result}'


def test_DRB1_1209():
    result = parse("DRB1_1209", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1209") to be Pair but got {result}'


def test_DRB1_1210():
    result = parse("DRB1_1210", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1210") to be Pair but got {result}'


def test_DRB1_1211():
    result = parse("DRB1_1211", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1211") to be Pair but got {result}'


def test_DRB1_1212():
    result = parse("DRB1_1212", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1212") to be Pair but got {result}'


def test_DRB1_1213():
    result = parse("DRB1_1213", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1213") to be Pair but got {result}'


def test_DRB1_1214():
    result = parse("DRB1_1214", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1214") to be Pair but got {result}'


def test_DRB1_1215():
    result = parse("DRB1_1215", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1215") to be Pair but got {result}'


def test_DRB1_1216():
    result = parse("DRB1_1216", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1216") to be Pair but got {result}'


def test_DRB1_1217():
    result = parse("DRB1_1217", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1217") to be Pair but got {result}'


def test_DRB1_1218():
    result = parse("DRB1_1218", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1218") to be Pair but got {result}'


def test_DRB1_1219():
    result = parse("DRB1_1219", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1219") to be Pair but got {result}'


def test_DRB1_1220():
    result = parse("DRB1_1220", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1220") to be Pair but got {result}'


def test_DRB1_1221():
    result = parse("DRB1_1221", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1221") to be Pair but got {result}'


def test_DRB1_1222():
    result = parse("DRB1_1222", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1222") to be Pair but got {result}'


def test_DRB1_1223():
    result = parse("DRB1_1223", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1223") to be Pair but got {result}'


def test_DRB1_1301():
    result = parse("DRB1_1301", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1301") to be Pair but got {result}'


def test_DRB1_1302():
    result = parse("DRB1_1302", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1302") to be Pair but got {result}'


def test_DRB1_1303():
    result = parse("DRB1_1303", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1303") to be Pair but got {result}'


def test_DRB1_1304():
    result = parse("DRB1_1304", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1304") to be Pair but got {result}'


def test_DRB1_1305():
    result = parse("DRB1_1305", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1305") to be Pair but got {result}'


def test_DRB1_1306():
    result = parse("DRB1_1306", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1306") to be Pair but got {result}'


def test_DRB1_1307():
    result = parse("DRB1_1307", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1307") to be Pair but got {result}'


def test_DRB1_1308():
    result = parse("DRB1_1308", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1308") to be Pair but got {result}'


def test_DRB1_1309():
    result = parse("DRB1_1309", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1309") to be Pair but got {result}'


def test_DRB1_1310():
    result = parse("DRB1_1310", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1310") to be Pair but got {result}'


def test_DRB1_13100():
    result = parse("DRB1_13100", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_13100") to be Pair but got {result}'


def test_DRB1_13101():
    result = parse("DRB1_13101", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_13101") to be Pair but got {result}'


def test_DRB1_1311():
    result = parse("DRB1_1311", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1311") to be Pair but got {result}'


def test_DRB1_1312():
    result = parse("DRB1_1312", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1312") to be Pair but got {result}'


def test_DRB1_1313():
    result = parse("DRB1_1313", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1313") to be Pair but got {result}'


def test_DRB1_1314():
    result = parse("DRB1_1314", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1314") to be Pair but got {result}'


def test_DRB1_1315():
    result = parse("DRB1_1315", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1315") to be Pair but got {result}'


def test_DRB1_1316():
    result = parse("DRB1_1316", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1316") to be Pair but got {result}'


def test_DRB1_1317():
    result = parse("DRB1_1317", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1317") to be Pair but got {result}'


def test_DRB1_1318():
    result = parse("DRB1_1318", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1318") to be Pair but got {result}'


def test_DRB1_1319():
    result = parse("DRB1_1319", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1319") to be Pair but got {result}'


def test_DRB1_1320():
    result = parse("DRB1_1320", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1320") to be Pair but got {result}'


def test_DRB1_1321():
    result = parse("DRB1_1321", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1321") to be Pair but got {result}'


def test_DRB1_1322():
    result = parse("DRB1_1322", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1322") to be Pair but got {result}'


def test_DRB1_1323():
    result = parse("DRB1_1323", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1323") to be Pair but got {result}'


def test_DRB1_1324():
    result = parse("DRB1_1324", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1324") to be Pair but got {result}'


def test_DRB1_1326():
    result = parse("DRB1_1326", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1326") to be Pair but got {result}'


def test_DRB1_1327():
    result = parse("DRB1_1327", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1327") to be Pair but got {result}'


def test_DRB1_1329():
    result = parse("DRB1_1329", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1329") to be Pair but got {result}'


def test_DRB1_1330():
    result = parse("DRB1_1330", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1330") to be Pair but got {result}'


def test_DRB1_1331():
    result = parse("DRB1_1331", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1331") to be Pair but got {result}'


def test_DRB1_1332():
    result = parse("DRB1_1332", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1332") to be Pair but got {result}'


def test_DRB1_1333():
    result = parse("DRB1_1333", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1333") to be Pair but got {result}'


def test_DRB1_1334():
    result = parse("DRB1_1334", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1334") to be Pair but got {result}'


def test_DRB1_1335():
    result = parse("DRB1_1335", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1335") to be Pair but got {result}'


def test_DRB1_1336():
    result = parse("DRB1_1336", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1336") to be Pair but got {result}'


def test_DRB1_1337():
    result = parse("DRB1_1337", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1337") to be Pair but got {result}'


def test_DRB1_1338():
    result = parse("DRB1_1338", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1338") to be Pair but got {result}'


def test_DRB1_1339():
    result = parse("DRB1_1339", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1339") to be Pair but got {result}'


def test_DRB1_1341():
    result = parse("DRB1_1341", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1341") to be Pair but got {result}'


def test_DRB1_1342():
    result = parse("DRB1_1342", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1342") to be Pair but got {result}'


def test_DRB1_1343():
    result = parse("DRB1_1343", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1343") to be Pair but got {result}'


def test_DRB1_1344():
    result = parse("DRB1_1344", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1344") to be Pair but got {result}'


def test_DRB1_1346():
    result = parse("DRB1_1346", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1346") to be Pair but got {result}'


def test_DRB1_1347():
    result = parse("DRB1_1347", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1347") to be Pair but got {result}'


def test_DRB1_1348():
    result = parse("DRB1_1348", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1348") to be Pair but got {result}'


def test_DRB1_1349():
    result = parse("DRB1_1349", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1349") to be Pair but got {result}'


def test_DRB1_1350():
    result = parse("DRB1_1350", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1350") to be Pair but got {result}'


def test_DRB1_1351():
    result = parse("DRB1_1351", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1351") to be Pair but got {result}'


def test_DRB1_1352():
    result = parse("DRB1_1352", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1352") to be Pair but got {result}'


def test_DRB1_1353():
    result = parse("DRB1_1353", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1353") to be Pair but got {result}'


def test_DRB1_1354():
    result = parse("DRB1_1354", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1354") to be Pair but got {result}'


def test_DRB1_1355():
    result = parse("DRB1_1355", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1355") to be Pair but got {result}'


def test_DRB1_1356():
    result = parse("DRB1_1356", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1356") to be Pair but got {result}'


def test_DRB1_1357():
    result = parse("DRB1_1357", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1357") to be Pair but got {result}'


def test_DRB1_1358():
    result = parse("DRB1_1358", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1358") to be Pair but got {result}'


def test_DRB1_1359():
    result = parse("DRB1_1359", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1359") to be Pair but got {result}'


def test_DRB1_1360():
    result = parse("DRB1_1360", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1360") to be Pair but got {result}'


def test_DRB1_1361():
    result = parse("DRB1_1361", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1361") to be Pair but got {result}'


def test_DRB1_1362():
    result = parse("DRB1_1362", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1362") to be Pair but got {result}'


def test_DRB1_1363():
    result = parse("DRB1_1363", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1363") to be Pair but got {result}'


def test_DRB1_1364():
    result = parse("DRB1_1364", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1364") to be Pair but got {result}'


def test_DRB1_1365():
    result = parse("DRB1_1365", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1365") to be Pair but got {result}'


def test_DRB1_1366():
    result = parse("DRB1_1366", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1366") to be Pair but got {result}'


def test_DRB1_1367():
    result = parse("DRB1_1367", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1367") to be Pair but got {result}'


def test_DRB1_1368():
    result = parse("DRB1_1368", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1368") to be Pair but got {result}'


def test_DRB1_1369():
    result = parse("DRB1_1369", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1369") to be Pair but got {result}'


def test_DRB1_1370():
    result = parse("DRB1_1370", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1370") to be Pair but got {result}'


def test_DRB1_1371():
    result = parse("DRB1_1371", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1371") to be Pair but got {result}'


def test_DRB1_1372():
    result = parse("DRB1_1372", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1372") to be Pair but got {result}'


def test_DRB1_1373():
    result = parse("DRB1_1373", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1373") to be Pair but got {result}'


def test_DRB1_1374():
    result = parse("DRB1_1374", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1374") to be Pair but got {result}'


def test_DRB1_1375():
    result = parse("DRB1_1375", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1375") to be Pair but got {result}'


def test_DRB1_1376():
    result = parse("DRB1_1376", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1376") to be Pair but got {result}'


def test_DRB1_1377():
    result = parse("DRB1_1377", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1377") to be Pair but got {result}'


def test_DRB1_1378():
    result = parse("DRB1_1378", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1378") to be Pair but got {result}'


def test_DRB1_1379():
    result = parse("DRB1_1379", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1379") to be Pair but got {result}'


def test_DRB1_1380():
    result = parse("DRB1_1380", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1380") to be Pair but got {result}'


def test_DRB1_1381():
    result = parse("DRB1_1381", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1381") to be Pair but got {result}'


def test_DRB1_1382():
    result = parse("DRB1_1382", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1382") to be Pair but got {result}'


def test_DRB1_1383():
    result = parse("DRB1_1383", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1383") to be Pair but got {result}'


def test_DRB1_1384():
    result = parse("DRB1_1384", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1384") to be Pair but got {result}'


def test_DRB1_1385():
    result = parse("DRB1_1385", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1385") to be Pair but got {result}'


def test_DRB1_1386():
    result = parse("DRB1_1386", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1386") to be Pair but got {result}'


def test_DRB1_1387():
    result = parse("DRB1_1387", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1387") to be Pair but got {result}'


def test_DRB1_1388():
    result = parse("DRB1_1388", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1388") to be Pair but got {result}'


def test_DRB1_1389():
    result = parse("DRB1_1389", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1389") to be Pair but got {result}'


def test_DRB1_1390():
    result = parse("DRB1_1390", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1390") to be Pair but got {result}'


def test_DRB1_1391():
    result = parse("DRB1_1391", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1391") to be Pair but got {result}'


def test_DRB1_1392():
    result = parse("DRB1_1392", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1392") to be Pair but got {result}'


def test_DRB1_1393():
    result = parse("DRB1_1393", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1393") to be Pair but got {result}'


def test_DRB1_1394():
    result = parse("DRB1_1394", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1394") to be Pair but got {result}'


def test_DRB1_1395():
    result = parse("DRB1_1395", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1395") to be Pair but got {result}'


def test_DRB1_1396():
    result = parse("DRB1_1396", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1396") to be Pair but got {result}'


def test_DRB1_1397():
    result = parse("DRB1_1397", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1397") to be Pair but got {result}'


def test_DRB1_1398():
    result = parse("DRB1_1398", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1398") to be Pair but got {result}'


def test_DRB1_1399():
    result = parse("DRB1_1399", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1399") to be Pair but got {result}'


def test_DRB1_1401():
    result = parse("DRB1_1401", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1401") to be Pair but got {result}'


def test_DRB1_1402():
    result = parse("DRB1_1402", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1402") to be Pair but got {result}'


def test_DRB1_1403():
    result = parse("DRB1_1403", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1403") to be Pair but got {result}'


def test_DRB1_1404():
    result = parse("DRB1_1404", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1404") to be Pair but got {result}'


def test_DRB1_1405():
    result = parse("DRB1_1405", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1405") to be Pair but got {result}'


def test_DRB1_1406():
    result = parse("DRB1_1406", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1406") to be Pair but got {result}'


def test_DRB1_1407():
    result = parse("DRB1_1407", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1407") to be Pair but got {result}'


def test_DRB1_1408():
    result = parse("DRB1_1408", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1408") to be Pair but got {result}'


def test_DRB1_1409():
    result = parse("DRB1_1409", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1409") to be Pair but got {result}'


def test_DRB1_1410():
    result = parse("DRB1_1410", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1410") to be Pair but got {result}'


def test_DRB1_1411():
    result = parse("DRB1_1411", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1411") to be Pair but got {result}'


def test_DRB1_1412():
    result = parse("DRB1_1412", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1412") to be Pair but got {result}'


def test_DRB1_1413():
    result = parse("DRB1_1413", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1413") to be Pair but got {result}'


def test_DRB1_1414():
    result = parse("DRB1_1414", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1414") to be Pair but got {result}'


def test_DRB1_1415():
    result = parse("DRB1_1415", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1415") to be Pair but got {result}'


def test_DRB1_1416():
    result = parse("DRB1_1416", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1416") to be Pair but got {result}'


def test_DRB1_1417():
    result = parse("DRB1_1417", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1417") to be Pair but got {result}'


def test_DRB1_1418():
    result = parse("DRB1_1418", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1418") to be Pair but got {result}'


def test_DRB1_1419():
    result = parse("DRB1_1419", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1419") to be Pair but got {result}'


def test_DRB1_1420():
    result = parse("DRB1_1420", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1420") to be Pair but got {result}'


def test_DRB1_1421():
    result = parse("DRB1_1421", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1421") to be Pair but got {result}'


def test_DRB1_1422():
    result = parse("DRB1_1422", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1422") to be Pair but got {result}'


def test_DRB1_1423():
    result = parse("DRB1_1423", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1423") to be Pair but got {result}'


def test_DRB1_1424():
    result = parse("DRB1_1424", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1424") to be Pair but got {result}'


def test_DRB1_1425():
    result = parse("DRB1_1425", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1425") to be Pair but got {result}'


def test_DRB1_1426():
    result = parse("DRB1_1426", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1426") to be Pair but got {result}'


def test_DRB1_1427():
    result = parse("DRB1_1427", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1427") to be Pair but got {result}'


def test_DRB1_1428():
    result = parse("DRB1_1428", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1428") to be Pair but got {result}'


def test_DRB1_1429():
    result = parse("DRB1_1429", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1429") to be Pair but got {result}'


def test_DRB1_1430():
    result = parse("DRB1_1430", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1430") to be Pair but got {result}'


def test_DRB1_1431():
    result = parse("DRB1_1431", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1431") to be Pair but got {result}'


def test_DRB1_1432():
    result = parse("DRB1_1432", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1432") to be Pair but got {result}'


def test_DRB1_1433():
    result = parse("DRB1_1433", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1433") to be Pair but got {result}'


def test_DRB1_1434():
    result = parse("DRB1_1434", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1434") to be Pair but got {result}'


def test_DRB1_1435():
    result = parse("DRB1_1435", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1435") to be Pair but got {result}'


def test_DRB1_1436():
    result = parse("DRB1_1436", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1436") to be Pair but got {result}'


def test_DRB1_1437():
    result = parse("DRB1_1437", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1437") to be Pair but got {result}'


def test_DRB1_1438():
    result = parse("DRB1_1438", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1438") to be Pair but got {result}'


def test_DRB1_1439():
    result = parse("DRB1_1439", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1439") to be Pair but got {result}'


def test_DRB1_1440():
    result = parse("DRB1_1440", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1440") to be Pair but got {result}'


def test_DRB1_1441():
    result = parse("DRB1_1441", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1441") to be Pair but got {result}'


def test_DRB1_1442():
    result = parse("DRB1_1442", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1442") to be Pair but got {result}'


def test_DRB1_1443():
    result = parse("DRB1_1443", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1443") to be Pair but got {result}'


def test_DRB1_1444():
    result = parse("DRB1_1444", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1444") to be Pair but got {result}'


def test_DRB1_1445():
    result = parse("DRB1_1445", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1445") to be Pair but got {result}'


def test_DRB1_1446():
    result = parse("DRB1_1446", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1446") to be Pair but got {result}'


def test_DRB1_1447():
    result = parse("DRB1_1447", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1447") to be Pair but got {result}'


def test_DRB1_1448():
    result = parse("DRB1_1448", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1448") to be Pair but got {result}'


def test_DRB1_1449():
    result = parse("DRB1_1449", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1449") to be Pair but got {result}'


def test_DRB1_1450():
    result = parse("DRB1_1450", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1450") to be Pair but got {result}'


def test_DRB1_1451():
    result = parse("DRB1_1451", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1451") to be Pair but got {result}'


def test_DRB1_1452():
    result = parse("DRB1_1452", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1452") to be Pair but got {result}'


def test_DRB1_1453():
    result = parse("DRB1_1453", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1453") to be Pair but got {result}'


def test_DRB1_1454():
    result = parse("DRB1_1454", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1454") to be Pair but got {result}'


def test_DRB1_1455():
    result = parse("DRB1_1455", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1455") to be Pair but got {result}'


def test_DRB1_1456():
    result = parse("DRB1_1456", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1456") to be Pair but got {result}'


def test_DRB1_1457():
    result = parse("DRB1_1457", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1457") to be Pair but got {result}'


def test_DRB1_1458():
    result = parse("DRB1_1458", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1458") to be Pair but got {result}'


def test_DRB1_1459():
    result = parse("DRB1_1459", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1459") to be Pair but got {result}'


def test_DRB1_1460():
    result = parse("DRB1_1460", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1460") to be Pair but got {result}'


def test_DRB1_1461():
    result = parse("DRB1_1461", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1461") to be Pair but got {result}'


def test_DRB1_1462():
    result = parse("DRB1_1462", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1462") to be Pair but got {result}'


def test_DRB1_1463():
    result = parse("DRB1_1463", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1463") to be Pair but got {result}'


def test_DRB1_1464():
    result = parse("DRB1_1464", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1464") to be Pair but got {result}'


def test_DRB1_1465():
    result = parse("DRB1_1465", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1465") to be Pair but got {result}'


def test_DRB1_1467():
    result = parse("DRB1_1467", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1467") to be Pair but got {result}'


def test_DRB1_1468():
    result = parse("DRB1_1468", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1468") to be Pair but got {result}'


def test_DRB1_1469():
    result = parse("DRB1_1469", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1469") to be Pair but got {result}'


def test_DRB1_1470():
    result = parse("DRB1_1470", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1470") to be Pair but got {result}'


def test_DRB1_1471():
    result = parse("DRB1_1471", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1471") to be Pair but got {result}'


def test_DRB1_1472():
    result = parse("DRB1_1472", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1472") to be Pair but got {result}'


def test_DRB1_1473():
    result = parse("DRB1_1473", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1473") to be Pair but got {result}'


def test_DRB1_1474():
    result = parse("DRB1_1474", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1474") to be Pair but got {result}'


def test_DRB1_1475():
    result = parse("DRB1_1475", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1475") to be Pair but got {result}'


def test_DRB1_1476():
    result = parse("DRB1_1476", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1476") to be Pair but got {result}'


def test_DRB1_1477():
    result = parse("DRB1_1477", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1477") to be Pair but got {result}'


def test_DRB1_1478():
    result = parse("DRB1_1478", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1478") to be Pair but got {result}'


def test_DRB1_1479():
    result = parse("DRB1_1479", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1479") to be Pair but got {result}'


def test_DRB1_1480():
    result = parse("DRB1_1480", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1480") to be Pair but got {result}'


def test_DRB1_1481():
    result = parse("DRB1_1481", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1481") to be Pair but got {result}'


def test_DRB1_1482():
    result = parse("DRB1_1482", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1482") to be Pair but got {result}'


def test_DRB1_1483():
    result = parse("DRB1_1483", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1483") to be Pair but got {result}'


def test_DRB1_1484():
    result = parse("DRB1_1484", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1484") to be Pair but got {result}'


def test_DRB1_1485():
    result = parse("DRB1_1485", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1485") to be Pair but got {result}'


def test_DRB1_1486():
    result = parse("DRB1_1486", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1486") to be Pair but got {result}'


def test_DRB1_1487():
    result = parse("DRB1_1487", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1487") to be Pair but got {result}'


def test_DRB1_1488():
    result = parse("DRB1_1488", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1488") to be Pair but got {result}'


def test_DRB1_1489():
    result = parse("DRB1_1489", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1489") to be Pair but got {result}'


def test_DRB1_1490():
    result = parse("DRB1_1490", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1490") to be Pair but got {result}'


def test_DRB1_1491():
    result = parse("DRB1_1491", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1491") to be Pair but got {result}'


def test_DRB1_1493():
    result = parse("DRB1_1493", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1493") to be Pair but got {result}'


def test_DRB1_1494():
    result = parse("DRB1_1494", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1494") to be Pair but got {result}'


def test_DRB1_1495():
    result = parse("DRB1_1495", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1495") to be Pair but got {result}'


def test_DRB1_1496():
    result = parse("DRB1_1496", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1496") to be Pair but got {result}'


def test_DRB1_1497():
    result = parse("DRB1_1497", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1497") to be Pair but got {result}'


def test_DRB1_1498():
    result = parse("DRB1_1498", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1498") to be Pair but got {result}'


def test_DRB1_1499():
    result = parse("DRB1_1499", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1499") to be Pair but got {result}'


def test_DRB1_1501():
    result = parse("DRB1_1501", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1501") to be Pair but got {result}'


def test_DRB1_1502():
    result = parse("DRB1_1502", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1502") to be Pair but got {result}'


def test_DRB1_1503():
    result = parse("DRB1_1503", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1503") to be Pair but got {result}'


def test_DRB1_1504():
    result = parse("DRB1_1504", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1504") to be Pair but got {result}'


def test_DRB1_1505():
    result = parse("DRB1_1505", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1505") to be Pair but got {result}'


def test_DRB1_1506():
    result = parse("DRB1_1506", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1506") to be Pair but got {result}'


def test_DRB1_1507():
    result = parse("DRB1_1507", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1507") to be Pair but got {result}'


def test_DRB1_1508():
    result = parse("DRB1_1508", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1508") to be Pair but got {result}'


def test_DRB1_1509():
    result = parse("DRB1_1509", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1509") to be Pair but got {result}'


def test_DRB1_1510():
    result = parse("DRB1_1510", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1510") to be Pair but got {result}'


def test_DRB1_1511():
    result = parse("DRB1_1511", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1511") to be Pair but got {result}'


def test_DRB1_1512():
    result = parse("DRB1_1512", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1512") to be Pair but got {result}'


def test_DRB1_1513():
    result = parse("DRB1_1513", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1513") to be Pair but got {result}'


def test_DRB1_1514():
    result = parse("DRB1_1514", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1514") to be Pair but got {result}'


def test_DRB1_1515():
    result = parse("DRB1_1515", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1515") to be Pair but got {result}'


def test_DRB1_1516():
    result = parse("DRB1_1516", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1516") to be Pair but got {result}'


def test_DRB1_1518():
    result = parse("DRB1_1518", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1518") to be Pair but got {result}'


def test_DRB1_1519():
    result = parse("DRB1_1519", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1519") to be Pair but got {result}'


def test_DRB1_1520():
    result = parse("DRB1_1520", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1520") to be Pair but got {result}'


def test_DRB1_1521():
    result = parse("DRB1_1521", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1521") to be Pair but got {result}'


def test_DRB1_1522():
    result = parse("DRB1_1522", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1522") to be Pair but got {result}'


def test_DRB1_1523():
    result = parse("DRB1_1523", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1523") to be Pair but got {result}'


def test_DRB1_1524():
    result = parse("DRB1_1524", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1524") to be Pair but got {result}'


def test_DRB1_1525():
    result = parse("DRB1_1525", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1525") to be Pair but got {result}'


def test_DRB1_1526():
    result = parse("DRB1_1526", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1526") to be Pair but got {result}'


def test_DRB1_1527():
    result = parse("DRB1_1527", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1527") to be Pair but got {result}'


def test_DRB1_1528():
    result = parse("DRB1_1528", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1528") to be Pair but got {result}'


def test_DRB1_1529():
    result = parse("DRB1_1529", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1529") to be Pair but got {result}'


def test_DRB1_1530():
    result = parse("DRB1_1530", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1530") to be Pair but got {result}'


def test_DRB1_1531():
    result = parse("DRB1_1531", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1531") to be Pair but got {result}'


def test_DRB1_1532():
    result = parse("DRB1_1532", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1532") to be Pair but got {result}'


def test_DRB1_1533():
    result = parse("DRB1_1533", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1533") to be Pair but got {result}'


def test_DRB1_1534():
    result = parse("DRB1_1534", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1534") to be Pair but got {result}'


def test_DRB1_1535():
    result = parse("DRB1_1535", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1535") to be Pair but got {result}'


def test_DRB1_1536():
    result = parse("DRB1_1536", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1536") to be Pair but got {result}'


def test_DRB1_1537():
    result = parse("DRB1_1537", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1537") to be Pair but got {result}'


def test_DRB1_1538():
    result = parse("DRB1_1538", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1538") to be Pair but got {result}'


def test_DRB1_1539():
    result = parse("DRB1_1539", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1539") to be Pair but got {result}'


def test_DRB1_1540():
    result = parse("DRB1_1540", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1540") to be Pair but got {result}'


def test_DRB1_1541():
    result = parse("DRB1_1541", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1541") to be Pair but got {result}'


def test_DRB1_1542():
    result = parse("DRB1_1542", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1542") to be Pair but got {result}'


def test_DRB1_1543():
    result = parse("DRB1_1543", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1543") to be Pair but got {result}'


def test_DRB1_1544():
    result = parse("DRB1_1544", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1544") to be Pair but got {result}'


def test_DRB1_1545():
    result = parse("DRB1_1545", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1545") to be Pair but got {result}'


def test_DRB1_1546():
    result = parse("DRB1_1546", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1546") to be Pair but got {result}'


def test_DRB1_1547():
    result = parse("DRB1_1547", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1547") to be Pair but got {result}'


def test_DRB1_1548():
    result = parse("DRB1_1548", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1548") to be Pair but got {result}'


def test_DRB1_1549():
    result = parse("DRB1_1549", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1549") to be Pair but got {result}'


def test_DRB1_1601():
    result = parse("DRB1_1601", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1601") to be Pair but got {result}'


def test_DRB1_1602():
    result = parse("DRB1_1602", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1602") to be Pair but got {result}'


def test_DRB1_1603():
    result = parse("DRB1_1603", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1603") to be Pair but got {result}'


def test_DRB1_1604():
    result = parse("DRB1_1604", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1604") to be Pair but got {result}'


def test_DRB1_1605():
    result = parse("DRB1_1605", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1605") to be Pair but got {result}'


def test_DRB1_1607():
    result = parse("DRB1_1607", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1607") to be Pair but got {result}'


def test_DRB1_1608():
    result = parse("DRB1_1608", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1608") to be Pair but got {result}'


def test_DRB1_1609():
    result = parse("DRB1_1609", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1609") to be Pair but got {result}'


def test_DRB1_1610():
    result = parse("DRB1_1610", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1610") to be Pair but got {result}'


def test_DRB1_1611():
    result = parse("DRB1_1611", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1611") to be Pair but got {result}'


def test_DRB1_1612():
    result = parse("DRB1_1612", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1612") to be Pair but got {result}'


def test_DRB1_1614():
    result = parse("DRB1_1614", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1614") to be Pair but got {result}'


def test_DRB1_1615():
    result = parse("DRB1_1615", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1615") to be Pair but got {result}'


def test_DRB1_1616():
    result = parse("DRB1_1616", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB1_1616") to be Pair but got {result}'


def test_DRB3_0101():
    result = parse("DRB3_0101", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB3_0101") to be Pair but got {result}'


def test_DRB3_0104():
    result = parse("DRB3_0104", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB3_0104") to be Pair but got {result}'


def test_DRB3_0105():
    result = parse("DRB3_0105", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB3_0105") to be Pair but got {result}'


def test_DRB3_0108():
    result = parse("DRB3_0108", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB3_0108") to be Pair but got {result}'


def test_DRB3_0109():
    result = parse("DRB3_0109", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB3_0109") to be Pair but got {result}'


def test_DRB3_0111():
    result = parse("DRB3_0111", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB3_0111") to be Pair but got {result}'


def test_DRB3_0112():
    result = parse("DRB3_0112", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB3_0112") to be Pair but got {result}'


def test_DRB3_0113():
    result = parse("DRB3_0113", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB3_0113") to be Pair but got {result}'


def test_DRB3_0114():
    result = parse("DRB3_0114", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB3_0114") to be Pair but got {result}'


def test_DRB3_0201():
    result = parse("DRB3_0201", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB3_0201") to be Pair but got {result}'


def test_DRB3_0202():
    result = parse("DRB3_0202", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB3_0202") to be Pair but got {result}'


def test_DRB3_0204():
    result = parse("DRB3_0204", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB3_0204") to be Pair but got {result}'


def test_DRB3_0205():
    result = parse("DRB3_0205", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB3_0205") to be Pair but got {result}'


def test_DRB3_0209():
    result = parse("DRB3_0209", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB3_0209") to be Pair but got {result}'


def test_DRB3_0210():
    result = parse("DRB3_0210", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB3_0210") to be Pair but got {result}'


def test_DRB3_0211():
    result = parse("DRB3_0211", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB3_0211") to be Pair but got {result}'


def test_DRB3_0212():
    result = parse("DRB3_0212", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB3_0212") to be Pair but got {result}'


def test_DRB3_0213():
    result = parse("DRB3_0213", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB3_0213") to be Pair but got {result}'


def test_DRB3_0214():
    result = parse("DRB3_0214", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB3_0214") to be Pair but got {result}'


def test_DRB3_0215():
    result = parse("DRB3_0215", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB3_0215") to be Pair but got {result}'


def test_DRB3_0216():
    result = parse("DRB3_0216", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB3_0216") to be Pair but got {result}'


def test_DRB3_0217():
    result = parse("DRB3_0217", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB3_0217") to be Pair but got {result}'


def test_DRB3_0218():
    result = parse("DRB3_0218", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB3_0218") to be Pair but got {result}'


def test_DRB3_0219():
    result = parse("DRB3_0219", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB3_0219") to be Pair but got {result}'


def test_DRB3_0220():
    result = parse("DRB3_0220", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB3_0220") to be Pair but got {result}'


def test_DRB3_0221():
    result = parse("DRB3_0221", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB3_0221") to be Pair but got {result}'


def test_DRB3_0222():
    result = parse("DRB3_0222", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB3_0222") to be Pair but got {result}'


def test_DRB3_0223():
    result = parse("DRB3_0223", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB3_0223") to be Pair but got {result}'


def test_DRB3_0224():
    result = parse("DRB3_0224", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB3_0224") to be Pair but got {result}'


def test_DRB3_0225():
    result = parse("DRB3_0225", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB3_0225") to be Pair but got {result}'


def test_DRB3_0301():
    result = parse("DRB3_0301", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB3_0301") to be Pair but got {result}'


def test_DRB3_0303():
    result = parse("DRB3_0303", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB3_0303") to be Pair but got {result}'


def test_DRB4_0101():
    result = parse("DRB4_0101", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB4_0101") to be Pair but got {result}'


def test_DRB4_0103():
    result = parse("DRB4_0103", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB4_0103") to be Pair but got {result}'


def test_DRB4_0104():
    result = parse("DRB4_0104", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB4_0104") to be Pair but got {result}'


def test_DRB4_0106():
    result = parse("DRB4_0106", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB4_0106") to be Pair but got {result}'


def test_DRB4_0107():
    result = parse("DRB4_0107", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB4_0107") to be Pair but got {result}'


def test_DRB4_0108():
    result = parse("DRB4_0108", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB4_0108") to be Pair but got {result}'


def test_DRB5_0101():
    result = parse("DRB5_0101", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB5_0101") to be Pair but got {result}'


def test_DRB5_0102():
    result = parse("DRB5_0102", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB5_0102") to be Pair but got {result}'


def test_DRB5_0103():
    result = parse("DRB5_0103", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB5_0103") to be Pair but got {result}'


def test_DRB5_0104():
    result = parse("DRB5_0104", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB5_0104") to be Pair but got {result}'


def test_DRB5_0105():
    result = parse("DRB5_0105", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB5_0105") to be Pair but got {result}'


def test_DRB5_0106():
    result = parse("DRB5_0106", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB5_0106") to be Pair but got {result}'


def test_DRB5_0108N():
    result = parse("DRB5_0108N", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB5_0108N") to be Pair but got {result}'


def test_DRB5_0111():
    result = parse("DRB5_0111", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB5_0111") to be Pair but got {result}'


def test_DRB5_0112():
    result = parse("DRB5_0112", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB5_0112") to be Pair but got {result}'


def test_DRB5_0113():
    result = parse("DRB5_0113", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB5_0113") to be Pair but got {result}'


def test_DRB5_0114():
    result = parse("DRB5_0114", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB5_0114") to be Pair but got {result}'


def test_DRB5_0202():
    result = parse("DRB5_0202", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB5_0202") to be Pair but got {result}'


def test_DRB5_0203():
    result = parse("DRB5_0203", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB5_0203") to be Pair but got {result}'


def test_DRB5_0204():
    result = parse("DRB5_0204", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB5_0204") to be Pair but got {result}'


def test_DRB5_0205():
    result = parse("DRB5_0205", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("DRB5_0205") to be Pair but got {result}'


def test_H_2_IAb():
    result = parse("H-2-IAb", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("H-2-IAb") to be Pair but got {result}'


def test_H_2_IAd():
    result = parse("H-2-IAd", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("H-2-IAd") to be Pair but got {result}'


def test_H_2_IAk():
    result = parse("H-2-IAk", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("H-2-IAk") to be Pair but got {result}'


def test_H_2_IAq():
    result = parse("H-2-IAq", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("H-2-IAq") to be Pair but got {result}'


def test_H_2_IAs():
    result = parse("H-2-IAs", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("H-2-IAs") to be Pair but got {result}'


def test_H_2_IAu():
    result = parse("H-2-IAu", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("H-2-IAu") to be Pair but got {result}'


def test_H_2_IEd():
    result = parse("H-2-IEd", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("H-2-IEd") to be Pair but got {result}'


def test_H_2_IEk():
    result = parse("H-2-IEk", infer_class2_pairing=True)
    assert result.__class__ is Pair, f'Expected parse("H-2-IEk") to be Pair but got {result}'


def test_HLA_DPA10103_DPB10101():
    result = parse("HLA-DPA10103-DPB10101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB10101") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB10201():
    result = parse("HLA-DPA10103-DPB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB10201") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB10202():
    result = parse("HLA-DPA10103-DPB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB10202") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB10301():
    result = parse("HLA-DPA10103-DPB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB10301") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB10401():
    result = parse("HLA-DPA10103-DPB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB10401") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB10402():
    result = parse("HLA-DPA10103-DPB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB10402") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB10501():
    result = parse("HLA-DPA10103-DPB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB10501") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB10601():
    result = parse("HLA-DPA10103-DPB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB10601") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB10801():
    result = parse("HLA-DPA10103-DPB10801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB10801") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB10901():
    result = parse("HLA-DPA10103-DPB10901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB10901") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB110001():
    result = parse("HLA-DPA10103-DPB110001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB110001") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB11001():
    result = parse("HLA-DPA10103-DPB11001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB11001") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB110101():
    result = parse("HLA-DPA10103-DPB110101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB110101") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB110201():
    result = parse("HLA-DPA10103-DPB110201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB110201") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB110301():
    result = parse("HLA-DPA10103-DPB110301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB110301") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB110401():
    result = parse("HLA-DPA10103-DPB110401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB110401") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB110501():
    result = parse("HLA-DPA10103-DPB110501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB110501") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB110601():
    result = parse("HLA-DPA10103-DPB110601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB110601") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB110701():
    result = parse("HLA-DPA10103-DPB110701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB110701") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB110801():
    result = parse("HLA-DPA10103-DPB110801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB110801") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB110901():
    result = parse("HLA-DPA10103-DPB110901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB110901") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB111001():
    result = parse("HLA-DPA10103-DPB111001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB111001") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB11101():
    result = parse("HLA-DPA10103-DPB11101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB11101") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB111101():
    result = parse("HLA-DPA10103-DPB111101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB111101") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB111201():
    result = parse("HLA-DPA10103-DPB111201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB111201") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB111301():
    result = parse("HLA-DPA10103-DPB111301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB111301") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB111401():
    result = parse("HLA-DPA10103-DPB111401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB111401") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB111501():
    result = parse("HLA-DPA10103-DPB111501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB111501") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB111601():
    result = parse("HLA-DPA10103-DPB111601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB111601") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB111701():
    result = parse("HLA-DPA10103-DPB111701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB111701") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB111801():
    result = parse("HLA-DPA10103-DPB111801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB111801") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB111901():
    result = parse("HLA-DPA10103-DPB111901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB111901") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB112101():
    result = parse("HLA-DPA10103-DPB112101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB112101") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB112201():
    result = parse("HLA-DPA10103-DPB112201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB112201") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB112301():
    result = parse("HLA-DPA10103-DPB112301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB112301") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB112401():
    result = parse("HLA-DPA10103-DPB112401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB112401") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB112501():
    result = parse("HLA-DPA10103-DPB112501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB112501") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB112601():
    result = parse("HLA-DPA10103-DPB112601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB112601") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB112701():
    result = parse("HLA-DPA10103-DPB112701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB112701") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB112801():
    result = parse("HLA-DPA10103-DPB112801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB112801") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB112901():
    result = parse("HLA-DPA10103-DPB112901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB112901") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB113001():
    result = parse("HLA-DPA10103-DPB113001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB113001") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB11301():
    result = parse("HLA-DPA10103-DPB11301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB11301") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB113101():
    result = parse("HLA-DPA10103-DPB113101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB113101") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB113201():
    result = parse("HLA-DPA10103-DPB113201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB113201") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB113301():
    result = parse("HLA-DPA10103-DPB113301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB113301") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB113401():
    result = parse("HLA-DPA10103-DPB113401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB113401") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB11401():
    result = parse("HLA-DPA10103-DPB11401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB11401") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB11501():
    result = parse("HLA-DPA10103-DPB11501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB11501") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB11601():
    result = parse("HLA-DPA10103-DPB11601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB11601") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB11701():
    result = parse("HLA-DPA10103-DPB11701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB11701") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB11801():
    result = parse("HLA-DPA10103-DPB11801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB11801") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB11901():
    result = parse("HLA-DPA10103-DPB11901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB11901") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB12001():
    result = parse("HLA-DPA10103-DPB12001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB12001") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB12101():
    result = parse("HLA-DPA10103-DPB12101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB12101") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB12201():
    result = parse("HLA-DPA10103-DPB12201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB12201") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB12301():
    result = parse("HLA-DPA10103-DPB12301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB12301") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB12401():
    result = parse("HLA-DPA10103-DPB12401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB12401") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB12501():
    result = parse("HLA-DPA10103-DPB12501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB12501") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB12601():
    result = parse("HLA-DPA10103-DPB12601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB12601") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB12701():
    result = parse("HLA-DPA10103-DPB12701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB12701") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB12801():
    result = parse("HLA-DPA10103-DPB12801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB12801") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB12901():
    result = parse("HLA-DPA10103-DPB12901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB12901") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB13001():
    result = parse("HLA-DPA10103-DPB13001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB13001") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB13101():
    result = parse("HLA-DPA10103-DPB13101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB13101") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB13201():
    result = parse("HLA-DPA10103-DPB13201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB13201") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB13301():
    result = parse("HLA-DPA10103-DPB13301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB13301") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB13401():
    result = parse("HLA-DPA10103-DPB13401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB13401") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB13501():
    result = parse("HLA-DPA10103-DPB13501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB13501") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB13601():
    result = parse("HLA-DPA10103-DPB13601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB13601") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB13701():
    result = parse("HLA-DPA10103-DPB13701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB13701") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB13801():
    result = parse("HLA-DPA10103-DPB13801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB13801") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB13901():
    result = parse("HLA-DPA10103-DPB13901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB13901") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB14001():
    result = parse("HLA-DPA10103-DPB14001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB14001") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB14101():
    result = parse("HLA-DPA10103-DPB14101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB14101") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB14401():
    result = parse("HLA-DPA10103-DPB14401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB14401") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB14501():
    result = parse("HLA-DPA10103-DPB14501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB14501") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB14601():
    result = parse("HLA-DPA10103-DPB14601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB14601") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB14701():
    result = parse("HLA-DPA10103-DPB14701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB14701") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB14801():
    result = parse("HLA-DPA10103-DPB14801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB14801") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB14901():
    result = parse("HLA-DPA10103-DPB14901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB14901") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB15001():
    result = parse("HLA-DPA10103-DPB15001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB15001") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB15101():
    result = parse("HLA-DPA10103-DPB15101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB15101") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB15201():
    result = parse("HLA-DPA10103-DPB15201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB15201") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB15301():
    result = parse("HLA-DPA10103-DPB15301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB15301") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB15401():
    result = parse("HLA-DPA10103-DPB15401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB15401") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB15501():
    result = parse("HLA-DPA10103-DPB15501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB15501") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB15601():
    result = parse("HLA-DPA10103-DPB15601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB15601") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB15801():
    result = parse("HLA-DPA10103-DPB15801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB15801") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB15901():
    result = parse("HLA-DPA10103-DPB15901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB15901") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB16001():
    result = parse("HLA-DPA10103-DPB16001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB16001") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB16201():
    result = parse("HLA-DPA10103-DPB16201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB16201") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB16301():
    result = parse("HLA-DPA10103-DPB16301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB16301") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB16501():
    result = parse("HLA-DPA10103-DPB16501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB16501") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB16601():
    result = parse("HLA-DPA10103-DPB16601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB16601") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB16701():
    result = parse("HLA-DPA10103-DPB16701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB16701") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB16801():
    result = parse("HLA-DPA10103-DPB16801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB16801") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB16901():
    result = parse("HLA-DPA10103-DPB16901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB16901") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB17001():
    result = parse("HLA-DPA10103-DPB17001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB17001") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB17101():
    result = parse("HLA-DPA10103-DPB17101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB17101") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB17201():
    result = parse("HLA-DPA10103-DPB17201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB17201") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB17301():
    result = parse("HLA-DPA10103-DPB17301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB17301") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB17401():
    result = parse("HLA-DPA10103-DPB17401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB17401") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB17501():
    result = parse("HLA-DPA10103-DPB17501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB17501") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB17601():
    result = parse("HLA-DPA10103-DPB17601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB17601") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB17701():
    result = parse("HLA-DPA10103-DPB17701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB17701") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB17801():
    result = parse("HLA-DPA10103-DPB17801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB17801") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB17901():
    result = parse("HLA-DPA10103-DPB17901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB17901") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB18001():
    result = parse("HLA-DPA10103-DPB18001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB18001") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB18101():
    result = parse("HLA-DPA10103-DPB18101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB18101") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB18201():
    result = parse("HLA-DPA10103-DPB18201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB18201") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB18301():
    result = parse("HLA-DPA10103-DPB18301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB18301") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB18401():
    result = parse("HLA-DPA10103-DPB18401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB18401") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB18501():
    result = parse("HLA-DPA10103-DPB18501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB18501") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB18601():
    result = parse("HLA-DPA10103-DPB18601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB18601") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB18701():
    result = parse("HLA-DPA10103-DPB18701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB18701") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB18801():
    result = parse("HLA-DPA10103-DPB18801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB18801") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB18901():
    result = parse("HLA-DPA10103-DPB18901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB18901") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB19001():
    result = parse("HLA-DPA10103-DPB19001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB19001") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB19101():
    result = parse("HLA-DPA10103-DPB19101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB19101") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB19201():
    result = parse("HLA-DPA10103-DPB19201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB19201") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB19301():
    result = parse("HLA-DPA10103-DPB19301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB19301") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB19401():
    result = parse("HLA-DPA10103-DPB19401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB19401") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB19501():
    result = parse("HLA-DPA10103-DPB19501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB19501") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB19601():
    result = parse("HLA-DPA10103-DPB19601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB19601") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB19701():
    result = parse("HLA-DPA10103-DPB19701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB19701") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB19801():
    result = parse("HLA-DPA10103-DPB19801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB19801") to be Pair but got {result}'
    )


def test_HLA_DPA10103_DPB19901():
    result = parse("HLA-DPA10103-DPB19901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10103-DPB19901") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB10101():
    result = parse("HLA-DPA10104-DPB10101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB10101") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB10201():
    result = parse("HLA-DPA10104-DPB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB10201") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB10202():
    result = parse("HLA-DPA10104-DPB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB10202") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB10301():
    result = parse("HLA-DPA10104-DPB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB10301") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB10401():
    result = parse("HLA-DPA10104-DPB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB10401") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB10402():
    result = parse("HLA-DPA10104-DPB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB10402") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB10501():
    result = parse("HLA-DPA10104-DPB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB10501") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB10601():
    result = parse("HLA-DPA10104-DPB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB10601") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB10801():
    result = parse("HLA-DPA10104-DPB10801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB10801") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB10901():
    result = parse("HLA-DPA10104-DPB10901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB10901") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB110001():
    result = parse("HLA-DPA10104-DPB110001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB110001") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB11001():
    result = parse("HLA-DPA10104-DPB11001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB11001") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB110101():
    result = parse("HLA-DPA10104-DPB110101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB110101") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB110201():
    result = parse("HLA-DPA10104-DPB110201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB110201") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB110301():
    result = parse("HLA-DPA10104-DPB110301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB110301") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB110401():
    result = parse("HLA-DPA10104-DPB110401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB110401") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB110501():
    result = parse("HLA-DPA10104-DPB110501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB110501") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB110601():
    result = parse("HLA-DPA10104-DPB110601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB110601") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB110701():
    result = parse("HLA-DPA10104-DPB110701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB110701") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB110801():
    result = parse("HLA-DPA10104-DPB110801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB110801") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB110901():
    result = parse("HLA-DPA10104-DPB110901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB110901") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB111001():
    result = parse("HLA-DPA10104-DPB111001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB111001") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB11101():
    result = parse("HLA-DPA10104-DPB11101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB11101") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB111101():
    result = parse("HLA-DPA10104-DPB111101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB111101") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB111201():
    result = parse("HLA-DPA10104-DPB111201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB111201") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB111301():
    result = parse("HLA-DPA10104-DPB111301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB111301") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB111401():
    result = parse("HLA-DPA10104-DPB111401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB111401") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB111501():
    result = parse("HLA-DPA10104-DPB111501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB111501") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB111601():
    result = parse("HLA-DPA10104-DPB111601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB111601") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB111701():
    result = parse("HLA-DPA10104-DPB111701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB111701") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB111801():
    result = parse("HLA-DPA10104-DPB111801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB111801") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB111901():
    result = parse("HLA-DPA10104-DPB111901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB111901") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB112101():
    result = parse("HLA-DPA10104-DPB112101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB112101") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB112201():
    result = parse("HLA-DPA10104-DPB112201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB112201") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB112301():
    result = parse("HLA-DPA10104-DPB112301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB112301") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB112401():
    result = parse("HLA-DPA10104-DPB112401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB112401") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB112501():
    result = parse("HLA-DPA10104-DPB112501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB112501") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB112601():
    result = parse("HLA-DPA10104-DPB112601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB112601") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB112701():
    result = parse("HLA-DPA10104-DPB112701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB112701") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB112801():
    result = parse("HLA-DPA10104-DPB112801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB112801") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB112901():
    result = parse("HLA-DPA10104-DPB112901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB112901") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB113001():
    result = parse("HLA-DPA10104-DPB113001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB113001") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB11301():
    result = parse("HLA-DPA10104-DPB11301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB11301") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB113101():
    result = parse("HLA-DPA10104-DPB113101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB113101") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB113201():
    result = parse("HLA-DPA10104-DPB113201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB113201") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB113301():
    result = parse("HLA-DPA10104-DPB113301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB113301") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB113401():
    result = parse("HLA-DPA10104-DPB113401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB113401") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB11401():
    result = parse("HLA-DPA10104-DPB11401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB11401") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB11501():
    result = parse("HLA-DPA10104-DPB11501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB11501") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB11601():
    result = parse("HLA-DPA10104-DPB11601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB11601") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB11701():
    result = parse("HLA-DPA10104-DPB11701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB11701") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB11801():
    result = parse("HLA-DPA10104-DPB11801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB11801") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB11901():
    result = parse("HLA-DPA10104-DPB11901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB11901") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB12001():
    result = parse("HLA-DPA10104-DPB12001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB12001") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB12101():
    result = parse("HLA-DPA10104-DPB12101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB12101") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB12201():
    result = parse("HLA-DPA10104-DPB12201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB12201") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB12301():
    result = parse("HLA-DPA10104-DPB12301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB12301") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB12401():
    result = parse("HLA-DPA10104-DPB12401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB12401") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB12501():
    result = parse("HLA-DPA10104-DPB12501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB12501") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB12601():
    result = parse("HLA-DPA10104-DPB12601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB12601") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB12701():
    result = parse("HLA-DPA10104-DPB12701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB12701") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB12801():
    result = parse("HLA-DPA10104-DPB12801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB12801") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB12901():
    result = parse("HLA-DPA10104-DPB12901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB12901") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB13001():
    result = parse("HLA-DPA10104-DPB13001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB13001") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB13101():
    result = parse("HLA-DPA10104-DPB13101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB13101") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB13201():
    result = parse("HLA-DPA10104-DPB13201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB13201") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB13301():
    result = parse("HLA-DPA10104-DPB13301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB13301") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB13401():
    result = parse("HLA-DPA10104-DPB13401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB13401") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB13501():
    result = parse("HLA-DPA10104-DPB13501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB13501") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB13601():
    result = parse("HLA-DPA10104-DPB13601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB13601") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB13701():
    result = parse("HLA-DPA10104-DPB13701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB13701") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB13801():
    result = parse("HLA-DPA10104-DPB13801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB13801") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB13901():
    result = parse("HLA-DPA10104-DPB13901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB13901") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB14001():
    result = parse("HLA-DPA10104-DPB14001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB14001") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB14101():
    result = parse("HLA-DPA10104-DPB14101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB14101") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB14401():
    result = parse("HLA-DPA10104-DPB14401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB14401") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB14501():
    result = parse("HLA-DPA10104-DPB14501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB14501") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB14601():
    result = parse("HLA-DPA10104-DPB14601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB14601") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB14701():
    result = parse("HLA-DPA10104-DPB14701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB14701") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB14801():
    result = parse("HLA-DPA10104-DPB14801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB14801") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB14901():
    result = parse("HLA-DPA10104-DPB14901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB14901") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB15001():
    result = parse("HLA-DPA10104-DPB15001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB15001") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB15101():
    result = parse("HLA-DPA10104-DPB15101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB15101") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB15201():
    result = parse("HLA-DPA10104-DPB15201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB15201") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB15301():
    result = parse("HLA-DPA10104-DPB15301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB15301") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB15401():
    result = parse("HLA-DPA10104-DPB15401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB15401") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB15501():
    result = parse("HLA-DPA10104-DPB15501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB15501") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB15601():
    result = parse("HLA-DPA10104-DPB15601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB15601") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB15801():
    result = parse("HLA-DPA10104-DPB15801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB15801") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB15901():
    result = parse("HLA-DPA10104-DPB15901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB15901") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB16001():
    result = parse("HLA-DPA10104-DPB16001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB16001") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB16201():
    result = parse("HLA-DPA10104-DPB16201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB16201") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB16301():
    result = parse("HLA-DPA10104-DPB16301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB16301") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB16501():
    result = parse("HLA-DPA10104-DPB16501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB16501") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB16601():
    result = parse("HLA-DPA10104-DPB16601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB16601") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB16701():
    result = parse("HLA-DPA10104-DPB16701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB16701") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB16801():
    result = parse("HLA-DPA10104-DPB16801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB16801") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB16901():
    result = parse("HLA-DPA10104-DPB16901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB16901") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB17001():
    result = parse("HLA-DPA10104-DPB17001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB17001") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB17101():
    result = parse("HLA-DPA10104-DPB17101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB17101") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB17201():
    result = parse("HLA-DPA10104-DPB17201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB17201") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB17301():
    result = parse("HLA-DPA10104-DPB17301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB17301") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB17401():
    result = parse("HLA-DPA10104-DPB17401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB17401") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB17501():
    result = parse("HLA-DPA10104-DPB17501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB17501") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB17601():
    result = parse("HLA-DPA10104-DPB17601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB17601") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB17701():
    result = parse("HLA-DPA10104-DPB17701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB17701") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB17801():
    result = parse("HLA-DPA10104-DPB17801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB17801") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB17901():
    result = parse("HLA-DPA10104-DPB17901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB17901") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB18001():
    result = parse("HLA-DPA10104-DPB18001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB18001") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB18101():
    result = parse("HLA-DPA10104-DPB18101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB18101") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB18201():
    result = parse("HLA-DPA10104-DPB18201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB18201") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB18301():
    result = parse("HLA-DPA10104-DPB18301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB18301") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB18401():
    result = parse("HLA-DPA10104-DPB18401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB18401") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB18501():
    result = parse("HLA-DPA10104-DPB18501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB18501") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB18601():
    result = parse("HLA-DPA10104-DPB18601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB18601") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB18701():
    result = parse("HLA-DPA10104-DPB18701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB18701") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB18801():
    result = parse("HLA-DPA10104-DPB18801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB18801") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB18901():
    result = parse("HLA-DPA10104-DPB18901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB18901") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB19001():
    result = parse("HLA-DPA10104-DPB19001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB19001") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB19101():
    result = parse("HLA-DPA10104-DPB19101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB19101") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB19201():
    result = parse("HLA-DPA10104-DPB19201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB19201") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB19301():
    result = parse("HLA-DPA10104-DPB19301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB19301") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB19401():
    result = parse("HLA-DPA10104-DPB19401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB19401") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB19501():
    result = parse("HLA-DPA10104-DPB19501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB19501") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB19601():
    result = parse("HLA-DPA10104-DPB19601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB19601") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB19701():
    result = parse("HLA-DPA10104-DPB19701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB19701") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB19801():
    result = parse("HLA-DPA10104-DPB19801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB19801") to be Pair but got {result}'
    )


def test_HLA_DPA10104_DPB19901():
    result = parse("HLA-DPA10104-DPB19901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10104-DPB19901") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB10101():
    result = parse("HLA-DPA10105-DPB10101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB10101") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB10201():
    result = parse("HLA-DPA10105-DPB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB10201") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB10202():
    result = parse("HLA-DPA10105-DPB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB10202") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB10301():
    result = parse("HLA-DPA10105-DPB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB10301") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB10401():
    result = parse("HLA-DPA10105-DPB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB10401") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB10402():
    result = parse("HLA-DPA10105-DPB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB10402") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB10501():
    result = parse("HLA-DPA10105-DPB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB10501") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB10601():
    result = parse("HLA-DPA10105-DPB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB10601") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB10801():
    result = parse("HLA-DPA10105-DPB10801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB10801") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB10901():
    result = parse("HLA-DPA10105-DPB10901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB10901") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB110001():
    result = parse("HLA-DPA10105-DPB110001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB110001") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB11001():
    result = parse("HLA-DPA10105-DPB11001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB11001") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB110101():
    result = parse("HLA-DPA10105-DPB110101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB110101") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB110201():
    result = parse("HLA-DPA10105-DPB110201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB110201") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB110301():
    result = parse("HLA-DPA10105-DPB110301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB110301") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB110401():
    result = parse("HLA-DPA10105-DPB110401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB110401") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB110501():
    result = parse("HLA-DPA10105-DPB110501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB110501") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB110601():
    result = parse("HLA-DPA10105-DPB110601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB110601") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB110701():
    result = parse("HLA-DPA10105-DPB110701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB110701") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB110801():
    result = parse("HLA-DPA10105-DPB110801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB110801") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB110901():
    result = parse("HLA-DPA10105-DPB110901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB110901") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB111001():
    result = parse("HLA-DPA10105-DPB111001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB111001") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB11101():
    result = parse("HLA-DPA10105-DPB11101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB11101") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB111101():
    result = parse("HLA-DPA10105-DPB111101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB111101") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB111201():
    result = parse("HLA-DPA10105-DPB111201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB111201") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB111301():
    result = parse("HLA-DPA10105-DPB111301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB111301") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB111401():
    result = parse("HLA-DPA10105-DPB111401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB111401") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB111501():
    result = parse("HLA-DPA10105-DPB111501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB111501") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB111601():
    result = parse("HLA-DPA10105-DPB111601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB111601") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB111701():
    result = parse("HLA-DPA10105-DPB111701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB111701") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB111801():
    result = parse("HLA-DPA10105-DPB111801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB111801") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB111901():
    result = parse("HLA-DPA10105-DPB111901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB111901") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB112101():
    result = parse("HLA-DPA10105-DPB112101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB112101") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB112201():
    result = parse("HLA-DPA10105-DPB112201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB112201") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB112301():
    result = parse("HLA-DPA10105-DPB112301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB112301") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB112401():
    result = parse("HLA-DPA10105-DPB112401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB112401") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB112501():
    result = parse("HLA-DPA10105-DPB112501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB112501") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB112601():
    result = parse("HLA-DPA10105-DPB112601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB112601") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB112701():
    result = parse("HLA-DPA10105-DPB112701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB112701") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB112801():
    result = parse("HLA-DPA10105-DPB112801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB112801") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB112901():
    result = parse("HLA-DPA10105-DPB112901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB112901") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB113001():
    result = parse("HLA-DPA10105-DPB113001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB113001") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB11301():
    result = parse("HLA-DPA10105-DPB11301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB11301") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB113101():
    result = parse("HLA-DPA10105-DPB113101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB113101") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB113201():
    result = parse("HLA-DPA10105-DPB113201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB113201") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB113301():
    result = parse("HLA-DPA10105-DPB113301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB113301") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB113401():
    result = parse("HLA-DPA10105-DPB113401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB113401") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB11401():
    result = parse("HLA-DPA10105-DPB11401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB11401") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB11501():
    result = parse("HLA-DPA10105-DPB11501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB11501") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB11601():
    result = parse("HLA-DPA10105-DPB11601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB11601") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB11701():
    result = parse("HLA-DPA10105-DPB11701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB11701") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB11801():
    result = parse("HLA-DPA10105-DPB11801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB11801") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB11901():
    result = parse("HLA-DPA10105-DPB11901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB11901") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB12001():
    result = parse("HLA-DPA10105-DPB12001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB12001") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB12101():
    result = parse("HLA-DPA10105-DPB12101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB12101") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB12201():
    result = parse("HLA-DPA10105-DPB12201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB12201") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB12301():
    result = parse("HLA-DPA10105-DPB12301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB12301") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB12401():
    result = parse("HLA-DPA10105-DPB12401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB12401") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB12501():
    result = parse("HLA-DPA10105-DPB12501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB12501") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB12601():
    result = parse("HLA-DPA10105-DPB12601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB12601") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB12701():
    result = parse("HLA-DPA10105-DPB12701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB12701") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB12801():
    result = parse("HLA-DPA10105-DPB12801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB12801") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB12901():
    result = parse("HLA-DPA10105-DPB12901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB12901") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB13001():
    result = parse("HLA-DPA10105-DPB13001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB13001") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB13101():
    result = parse("HLA-DPA10105-DPB13101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB13101") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB13201():
    result = parse("HLA-DPA10105-DPB13201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB13201") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB13301():
    result = parse("HLA-DPA10105-DPB13301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB13301") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB13401():
    result = parse("HLA-DPA10105-DPB13401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB13401") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB13501():
    result = parse("HLA-DPA10105-DPB13501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB13501") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB13601():
    result = parse("HLA-DPA10105-DPB13601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB13601") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB13701():
    result = parse("HLA-DPA10105-DPB13701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB13701") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB13801():
    result = parse("HLA-DPA10105-DPB13801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB13801") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB13901():
    result = parse("HLA-DPA10105-DPB13901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB13901") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB14001():
    result = parse("HLA-DPA10105-DPB14001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB14001") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB14101():
    result = parse("HLA-DPA10105-DPB14101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB14101") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB14401():
    result = parse("HLA-DPA10105-DPB14401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB14401") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB14501():
    result = parse("HLA-DPA10105-DPB14501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB14501") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB14601():
    result = parse("HLA-DPA10105-DPB14601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB14601") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB14701():
    result = parse("HLA-DPA10105-DPB14701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB14701") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB14801():
    result = parse("HLA-DPA10105-DPB14801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB14801") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB14901():
    result = parse("HLA-DPA10105-DPB14901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB14901") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB15001():
    result = parse("HLA-DPA10105-DPB15001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB15001") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB15101():
    result = parse("HLA-DPA10105-DPB15101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB15101") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB15201():
    result = parse("HLA-DPA10105-DPB15201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB15201") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB15301():
    result = parse("HLA-DPA10105-DPB15301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB15301") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB15401():
    result = parse("HLA-DPA10105-DPB15401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB15401") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB15501():
    result = parse("HLA-DPA10105-DPB15501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB15501") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB15601():
    result = parse("HLA-DPA10105-DPB15601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB15601") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB15801():
    result = parse("HLA-DPA10105-DPB15801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB15801") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB15901():
    result = parse("HLA-DPA10105-DPB15901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB15901") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB16001():
    result = parse("HLA-DPA10105-DPB16001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB16001") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB16201():
    result = parse("HLA-DPA10105-DPB16201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB16201") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB16301():
    result = parse("HLA-DPA10105-DPB16301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB16301") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB16501():
    result = parse("HLA-DPA10105-DPB16501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB16501") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB16601():
    result = parse("HLA-DPA10105-DPB16601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB16601") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB16701():
    result = parse("HLA-DPA10105-DPB16701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB16701") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB16801():
    result = parse("HLA-DPA10105-DPB16801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB16801") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB16901():
    result = parse("HLA-DPA10105-DPB16901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB16901") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB17001():
    result = parse("HLA-DPA10105-DPB17001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB17001") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB17101():
    result = parse("HLA-DPA10105-DPB17101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB17101") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB17201():
    result = parse("HLA-DPA10105-DPB17201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB17201") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB17301():
    result = parse("HLA-DPA10105-DPB17301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB17301") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB17401():
    result = parse("HLA-DPA10105-DPB17401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB17401") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB17501():
    result = parse("HLA-DPA10105-DPB17501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB17501") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB17601():
    result = parse("HLA-DPA10105-DPB17601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB17601") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB17701():
    result = parse("HLA-DPA10105-DPB17701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB17701") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB17801():
    result = parse("HLA-DPA10105-DPB17801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB17801") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB17901():
    result = parse("HLA-DPA10105-DPB17901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB17901") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB18001():
    result = parse("HLA-DPA10105-DPB18001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB18001") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB18101():
    result = parse("HLA-DPA10105-DPB18101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB18101") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB18201():
    result = parse("HLA-DPA10105-DPB18201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB18201") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB18301():
    result = parse("HLA-DPA10105-DPB18301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB18301") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB18401():
    result = parse("HLA-DPA10105-DPB18401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB18401") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB18501():
    result = parse("HLA-DPA10105-DPB18501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB18501") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB18601():
    result = parse("HLA-DPA10105-DPB18601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB18601") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB18701():
    result = parse("HLA-DPA10105-DPB18701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB18701") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB18801():
    result = parse("HLA-DPA10105-DPB18801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB18801") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB18901():
    result = parse("HLA-DPA10105-DPB18901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB18901") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB19001():
    result = parse("HLA-DPA10105-DPB19001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB19001") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB19101():
    result = parse("HLA-DPA10105-DPB19101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB19101") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB19201():
    result = parse("HLA-DPA10105-DPB19201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB19201") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB19301():
    result = parse("HLA-DPA10105-DPB19301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB19301") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB19401():
    result = parse("HLA-DPA10105-DPB19401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB19401") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB19501():
    result = parse("HLA-DPA10105-DPB19501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB19501") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB19601():
    result = parse("HLA-DPA10105-DPB19601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB19601") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB19701():
    result = parse("HLA-DPA10105-DPB19701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB19701") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB19801():
    result = parse("HLA-DPA10105-DPB19801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB19801") to be Pair but got {result}'
    )


def test_HLA_DPA10105_DPB19901():
    result = parse("HLA-DPA10105-DPB19901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10105-DPB19901") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB10101():
    result = parse("HLA-DPA10106-DPB10101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB10101") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB10201():
    result = parse("HLA-DPA10106-DPB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB10201") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB10202():
    result = parse("HLA-DPA10106-DPB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB10202") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB10301():
    result = parse("HLA-DPA10106-DPB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB10301") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB10401():
    result = parse("HLA-DPA10106-DPB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB10401") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB10402():
    result = parse("HLA-DPA10106-DPB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB10402") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB10501():
    result = parse("HLA-DPA10106-DPB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB10501") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB10601():
    result = parse("HLA-DPA10106-DPB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB10601") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB10801():
    result = parse("HLA-DPA10106-DPB10801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB10801") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB10901():
    result = parse("HLA-DPA10106-DPB10901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB10901") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB110001():
    result = parse("HLA-DPA10106-DPB110001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB110001") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB11001():
    result = parse("HLA-DPA10106-DPB11001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB11001") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB110101():
    result = parse("HLA-DPA10106-DPB110101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB110101") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB110201():
    result = parse("HLA-DPA10106-DPB110201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB110201") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB110301():
    result = parse("HLA-DPA10106-DPB110301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB110301") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB110401():
    result = parse("HLA-DPA10106-DPB110401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB110401") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB110501():
    result = parse("HLA-DPA10106-DPB110501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB110501") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB110601():
    result = parse("HLA-DPA10106-DPB110601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB110601") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB110701():
    result = parse("HLA-DPA10106-DPB110701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB110701") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB110801():
    result = parse("HLA-DPA10106-DPB110801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB110801") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB110901():
    result = parse("HLA-DPA10106-DPB110901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB110901") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB111001():
    result = parse("HLA-DPA10106-DPB111001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB111001") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB11101():
    result = parse("HLA-DPA10106-DPB11101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB11101") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB111101():
    result = parse("HLA-DPA10106-DPB111101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB111101") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB111201():
    result = parse("HLA-DPA10106-DPB111201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB111201") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB111301():
    result = parse("HLA-DPA10106-DPB111301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB111301") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB111401():
    result = parse("HLA-DPA10106-DPB111401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB111401") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB111501():
    result = parse("HLA-DPA10106-DPB111501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB111501") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB111601():
    result = parse("HLA-DPA10106-DPB111601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB111601") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB111701():
    result = parse("HLA-DPA10106-DPB111701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB111701") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB111801():
    result = parse("HLA-DPA10106-DPB111801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB111801") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB111901():
    result = parse("HLA-DPA10106-DPB111901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB111901") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB112101():
    result = parse("HLA-DPA10106-DPB112101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB112101") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB112201():
    result = parse("HLA-DPA10106-DPB112201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB112201") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB112301():
    result = parse("HLA-DPA10106-DPB112301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB112301") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB112401():
    result = parse("HLA-DPA10106-DPB112401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB112401") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB112501():
    result = parse("HLA-DPA10106-DPB112501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB112501") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB112601():
    result = parse("HLA-DPA10106-DPB112601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB112601") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB112701():
    result = parse("HLA-DPA10106-DPB112701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB112701") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB112801():
    result = parse("HLA-DPA10106-DPB112801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB112801") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB112901():
    result = parse("HLA-DPA10106-DPB112901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB112901") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB113001():
    result = parse("HLA-DPA10106-DPB113001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB113001") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB11301():
    result = parse("HLA-DPA10106-DPB11301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB11301") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB113101():
    result = parse("HLA-DPA10106-DPB113101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB113101") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB113201():
    result = parse("HLA-DPA10106-DPB113201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB113201") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB113301():
    result = parse("HLA-DPA10106-DPB113301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB113301") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB113401():
    result = parse("HLA-DPA10106-DPB113401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB113401") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB11401():
    result = parse("HLA-DPA10106-DPB11401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB11401") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB11501():
    result = parse("HLA-DPA10106-DPB11501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB11501") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB11601():
    result = parse("HLA-DPA10106-DPB11601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB11601") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB11701():
    result = parse("HLA-DPA10106-DPB11701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB11701") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB11801():
    result = parse("HLA-DPA10106-DPB11801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB11801") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB11901():
    result = parse("HLA-DPA10106-DPB11901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB11901") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB12001():
    result = parse("HLA-DPA10106-DPB12001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB12001") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB12101():
    result = parse("HLA-DPA10106-DPB12101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB12101") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB12201():
    result = parse("HLA-DPA10106-DPB12201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB12201") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB12301():
    result = parse("HLA-DPA10106-DPB12301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB12301") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB12401():
    result = parse("HLA-DPA10106-DPB12401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB12401") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB12501():
    result = parse("HLA-DPA10106-DPB12501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB12501") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB12601():
    result = parse("HLA-DPA10106-DPB12601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB12601") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB12701():
    result = parse("HLA-DPA10106-DPB12701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB12701") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB12801():
    result = parse("HLA-DPA10106-DPB12801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB12801") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB12901():
    result = parse("HLA-DPA10106-DPB12901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB12901") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB13001():
    result = parse("HLA-DPA10106-DPB13001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB13001") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB13101():
    result = parse("HLA-DPA10106-DPB13101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB13101") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB13201():
    result = parse("HLA-DPA10106-DPB13201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB13201") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB13301():
    result = parse("HLA-DPA10106-DPB13301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB13301") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB13401():
    result = parse("HLA-DPA10106-DPB13401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB13401") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB13501():
    result = parse("HLA-DPA10106-DPB13501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB13501") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB13601():
    result = parse("HLA-DPA10106-DPB13601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB13601") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB13701():
    result = parse("HLA-DPA10106-DPB13701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB13701") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB13801():
    result = parse("HLA-DPA10106-DPB13801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB13801") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB13901():
    result = parse("HLA-DPA10106-DPB13901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB13901") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB14001():
    result = parse("HLA-DPA10106-DPB14001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB14001") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB14101():
    result = parse("HLA-DPA10106-DPB14101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB14101") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB14401():
    result = parse("HLA-DPA10106-DPB14401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB14401") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB14501():
    result = parse("HLA-DPA10106-DPB14501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB14501") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB14601():
    result = parse("HLA-DPA10106-DPB14601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB14601") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB14701():
    result = parse("HLA-DPA10106-DPB14701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB14701") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB14801():
    result = parse("HLA-DPA10106-DPB14801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB14801") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB14901():
    result = parse("HLA-DPA10106-DPB14901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB14901") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB15001():
    result = parse("HLA-DPA10106-DPB15001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB15001") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB15101():
    result = parse("HLA-DPA10106-DPB15101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB15101") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB15201():
    result = parse("HLA-DPA10106-DPB15201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB15201") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB15301():
    result = parse("HLA-DPA10106-DPB15301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB15301") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB15401():
    result = parse("HLA-DPA10106-DPB15401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB15401") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB15501():
    result = parse("HLA-DPA10106-DPB15501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB15501") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB15601():
    result = parse("HLA-DPA10106-DPB15601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB15601") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB15801():
    result = parse("HLA-DPA10106-DPB15801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB15801") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB15901():
    result = parse("HLA-DPA10106-DPB15901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB15901") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB16001():
    result = parse("HLA-DPA10106-DPB16001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB16001") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB16201():
    result = parse("HLA-DPA10106-DPB16201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB16201") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB16301():
    result = parse("HLA-DPA10106-DPB16301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB16301") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB16501():
    result = parse("HLA-DPA10106-DPB16501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB16501") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB16601():
    result = parse("HLA-DPA10106-DPB16601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB16601") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB16701():
    result = parse("HLA-DPA10106-DPB16701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB16701") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB16801():
    result = parse("HLA-DPA10106-DPB16801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB16801") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB16901():
    result = parse("HLA-DPA10106-DPB16901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB16901") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB17001():
    result = parse("HLA-DPA10106-DPB17001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB17001") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB17101():
    result = parse("HLA-DPA10106-DPB17101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB17101") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB17201():
    result = parse("HLA-DPA10106-DPB17201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB17201") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB17301():
    result = parse("HLA-DPA10106-DPB17301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB17301") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB17401():
    result = parse("HLA-DPA10106-DPB17401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB17401") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB17501():
    result = parse("HLA-DPA10106-DPB17501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB17501") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB17601():
    result = parse("HLA-DPA10106-DPB17601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB17601") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB17701():
    result = parse("HLA-DPA10106-DPB17701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB17701") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB17801():
    result = parse("HLA-DPA10106-DPB17801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB17801") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB17901():
    result = parse("HLA-DPA10106-DPB17901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB17901") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB18001():
    result = parse("HLA-DPA10106-DPB18001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB18001") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB18101():
    result = parse("HLA-DPA10106-DPB18101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB18101") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB18201():
    result = parse("HLA-DPA10106-DPB18201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB18201") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB18301():
    result = parse("HLA-DPA10106-DPB18301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB18301") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB18401():
    result = parse("HLA-DPA10106-DPB18401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB18401") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB18501():
    result = parse("HLA-DPA10106-DPB18501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB18501") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB18601():
    result = parse("HLA-DPA10106-DPB18601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB18601") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB18701():
    result = parse("HLA-DPA10106-DPB18701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB18701") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB18801():
    result = parse("HLA-DPA10106-DPB18801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB18801") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB18901():
    result = parse("HLA-DPA10106-DPB18901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB18901") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB19001():
    result = parse("HLA-DPA10106-DPB19001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB19001") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB19101():
    result = parse("HLA-DPA10106-DPB19101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB19101") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB19201():
    result = parse("HLA-DPA10106-DPB19201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB19201") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB19301():
    result = parse("HLA-DPA10106-DPB19301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB19301") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB19401():
    result = parse("HLA-DPA10106-DPB19401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB19401") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB19501():
    result = parse("HLA-DPA10106-DPB19501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB19501") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB19601():
    result = parse("HLA-DPA10106-DPB19601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB19601") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB19701():
    result = parse("HLA-DPA10106-DPB19701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB19701") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB19801():
    result = parse("HLA-DPA10106-DPB19801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB19801") to be Pair but got {result}'
    )


def test_HLA_DPA10106_DPB19901():
    result = parse("HLA-DPA10106-DPB19901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10106-DPB19901") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB10101():
    result = parse("HLA-DPA10107-DPB10101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB10101") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB10201():
    result = parse("HLA-DPA10107-DPB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB10201") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB10202():
    result = parse("HLA-DPA10107-DPB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB10202") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB10301():
    result = parse("HLA-DPA10107-DPB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB10301") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB10401():
    result = parse("HLA-DPA10107-DPB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB10401") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB10402():
    result = parse("HLA-DPA10107-DPB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB10402") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB10501():
    result = parse("HLA-DPA10107-DPB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB10501") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB10601():
    result = parse("HLA-DPA10107-DPB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB10601") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB10801():
    result = parse("HLA-DPA10107-DPB10801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB10801") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB10901():
    result = parse("HLA-DPA10107-DPB10901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB10901") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB110001():
    result = parse("HLA-DPA10107-DPB110001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB110001") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB11001():
    result = parse("HLA-DPA10107-DPB11001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB11001") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB110101():
    result = parse("HLA-DPA10107-DPB110101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB110101") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB110201():
    result = parse("HLA-DPA10107-DPB110201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB110201") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB110301():
    result = parse("HLA-DPA10107-DPB110301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB110301") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB110401():
    result = parse("HLA-DPA10107-DPB110401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB110401") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB110501():
    result = parse("HLA-DPA10107-DPB110501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB110501") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB110601():
    result = parse("HLA-DPA10107-DPB110601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB110601") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB110701():
    result = parse("HLA-DPA10107-DPB110701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB110701") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB110801():
    result = parse("HLA-DPA10107-DPB110801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB110801") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB110901():
    result = parse("HLA-DPA10107-DPB110901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB110901") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB111001():
    result = parse("HLA-DPA10107-DPB111001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB111001") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB11101():
    result = parse("HLA-DPA10107-DPB11101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB11101") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB111101():
    result = parse("HLA-DPA10107-DPB111101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB111101") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB111201():
    result = parse("HLA-DPA10107-DPB111201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB111201") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB111301():
    result = parse("HLA-DPA10107-DPB111301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB111301") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB111401():
    result = parse("HLA-DPA10107-DPB111401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB111401") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB111501():
    result = parse("HLA-DPA10107-DPB111501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB111501") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB111601():
    result = parse("HLA-DPA10107-DPB111601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB111601") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB111701():
    result = parse("HLA-DPA10107-DPB111701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB111701") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB111801():
    result = parse("HLA-DPA10107-DPB111801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB111801") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB111901():
    result = parse("HLA-DPA10107-DPB111901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB111901") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB112101():
    result = parse("HLA-DPA10107-DPB112101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB112101") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB112201():
    result = parse("HLA-DPA10107-DPB112201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB112201") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB112301():
    result = parse("HLA-DPA10107-DPB112301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB112301") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB112401():
    result = parse("HLA-DPA10107-DPB112401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB112401") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB112501():
    result = parse("HLA-DPA10107-DPB112501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB112501") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB112601():
    result = parse("HLA-DPA10107-DPB112601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB112601") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB112701():
    result = parse("HLA-DPA10107-DPB112701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB112701") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB112801():
    result = parse("HLA-DPA10107-DPB112801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB112801") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB112901():
    result = parse("HLA-DPA10107-DPB112901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB112901") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB113001():
    result = parse("HLA-DPA10107-DPB113001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB113001") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB11301():
    result = parse("HLA-DPA10107-DPB11301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB11301") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB113101():
    result = parse("HLA-DPA10107-DPB113101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB113101") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB113201():
    result = parse("HLA-DPA10107-DPB113201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB113201") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB113301():
    result = parse("HLA-DPA10107-DPB113301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB113301") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB113401():
    result = parse("HLA-DPA10107-DPB113401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB113401") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB11401():
    result = parse("HLA-DPA10107-DPB11401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB11401") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB11501():
    result = parse("HLA-DPA10107-DPB11501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB11501") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB11601():
    result = parse("HLA-DPA10107-DPB11601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB11601") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB11701():
    result = parse("HLA-DPA10107-DPB11701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB11701") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB11801():
    result = parse("HLA-DPA10107-DPB11801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB11801") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB11901():
    result = parse("HLA-DPA10107-DPB11901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB11901") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB12001():
    result = parse("HLA-DPA10107-DPB12001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB12001") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB12101():
    result = parse("HLA-DPA10107-DPB12101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB12101") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB12201():
    result = parse("HLA-DPA10107-DPB12201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB12201") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB12301():
    result = parse("HLA-DPA10107-DPB12301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB12301") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB12401():
    result = parse("HLA-DPA10107-DPB12401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB12401") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB12501():
    result = parse("HLA-DPA10107-DPB12501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB12501") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB12601():
    result = parse("HLA-DPA10107-DPB12601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB12601") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB12701():
    result = parse("HLA-DPA10107-DPB12701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB12701") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB12801():
    result = parse("HLA-DPA10107-DPB12801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB12801") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB12901():
    result = parse("HLA-DPA10107-DPB12901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB12901") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB13001():
    result = parse("HLA-DPA10107-DPB13001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB13001") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB13101():
    result = parse("HLA-DPA10107-DPB13101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB13101") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB13201():
    result = parse("HLA-DPA10107-DPB13201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB13201") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB13301():
    result = parse("HLA-DPA10107-DPB13301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB13301") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB13401():
    result = parse("HLA-DPA10107-DPB13401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB13401") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB13501():
    result = parse("HLA-DPA10107-DPB13501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB13501") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB13601():
    result = parse("HLA-DPA10107-DPB13601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB13601") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB13701():
    result = parse("HLA-DPA10107-DPB13701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB13701") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB13801():
    result = parse("HLA-DPA10107-DPB13801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB13801") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB13901():
    result = parse("HLA-DPA10107-DPB13901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB13901") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB14001():
    result = parse("HLA-DPA10107-DPB14001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB14001") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB14101():
    result = parse("HLA-DPA10107-DPB14101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB14101") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB14401():
    result = parse("HLA-DPA10107-DPB14401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB14401") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB14501():
    result = parse("HLA-DPA10107-DPB14501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB14501") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB14601():
    result = parse("HLA-DPA10107-DPB14601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB14601") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB14701():
    result = parse("HLA-DPA10107-DPB14701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB14701") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB14801():
    result = parse("HLA-DPA10107-DPB14801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB14801") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB14901():
    result = parse("HLA-DPA10107-DPB14901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB14901") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB15001():
    result = parse("HLA-DPA10107-DPB15001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB15001") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB15101():
    result = parse("HLA-DPA10107-DPB15101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB15101") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB15201():
    result = parse("HLA-DPA10107-DPB15201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB15201") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB15301():
    result = parse("HLA-DPA10107-DPB15301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB15301") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB15401():
    result = parse("HLA-DPA10107-DPB15401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB15401") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB15501():
    result = parse("HLA-DPA10107-DPB15501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB15501") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB15601():
    result = parse("HLA-DPA10107-DPB15601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB15601") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB15801():
    result = parse("HLA-DPA10107-DPB15801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB15801") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB15901():
    result = parse("HLA-DPA10107-DPB15901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB15901") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB16001():
    result = parse("HLA-DPA10107-DPB16001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB16001") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB16201():
    result = parse("HLA-DPA10107-DPB16201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB16201") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB16301():
    result = parse("HLA-DPA10107-DPB16301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB16301") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB16501():
    result = parse("HLA-DPA10107-DPB16501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB16501") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB16601():
    result = parse("HLA-DPA10107-DPB16601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB16601") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB16701():
    result = parse("HLA-DPA10107-DPB16701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB16701") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB16801():
    result = parse("HLA-DPA10107-DPB16801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB16801") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB16901():
    result = parse("HLA-DPA10107-DPB16901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB16901") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB17001():
    result = parse("HLA-DPA10107-DPB17001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB17001") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB17101():
    result = parse("HLA-DPA10107-DPB17101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB17101") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB17201():
    result = parse("HLA-DPA10107-DPB17201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB17201") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB17301():
    result = parse("HLA-DPA10107-DPB17301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB17301") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB17401():
    result = parse("HLA-DPA10107-DPB17401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB17401") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB17501():
    result = parse("HLA-DPA10107-DPB17501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB17501") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB17601():
    result = parse("HLA-DPA10107-DPB17601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB17601") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB17701():
    result = parse("HLA-DPA10107-DPB17701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB17701") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB17801():
    result = parse("HLA-DPA10107-DPB17801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB17801") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB17901():
    result = parse("HLA-DPA10107-DPB17901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB17901") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB18001():
    result = parse("HLA-DPA10107-DPB18001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB18001") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB18101():
    result = parse("HLA-DPA10107-DPB18101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB18101") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB18201():
    result = parse("HLA-DPA10107-DPB18201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB18201") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB18301():
    result = parse("HLA-DPA10107-DPB18301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB18301") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB18401():
    result = parse("HLA-DPA10107-DPB18401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB18401") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB18501():
    result = parse("HLA-DPA10107-DPB18501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB18501") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB18601():
    result = parse("HLA-DPA10107-DPB18601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB18601") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB18701():
    result = parse("HLA-DPA10107-DPB18701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB18701") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB18801():
    result = parse("HLA-DPA10107-DPB18801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB18801") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB18901():
    result = parse("HLA-DPA10107-DPB18901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB18901") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB19001():
    result = parse("HLA-DPA10107-DPB19001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB19001") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB19101():
    result = parse("HLA-DPA10107-DPB19101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB19101") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB19201():
    result = parse("HLA-DPA10107-DPB19201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB19201") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB19301():
    result = parse("HLA-DPA10107-DPB19301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB19301") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB19401():
    result = parse("HLA-DPA10107-DPB19401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB19401") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB19501():
    result = parse("HLA-DPA10107-DPB19501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB19501") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB19601():
    result = parse("HLA-DPA10107-DPB19601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB19601") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB19701():
    result = parse("HLA-DPA10107-DPB19701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB19701") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB19801():
    result = parse("HLA-DPA10107-DPB19801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB19801") to be Pair but got {result}'
    )


def test_HLA_DPA10107_DPB19901():
    result = parse("HLA-DPA10107-DPB19901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10107-DPB19901") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB10101():
    result = parse("HLA-DPA10108-DPB10101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB10101") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB10201():
    result = parse("HLA-DPA10108-DPB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB10201") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB10202():
    result = parse("HLA-DPA10108-DPB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB10202") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB10301():
    result = parse("HLA-DPA10108-DPB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB10301") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB10401():
    result = parse("HLA-DPA10108-DPB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB10401") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB10402():
    result = parse("HLA-DPA10108-DPB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB10402") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB10501():
    result = parse("HLA-DPA10108-DPB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB10501") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB10601():
    result = parse("HLA-DPA10108-DPB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB10601") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB10801():
    result = parse("HLA-DPA10108-DPB10801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB10801") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB10901():
    result = parse("HLA-DPA10108-DPB10901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB10901") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB110001():
    result = parse("HLA-DPA10108-DPB110001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB110001") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB11001():
    result = parse("HLA-DPA10108-DPB11001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB11001") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB110101():
    result = parse("HLA-DPA10108-DPB110101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB110101") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB110201():
    result = parse("HLA-DPA10108-DPB110201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB110201") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB110301():
    result = parse("HLA-DPA10108-DPB110301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB110301") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB110401():
    result = parse("HLA-DPA10108-DPB110401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB110401") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB110501():
    result = parse("HLA-DPA10108-DPB110501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB110501") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB110601():
    result = parse("HLA-DPA10108-DPB110601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB110601") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB110701():
    result = parse("HLA-DPA10108-DPB110701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB110701") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB110801():
    result = parse("HLA-DPA10108-DPB110801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB110801") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB110901():
    result = parse("HLA-DPA10108-DPB110901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB110901") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB111001():
    result = parse("HLA-DPA10108-DPB111001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB111001") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB11101():
    result = parse("HLA-DPA10108-DPB11101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB11101") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB111101():
    result = parse("HLA-DPA10108-DPB111101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB111101") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB111201():
    result = parse("HLA-DPA10108-DPB111201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB111201") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB111301():
    result = parse("HLA-DPA10108-DPB111301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB111301") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB111401():
    result = parse("HLA-DPA10108-DPB111401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB111401") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB111501():
    result = parse("HLA-DPA10108-DPB111501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB111501") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB111601():
    result = parse("HLA-DPA10108-DPB111601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB111601") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB111701():
    result = parse("HLA-DPA10108-DPB111701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB111701") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB111801():
    result = parse("HLA-DPA10108-DPB111801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB111801") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB111901():
    result = parse("HLA-DPA10108-DPB111901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB111901") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB112101():
    result = parse("HLA-DPA10108-DPB112101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB112101") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB112201():
    result = parse("HLA-DPA10108-DPB112201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB112201") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB112301():
    result = parse("HLA-DPA10108-DPB112301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB112301") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB112401():
    result = parse("HLA-DPA10108-DPB112401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB112401") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB112501():
    result = parse("HLA-DPA10108-DPB112501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB112501") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB112601():
    result = parse("HLA-DPA10108-DPB112601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB112601") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB112701():
    result = parse("HLA-DPA10108-DPB112701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB112701") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB112801():
    result = parse("HLA-DPA10108-DPB112801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB112801") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB112901():
    result = parse("HLA-DPA10108-DPB112901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB112901") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB113001():
    result = parse("HLA-DPA10108-DPB113001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB113001") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB11301():
    result = parse("HLA-DPA10108-DPB11301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB11301") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB113101():
    result = parse("HLA-DPA10108-DPB113101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB113101") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB113201():
    result = parse("HLA-DPA10108-DPB113201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB113201") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB113301():
    result = parse("HLA-DPA10108-DPB113301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB113301") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB113401():
    result = parse("HLA-DPA10108-DPB113401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB113401") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB11401():
    result = parse("HLA-DPA10108-DPB11401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB11401") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB11501():
    result = parse("HLA-DPA10108-DPB11501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB11501") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB11601():
    result = parse("HLA-DPA10108-DPB11601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB11601") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB11701():
    result = parse("HLA-DPA10108-DPB11701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB11701") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB11801():
    result = parse("HLA-DPA10108-DPB11801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB11801") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB11901():
    result = parse("HLA-DPA10108-DPB11901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB11901") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB12001():
    result = parse("HLA-DPA10108-DPB12001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB12001") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB12101():
    result = parse("HLA-DPA10108-DPB12101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB12101") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB12201():
    result = parse("HLA-DPA10108-DPB12201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB12201") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB12301():
    result = parse("HLA-DPA10108-DPB12301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB12301") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB12401():
    result = parse("HLA-DPA10108-DPB12401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB12401") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB12501():
    result = parse("HLA-DPA10108-DPB12501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB12501") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB12601():
    result = parse("HLA-DPA10108-DPB12601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB12601") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB12701():
    result = parse("HLA-DPA10108-DPB12701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB12701") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB12801():
    result = parse("HLA-DPA10108-DPB12801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB12801") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB12901():
    result = parse("HLA-DPA10108-DPB12901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB12901") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB13001():
    result = parse("HLA-DPA10108-DPB13001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB13001") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB13101():
    result = parse("HLA-DPA10108-DPB13101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB13101") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB13201():
    result = parse("HLA-DPA10108-DPB13201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB13201") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB13301():
    result = parse("HLA-DPA10108-DPB13301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB13301") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB13401():
    result = parse("HLA-DPA10108-DPB13401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB13401") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB13501():
    result = parse("HLA-DPA10108-DPB13501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB13501") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB13601():
    result = parse("HLA-DPA10108-DPB13601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB13601") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB13701():
    result = parse("HLA-DPA10108-DPB13701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB13701") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB13801():
    result = parse("HLA-DPA10108-DPB13801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB13801") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB13901():
    result = parse("HLA-DPA10108-DPB13901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB13901") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB14001():
    result = parse("HLA-DPA10108-DPB14001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB14001") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB14101():
    result = parse("HLA-DPA10108-DPB14101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB14101") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB14401():
    result = parse("HLA-DPA10108-DPB14401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB14401") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB14501():
    result = parse("HLA-DPA10108-DPB14501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB14501") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB14601():
    result = parse("HLA-DPA10108-DPB14601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB14601") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB14701():
    result = parse("HLA-DPA10108-DPB14701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB14701") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB14801():
    result = parse("HLA-DPA10108-DPB14801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB14801") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB14901():
    result = parse("HLA-DPA10108-DPB14901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB14901") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB15001():
    result = parse("HLA-DPA10108-DPB15001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB15001") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB15101():
    result = parse("HLA-DPA10108-DPB15101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB15101") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB15201():
    result = parse("HLA-DPA10108-DPB15201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB15201") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB15301():
    result = parse("HLA-DPA10108-DPB15301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB15301") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB15401():
    result = parse("HLA-DPA10108-DPB15401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB15401") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB15501():
    result = parse("HLA-DPA10108-DPB15501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB15501") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB15601():
    result = parse("HLA-DPA10108-DPB15601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB15601") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB15801():
    result = parse("HLA-DPA10108-DPB15801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB15801") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB15901():
    result = parse("HLA-DPA10108-DPB15901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB15901") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB16001():
    result = parse("HLA-DPA10108-DPB16001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB16001") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB16201():
    result = parse("HLA-DPA10108-DPB16201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB16201") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB16301():
    result = parse("HLA-DPA10108-DPB16301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB16301") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB16501():
    result = parse("HLA-DPA10108-DPB16501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB16501") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB16601():
    result = parse("HLA-DPA10108-DPB16601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB16601") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB16701():
    result = parse("HLA-DPA10108-DPB16701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB16701") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB16801():
    result = parse("HLA-DPA10108-DPB16801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB16801") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB16901():
    result = parse("HLA-DPA10108-DPB16901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB16901") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB17001():
    result = parse("HLA-DPA10108-DPB17001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB17001") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB17101():
    result = parse("HLA-DPA10108-DPB17101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB17101") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB17201():
    result = parse("HLA-DPA10108-DPB17201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB17201") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB17301():
    result = parse("HLA-DPA10108-DPB17301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB17301") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB17401():
    result = parse("HLA-DPA10108-DPB17401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB17401") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB17501():
    result = parse("HLA-DPA10108-DPB17501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB17501") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB17601():
    result = parse("HLA-DPA10108-DPB17601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB17601") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB17701():
    result = parse("HLA-DPA10108-DPB17701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB17701") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB17801():
    result = parse("HLA-DPA10108-DPB17801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB17801") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB17901():
    result = parse("HLA-DPA10108-DPB17901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB17901") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB18001():
    result = parse("HLA-DPA10108-DPB18001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB18001") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB18101():
    result = parse("HLA-DPA10108-DPB18101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB18101") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB18201():
    result = parse("HLA-DPA10108-DPB18201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB18201") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB18301():
    result = parse("HLA-DPA10108-DPB18301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB18301") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB18401():
    result = parse("HLA-DPA10108-DPB18401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB18401") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB18501():
    result = parse("HLA-DPA10108-DPB18501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB18501") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB18601():
    result = parse("HLA-DPA10108-DPB18601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB18601") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB18701():
    result = parse("HLA-DPA10108-DPB18701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB18701") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB18801():
    result = parse("HLA-DPA10108-DPB18801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB18801") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB18901():
    result = parse("HLA-DPA10108-DPB18901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB18901") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB19001():
    result = parse("HLA-DPA10108-DPB19001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB19001") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB19101():
    result = parse("HLA-DPA10108-DPB19101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB19101") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB19201():
    result = parse("HLA-DPA10108-DPB19201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB19201") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB19301():
    result = parse("HLA-DPA10108-DPB19301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB19301") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB19401():
    result = parse("HLA-DPA10108-DPB19401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB19401") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB19501():
    result = parse("HLA-DPA10108-DPB19501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB19501") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB19601():
    result = parse("HLA-DPA10108-DPB19601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB19601") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB19701():
    result = parse("HLA-DPA10108-DPB19701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB19701") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB19801():
    result = parse("HLA-DPA10108-DPB19801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB19801") to be Pair but got {result}'
    )


def test_HLA_DPA10108_DPB19901():
    result = parse("HLA-DPA10108-DPB19901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10108-DPB19901") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB10101():
    result = parse("HLA-DPA10109-DPB10101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB10101") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB10201():
    result = parse("HLA-DPA10109-DPB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB10201") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB10202():
    result = parse("HLA-DPA10109-DPB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB10202") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB10301():
    result = parse("HLA-DPA10109-DPB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB10301") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB10401():
    result = parse("HLA-DPA10109-DPB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB10401") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB10402():
    result = parse("HLA-DPA10109-DPB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB10402") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB10501():
    result = parse("HLA-DPA10109-DPB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB10501") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB10601():
    result = parse("HLA-DPA10109-DPB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB10601") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB10801():
    result = parse("HLA-DPA10109-DPB10801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB10801") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB10901():
    result = parse("HLA-DPA10109-DPB10901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB10901") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB110001():
    result = parse("HLA-DPA10109-DPB110001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB110001") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB11001():
    result = parse("HLA-DPA10109-DPB11001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB11001") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB110101():
    result = parse("HLA-DPA10109-DPB110101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB110101") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB110201():
    result = parse("HLA-DPA10109-DPB110201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB110201") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB110301():
    result = parse("HLA-DPA10109-DPB110301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB110301") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB110401():
    result = parse("HLA-DPA10109-DPB110401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB110401") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB110501():
    result = parse("HLA-DPA10109-DPB110501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB110501") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB110601():
    result = parse("HLA-DPA10109-DPB110601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB110601") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB110701():
    result = parse("HLA-DPA10109-DPB110701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB110701") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB110801():
    result = parse("HLA-DPA10109-DPB110801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB110801") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB110901():
    result = parse("HLA-DPA10109-DPB110901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB110901") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB111001():
    result = parse("HLA-DPA10109-DPB111001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB111001") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB11101():
    result = parse("HLA-DPA10109-DPB11101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB11101") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB111101():
    result = parse("HLA-DPA10109-DPB111101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB111101") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB111201():
    result = parse("HLA-DPA10109-DPB111201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB111201") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB111301():
    result = parse("HLA-DPA10109-DPB111301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB111301") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB111401():
    result = parse("HLA-DPA10109-DPB111401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB111401") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB111501():
    result = parse("HLA-DPA10109-DPB111501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB111501") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB111601():
    result = parse("HLA-DPA10109-DPB111601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB111601") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB111701():
    result = parse("HLA-DPA10109-DPB111701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB111701") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB111801():
    result = parse("HLA-DPA10109-DPB111801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB111801") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB111901():
    result = parse("HLA-DPA10109-DPB111901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB111901") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB112101():
    result = parse("HLA-DPA10109-DPB112101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB112101") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB112201():
    result = parse("HLA-DPA10109-DPB112201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB112201") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB112301():
    result = parse("HLA-DPA10109-DPB112301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB112301") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB112401():
    result = parse("HLA-DPA10109-DPB112401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB112401") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB112501():
    result = parse("HLA-DPA10109-DPB112501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB112501") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB112601():
    result = parse("HLA-DPA10109-DPB112601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB112601") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB112701():
    result = parse("HLA-DPA10109-DPB112701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB112701") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB112801():
    result = parse("HLA-DPA10109-DPB112801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB112801") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB112901():
    result = parse("HLA-DPA10109-DPB112901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB112901") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB113001():
    result = parse("HLA-DPA10109-DPB113001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB113001") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB11301():
    result = parse("HLA-DPA10109-DPB11301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB11301") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB113101():
    result = parse("HLA-DPA10109-DPB113101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB113101") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB113201():
    result = parse("HLA-DPA10109-DPB113201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB113201") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB113301():
    result = parse("HLA-DPA10109-DPB113301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB113301") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB113401():
    result = parse("HLA-DPA10109-DPB113401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB113401") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB11401():
    result = parse("HLA-DPA10109-DPB11401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB11401") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB11501():
    result = parse("HLA-DPA10109-DPB11501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB11501") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB11601():
    result = parse("HLA-DPA10109-DPB11601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB11601") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB11701():
    result = parse("HLA-DPA10109-DPB11701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB11701") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB11801():
    result = parse("HLA-DPA10109-DPB11801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB11801") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB11901():
    result = parse("HLA-DPA10109-DPB11901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB11901") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB12001():
    result = parse("HLA-DPA10109-DPB12001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB12001") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB12101():
    result = parse("HLA-DPA10109-DPB12101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB12101") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB12201():
    result = parse("HLA-DPA10109-DPB12201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB12201") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB12301():
    result = parse("HLA-DPA10109-DPB12301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB12301") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB12401():
    result = parse("HLA-DPA10109-DPB12401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB12401") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB12501():
    result = parse("HLA-DPA10109-DPB12501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB12501") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB12601():
    result = parse("HLA-DPA10109-DPB12601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB12601") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB12701():
    result = parse("HLA-DPA10109-DPB12701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB12701") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB12801():
    result = parse("HLA-DPA10109-DPB12801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB12801") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB12901():
    result = parse("HLA-DPA10109-DPB12901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB12901") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB13001():
    result = parse("HLA-DPA10109-DPB13001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB13001") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB13101():
    result = parse("HLA-DPA10109-DPB13101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB13101") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB13201():
    result = parse("HLA-DPA10109-DPB13201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB13201") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB13301():
    result = parse("HLA-DPA10109-DPB13301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB13301") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB13401():
    result = parse("HLA-DPA10109-DPB13401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB13401") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB13501():
    result = parse("HLA-DPA10109-DPB13501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB13501") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB13601():
    result = parse("HLA-DPA10109-DPB13601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB13601") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB13701():
    result = parse("HLA-DPA10109-DPB13701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB13701") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB13801():
    result = parse("HLA-DPA10109-DPB13801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB13801") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB13901():
    result = parse("HLA-DPA10109-DPB13901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB13901") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB14001():
    result = parse("HLA-DPA10109-DPB14001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB14001") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB14101():
    result = parse("HLA-DPA10109-DPB14101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB14101") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB14401():
    result = parse("HLA-DPA10109-DPB14401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB14401") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB14501():
    result = parse("HLA-DPA10109-DPB14501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB14501") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB14601():
    result = parse("HLA-DPA10109-DPB14601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB14601") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB14701():
    result = parse("HLA-DPA10109-DPB14701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB14701") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB14801():
    result = parse("HLA-DPA10109-DPB14801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB14801") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB14901():
    result = parse("HLA-DPA10109-DPB14901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB14901") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB15001():
    result = parse("HLA-DPA10109-DPB15001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB15001") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB15101():
    result = parse("HLA-DPA10109-DPB15101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB15101") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB15201():
    result = parse("HLA-DPA10109-DPB15201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB15201") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB15301():
    result = parse("HLA-DPA10109-DPB15301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB15301") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB15401():
    result = parse("HLA-DPA10109-DPB15401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB15401") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB15501():
    result = parse("HLA-DPA10109-DPB15501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB15501") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB15601():
    result = parse("HLA-DPA10109-DPB15601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB15601") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB15801():
    result = parse("HLA-DPA10109-DPB15801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB15801") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB15901():
    result = parse("HLA-DPA10109-DPB15901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB15901") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB16001():
    result = parse("HLA-DPA10109-DPB16001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB16001") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB16201():
    result = parse("HLA-DPA10109-DPB16201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB16201") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB16301():
    result = parse("HLA-DPA10109-DPB16301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB16301") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB16501():
    result = parse("HLA-DPA10109-DPB16501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB16501") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB16601():
    result = parse("HLA-DPA10109-DPB16601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB16601") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB16701():
    result = parse("HLA-DPA10109-DPB16701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB16701") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB16801():
    result = parse("HLA-DPA10109-DPB16801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB16801") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB16901():
    result = parse("HLA-DPA10109-DPB16901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB16901") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB17001():
    result = parse("HLA-DPA10109-DPB17001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB17001") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB17101():
    result = parse("HLA-DPA10109-DPB17101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB17101") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB17201():
    result = parse("HLA-DPA10109-DPB17201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB17201") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB17301():
    result = parse("HLA-DPA10109-DPB17301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB17301") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB17401():
    result = parse("HLA-DPA10109-DPB17401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB17401") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB17501():
    result = parse("HLA-DPA10109-DPB17501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB17501") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB17601():
    result = parse("HLA-DPA10109-DPB17601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB17601") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB17701():
    result = parse("HLA-DPA10109-DPB17701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB17701") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB17801():
    result = parse("HLA-DPA10109-DPB17801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB17801") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB17901():
    result = parse("HLA-DPA10109-DPB17901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB17901") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB18001():
    result = parse("HLA-DPA10109-DPB18001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB18001") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB18101():
    result = parse("HLA-DPA10109-DPB18101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB18101") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB18201():
    result = parse("HLA-DPA10109-DPB18201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB18201") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB18301():
    result = parse("HLA-DPA10109-DPB18301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB18301") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB18401():
    result = parse("HLA-DPA10109-DPB18401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB18401") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB18501():
    result = parse("HLA-DPA10109-DPB18501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB18501") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB18601():
    result = parse("HLA-DPA10109-DPB18601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB18601") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB18701():
    result = parse("HLA-DPA10109-DPB18701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB18701") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB18801():
    result = parse("HLA-DPA10109-DPB18801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB18801") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB18901():
    result = parse("HLA-DPA10109-DPB18901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB18901") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB19001():
    result = parse("HLA-DPA10109-DPB19001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB19001") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB19101():
    result = parse("HLA-DPA10109-DPB19101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB19101") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB19201():
    result = parse("HLA-DPA10109-DPB19201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB19201") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB19301():
    result = parse("HLA-DPA10109-DPB19301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB19301") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB19401():
    result = parse("HLA-DPA10109-DPB19401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB19401") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB19501():
    result = parse("HLA-DPA10109-DPB19501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB19501") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB19601():
    result = parse("HLA-DPA10109-DPB19601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB19601") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB19701():
    result = parse("HLA-DPA10109-DPB19701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB19701") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB19801():
    result = parse("HLA-DPA10109-DPB19801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB19801") to be Pair but got {result}'
    )


def test_HLA_DPA10109_DPB19901():
    result = parse("HLA-DPA10109-DPB19901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10109-DPB19901") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB10101():
    result = parse("HLA-DPA10110-DPB10101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB10101") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB10201():
    result = parse("HLA-DPA10110-DPB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB10201") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB10202():
    result = parse("HLA-DPA10110-DPB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB10202") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB10301():
    result = parse("HLA-DPA10110-DPB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB10301") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB10401():
    result = parse("HLA-DPA10110-DPB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB10401") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB10402():
    result = parse("HLA-DPA10110-DPB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB10402") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB10501():
    result = parse("HLA-DPA10110-DPB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB10501") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB10601():
    result = parse("HLA-DPA10110-DPB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB10601") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB10801():
    result = parse("HLA-DPA10110-DPB10801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB10801") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB10901():
    result = parse("HLA-DPA10110-DPB10901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB10901") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB110001():
    result = parse("HLA-DPA10110-DPB110001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB110001") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB11001():
    result = parse("HLA-DPA10110-DPB11001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB11001") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB110101():
    result = parse("HLA-DPA10110-DPB110101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB110101") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB110201():
    result = parse("HLA-DPA10110-DPB110201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB110201") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB110301():
    result = parse("HLA-DPA10110-DPB110301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB110301") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB110401():
    result = parse("HLA-DPA10110-DPB110401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB110401") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB110501():
    result = parse("HLA-DPA10110-DPB110501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB110501") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB110601():
    result = parse("HLA-DPA10110-DPB110601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB110601") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB110701():
    result = parse("HLA-DPA10110-DPB110701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB110701") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB110801():
    result = parse("HLA-DPA10110-DPB110801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB110801") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB110901():
    result = parse("HLA-DPA10110-DPB110901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB110901") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB111001():
    result = parse("HLA-DPA10110-DPB111001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB111001") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB11101():
    result = parse("HLA-DPA10110-DPB11101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB11101") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB111101():
    result = parse("HLA-DPA10110-DPB111101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB111101") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB111201():
    result = parse("HLA-DPA10110-DPB111201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB111201") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB111301():
    result = parse("HLA-DPA10110-DPB111301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB111301") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB111401():
    result = parse("HLA-DPA10110-DPB111401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB111401") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB111501():
    result = parse("HLA-DPA10110-DPB111501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB111501") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB111601():
    result = parse("HLA-DPA10110-DPB111601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB111601") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB111701():
    result = parse("HLA-DPA10110-DPB111701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB111701") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB111801():
    result = parse("HLA-DPA10110-DPB111801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB111801") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB111901():
    result = parse("HLA-DPA10110-DPB111901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB111901") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB112101():
    result = parse("HLA-DPA10110-DPB112101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB112101") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB112201():
    result = parse("HLA-DPA10110-DPB112201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB112201") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB112301():
    result = parse("HLA-DPA10110-DPB112301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB112301") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB112401():
    result = parse("HLA-DPA10110-DPB112401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB112401") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB112501():
    result = parse("HLA-DPA10110-DPB112501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB112501") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB112601():
    result = parse("HLA-DPA10110-DPB112601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB112601") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB112701():
    result = parse("HLA-DPA10110-DPB112701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB112701") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB112801():
    result = parse("HLA-DPA10110-DPB112801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB112801") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB112901():
    result = parse("HLA-DPA10110-DPB112901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB112901") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB113001():
    result = parse("HLA-DPA10110-DPB113001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB113001") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB11301():
    result = parse("HLA-DPA10110-DPB11301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB11301") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB113101():
    result = parse("HLA-DPA10110-DPB113101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB113101") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB113201():
    result = parse("HLA-DPA10110-DPB113201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB113201") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB113301():
    result = parse("HLA-DPA10110-DPB113301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB113301") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB113401():
    result = parse("HLA-DPA10110-DPB113401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB113401") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB11401():
    result = parse("HLA-DPA10110-DPB11401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB11401") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB11501():
    result = parse("HLA-DPA10110-DPB11501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB11501") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB11601():
    result = parse("HLA-DPA10110-DPB11601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB11601") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB11701():
    result = parse("HLA-DPA10110-DPB11701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB11701") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB11801():
    result = parse("HLA-DPA10110-DPB11801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB11801") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB11901():
    result = parse("HLA-DPA10110-DPB11901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB11901") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB12001():
    result = parse("HLA-DPA10110-DPB12001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB12001") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB12101():
    result = parse("HLA-DPA10110-DPB12101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB12101") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB12201():
    result = parse("HLA-DPA10110-DPB12201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB12201") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB12301():
    result = parse("HLA-DPA10110-DPB12301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB12301") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB12401():
    result = parse("HLA-DPA10110-DPB12401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB12401") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB12501():
    result = parse("HLA-DPA10110-DPB12501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB12501") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB12601():
    result = parse("HLA-DPA10110-DPB12601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB12601") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB12701():
    result = parse("HLA-DPA10110-DPB12701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB12701") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB12801():
    result = parse("HLA-DPA10110-DPB12801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB12801") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB12901():
    result = parse("HLA-DPA10110-DPB12901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB12901") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB13001():
    result = parse("HLA-DPA10110-DPB13001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB13001") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB13101():
    result = parse("HLA-DPA10110-DPB13101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB13101") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB13201():
    result = parse("HLA-DPA10110-DPB13201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB13201") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB13301():
    result = parse("HLA-DPA10110-DPB13301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB13301") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB13401():
    result = parse("HLA-DPA10110-DPB13401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB13401") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB13501():
    result = parse("HLA-DPA10110-DPB13501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB13501") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB13601():
    result = parse("HLA-DPA10110-DPB13601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB13601") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB13701():
    result = parse("HLA-DPA10110-DPB13701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB13701") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB13801():
    result = parse("HLA-DPA10110-DPB13801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB13801") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB13901():
    result = parse("HLA-DPA10110-DPB13901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB13901") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB14001():
    result = parse("HLA-DPA10110-DPB14001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB14001") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB14101():
    result = parse("HLA-DPA10110-DPB14101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB14101") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB14401():
    result = parse("HLA-DPA10110-DPB14401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB14401") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB14501():
    result = parse("HLA-DPA10110-DPB14501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB14501") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB14601():
    result = parse("HLA-DPA10110-DPB14601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB14601") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB14701():
    result = parse("HLA-DPA10110-DPB14701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB14701") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB14801():
    result = parse("HLA-DPA10110-DPB14801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB14801") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB14901():
    result = parse("HLA-DPA10110-DPB14901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB14901") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB15001():
    result = parse("HLA-DPA10110-DPB15001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB15001") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB15101():
    result = parse("HLA-DPA10110-DPB15101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB15101") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB15201():
    result = parse("HLA-DPA10110-DPB15201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB15201") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB15301():
    result = parse("HLA-DPA10110-DPB15301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB15301") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB15401():
    result = parse("HLA-DPA10110-DPB15401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB15401") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB15501():
    result = parse("HLA-DPA10110-DPB15501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB15501") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB15601():
    result = parse("HLA-DPA10110-DPB15601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB15601") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB15801():
    result = parse("HLA-DPA10110-DPB15801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB15801") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB15901():
    result = parse("HLA-DPA10110-DPB15901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB15901") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB16001():
    result = parse("HLA-DPA10110-DPB16001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB16001") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB16201():
    result = parse("HLA-DPA10110-DPB16201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB16201") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB16301():
    result = parse("HLA-DPA10110-DPB16301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB16301") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB16501():
    result = parse("HLA-DPA10110-DPB16501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB16501") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB16601():
    result = parse("HLA-DPA10110-DPB16601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB16601") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB16701():
    result = parse("HLA-DPA10110-DPB16701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB16701") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB16801():
    result = parse("HLA-DPA10110-DPB16801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB16801") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB16901():
    result = parse("HLA-DPA10110-DPB16901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB16901") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB17001():
    result = parse("HLA-DPA10110-DPB17001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB17001") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB17101():
    result = parse("HLA-DPA10110-DPB17101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB17101") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB17201():
    result = parse("HLA-DPA10110-DPB17201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB17201") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB17301():
    result = parse("HLA-DPA10110-DPB17301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB17301") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB17401():
    result = parse("HLA-DPA10110-DPB17401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB17401") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB17501():
    result = parse("HLA-DPA10110-DPB17501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB17501") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB17601():
    result = parse("HLA-DPA10110-DPB17601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB17601") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB17701():
    result = parse("HLA-DPA10110-DPB17701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB17701") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB17801():
    result = parse("HLA-DPA10110-DPB17801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB17801") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB17901():
    result = parse("HLA-DPA10110-DPB17901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB17901") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB18001():
    result = parse("HLA-DPA10110-DPB18001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB18001") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB18101():
    result = parse("HLA-DPA10110-DPB18101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB18101") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB18201():
    result = parse("HLA-DPA10110-DPB18201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB18201") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB18301():
    result = parse("HLA-DPA10110-DPB18301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB18301") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB18401():
    result = parse("HLA-DPA10110-DPB18401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB18401") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB18501():
    result = parse("HLA-DPA10110-DPB18501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB18501") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB18601():
    result = parse("HLA-DPA10110-DPB18601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB18601") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB18701():
    result = parse("HLA-DPA10110-DPB18701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB18701") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB18801():
    result = parse("HLA-DPA10110-DPB18801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB18801") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB18901():
    result = parse("HLA-DPA10110-DPB18901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB18901") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB19001():
    result = parse("HLA-DPA10110-DPB19001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB19001") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB19101():
    result = parse("HLA-DPA10110-DPB19101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB19101") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB19201():
    result = parse("HLA-DPA10110-DPB19201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB19201") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB19301():
    result = parse("HLA-DPA10110-DPB19301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB19301") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB19401():
    result = parse("HLA-DPA10110-DPB19401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB19401") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB19501():
    result = parse("HLA-DPA10110-DPB19501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB19501") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB19601():
    result = parse("HLA-DPA10110-DPB19601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB19601") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB19701():
    result = parse("HLA-DPA10110-DPB19701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB19701") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB19801():
    result = parse("HLA-DPA10110-DPB19801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB19801") to be Pair but got {result}'
    )


def test_HLA_DPA10110_DPB19901():
    result = parse("HLA-DPA10110-DPB19901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10110-DPB19901") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB10101():
    result = parse("HLA-DPA10201-DPB10101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB10101") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB10201():
    result = parse("HLA-DPA10201-DPB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB10201") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB10202():
    result = parse("HLA-DPA10201-DPB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB10202") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB10301():
    result = parse("HLA-DPA10201-DPB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB10301") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB10401():
    result = parse("HLA-DPA10201-DPB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB10401") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB10402():
    result = parse("HLA-DPA10201-DPB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB10402") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB10501():
    result = parse("HLA-DPA10201-DPB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB10501") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB10601():
    result = parse("HLA-DPA10201-DPB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB10601") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB10801():
    result = parse("HLA-DPA10201-DPB10801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB10801") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB10901():
    result = parse("HLA-DPA10201-DPB10901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB10901") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB110001():
    result = parse("HLA-DPA10201-DPB110001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB110001") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB11001():
    result = parse("HLA-DPA10201-DPB11001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB11001") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB110101():
    result = parse("HLA-DPA10201-DPB110101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB110101") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB110201():
    result = parse("HLA-DPA10201-DPB110201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB110201") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB110301():
    result = parse("HLA-DPA10201-DPB110301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB110301") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB110401():
    result = parse("HLA-DPA10201-DPB110401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB110401") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB110501():
    result = parse("HLA-DPA10201-DPB110501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB110501") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB110601():
    result = parse("HLA-DPA10201-DPB110601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB110601") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB110701():
    result = parse("HLA-DPA10201-DPB110701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB110701") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB110801():
    result = parse("HLA-DPA10201-DPB110801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB110801") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB110901():
    result = parse("HLA-DPA10201-DPB110901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB110901") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB111001():
    result = parse("HLA-DPA10201-DPB111001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB111001") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB11101():
    result = parse("HLA-DPA10201-DPB11101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB11101") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB111101():
    result = parse("HLA-DPA10201-DPB111101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB111101") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB111201():
    result = parse("HLA-DPA10201-DPB111201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB111201") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB111301():
    result = parse("HLA-DPA10201-DPB111301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB111301") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB111401():
    result = parse("HLA-DPA10201-DPB111401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB111401") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB111501():
    result = parse("HLA-DPA10201-DPB111501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB111501") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB111601():
    result = parse("HLA-DPA10201-DPB111601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB111601") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB111701():
    result = parse("HLA-DPA10201-DPB111701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB111701") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB111801():
    result = parse("HLA-DPA10201-DPB111801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB111801") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB111901():
    result = parse("HLA-DPA10201-DPB111901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB111901") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB112101():
    result = parse("HLA-DPA10201-DPB112101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB112101") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB112201():
    result = parse("HLA-DPA10201-DPB112201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB112201") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB112301():
    result = parse("HLA-DPA10201-DPB112301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB112301") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB112401():
    result = parse("HLA-DPA10201-DPB112401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB112401") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB112501():
    result = parse("HLA-DPA10201-DPB112501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB112501") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB112601():
    result = parse("HLA-DPA10201-DPB112601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB112601") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB112701():
    result = parse("HLA-DPA10201-DPB112701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB112701") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB112801():
    result = parse("HLA-DPA10201-DPB112801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB112801") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB112901():
    result = parse("HLA-DPA10201-DPB112901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB112901") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB113001():
    result = parse("HLA-DPA10201-DPB113001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB113001") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB11301():
    result = parse("HLA-DPA10201-DPB11301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB11301") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB113101():
    result = parse("HLA-DPA10201-DPB113101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB113101") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB113201():
    result = parse("HLA-DPA10201-DPB113201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB113201") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB113301():
    result = parse("HLA-DPA10201-DPB113301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB113301") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB113401():
    result = parse("HLA-DPA10201-DPB113401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB113401") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB11401():
    result = parse("HLA-DPA10201-DPB11401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB11401") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB11501():
    result = parse("HLA-DPA10201-DPB11501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB11501") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB11601():
    result = parse("HLA-DPA10201-DPB11601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB11601") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB11701():
    result = parse("HLA-DPA10201-DPB11701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB11701") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB11801():
    result = parse("HLA-DPA10201-DPB11801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB11801") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB11901():
    result = parse("HLA-DPA10201-DPB11901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB11901") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB12001():
    result = parse("HLA-DPA10201-DPB12001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB12001") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB12101():
    result = parse("HLA-DPA10201-DPB12101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB12101") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB12201():
    result = parse("HLA-DPA10201-DPB12201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB12201") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB12301():
    result = parse("HLA-DPA10201-DPB12301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB12301") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB12401():
    result = parse("HLA-DPA10201-DPB12401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB12401") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB12501():
    result = parse("HLA-DPA10201-DPB12501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB12501") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB12601():
    result = parse("HLA-DPA10201-DPB12601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB12601") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB12701():
    result = parse("HLA-DPA10201-DPB12701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB12701") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB12801():
    result = parse("HLA-DPA10201-DPB12801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB12801") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB12901():
    result = parse("HLA-DPA10201-DPB12901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB12901") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB13001():
    result = parse("HLA-DPA10201-DPB13001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB13001") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB13101():
    result = parse("HLA-DPA10201-DPB13101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB13101") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB13201():
    result = parse("HLA-DPA10201-DPB13201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB13201") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB13301():
    result = parse("HLA-DPA10201-DPB13301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB13301") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB13401():
    result = parse("HLA-DPA10201-DPB13401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB13401") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB13501():
    result = parse("HLA-DPA10201-DPB13501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB13501") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB13601():
    result = parse("HLA-DPA10201-DPB13601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB13601") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB13701():
    result = parse("HLA-DPA10201-DPB13701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB13701") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB13801():
    result = parse("HLA-DPA10201-DPB13801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB13801") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB13901():
    result = parse("HLA-DPA10201-DPB13901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB13901") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB14001():
    result = parse("HLA-DPA10201-DPB14001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB14001") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB14101():
    result = parse("HLA-DPA10201-DPB14101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB14101") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB14401():
    result = parse("HLA-DPA10201-DPB14401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB14401") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB14501():
    result = parse("HLA-DPA10201-DPB14501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB14501") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB14601():
    result = parse("HLA-DPA10201-DPB14601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB14601") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB14701():
    result = parse("HLA-DPA10201-DPB14701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB14701") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB14801():
    result = parse("HLA-DPA10201-DPB14801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB14801") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB14901():
    result = parse("HLA-DPA10201-DPB14901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB14901") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB15001():
    result = parse("HLA-DPA10201-DPB15001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB15001") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB15101():
    result = parse("HLA-DPA10201-DPB15101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB15101") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB15201():
    result = parse("HLA-DPA10201-DPB15201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB15201") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB15301():
    result = parse("HLA-DPA10201-DPB15301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB15301") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB15401():
    result = parse("HLA-DPA10201-DPB15401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB15401") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB15501():
    result = parse("HLA-DPA10201-DPB15501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB15501") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB15601():
    result = parse("HLA-DPA10201-DPB15601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB15601") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB15801():
    result = parse("HLA-DPA10201-DPB15801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB15801") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB15901():
    result = parse("HLA-DPA10201-DPB15901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB15901") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB16001():
    result = parse("HLA-DPA10201-DPB16001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB16001") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB16201():
    result = parse("HLA-DPA10201-DPB16201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB16201") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB16301():
    result = parse("HLA-DPA10201-DPB16301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB16301") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB16501():
    result = parse("HLA-DPA10201-DPB16501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB16501") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB16601():
    result = parse("HLA-DPA10201-DPB16601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB16601") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB16701():
    result = parse("HLA-DPA10201-DPB16701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB16701") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB16801():
    result = parse("HLA-DPA10201-DPB16801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB16801") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB16901():
    result = parse("HLA-DPA10201-DPB16901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB16901") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB17001():
    result = parse("HLA-DPA10201-DPB17001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB17001") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB17101():
    result = parse("HLA-DPA10201-DPB17101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB17101") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB17201():
    result = parse("HLA-DPA10201-DPB17201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB17201") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB17301():
    result = parse("HLA-DPA10201-DPB17301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB17301") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB17401():
    result = parse("HLA-DPA10201-DPB17401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB17401") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB17501():
    result = parse("HLA-DPA10201-DPB17501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB17501") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB17601():
    result = parse("HLA-DPA10201-DPB17601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB17601") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB17701():
    result = parse("HLA-DPA10201-DPB17701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB17701") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB17801():
    result = parse("HLA-DPA10201-DPB17801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB17801") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB17901():
    result = parse("HLA-DPA10201-DPB17901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB17901") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB18001():
    result = parse("HLA-DPA10201-DPB18001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB18001") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB18101():
    result = parse("HLA-DPA10201-DPB18101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB18101") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB18201():
    result = parse("HLA-DPA10201-DPB18201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB18201") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB18301():
    result = parse("HLA-DPA10201-DPB18301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB18301") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB18401():
    result = parse("HLA-DPA10201-DPB18401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB18401") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB18501():
    result = parse("HLA-DPA10201-DPB18501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB18501") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB18601():
    result = parse("HLA-DPA10201-DPB18601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB18601") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB18701():
    result = parse("HLA-DPA10201-DPB18701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB18701") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB18801():
    result = parse("HLA-DPA10201-DPB18801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB18801") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB18901():
    result = parse("HLA-DPA10201-DPB18901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB18901") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB19001():
    result = parse("HLA-DPA10201-DPB19001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB19001") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB19101():
    result = parse("HLA-DPA10201-DPB19101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB19101") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB19201():
    result = parse("HLA-DPA10201-DPB19201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB19201") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB19301():
    result = parse("HLA-DPA10201-DPB19301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB19301") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB19401():
    result = parse("HLA-DPA10201-DPB19401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB19401") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB19501():
    result = parse("HLA-DPA10201-DPB19501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB19501") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB19601():
    result = parse("HLA-DPA10201-DPB19601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB19601") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB19701():
    result = parse("HLA-DPA10201-DPB19701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB19701") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB19801():
    result = parse("HLA-DPA10201-DPB19801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB19801") to be Pair but got {result}'
    )


def test_HLA_DPA10201_DPB19901():
    result = parse("HLA-DPA10201-DPB19901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10201-DPB19901") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB10101():
    result = parse("HLA-DPA10202-DPB10101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB10101") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB10201():
    result = parse("HLA-DPA10202-DPB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB10201") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB10202():
    result = parse("HLA-DPA10202-DPB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB10202") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB10301():
    result = parse("HLA-DPA10202-DPB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB10301") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB10401():
    result = parse("HLA-DPA10202-DPB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB10401") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB10402():
    result = parse("HLA-DPA10202-DPB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB10402") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB10501():
    result = parse("HLA-DPA10202-DPB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB10501") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB10601():
    result = parse("HLA-DPA10202-DPB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB10601") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB10801():
    result = parse("HLA-DPA10202-DPB10801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB10801") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB10901():
    result = parse("HLA-DPA10202-DPB10901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB10901") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB110001():
    result = parse("HLA-DPA10202-DPB110001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB110001") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB11001():
    result = parse("HLA-DPA10202-DPB11001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB11001") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB110101():
    result = parse("HLA-DPA10202-DPB110101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB110101") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB110201():
    result = parse("HLA-DPA10202-DPB110201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB110201") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB110301():
    result = parse("HLA-DPA10202-DPB110301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB110301") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB110401():
    result = parse("HLA-DPA10202-DPB110401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB110401") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB110501():
    result = parse("HLA-DPA10202-DPB110501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB110501") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB110601():
    result = parse("HLA-DPA10202-DPB110601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB110601") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB110701():
    result = parse("HLA-DPA10202-DPB110701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB110701") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB110801():
    result = parse("HLA-DPA10202-DPB110801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB110801") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB110901():
    result = parse("HLA-DPA10202-DPB110901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB110901") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB111001():
    result = parse("HLA-DPA10202-DPB111001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB111001") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB11101():
    result = parse("HLA-DPA10202-DPB11101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB11101") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB111101():
    result = parse("HLA-DPA10202-DPB111101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB111101") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB111201():
    result = parse("HLA-DPA10202-DPB111201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB111201") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB111301():
    result = parse("HLA-DPA10202-DPB111301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB111301") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB111401():
    result = parse("HLA-DPA10202-DPB111401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB111401") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB111501():
    result = parse("HLA-DPA10202-DPB111501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB111501") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB111601():
    result = parse("HLA-DPA10202-DPB111601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB111601") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB111701():
    result = parse("HLA-DPA10202-DPB111701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB111701") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB111801():
    result = parse("HLA-DPA10202-DPB111801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB111801") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB111901():
    result = parse("HLA-DPA10202-DPB111901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB111901") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB112101():
    result = parse("HLA-DPA10202-DPB112101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB112101") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB112201():
    result = parse("HLA-DPA10202-DPB112201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB112201") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB112301():
    result = parse("HLA-DPA10202-DPB112301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB112301") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB112401():
    result = parse("HLA-DPA10202-DPB112401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB112401") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB112501():
    result = parse("HLA-DPA10202-DPB112501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB112501") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB112601():
    result = parse("HLA-DPA10202-DPB112601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB112601") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB112701():
    result = parse("HLA-DPA10202-DPB112701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB112701") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB112801():
    result = parse("HLA-DPA10202-DPB112801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB112801") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB112901():
    result = parse("HLA-DPA10202-DPB112901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB112901") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB113001():
    result = parse("HLA-DPA10202-DPB113001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB113001") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB11301():
    result = parse("HLA-DPA10202-DPB11301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB11301") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB113101():
    result = parse("HLA-DPA10202-DPB113101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB113101") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB113201():
    result = parse("HLA-DPA10202-DPB113201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB113201") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB113301():
    result = parse("HLA-DPA10202-DPB113301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB113301") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB113401():
    result = parse("HLA-DPA10202-DPB113401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB113401") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB11401():
    result = parse("HLA-DPA10202-DPB11401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB11401") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB11501():
    result = parse("HLA-DPA10202-DPB11501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB11501") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB11601():
    result = parse("HLA-DPA10202-DPB11601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB11601") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB11701():
    result = parse("HLA-DPA10202-DPB11701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB11701") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB11801():
    result = parse("HLA-DPA10202-DPB11801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB11801") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB11901():
    result = parse("HLA-DPA10202-DPB11901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB11901") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB12001():
    result = parse("HLA-DPA10202-DPB12001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB12001") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB12101():
    result = parse("HLA-DPA10202-DPB12101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB12101") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB12201():
    result = parse("HLA-DPA10202-DPB12201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB12201") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB12301():
    result = parse("HLA-DPA10202-DPB12301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB12301") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB12401():
    result = parse("HLA-DPA10202-DPB12401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB12401") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB12501():
    result = parse("HLA-DPA10202-DPB12501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB12501") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB12601():
    result = parse("HLA-DPA10202-DPB12601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB12601") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB12701():
    result = parse("HLA-DPA10202-DPB12701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB12701") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB12801():
    result = parse("HLA-DPA10202-DPB12801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB12801") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB12901():
    result = parse("HLA-DPA10202-DPB12901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB12901") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB13001():
    result = parse("HLA-DPA10202-DPB13001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB13001") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB13101():
    result = parse("HLA-DPA10202-DPB13101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB13101") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB13201():
    result = parse("HLA-DPA10202-DPB13201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB13201") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB13301():
    result = parse("HLA-DPA10202-DPB13301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB13301") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB13401():
    result = parse("HLA-DPA10202-DPB13401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB13401") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB13501():
    result = parse("HLA-DPA10202-DPB13501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB13501") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB13601():
    result = parse("HLA-DPA10202-DPB13601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB13601") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB13701():
    result = parse("HLA-DPA10202-DPB13701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB13701") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB13801():
    result = parse("HLA-DPA10202-DPB13801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB13801") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB13901():
    result = parse("HLA-DPA10202-DPB13901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB13901") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB14001():
    result = parse("HLA-DPA10202-DPB14001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB14001") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB14101():
    result = parse("HLA-DPA10202-DPB14101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB14101") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB14401():
    result = parse("HLA-DPA10202-DPB14401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB14401") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB14501():
    result = parse("HLA-DPA10202-DPB14501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB14501") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB14601():
    result = parse("HLA-DPA10202-DPB14601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB14601") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB14701():
    result = parse("HLA-DPA10202-DPB14701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB14701") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB14801():
    result = parse("HLA-DPA10202-DPB14801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB14801") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB14901():
    result = parse("HLA-DPA10202-DPB14901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB14901") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB15001():
    result = parse("HLA-DPA10202-DPB15001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB15001") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB15101():
    result = parse("HLA-DPA10202-DPB15101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB15101") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB15201():
    result = parse("HLA-DPA10202-DPB15201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB15201") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB15301():
    result = parse("HLA-DPA10202-DPB15301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB15301") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB15401():
    result = parse("HLA-DPA10202-DPB15401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB15401") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB15501():
    result = parse("HLA-DPA10202-DPB15501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB15501") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB15601():
    result = parse("HLA-DPA10202-DPB15601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB15601") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB15801():
    result = parse("HLA-DPA10202-DPB15801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB15801") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB15901():
    result = parse("HLA-DPA10202-DPB15901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB15901") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB16001():
    result = parse("HLA-DPA10202-DPB16001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB16001") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB16201():
    result = parse("HLA-DPA10202-DPB16201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB16201") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB16301():
    result = parse("HLA-DPA10202-DPB16301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB16301") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB16501():
    result = parse("HLA-DPA10202-DPB16501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB16501") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB16601():
    result = parse("HLA-DPA10202-DPB16601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB16601") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB16701():
    result = parse("HLA-DPA10202-DPB16701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB16701") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB16801():
    result = parse("HLA-DPA10202-DPB16801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB16801") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB16901():
    result = parse("HLA-DPA10202-DPB16901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB16901") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB17001():
    result = parse("HLA-DPA10202-DPB17001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB17001") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB17101():
    result = parse("HLA-DPA10202-DPB17101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB17101") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB17201():
    result = parse("HLA-DPA10202-DPB17201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB17201") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB17301():
    result = parse("HLA-DPA10202-DPB17301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB17301") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB17401():
    result = parse("HLA-DPA10202-DPB17401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB17401") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB17501():
    result = parse("HLA-DPA10202-DPB17501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB17501") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB17601():
    result = parse("HLA-DPA10202-DPB17601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB17601") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB17701():
    result = parse("HLA-DPA10202-DPB17701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB17701") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB17801():
    result = parse("HLA-DPA10202-DPB17801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB17801") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB17901():
    result = parse("HLA-DPA10202-DPB17901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB17901") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB18001():
    result = parse("HLA-DPA10202-DPB18001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB18001") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB18101():
    result = parse("HLA-DPA10202-DPB18101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB18101") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB18201():
    result = parse("HLA-DPA10202-DPB18201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB18201") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB18301():
    result = parse("HLA-DPA10202-DPB18301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB18301") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB18401():
    result = parse("HLA-DPA10202-DPB18401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB18401") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB18501():
    result = parse("HLA-DPA10202-DPB18501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB18501") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB18601():
    result = parse("HLA-DPA10202-DPB18601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB18601") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB18701():
    result = parse("HLA-DPA10202-DPB18701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB18701") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB18801():
    result = parse("HLA-DPA10202-DPB18801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB18801") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB18901():
    result = parse("HLA-DPA10202-DPB18901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB18901") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB19001():
    result = parse("HLA-DPA10202-DPB19001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB19001") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB19101():
    result = parse("HLA-DPA10202-DPB19101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB19101") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB19201():
    result = parse("HLA-DPA10202-DPB19201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB19201") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB19301():
    result = parse("HLA-DPA10202-DPB19301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB19301") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB19401():
    result = parse("HLA-DPA10202-DPB19401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB19401") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB19501():
    result = parse("HLA-DPA10202-DPB19501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB19501") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB19601():
    result = parse("HLA-DPA10202-DPB19601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB19601") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB19701():
    result = parse("HLA-DPA10202-DPB19701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB19701") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB19801():
    result = parse("HLA-DPA10202-DPB19801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB19801") to be Pair but got {result}'
    )


def test_HLA_DPA10202_DPB19901():
    result = parse("HLA-DPA10202-DPB19901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10202-DPB19901") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB10101():
    result = parse("HLA-DPA10203-DPB10101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB10101") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB10201():
    result = parse("HLA-DPA10203-DPB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB10201") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB10202():
    result = parse("HLA-DPA10203-DPB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB10202") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB10301():
    result = parse("HLA-DPA10203-DPB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB10301") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB10401():
    result = parse("HLA-DPA10203-DPB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB10401") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB10402():
    result = parse("HLA-DPA10203-DPB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB10402") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB10501():
    result = parse("HLA-DPA10203-DPB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB10501") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB10601():
    result = parse("HLA-DPA10203-DPB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB10601") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB10801():
    result = parse("HLA-DPA10203-DPB10801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB10801") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB10901():
    result = parse("HLA-DPA10203-DPB10901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB10901") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB110001():
    result = parse("HLA-DPA10203-DPB110001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB110001") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB11001():
    result = parse("HLA-DPA10203-DPB11001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB11001") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB110101():
    result = parse("HLA-DPA10203-DPB110101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB110101") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB110201():
    result = parse("HLA-DPA10203-DPB110201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB110201") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB110301():
    result = parse("HLA-DPA10203-DPB110301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB110301") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB110401():
    result = parse("HLA-DPA10203-DPB110401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB110401") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB110501():
    result = parse("HLA-DPA10203-DPB110501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB110501") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB110601():
    result = parse("HLA-DPA10203-DPB110601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB110601") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB110701():
    result = parse("HLA-DPA10203-DPB110701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB110701") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB110801():
    result = parse("HLA-DPA10203-DPB110801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB110801") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB110901():
    result = parse("HLA-DPA10203-DPB110901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB110901") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB111001():
    result = parse("HLA-DPA10203-DPB111001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB111001") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB11101():
    result = parse("HLA-DPA10203-DPB11101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB11101") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB111101():
    result = parse("HLA-DPA10203-DPB111101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB111101") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB111201():
    result = parse("HLA-DPA10203-DPB111201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB111201") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB111301():
    result = parse("HLA-DPA10203-DPB111301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB111301") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB111401():
    result = parse("HLA-DPA10203-DPB111401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB111401") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB111501():
    result = parse("HLA-DPA10203-DPB111501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB111501") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB111601():
    result = parse("HLA-DPA10203-DPB111601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB111601") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB111701():
    result = parse("HLA-DPA10203-DPB111701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB111701") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB111801():
    result = parse("HLA-DPA10203-DPB111801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB111801") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB111901():
    result = parse("HLA-DPA10203-DPB111901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB111901") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB112101():
    result = parse("HLA-DPA10203-DPB112101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB112101") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB112201():
    result = parse("HLA-DPA10203-DPB112201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB112201") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB112301():
    result = parse("HLA-DPA10203-DPB112301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB112301") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB112401():
    result = parse("HLA-DPA10203-DPB112401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB112401") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB112501():
    result = parse("HLA-DPA10203-DPB112501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB112501") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB112601():
    result = parse("HLA-DPA10203-DPB112601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB112601") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB112701():
    result = parse("HLA-DPA10203-DPB112701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB112701") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB112801():
    result = parse("HLA-DPA10203-DPB112801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB112801") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB112901():
    result = parse("HLA-DPA10203-DPB112901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB112901") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB113001():
    result = parse("HLA-DPA10203-DPB113001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB113001") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB11301():
    result = parse("HLA-DPA10203-DPB11301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB11301") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB113101():
    result = parse("HLA-DPA10203-DPB113101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB113101") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB113201():
    result = parse("HLA-DPA10203-DPB113201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB113201") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB113301():
    result = parse("HLA-DPA10203-DPB113301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB113301") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB113401():
    result = parse("HLA-DPA10203-DPB113401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB113401") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB11401():
    result = parse("HLA-DPA10203-DPB11401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB11401") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB11501():
    result = parse("HLA-DPA10203-DPB11501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB11501") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB11601():
    result = parse("HLA-DPA10203-DPB11601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB11601") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB11701():
    result = parse("HLA-DPA10203-DPB11701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB11701") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB11801():
    result = parse("HLA-DPA10203-DPB11801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB11801") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB11901():
    result = parse("HLA-DPA10203-DPB11901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB11901") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB12001():
    result = parse("HLA-DPA10203-DPB12001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB12001") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB12101():
    result = parse("HLA-DPA10203-DPB12101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB12101") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB12201():
    result = parse("HLA-DPA10203-DPB12201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB12201") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB12301():
    result = parse("HLA-DPA10203-DPB12301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB12301") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB12401():
    result = parse("HLA-DPA10203-DPB12401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB12401") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB12501():
    result = parse("HLA-DPA10203-DPB12501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB12501") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB12601():
    result = parse("HLA-DPA10203-DPB12601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB12601") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB12701():
    result = parse("HLA-DPA10203-DPB12701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB12701") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB12801():
    result = parse("HLA-DPA10203-DPB12801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB12801") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB12901():
    result = parse("HLA-DPA10203-DPB12901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB12901") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB13001():
    result = parse("HLA-DPA10203-DPB13001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB13001") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB13101():
    result = parse("HLA-DPA10203-DPB13101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB13101") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB13201():
    result = parse("HLA-DPA10203-DPB13201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB13201") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB13301():
    result = parse("HLA-DPA10203-DPB13301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB13301") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB13401():
    result = parse("HLA-DPA10203-DPB13401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB13401") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB13501():
    result = parse("HLA-DPA10203-DPB13501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB13501") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB13601():
    result = parse("HLA-DPA10203-DPB13601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB13601") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB13701():
    result = parse("HLA-DPA10203-DPB13701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB13701") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB13801():
    result = parse("HLA-DPA10203-DPB13801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB13801") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB13901():
    result = parse("HLA-DPA10203-DPB13901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB13901") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB14001():
    result = parse("HLA-DPA10203-DPB14001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB14001") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB14101():
    result = parse("HLA-DPA10203-DPB14101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB14101") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB14401():
    result = parse("HLA-DPA10203-DPB14401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB14401") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB14501():
    result = parse("HLA-DPA10203-DPB14501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB14501") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB14601():
    result = parse("HLA-DPA10203-DPB14601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB14601") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB14701():
    result = parse("HLA-DPA10203-DPB14701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB14701") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB14801():
    result = parse("HLA-DPA10203-DPB14801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB14801") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB14901():
    result = parse("HLA-DPA10203-DPB14901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB14901") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB15001():
    result = parse("HLA-DPA10203-DPB15001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB15001") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB15101():
    result = parse("HLA-DPA10203-DPB15101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB15101") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB15201():
    result = parse("HLA-DPA10203-DPB15201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB15201") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB15301():
    result = parse("HLA-DPA10203-DPB15301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB15301") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB15401():
    result = parse("HLA-DPA10203-DPB15401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB15401") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB15501():
    result = parse("HLA-DPA10203-DPB15501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB15501") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB15601():
    result = parse("HLA-DPA10203-DPB15601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB15601") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB15801():
    result = parse("HLA-DPA10203-DPB15801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB15801") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB15901():
    result = parse("HLA-DPA10203-DPB15901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB15901") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB16001():
    result = parse("HLA-DPA10203-DPB16001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB16001") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB16201():
    result = parse("HLA-DPA10203-DPB16201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB16201") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB16301():
    result = parse("HLA-DPA10203-DPB16301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB16301") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB16501():
    result = parse("HLA-DPA10203-DPB16501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB16501") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB16601():
    result = parse("HLA-DPA10203-DPB16601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB16601") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB16701():
    result = parse("HLA-DPA10203-DPB16701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB16701") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB16801():
    result = parse("HLA-DPA10203-DPB16801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB16801") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB16901():
    result = parse("HLA-DPA10203-DPB16901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB16901") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB17001():
    result = parse("HLA-DPA10203-DPB17001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB17001") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB17101():
    result = parse("HLA-DPA10203-DPB17101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB17101") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB17201():
    result = parse("HLA-DPA10203-DPB17201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB17201") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB17301():
    result = parse("HLA-DPA10203-DPB17301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB17301") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB17401():
    result = parse("HLA-DPA10203-DPB17401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB17401") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB17501():
    result = parse("HLA-DPA10203-DPB17501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB17501") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB17601():
    result = parse("HLA-DPA10203-DPB17601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB17601") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB17701():
    result = parse("HLA-DPA10203-DPB17701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB17701") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB17801():
    result = parse("HLA-DPA10203-DPB17801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB17801") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB17901():
    result = parse("HLA-DPA10203-DPB17901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB17901") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB18001():
    result = parse("HLA-DPA10203-DPB18001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB18001") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB18101():
    result = parse("HLA-DPA10203-DPB18101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB18101") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB18201():
    result = parse("HLA-DPA10203-DPB18201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB18201") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB18301():
    result = parse("HLA-DPA10203-DPB18301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB18301") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB18401():
    result = parse("HLA-DPA10203-DPB18401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB18401") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB18501():
    result = parse("HLA-DPA10203-DPB18501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB18501") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB18601():
    result = parse("HLA-DPA10203-DPB18601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB18601") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB18701():
    result = parse("HLA-DPA10203-DPB18701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB18701") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB18801():
    result = parse("HLA-DPA10203-DPB18801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB18801") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB18901():
    result = parse("HLA-DPA10203-DPB18901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB18901") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB19001():
    result = parse("HLA-DPA10203-DPB19001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB19001") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB19101():
    result = parse("HLA-DPA10203-DPB19101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB19101") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB19201():
    result = parse("HLA-DPA10203-DPB19201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB19201") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB19301():
    result = parse("HLA-DPA10203-DPB19301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB19301") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB19401():
    result = parse("HLA-DPA10203-DPB19401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB19401") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB19501():
    result = parse("HLA-DPA10203-DPB19501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB19501") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB19601():
    result = parse("HLA-DPA10203-DPB19601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB19601") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB19701():
    result = parse("HLA-DPA10203-DPB19701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB19701") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB19801():
    result = parse("HLA-DPA10203-DPB19801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB19801") to be Pair but got {result}'
    )


def test_HLA_DPA10203_DPB19901():
    result = parse("HLA-DPA10203-DPB19901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10203-DPB19901") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB10101():
    result = parse("HLA-DPA10204-DPB10101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB10101") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB10201():
    result = parse("HLA-DPA10204-DPB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB10201") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB10202():
    result = parse("HLA-DPA10204-DPB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB10202") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB10301():
    result = parse("HLA-DPA10204-DPB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB10301") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB10401():
    result = parse("HLA-DPA10204-DPB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB10401") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB10402():
    result = parse("HLA-DPA10204-DPB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB10402") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB10501():
    result = parse("HLA-DPA10204-DPB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB10501") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB10601():
    result = parse("HLA-DPA10204-DPB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB10601") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB10801():
    result = parse("HLA-DPA10204-DPB10801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB10801") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB10901():
    result = parse("HLA-DPA10204-DPB10901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB10901") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB110001():
    result = parse("HLA-DPA10204-DPB110001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB110001") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB11001():
    result = parse("HLA-DPA10204-DPB11001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB11001") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB110101():
    result = parse("HLA-DPA10204-DPB110101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB110101") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB110201():
    result = parse("HLA-DPA10204-DPB110201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB110201") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB110301():
    result = parse("HLA-DPA10204-DPB110301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB110301") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB110401():
    result = parse("HLA-DPA10204-DPB110401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB110401") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB110501():
    result = parse("HLA-DPA10204-DPB110501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB110501") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB110601():
    result = parse("HLA-DPA10204-DPB110601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB110601") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB110701():
    result = parse("HLA-DPA10204-DPB110701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB110701") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB110801():
    result = parse("HLA-DPA10204-DPB110801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB110801") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB110901():
    result = parse("HLA-DPA10204-DPB110901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB110901") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB111001():
    result = parse("HLA-DPA10204-DPB111001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB111001") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB11101():
    result = parse("HLA-DPA10204-DPB11101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB11101") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB111101():
    result = parse("HLA-DPA10204-DPB111101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB111101") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB111201():
    result = parse("HLA-DPA10204-DPB111201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB111201") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB111301():
    result = parse("HLA-DPA10204-DPB111301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB111301") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB111401():
    result = parse("HLA-DPA10204-DPB111401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB111401") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB111501():
    result = parse("HLA-DPA10204-DPB111501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB111501") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB111601():
    result = parse("HLA-DPA10204-DPB111601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB111601") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB111701():
    result = parse("HLA-DPA10204-DPB111701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB111701") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB111801():
    result = parse("HLA-DPA10204-DPB111801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB111801") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB111901():
    result = parse("HLA-DPA10204-DPB111901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB111901") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB112101():
    result = parse("HLA-DPA10204-DPB112101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB112101") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB112201():
    result = parse("HLA-DPA10204-DPB112201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB112201") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB112301():
    result = parse("HLA-DPA10204-DPB112301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB112301") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB112401():
    result = parse("HLA-DPA10204-DPB112401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB112401") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB112501():
    result = parse("HLA-DPA10204-DPB112501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB112501") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB112601():
    result = parse("HLA-DPA10204-DPB112601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB112601") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB112701():
    result = parse("HLA-DPA10204-DPB112701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB112701") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB112801():
    result = parse("HLA-DPA10204-DPB112801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB112801") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB112901():
    result = parse("HLA-DPA10204-DPB112901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB112901") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB113001():
    result = parse("HLA-DPA10204-DPB113001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB113001") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB11301():
    result = parse("HLA-DPA10204-DPB11301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB11301") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB113101():
    result = parse("HLA-DPA10204-DPB113101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB113101") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB113201():
    result = parse("HLA-DPA10204-DPB113201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB113201") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB113301():
    result = parse("HLA-DPA10204-DPB113301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB113301") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB113401():
    result = parse("HLA-DPA10204-DPB113401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB113401") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB11401():
    result = parse("HLA-DPA10204-DPB11401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB11401") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB11501():
    result = parse("HLA-DPA10204-DPB11501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB11501") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB11601():
    result = parse("HLA-DPA10204-DPB11601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB11601") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB11701():
    result = parse("HLA-DPA10204-DPB11701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB11701") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB11801():
    result = parse("HLA-DPA10204-DPB11801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB11801") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB11901():
    result = parse("HLA-DPA10204-DPB11901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB11901") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB12001():
    result = parse("HLA-DPA10204-DPB12001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB12001") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB12101():
    result = parse("HLA-DPA10204-DPB12101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB12101") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB12201():
    result = parse("HLA-DPA10204-DPB12201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB12201") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB12301():
    result = parse("HLA-DPA10204-DPB12301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB12301") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB12401():
    result = parse("HLA-DPA10204-DPB12401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB12401") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB12501():
    result = parse("HLA-DPA10204-DPB12501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB12501") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB12601():
    result = parse("HLA-DPA10204-DPB12601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB12601") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB12701():
    result = parse("HLA-DPA10204-DPB12701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB12701") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB12801():
    result = parse("HLA-DPA10204-DPB12801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB12801") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB12901():
    result = parse("HLA-DPA10204-DPB12901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB12901") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB13001():
    result = parse("HLA-DPA10204-DPB13001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB13001") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB13101():
    result = parse("HLA-DPA10204-DPB13101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB13101") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB13201():
    result = parse("HLA-DPA10204-DPB13201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB13201") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB13301():
    result = parse("HLA-DPA10204-DPB13301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB13301") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB13401():
    result = parse("HLA-DPA10204-DPB13401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB13401") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB13501():
    result = parse("HLA-DPA10204-DPB13501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB13501") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB13601():
    result = parse("HLA-DPA10204-DPB13601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB13601") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB13701():
    result = parse("HLA-DPA10204-DPB13701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB13701") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB13801():
    result = parse("HLA-DPA10204-DPB13801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB13801") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB13901():
    result = parse("HLA-DPA10204-DPB13901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB13901") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB14001():
    result = parse("HLA-DPA10204-DPB14001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB14001") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB14101():
    result = parse("HLA-DPA10204-DPB14101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB14101") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB14401():
    result = parse("HLA-DPA10204-DPB14401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB14401") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB14501():
    result = parse("HLA-DPA10204-DPB14501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB14501") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB14601():
    result = parse("HLA-DPA10204-DPB14601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB14601") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB14701():
    result = parse("HLA-DPA10204-DPB14701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB14701") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB14801():
    result = parse("HLA-DPA10204-DPB14801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB14801") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB14901():
    result = parse("HLA-DPA10204-DPB14901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB14901") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB15001():
    result = parse("HLA-DPA10204-DPB15001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB15001") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB15101():
    result = parse("HLA-DPA10204-DPB15101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB15101") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB15201():
    result = parse("HLA-DPA10204-DPB15201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB15201") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB15301():
    result = parse("HLA-DPA10204-DPB15301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB15301") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB15401():
    result = parse("HLA-DPA10204-DPB15401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB15401") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB15501():
    result = parse("HLA-DPA10204-DPB15501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB15501") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB15601():
    result = parse("HLA-DPA10204-DPB15601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB15601") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB15801():
    result = parse("HLA-DPA10204-DPB15801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB15801") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB15901():
    result = parse("HLA-DPA10204-DPB15901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB15901") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB16001():
    result = parse("HLA-DPA10204-DPB16001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB16001") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB16201():
    result = parse("HLA-DPA10204-DPB16201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB16201") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB16301():
    result = parse("HLA-DPA10204-DPB16301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB16301") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB16501():
    result = parse("HLA-DPA10204-DPB16501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB16501") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB16601():
    result = parse("HLA-DPA10204-DPB16601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB16601") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB16701():
    result = parse("HLA-DPA10204-DPB16701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB16701") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB16801():
    result = parse("HLA-DPA10204-DPB16801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB16801") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB16901():
    result = parse("HLA-DPA10204-DPB16901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB16901") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB17001():
    result = parse("HLA-DPA10204-DPB17001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB17001") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB17101():
    result = parse("HLA-DPA10204-DPB17101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB17101") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB17201():
    result = parse("HLA-DPA10204-DPB17201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB17201") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB17301():
    result = parse("HLA-DPA10204-DPB17301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB17301") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB17401():
    result = parse("HLA-DPA10204-DPB17401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB17401") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB17501():
    result = parse("HLA-DPA10204-DPB17501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB17501") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB17601():
    result = parse("HLA-DPA10204-DPB17601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB17601") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB17701():
    result = parse("HLA-DPA10204-DPB17701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB17701") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB17801():
    result = parse("HLA-DPA10204-DPB17801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB17801") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB17901():
    result = parse("HLA-DPA10204-DPB17901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB17901") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB18001():
    result = parse("HLA-DPA10204-DPB18001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB18001") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB18101():
    result = parse("HLA-DPA10204-DPB18101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB18101") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB18201():
    result = parse("HLA-DPA10204-DPB18201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB18201") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB18301():
    result = parse("HLA-DPA10204-DPB18301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB18301") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB18401():
    result = parse("HLA-DPA10204-DPB18401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB18401") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB18501():
    result = parse("HLA-DPA10204-DPB18501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB18501") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB18601():
    result = parse("HLA-DPA10204-DPB18601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB18601") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB18701():
    result = parse("HLA-DPA10204-DPB18701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB18701") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB18801():
    result = parse("HLA-DPA10204-DPB18801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB18801") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB18901():
    result = parse("HLA-DPA10204-DPB18901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB18901") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB19001():
    result = parse("HLA-DPA10204-DPB19001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB19001") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB19101():
    result = parse("HLA-DPA10204-DPB19101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB19101") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB19201():
    result = parse("HLA-DPA10204-DPB19201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB19201") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB19301():
    result = parse("HLA-DPA10204-DPB19301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB19301") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB19401():
    result = parse("HLA-DPA10204-DPB19401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB19401") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB19501():
    result = parse("HLA-DPA10204-DPB19501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB19501") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB19601():
    result = parse("HLA-DPA10204-DPB19601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB19601") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB19701():
    result = parse("HLA-DPA10204-DPB19701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB19701") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB19801():
    result = parse("HLA-DPA10204-DPB19801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB19801") to be Pair but got {result}'
    )


def test_HLA_DPA10204_DPB19901():
    result = parse("HLA-DPA10204-DPB19901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10204-DPB19901") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB10101():
    result = parse("HLA-DPA10301-DPB10101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB10101") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB10201():
    result = parse("HLA-DPA10301-DPB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB10201") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB10202():
    result = parse("HLA-DPA10301-DPB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB10202") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB10301():
    result = parse("HLA-DPA10301-DPB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB10301") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB10401():
    result = parse("HLA-DPA10301-DPB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB10401") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB10402():
    result = parse("HLA-DPA10301-DPB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB10402") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB10501():
    result = parse("HLA-DPA10301-DPB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB10501") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB10601():
    result = parse("HLA-DPA10301-DPB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB10601") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB10801():
    result = parse("HLA-DPA10301-DPB10801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB10801") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB10901():
    result = parse("HLA-DPA10301-DPB10901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB10901") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB110001():
    result = parse("HLA-DPA10301-DPB110001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB110001") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB11001():
    result = parse("HLA-DPA10301-DPB11001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB11001") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB110101():
    result = parse("HLA-DPA10301-DPB110101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB110101") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB110201():
    result = parse("HLA-DPA10301-DPB110201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB110201") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB110301():
    result = parse("HLA-DPA10301-DPB110301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB110301") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB110401():
    result = parse("HLA-DPA10301-DPB110401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB110401") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB110501():
    result = parse("HLA-DPA10301-DPB110501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB110501") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB110601():
    result = parse("HLA-DPA10301-DPB110601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB110601") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB110701():
    result = parse("HLA-DPA10301-DPB110701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB110701") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB110801():
    result = parse("HLA-DPA10301-DPB110801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB110801") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB110901():
    result = parse("HLA-DPA10301-DPB110901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB110901") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB111001():
    result = parse("HLA-DPA10301-DPB111001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB111001") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB11101():
    result = parse("HLA-DPA10301-DPB11101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB11101") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB111101():
    result = parse("HLA-DPA10301-DPB111101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB111101") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB111201():
    result = parse("HLA-DPA10301-DPB111201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB111201") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB111301():
    result = parse("HLA-DPA10301-DPB111301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB111301") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB111401():
    result = parse("HLA-DPA10301-DPB111401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB111401") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB111501():
    result = parse("HLA-DPA10301-DPB111501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB111501") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB111601():
    result = parse("HLA-DPA10301-DPB111601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB111601") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB111701():
    result = parse("HLA-DPA10301-DPB111701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB111701") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB111801():
    result = parse("HLA-DPA10301-DPB111801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB111801") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB111901():
    result = parse("HLA-DPA10301-DPB111901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB111901") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB112101():
    result = parse("HLA-DPA10301-DPB112101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB112101") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB112201():
    result = parse("HLA-DPA10301-DPB112201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB112201") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB112301():
    result = parse("HLA-DPA10301-DPB112301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB112301") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB112401():
    result = parse("HLA-DPA10301-DPB112401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB112401") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB112501():
    result = parse("HLA-DPA10301-DPB112501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB112501") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB112601():
    result = parse("HLA-DPA10301-DPB112601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB112601") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB112701():
    result = parse("HLA-DPA10301-DPB112701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB112701") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB112801():
    result = parse("HLA-DPA10301-DPB112801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB112801") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB112901():
    result = parse("HLA-DPA10301-DPB112901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB112901") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB113001():
    result = parse("HLA-DPA10301-DPB113001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB113001") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB11301():
    result = parse("HLA-DPA10301-DPB11301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB11301") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB113101():
    result = parse("HLA-DPA10301-DPB113101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB113101") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB113201():
    result = parse("HLA-DPA10301-DPB113201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB113201") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB113301():
    result = parse("HLA-DPA10301-DPB113301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB113301") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB113401():
    result = parse("HLA-DPA10301-DPB113401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB113401") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB11401():
    result = parse("HLA-DPA10301-DPB11401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB11401") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB11501():
    result = parse("HLA-DPA10301-DPB11501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB11501") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB11601():
    result = parse("HLA-DPA10301-DPB11601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB11601") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB11701():
    result = parse("HLA-DPA10301-DPB11701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB11701") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB11801():
    result = parse("HLA-DPA10301-DPB11801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB11801") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB11901():
    result = parse("HLA-DPA10301-DPB11901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB11901") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB12001():
    result = parse("HLA-DPA10301-DPB12001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB12001") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB12101():
    result = parse("HLA-DPA10301-DPB12101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB12101") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB12201():
    result = parse("HLA-DPA10301-DPB12201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB12201") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB12301():
    result = parse("HLA-DPA10301-DPB12301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB12301") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB12401():
    result = parse("HLA-DPA10301-DPB12401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB12401") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB12501():
    result = parse("HLA-DPA10301-DPB12501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB12501") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB12601():
    result = parse("HLA-DPA10301-DPB12601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB12601") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB12701():
    result = parse("HLA-DPA10301-DPB12701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB12701") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB12801():
    result = parse("HLA-DPA10301-DPB12801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB12801") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB12901():
    result = parse("HLA-DPA10301-DPB12901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB12901") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB13001():
    result = parse("HLA-DPA10301-DPB13001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB13001") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB13101():
    result = parse("HLA-DPA10301-DPB13101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB13101") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB13201():
    result = parse("HLA-DPA10301-DPB13201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB13201") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB13301():
    result = parse("HLA-DPA10301-DPB13301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB13301") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB13401():
    result = parse("HLA-DPA10301-DPB13401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB13401") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB13501():
    result = parse("HLA-DPA10301-DPB13501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB13501") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB13601():
    result = parse("HLA-DPA10301-DPB13601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB13601") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB13701():
    result = parse("HLA-DPA10301-DPB13701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB13701") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB13801():
    result = parse("HLA-DPA10301-DPB13801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB13801") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB13901():
    result = parse("HLA-DPA10301-DPB13901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB13901") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB14001():
    result = parse("HLA-DPA10301-DPB14001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB14001") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB14101():
    result = parse("HLA-DPA10301-DPB14101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB14101") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB14401():
    result = parse("HLA-DPA10301-DPB14401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB14401") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB14501():
    result = parse("HLA-DPA10301-DPB14501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB14501") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB14601():
    result = parse("HLA-DPA10301-DPB14601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB14601") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB14701():
    result = parse("HLA-DPA10301-DPB14701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB14701") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB14801():
    result = parse("HLA-DPA10301-DPB14801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB14801") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB14901():
    result = parse("HLA-DPA10301-DPB14901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB14901") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB15001():
    result = parse("HLA-DPA10301-DPB15001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB15001") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB15101():
    result = parse("HLA-DPA10301-DPB15101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB15101") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB15201():
    result = parse("HLA-DPA10301-DPB15201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB15201") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB15301():
    result = parse("HLA-DPA10301-DPB15301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB15301") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB15401():
    result = parse("HLA-DPA10301-DPB15401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB15401") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB15501():
    result = parse("HLA-DPA10301-DPB15501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB15501") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB15601():
    result = parse("HLA-DPA10301-DPB15601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB15601") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB15801():
    result = parse("HLA-DPA10301-DPB15801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB15801") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB15901():
    result = parse("HLA-DPA10301-DPB15901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB15901") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB16001():
    result = parse("HLA-DPA10301-DPB16001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB16001") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB16201():
    result = parse("HLA-DPA10301-DPB16201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB16201") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB16301():
    result = parse("HLA-DPA10301-DPB16301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB16301") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB16501():
    result = parse("HLA-DPA10301-DPB16501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB16501") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB16601():
    result = parse("HLA-DPA10301-DPB16601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB16601") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB16701():
    result = parse("HLA-DPA10301-DPB16701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB16701") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB16801():
    result = parse("HLA-DPA10301-DPB16801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB16801") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB16901():
    result = parse("HLA-DPA10301-DPB16901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB16901") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB17001():
    result = parse("HLA-DPA10301-DPB17001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB17001") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB17101():
    result = parse("HLA-DPA10301-DPB17101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB17101") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB17201():
    result = parse("HLA-DPA10301-DPB17201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB17201") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB17301():
    result = parse("HLA-DPA10301-DPB17301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB17301") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB17401():
    result = parse("HLA-DPA10301-DPB17401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB17401") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB17501():
    result = parse("HLA-DPA10301-DPB17501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB17501") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB17601():
    result = parse("HLA-DPA10301-DPB17601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB17601") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB17701():
    result = parse("HLA-DPA10301-DPB17701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB17701") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB17801():
    result = parse("HLA-DPA10301-DPB17801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB17801") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB17901():
    result = parse("HLA-DPA10301-DPB17901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB17901") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB18001():
    result = parse("HLA-DPA10301-DPB18001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB18001") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB18101():
    result = parse("HLA-DPA10301-DPB18101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB18101") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB18201():
    result = parse("HLA-DPA10301-DPB18201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB18201") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB18301():
    result = parse("HLA-DPA10301-DPB18301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB18301") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB18401():
    result = parse("HLA-DPA10301-DPB18401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB18401") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB18501():
    result = parse("HLA-DPA10301-DPB18501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB18501") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB18601():
    result = parse("HLA-DPA10301-DPB18601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB18601") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB18701():
    result = parse("HLA-DPA10301-DPB18701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB18701") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB18801():
    result = parse("HLA-DPA10301-DPB18801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB18801") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB18901():
    result = parse("HLA-DPA10301-DPB18901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB18901") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB19001():
    result = parse("HLA-DPA10301-DPB19001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB19001") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB19101():
    result = parse("HLA-DPA10301-DPB19101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB19101") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB19201():
    result = parse("HLA-DPA10301-DPB19201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB19201") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB19301():
    result = parse("HLA-DPA10301-DPB19301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB19301") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB19401():
    result = parse("HLA-DPA10301-DPB19401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB19401") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB19501():
    result = parse("HLA-DPA10301-DPB19501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB19501") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB19601():
    result = parse("HLA-DPA10301-DPB19601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB19601") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB19701():
    result = parse("HLA-DPA10301-DPB19701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB19701") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB19801():
    result = parse("HLA-DPA10301-DPB19801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB19801") to be Pair but got {result}'
    )


def test_HLA_DPA10301_DPB19901():
    result = parse("HLA-DPA10301-DPB19901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10301-DPB19901") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB10101():
    result = parse("HLA-DPA10302-DPB10101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB10101") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB10201():
    result = parse("HLA-DPA10302-DPB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB10201") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB10202():
    result = parse("HLA-DPA10302-DPB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB10202") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB10301():
    result = parse("HLA-DPA10302-DPB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB10301") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB10401():
    result = parse("HLA-DPA10302-DPB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB10401") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB10402():
    result = parse("HLA-DPA10302-DPB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB10402") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB10501():
    result = parse("HLA-DPA10302-DPB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB10501") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB10601():
    result = parse("HLA-DPA10302-DPB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB10601") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB10801():
    result = parse("HLA-DPA10302-DPB10801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB10801") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB10901():
    result = parse("HLA-DPA10302-DPB10901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB10901") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB110001():
    result = parse("HLA-DPA10302-DPB110001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB110001") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB11001():
    result = parse("HLA-DPA10302-DPB11001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB11001") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB110101():
    result = parse("HLA-DPA10302-DPB110101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB110101") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB110201():
    result = parse("HLA-DPA10302-DPB110201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB110201") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB110301():
    result = parse("HLA-DPA10302-DPB110301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB110301") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB110401():
    result = parse("HLA-DPA10302-DPB110401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB110401") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB110501():
    result = parse("HLA-DPA10302-DPB110501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB110501") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB110601():
    result = parse("HLA-DPA10302-DPB110601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB110601") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB110701():
    result = parse("HLA-DPA10302-DPB110701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB110701") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB110801():
    result = parse("HLA-DPA10302-DPB110801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB110801") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB110901():
    result = parse("HLA-DPA10302-DPB110901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB110901") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB111001():
    result = parse("HLA-DPA10302-DPB111001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB111001") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB11101():
    result = parse("HLA-DPA10302-DPB11101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB11101") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB111101():
    result = parse("HLA-DPA10302-DPB111101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB111101") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB111201():
    result = parse("HLA-DPA10302-DPB111201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB111201") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB111301():
    result = parse("HLA-DPA10302-DPB111301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB111301") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB111401():
    result = parse("HLA-DPA10302-DPB111401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB111401") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB111501():
    result = parse("HLA-DPA10302-DPB111501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB111501") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB111601():
    result = parse("HLA-DPA10302-DPB111601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB111601") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB111701():
    result = parse("HLA-DPA10302-DPB111701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB111701") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB111801():
    result = parse("HLA-DPA10302-DPB111801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB111801") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB111901():
    result = parse("HLA-DPA10302-DPB111901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB111901") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB112101():
    result = parse("HLA-DPA10302-DPB112101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB112101") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB112201():
    result = parse("HLA-DPA10302-DPB112201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB112201") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB112301():
    result = parse("HLA-DPA10302-DPB112301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB112301") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB112401():
    result = parse("HLA-DPA10302-DPB112401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB112401") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB112501():
    result = parse("HLA-DPA10302-DPB112501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB112501") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB112601():
    result = parse("HLA-DPA10302-DPB112601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB112601") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB112701():
    result = parse("HLA-DPA10302-DPB112701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB112701") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB112801():
    result = parse("HLA-DPA10302-DPB112801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB112801") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB112901():
    result = parse("HLA-DPA10302-DPB112901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB112901") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB113001():
    result = parse("HLA-DPA10302-DPB113001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB113001") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB11301():
    result = parse("HLA-DPA10302-DPB11301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB11301") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB113101():
    result = parse("HLA-DPA10302-DPB113101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB113101") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB113201():
    result = parse("HLA-DPA10302-DPB113201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB113201") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB113301():
    result = parse("HLA-DPA10302-DPB113301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB113301") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB113401():
    result = parse("HLA-DPA10302-DPB113401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB113401") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB11401():
    result = parse("HLA-DPA10302-DPB11401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB11401") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB11501():
    result = parse("HLA-DPA10302-DPB11501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB11501") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB11601():
    result = parse("HLA-DPA10302-DPB11601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB11601") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB11701():
    result = parse("HLA-DPA10302-DPB11701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB11701") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB11801():
    result = parse("HLA-DPA10302-DPB11801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB11801") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB11901():
    result = parse("HLA-DPA10302-DPB11901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB11901") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB12001():
    result = parse("HLA-DPA10302-DPB12001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB12001") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB12101():
    result = parse("HLA-DPA10302-DPB12101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB12101") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB12201():
    result = parse("HLA-DPA10302-DPB12201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB12201") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB12301():
    result = parse("HLA-DPA10302-DPB12301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB12301") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB12401():
    result = parse("HLA-DPA10302-DPB12401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB12401") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB12501():
    result = parse("HLA-DPA10302-DPB12501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB12501") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB12601():
    result = parse("HLA-DPA10302-DPB12601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB12601") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB12701():
    result = parse("HLA-DPA10302-DPB12701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB12701") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB12801():
    result = parse("HLA-DPA10302-DPB12801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB12801") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB12901():
    result = parse("HLA-DPA10302-DPB12901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB12901") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB13001():
    result = parse("HLA-DPA10302-DPB13001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB13001") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB13101():
    result = parse("HLA-DPA10302-DPB13101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB13101") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB13201():
    result = parse("HLA-DPA10302-DPB13201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB13201") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB13301():
    result = parse("HLA-DPA10302-DPB13301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB13301") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB13401():
    result = parse("HLA-DPA10302-DPB13401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB13401") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB13501():
    result = parse("HLA-DPA10302-DPB13501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB13501") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB13601():
    result = parse("HLA-DPA10302-DPB13601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB13601") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB13701():
    result = parse("HLA-DPA10302-DPB13701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB13701") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB13801():
    result = parse("HLA-DPA10302-DPB13801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB13801") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB13901():
    result = parse("HLA-DPA10302-DPB13901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB13901") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB14001():
    result = parse("HLA-DPA10302-DPB14001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB14001") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB14101():
    result = parse("HLA-DPA10302-DPB14101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB14101") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB14401():
    result = parse("HLA-DPA10302-DPB14401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB14401") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB14501():
    result = parse("HLA-DPA10302-DPB14501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB14501") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB14601():
    result = parse("HLA-DPA10302-DPB14601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB14601") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB14701():
    result = parse("HLA-DPA10302-DPB14701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB14701") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB14801():
    result = parse("HLA-DPA10302-DPB14801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB14801") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB14901():
    result = parse("HLA-DPA10302-DPB14901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB14901") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB15001():
    result = parse("HLA-DPA10302-DPB15001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB15001") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB15101():
    result = parse("HLA-DPA10302-DPB15101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB15101") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB15201():
    result = parse("HLA-DPA10302-DPB15201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB15201") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB15301():
    result = parse("HLA-DPA10302-DPB15301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB15301") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB15401():
    result = parse("HLA-DPA10302-DPB15401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB15401") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB15501():
    result = parse("HLA-DPA10302-DPB15501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB15501") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB15601():
    result = parse("HLA-DPA10302-DPB15601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB15601") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB15801():
    result = parse("HLA-DPA10302-DPB15801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB15801") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB15901():
    result = parse("HLA-DPA10302-DPB15901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB15901") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB16001():
    result = parse("HLA-DPA10302-DPB16001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB16001") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB16201():
    result = parse("HLA-DPA10302-DPB16201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB16201") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB16301():
    result = parse("HLA-DPA10302-DPB16301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB16301") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB16501():
    result = parse("HLA-DPA10302-DPB16501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB16501") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB16601():
    result = parse("HLA-DPA10302-DPB16601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB16601") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB16701():
    result = parse("HLA-DPA10302-DPB16701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB16701") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB16801():
    result = parse("HLA-DPA10302-DPB16801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB16801") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB16901():
    result = parse("HLA-DPA10302-DPB16901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB16901") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB17001():
    result = parse("HLA-DPA10302-DPB17001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB17001") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB17101():
    result = parse("HLA-DPA10302-DPB17101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB17101") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB17201():
    result = parse("HLA-DPA10302-DPB17201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB17201") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB17301():
    result = parse("HLA-DPA10302-DPB17301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB17301") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB17401():
    result = parse("HLA-DPA10302-DPB17401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB17401") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB17501():
    result = parse("HLA-DPA10302-DPB17501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB17501") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB17601():
    result = parse("HLA-DPA10302-DPB17601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB17601") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB17701():
    result = parse("HLA-DPA10302-DPB17701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB17701") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB17801():
    result = parse("HLA-DPA10302-DPB17801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB17801") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB17901():
    result = parse("HLA-DPA10302-DPB17901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB17901") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB18001():
    result = parse("HLA-DPA10302-DPB18001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB18001") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB18101():
    result = parse("HLA-DPA10302-DPB18101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB18101") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB18201():
    result = parse("HLA-DPA10302-DPB18201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB18201") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB18301():
    result = parse("HLA-DPA10302-DPB18301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB18301") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB18401():
    result = parse("HLA-DPA10302-DPB18401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB18401") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB18501():
    result = parse("HLA-DPA10302-DPB18501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB18501") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB18601():
    result = parse("HLA-DPA10302-DPB18601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB18601") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB18701():
    result = parse("HLA-DPA10302-DPB18701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB18701") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB18801():
    result = parse("HLA-DPA10302-DPB18801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB18801") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB18901():
    result = parse("HLA-DPA10302-DPB18901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB18901") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB19001():
    result = parse("HLA-DPA10302-DPB19001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB19001") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB19101():
    result = parse("HLA-DPA10302-DPB19101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB19101") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB19201():
    result = parse("HLA-DPA10302-DPB19201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB19201") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB19301():
    result = parse("HLA-DPA10302-DPB19301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB19301") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB19401():
    result = parse("HLA-DPA10302-DPB19401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB19401") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB19501():
    result = parse("HLA-DPA10302-DPB19501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB19501") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB19601():
    result = parse("HLA-DPA10302-DPB19601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB19601") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB19701():
    result = parse("HLA-DPA10302-DPB19701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB19701") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB19801():
    result = parse("HLA-DPA10302-DPB19801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB19801") to be Pair but got {result}'
    )


def test_HLA_DPA10302_DPB19901():
    result = parse("HLA-DPA10302-DPB19901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10302-DPB19901") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB10101():
    result = parse("HLA-DPA10303-DPB10101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB10101") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB10201():
    result = parse("HLA-DPA10303-DPB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB10201") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB10202():
    result = parse("HLA-DPA10303-DPB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB10202") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB10301():
    result = parse("HLA-DPA10303-DPB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB10301") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB10401():
    result = parse("HLA-DPA10303-DPB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB10401") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB10402():
    result = parse("HLA-DPA10303-DPB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB10402") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB10501():
    result = parse("HLA-DPA10303-DPB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB10501") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB10601():
    result = parse("HLA-DPA10303-DPB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB10601") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB10801():
    result = parse("HLA-DPA10303-DPB10801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB10801") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB10901():
    result = parse("HLA-DPA10303-DPB10901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB10901") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB110001():
    result = parse("HLA-DPA10303-DPB110001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB110001") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB11001():
    result = parse("HLA-DPA10303-DPB11001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB11001") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB110101():
    result = parse("HLA-DPA10303-DPB110101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB110101") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB110201():
    result = parse("HLA-DPA10303-DPB110201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB110201") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB110301():
    result = parse("HLA-DPA10303-DPB110301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB110301") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB110401():
    result = parse("HLA-DPA10303-DPB110401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB110401") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB110501():
    result = parse("HLA-DPA10303-DPB110501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB110501") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB110601():
    result = parse("HLA-DPA10303-DPB110601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB110601") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB110701():
    result = parse("HLA-DPA10303-DPB110701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB110701") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB110801():
    result = parse("HLA-DPA10303-DPB110801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB110801") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB110901():
    result = parse("HLA-DPA10303-DPB110901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB110901") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB111001():
    result = parse("HLA-DPA10303-DPB111001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB111001") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB11101():
    result = parse("HLA-DPA10303-DPB11101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB11101") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB111101():
    result = parse("HLA-DPA10303-DPB111101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB111101") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB111201():
    result = parse("HLA-DPA10303-DPB111201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB111201") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB111301():
    result = parse("HLA-DPA10303-DPB111301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB111301") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB111401():
    result = parse("HLA-DPA10303-DPB111401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB111401") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB111501():
    result = parse("HLA-DPA10303-DPB111501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB111501") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB111601():
    result = parse("HLA-DPA10303-DPB111601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB111601") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB111701():
    result = parse("HLA-DPA10303-DPB111701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB111701") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB111801():
    result = parse("HLA-DPA10303-DPB111801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB111801") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB111901():
    result = parse("HLA-DPA10303-DPB111901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB111901") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB112101():
    result = parse("HLA-DPA10303-DPB112101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB112101") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB112201():
    result = parse("HLA-DPA10303-DPB112201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB112201") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB112301():
    result = parse("HLA-DPA10303-DPB112301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB112301") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB112401():
    result = parse("HLA-DPA10303-DPB112401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB112401") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB112501():
    result = parse("HLA-DPA10303-DPB112501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB112501") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB112601():
    result = parse("HLA-DPA10303-DPB112601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB112601") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB112701():
    result = parse("HLA-DPA10303-DPB112701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB112701") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB112801():
    result = parse("HLA-DPA10303-DPB112801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB112801") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB112901():
    result = parse("HLA-DPA10303-DPB112901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB112901") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB113001():
    result = parse("HLA-DPA10303-DPB113001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB113001") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB11301():
    result = parse("HLA-DPA10303-DPB11301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB11301") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB113101():
    result = parse("HLA-DPA10303-DPB113101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB113101") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB113201():
    result = parse("HLA-DPA10303-DPB113201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB113201") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB113301():
    result = parse("HLA-DPA10303-DPB113301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB113301") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB113401():
    result = parse("HLA-DPA10303-DPB113401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB113401") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB11401():
    result = parse("HLA-DPA10303-DPB11401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB11401") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB11501():
    result = parse("HLA-DPA10303-DPB11501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB11501") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB11601():
    result = parse("HLA-DPA10303-DPB11601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB11601") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB11701():
    result = parse("HLA-DPA10303-DPB11701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB11701") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB11801():
    result = parse("HLA-DPA10303-DPB11801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB11801") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB11901():
    result = parse("HLA-DPA10303-DPB11901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB11901") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB12001():
    result = parse("HLA-DPA10303-DPB12001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB12001") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB12101():
    result = parse("HLA-DPA10303-DPB12101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB12101") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB12201():
    result = parse("HLA-DPA10303-DPB12201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB12201") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB12301():
    result = parse("HLA-DPA10303-DPB12301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB12301") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB12401():
    result = parse("HLA-DPA10303-DPB12401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB12401") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB12501():
    result = parse("HLA-DPA10303-DPB12501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB12501") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB12601():
    result = parse("HLA-DPA10303-DPB12601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB12601") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB12701():
    result = parse("HLA-DPA10303-DPB12701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB12701") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB12801():
    result = parse("HLA-DPA10303-DPB12801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB12801") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB12901():
    result = parse("HLA-DPA10303-DPB12901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB12901") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB13001():
    result = parse("HLA-DPA10303-DPB13001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB13001") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB13101():
    result = parse("HLA-DPA10303-DPB13101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB13101") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB13201():
    result = parse("HLA-DPA10303-DPB13201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB13201") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB13301():
    result = parse("HLA-DPA10303-DPB13301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB13301") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB13401():
    result = parse("HLA-DPA10303-DPB13401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB13401") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB13501():
    result = parse("HLA-DPA10303-DPB13501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB13501") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB13601():
    result = parse("HLA-DPA10303-DPB13601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB13601") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB13701():
    result = parse("HLA-DPA10303-DPB13701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB13701") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB13801():
    result = parse("HLA-DPA10303-DPB13801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB13801") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB13901():
    result = parse("HLA-DPA10303-DPB13901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB13901") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB14001():
    result = parse("HLA-DPA10303-DPB14001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB14001") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB14101():
    result = parse("HLA-DPA10303-DPB14101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB14101") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB14401():
    result = parse("HLA-DPA10303-DPB14401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB14401") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB14501():
    result = parse("HLA-DPA10303-DPB14501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB14501") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB14601():
    result = parse("HLA-DPA10303-DPB14601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB14601") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB14701():
    result = parse("HLA-DPA10303-DPB14701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB14701") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB14801():
    result = parse("HLA-DPA10303-DPB14801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB14801") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB14901():
    result = parse("HLA-DPA10303-DPB14901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB14901") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB15001():
    result = parse("HLA-DPA10303-DPB15001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB15001") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB15101():
    result = parse("HLA-DPA10303-DPB15101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB15101") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB15201():
    result = parse("HLA-DPA10303-DPB15201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB15201") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB15301():
    result = parse("HLA-DPA10303-DPB15301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB15301") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB15401():
    result = parse("HLA-DPA10303-DPB15401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB15401") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB15501():
    result = parse("HLA-DPA10303-DPB15501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB15501") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB15601():
    result = parse("HLA-DPA10303-DPB15601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB15601") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB15801():
    result = parse("HLA-DPA10303-DPB15801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB15801") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB15901():
    result = parse("HLA-DPA10303-DPB15901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB15901") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB16001():
    result = parse("HLA-DPA10303-DPB16001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB16001") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB16201():
    result = parse("HLA-DPA10303-DPB16201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB16201") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB16301():
    result = parse("HLA-DPA10303-DPB16301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB16301") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB16501():
    result = parse("HLA-DPA10303-DPB16501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB16501") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB16601():
    result = parse("HLA-DPA10303-DPB16601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB16601") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB16701():
    result = parse("HLA-DPA10303-DPB16701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB16701") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB16801():
    result = parse("HLA-DPA10303-DPB16801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB16801") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB16901():
    result = parse("HLA-DPA10303-DPB16901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB16901") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB17001():
    result = parse("HLA-DPA10303-DPB17001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB17001") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB17101():
    result = parse("HLA-DPA10303-DPB17101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB17101") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB17201():
    result = parse("HLA-DPA10303-DPB17201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB17201") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB17301():
    result = parse("HLA-DPA10303-DPB17301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB17301") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB17401():
    result = parse("HLA-DPA10303-DPB17401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB17401") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB17501():
    result = parse("HLA-DPA10303-DPB17501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB17501") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB17601():
    result = parse("HLA-DPA10303-DPB17601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB17601") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB17701():
    result = parse("HLA-DPA10303-DPB17701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB17701") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB17801():
    result = parse("HLA-DPA10303-DPB17801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB17801") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB17901():
    result = parse("HLA-DPA10303-DPB17901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB17901") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB18001():
    result = parse("HLA-DPA10303-DPB18001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB18001") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB18101():
    result = parse("HLA-DPA10303-DPB18101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB18101") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB18201():
    result = parse("HLA-DPA10303-DPB18201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB18201") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB18301():
    result = parse("HLA-DPA10303-DPB18301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB18301") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB18401():
    result = parse("HLA-DPA10303-DPB18401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB18401") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB18501():
    result = parse("HLA-DPA10303-DPB18501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB18501") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB18601():
    result = parse("HLA-DPA10303-DPB18601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB18601") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB18701():
    result = parse("HLA-DPA10303-DPB18701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB18701") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB18801():
    result = parse("HLA-DPA10303-DPB18801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB18801") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB18901():
    result = parse("HLA-DPA10303-DPB18901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB18901") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB19001():
    result = parse("HLA-DPA10303-DPB19001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB19001") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB19101():
    result = parse("HLA-DPA10303-DPB19101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB19101") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB19201():
    result = parse("HLA-DPA10303-DPB19201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB19201") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB19301():
    result = parse("HLA-DPA10303-DPB19301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB19301") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB19401():
    result = parse("HLA-DPA10303-DPB19401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB19401") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB19501():
    result = parse("HLA-DPA10303-DPB19501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB19501") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB19601():
    result = parse("HLA-DPA10303-DPB19601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB19601") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB19701():
    result = parse("HLA-DPA10303-DPB19701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB19701") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB19801():
    result = parse("HLA-DPA10303-DPB19801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB19801") to be Pair but got {result}'
    )


def test_HLA_DPA10303_DPB19901():
    result = parse("HLA-DPA10303-DPB19901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10303-DPB19901") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB10101():
    result = parse("HLA-DPA10401-DPB10101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB10101") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB10201():
    result = parse("HLA-DPA10401-DPB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB10201") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB10202():
    result = parse("HLA-DPA10401-DPB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB10202") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB10301():
    result = parse("HLA-DPA10401-DPB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB10301") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB10401():
    result = parse("HLA-DPA10401-DPB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB10401") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB10402():
    result = parse("HLA-DPA10401-DPB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB10402") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB10501():
    result = parse("HLA-DPA10401-DPB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB10501") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB10601():
    result = parse("HLA-DPA10401-DPB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB10601") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB10801():
    result = parse("HLA-DPA10401-DPB10801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB10801") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB10901():
    result = parse("HLA-DPA10401-DPB10901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB10901") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB110001():
    result = parse("HLA-DPA10401-DPB110001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB110001") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB11001():
    result = parse("HLA-DPA10401-DPB11001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB11001") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB110101():
    result = parse("HLA-DPA10401-DPB110101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB110101") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB110201():
    result = parse("HLA-DPA10401-DPB110201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB110201") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB110301():
    result = parse("HLA-DPA10401-DPB110301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB110301") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB110401():
    result = parse("HLA-DPA10401-DPB110401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB110401") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB110501():
    result = parse("HLA-DPA10401-DPB110501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB110501") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB110601():
    result = parse("HLA-DPA10401-DPB110601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB110601") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB110701():
    result = parse("HLA-DPA10401-DPB110701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB110701") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB110801():
    result = parse("HLA-DPA10401-DPB110801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB110801") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB110901():
    result = parse("HLA-DPA10401-DPB110901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB110901") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB111001():
    result = parse("HLA-DPA10401-DPB111001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB111001") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB11101():
    result = parse("HLA-DPA10401-DPB11101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB11101") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB111101():
    result = parse("HLA-DPA10401-DPB111101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB111101") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB111201():
    result = parse("HLA-DPA10401-DPB111201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB111201") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB111301():
    result = parse("HLA-DPA10401-DPB111301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB111301") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB111401():
    result = parse("HLA-DPA10401-DPB111401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB111401") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB111501():
    result = parse("HLA-DPA10401-DPB111501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB111501") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB111601():
    result = parse("HLA-DPA10401-DPB111601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB111601") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB111701():
    result = parse("HLA-DPA10401-DPB111701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB111701") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB111801():
    result = parse("HLA-DPA10401-DPB111801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB111801") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB111901():
    result = parse("HLA-DPA10401-DPB111901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB111901") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB112101():
    result = parse("HLA-DPA10401-DPB112101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB112101") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB112201():
    result = parse("HLA-DPA10401-DPB112201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB112201") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB112301():
    result = parse("HLA-DPA10401-DPB112301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB112301") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB112401():
    result = parse("HLA-DPA10401-DPB112401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB112401") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB112501():
    result = parse("HLA-DPA10401-DPB112501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB112501") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB112601():
    result = parse("HLA-DPA10401-DPB112601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB112601") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB112701():
    result = parse("HLA-DPA10401-DPB112701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB112701") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB112801():
    result = parse("HLA-DPA10401-DPB112801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB112801") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB112901():
    result = parse("HLA-DPA10401-DPB112901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB112901") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB113001():
    result = parse("HLA-DPA10401-DPB113001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB113001") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB11301():
    result = parse("HLA-DPA10401-DPB11301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB11301") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB113101():
    result = parse("HLA-DPA10401-DPB113101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB113101") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB113201():
    result = parse("HLA-DPA10401-DPB113201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB113201") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB113301():
    result = parse("HLA-DPA10401-DPB113301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB113301") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB113401():
    result = parse("HLA-DPA10401-DPB113401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB113401") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB11401():
    result = parse("HLA-DPA10401-DPB11401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB11401") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB11501():
    result = parse("HLA-DPA10401-DPB11501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB11501") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB11601():
    result = parse("HLA-DPA10401-DPB11601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB11601") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB11701():
    result = parse("HLA-DPA10401-DPB11701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB11701") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB11801():
    result = parse("HLA-DPA10401-DPB11801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB11801") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB11901():
    result = parse("HLA-DPA10401-DPB11901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB11901") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB12001():
    result = parse("HLA-DPA10401-DPB12001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB12001") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB12101():
    result = parse("HLA-DPA10401-DPB12101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB12101") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB12201():
    result = parse("HLA-DPA10401-DPB12201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB12201") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB12301():
    result = parse("HLA-DPA10401-DPB12301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB12301") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB12401():
    result = parse("HLA-DPA10401-DPB12401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB12401") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB12501():
    result = parse("HLA-DPA10401-DPB12501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB12501") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB12601():
    result = parse("HLA-DPA10401-DPB12601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB12601") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB12701():
    result = parse("HLA-DPA10401-DPB12701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB12701") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB12801():
    result = parse("HLA-DPA10401-DPB12801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB12801") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB12901():
    result = parse("HLA-DPA10401-DPB12901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB12901") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB13001():
    result = parse("HLA-DPA10401-DPB13001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB13001") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB13101():
    result = parse("HLA-DPA10401-DPB13101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB13101") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB13201():
    result = parse("HLA-DPA10401-DPB13201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB13201") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB13301():
    result = parse("HLA-DPA10401-DPB13301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB13301") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB13401():
    result = parse("HLA-DPA10401-DPB13401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB13401") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB13501():
    result = parse("HLA-DPA10401-DPB13501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB13501") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB13601():
    result = parse("HLA-DPA10401-DPB13601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB13601") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB13701():
    result = parse("HLA-DPA10401-DPB13701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB13701") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB13801():
    result = parse("HLA-DPA10401-DPB13801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB13801") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB13901():
    result = parse("HLA-DPA10401-DPB13901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB13901") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB14001():
    result = parse("HLA-DPA10401-DPB14001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB14001") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB14101():
    result = parse("HLA-DPA10401-DPB14101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB14101") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB14401():
    result = parse("HLA-DPA10401-DPB14401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB14401") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB14501():
    result = parse("HLA-DPA10401-DPB14501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB14501") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB14601():
    result = parse("HLA-DPA10401-DPB14601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB14601") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB14701():
    result = parse("HLA-DPA10401-DPB14701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB14701") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB14801():
    result = parse("HLA-DPA10401-DPB14801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB14801") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB14901():
    result = parse("HLA-DPA10401-DPB14901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB14901") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB15001():
    result = parse("HLA-DPA10401-DPB15001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB15001") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB15101():
    result = parse("HLA-DPA10401-DPB15101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB15101") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB15201():
    result = parse("HLA-DPA10401-DPB15201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB15201") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB15301():
    result = parse("HLA-DPA10401-DPB15301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB15301") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB15401():
    result = parse("HLA-DPA10401-DPB15401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB15401") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB15501():
    result = parse("HLA-DPA10401-DPB15501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB15501") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB15601():
    result = parse("HLA-DPA10401-DPB15601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB15601") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB15801():
    result = parse("HLA-DPA10401-DPB15801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB15801") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB15901():
    result = parse("HLA-DPA10401-DPB15901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB15901") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB16001():
    result = parse("HLA-DPA10401-DPB16001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB16001") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB16201():
    result = parse("HLA-DPA10401-DPB16201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB16201") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB16301():
    result = parse("HLA-DPA10401-DPB16301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB16301") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB16501():
    result = parse("HLA-DPA10401-DPB16501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB16501") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB16601():
    result = parse("HLA-DPA10401-DPB16601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB16601") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB16701():
    result = parse("HLA-DPA10401-DPB16701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB16701") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB16801():
    result = parse("HLA-DPA10401-DPB16801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB16801") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB16901():
    result = parse("HLA-DPA10401-DPB16901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB16901") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB17001():
    result = parse("HLA-DPA10401-DPB17001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB17001") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB17101():
    result = parse("HLA-DPA10401-DPB17101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB17101") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB17201():
    result = parse("HLA-DPA10401-DPB17201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB17201") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB17301():
    result = parse("HLA-DPA10401-DPB17301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB17301") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB17401():
    result = parse("HLA-DPA10401-DPB17401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB17401") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB17501():
    result = parse("HLA-DPA10401-DPB17501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB17501") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB17601():
    result = parse("HLA-DPA10401-DPB17601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB17601") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB17701():
    result = parse("HLA-DPA10401-DPB17701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB17701") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB17801():
    result = parse("HLA-DPA10401-DPB17801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB17801") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB17901():
    result = parse("HLA-DPA10401-DPB17901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB17901") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB18001():
    result = parse("HLA-DPA10401-DPB18001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB18001") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB18101():
    result = parse("HLA-DPA10401-DPB18101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB18101") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB18201():
    result = parse("HLA-DPA10401-DPB18201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB18201") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB18301():
    result = parse("HLA-DPA10401-DPB18301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB18301") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB18401():
    result = parse("HLA-DPA10401-DPB18401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB18401") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB18501():
    result = parse("HLA-DPA10401-DPB18501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB18501") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB18601():
    result = parse("HLA-DPA10401-DPB18601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB18601") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB18701():
    result = parse("HLA-DPA10401-DPB18701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB18701") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB18801():
    result = parse("HLA-DPA10401-DPB18801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB18801") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB18901():
    result = parse("HLA-DPA10401-DPB18901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB18901") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB19001():
    result = parse("HLA-DPA10401-DPB19001", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB19001") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB19101():
    result = parse("HLA-DPA10401-DPB19101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB19101") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB19201():
    result = parse("HLA-DPA10401-DPB19201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB19201") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB19301():
    result = parse("HLA-DPA10401-DPB19301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB19301") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB19401():
    result = parse("HLA-DPA10401-DPB19401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB19401") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB19501():
    result = parse("HLA-DPA10401-DPB19501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB19501") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB19601():
    result = parse("HLA-DPA10401-DPB19601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB19601") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB19701():
    result = parse("HLA-DPA10401-DPB19701", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB19701") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB19801():
    result = parse("HLA-DPA10401-DPB19801", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB19801") to be Pair but got {result}'
    )


def test_HLA_DPA10401_DPB19901():
    result = parse("HLA-DPA10401-DPB19901", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DPA10401-DPB19901") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10201():
    result = parse("HLA-DQA10101-DQB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10201") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10202():
    result = parse("HLA-DQA10101-DQB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10202") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10203():
    result = parse("HLA-DQA10101-DQB10203", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10203") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10204():
    result = parse("HLA-DQA10101-DQB10204", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10204") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10205():
    result = parse("HLA-DQA10101-DQB10205", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10205") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10206():
    result = parse("HLA-DQA10101-DQB10206", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10206") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10301():
    result = parse("HLA-DQA10101-DQB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10301") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10302():
    result = parse("HLA-DQA10101-DQB10302", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10302") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10303():
    result = parse("HLA-DQA10101-DQB10303", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10303") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10304():
    result = parse("HLA-DQA10101-DQB10304", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10304") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10305():
    result = parse("HLA-DQA10101-DQB10305", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10305") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10306():
    result = parse("HLA-DQA10101-DQB10306", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10306") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10307():
    result = parse("HLA-DQA10101-DQB10307", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10307") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10308():
    result = parse("HLA-DQA10101-DQB10308", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10308") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10309():
    result = parse("HLA-DQA10101-DQB10309", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10309") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10310():
    result = parse("HLA-DQA10101-DQB10310", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10310") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10311():
    result = parse("HLA-DQA10101-DQB10311", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10311") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10312():
    result = parse("HLA-DQA10101-DQB10312", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10312") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10313():
    result = parse("HLA-DQA10101-DQB10313", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10313") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10314():
    result = parse("HLA-DQA10101-DQB10314", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10314") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10315():
    result = parse("HLA-DQA10101-DQB10315", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10315") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10316():
    result = parse("HLA-DQA10101-DQB10316", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10316") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10317():
    result = parse("HLA-DQA10101-DQB10317", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10317") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10318():
    result = parse("HLA-DQA10101-DQB10318", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10318") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10319():
    result = parse("HLA-DQA10101-DQB10319", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10319") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10320():
    result = parse("HLA-DQA10101-DQB10320", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10320") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10321():
    result = parse("HLA-DQA10101-DQB10321", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10321") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10322():
    result = parse("HLA-DQA10101-DQB10322", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10322") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10323():
    result = parse("HLA-DQA10101-DQB10323", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10323") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10324():
    result = parse("HLA-DQA10101-DQB10324", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10324") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10325():
    result = parse("HLA-DQA10101-DQB10325", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10325") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10326():
    result = parse("HLA-DQA10101-DQB10326", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10326") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10327():
    result = parse("HLA-DQA10101-DQB10327", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10327") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10328():
    result = parse("HLA-DQA10101-DQB10328", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10328") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10329():
    result = parse("HLA-DQA10101-DQB10329", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10329") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10330():
    result = parse("HLA-DQA10101-DQB10330", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10330") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10331():
    result = parse("HLA-DQA10101-DQB10331", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10331") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10332():
    result = parse("HLA-DQA10101-DQB10332", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10332") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10333():
    result = parse("HLA-DQA10101-DQB10333", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10333") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10334():
    result = parse("HLA-DQA10101-DQB10334", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10334") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10335():
    result = parse("HLA-DQA10101-DQB10335", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10335") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10336():
    result = parse("HLA-DQA10101-DQB10336", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10336") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10337():
    result = parse("HLA-DQA10101-DQB10337", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10337") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10338():
    result = parse("HLA-DQA10101-DQB10338", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10338") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10401():
    result = parse("HLA-DQA10101-DQB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10401") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10402():
    result = parse("HLA-DQA10101-DQB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10402") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10403():
    result = parse("HLA-DQA10101-DQB10403", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10403") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10404():
    result = parse("HLA-DQA10101-DQB10404", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10404") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10405():
    result = parse("HLA-DQA10101-DQB10405", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10405") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10406():
    result = parse("HLA-DQA10101-DQB10406", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10406") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10407():
    result = parse("HLA-DQA10101-DQB10407", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10407") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10408():
    result = parse("HLA-DQA10101-DQB10408", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10408") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10501():
    result = parse("HLA-DQA10101-DQB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10501") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10502():
    result = parse("HLA-DQA10101-DQB10502", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10502") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10503():
    result = parse("HLA-DQA10101-DQB10503", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10503") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10505():
    result = parse("HLA-DQA10101-DQB10505", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10505") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10506():
    result = parse("HLA-DQA10101-DQB10506", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10506") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10507():
    result = parse("HLA-DQA10101-DQB10507", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10507") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10508():
    result = parse("HLA-DQA10101-DQB10508", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10508") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10509():
    result = parse("HLA-DQA10101-DQB10509", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10509") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10510():
    result = parse("HLA-DQA10101-DQB10510", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10510") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10511():
    result = parse("HLA-DQA10101-DQB10511", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10511") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10512():
    result = parse("HLA-DQA10101-DQB10512", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10512") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10513():
    result = parse("HLA-DQA10101-DQB10513", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10513") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10514():
    result = parse("HLA-DQA10101-DQB10514", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10514") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10601():
    result = parse("HLA-DQA10101-DQB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10601") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10602():
    result = parse("HLA-DQA10101-DQB10602", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10602") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10603():
    result = parse("HLA-DQA10101-DQB10603", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10603") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10604():
    result = parse("HLA-DQA10101-DQB10604", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10604") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10607():
    result = parse("HLA-DQA10101-DQB10607", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10607") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10608():
    result = parse("HLA-DQA10101-DQB10608", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10608") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10609():
    result = parse("HLA-DQA10101-DQB10609", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10609") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10610():
    result = parse("HLA-DQA10101-DQB10610", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10610") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10611():
    result = parse("HLA-DQA10101-DQB10611", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10611") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10612():
    result = parse("HLA-DQA10101-DQB10612", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10612") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10614():
    result = parse("HLA-DQA10101-DQB10614", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10614") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10615():
    result = parse("HLA-DQA10101-DQB10615", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10615") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10616():
    result = parse("HLA-DQA10101-DQB10616", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10616") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10617():
    result = parse("HLA-DQA10101-DQB10617", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10617") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10618():
    result = parse("HLA-DQA10101-DQB10618", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10618") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10619():
    result = parse("HLA-DQA10101-DQB10619", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10619") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10621():
    result = parse("HLA-DQA10101-DQB10621", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10621") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10622():
    result = parse("HLA-DQA10101-DQB10622", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10622") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10623():
    result = parse("HLA-DQA10101-DQB10623", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10623") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10624():
    result = parse("HLA-DQA10101-DQB10624", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10624") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10625():
    result = parse("HLA-DQA10101-DQB10625", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10625") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10627():
    result = parse("HLA-DQA10101-DQB10627", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10627") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10628():
    result = parse("HLA-DQA10101-DQB10628", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10628") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10629():
    result = parse("HLA-DQA10101-DQB10629", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10629") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10630():
    result = parse("HLA-DQA10101-DQB10630", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10630") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10631():
    result = parse("HLA-DQA10101-DQB10631", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10631") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10632():
    result = parse("HLA-DQA10101-DQB10632", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10632") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10633():
    result = parse("HLA-DQA10101-DQB10633", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10633") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10634():
    result = parse("HLA-DQA10101-DQB10634", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10634") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10635():
    result = parse("HLA-DQA10101-DQB10635", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10635") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10636():
    result = parse("HLA-DQA10101-DQB10636", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10636") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10637():
    result = parse("HLA-DQA10101-DQB10637", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10637") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10638():
    result = parse("HLA-DQA10101-DQB10638", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10638") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10639():
    result = parse("HLA-DQA10101-DQB10639", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10639") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10640():
    result = parse("HLA-DQA10101-DQB10640", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10640") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10641():
    result = parse("HLA-DQA10101-DQB10641", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10641") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10642():
    result = parse("HLA-DQA10101-DQB10642", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10642") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10643():
    result = parse("HLA-DQA10101-DQB10643", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10643") to be Pair but got {result}'
    )


def test_HLA_DQA10101_DQB10644():
    result = parse("HLA-DQA10101-DQB10644", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10101-DQB10644") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10201():
    result = parse("HLA-DQA10102-DQB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10201") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10202():
    result = parse("HLA-DQA10102-DQB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10202") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10203():
    result = parse("HLA-DQA10102-DQB10203", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10203") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10204():
    result = parse("HLA-DQA10102-DQB10204", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10204") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10205():
    result = parse("HLA-DQA10102-DQB10205", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10205") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10206():
    result = parse("HLA-DQA10102-DQB10206", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10206") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10301():
    result = parse("HLA-DQA10102-DQB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10301") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10302():
    result = parse("HLA-DQA10102-DQB10302", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10302") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10303():
    result = parse("HLA-DQA10102-DQB10303", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10303") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10304():
    result = parse("HLA-DQA10102-DQB10304", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10304") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10305():
    result = parse("HLA-DQA10102-DQB10305", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10305") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10306():
    result = parse("HLA-DQA10102-DQB10306", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10306") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10307():
    result = parse("HLA-DQA10102-DQB10307", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10307") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10308():
    result = parse("HLA-DQA10102-DQB10308", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10308") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10309():
    result = parse("HLA-DQA10102-DQB10309", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10309") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10310():
    result = parse("HLA-DQA10102-DQB10310", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10310") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10311():
    result = parse("HLA-DQA10102-DQB10311", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10311") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10312():
    result = parse("HLA-DQA10102-DQB10312", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10312") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10313():
    result = parse("HLA-DQA10102-DQB10313", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10313") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10314():
    result = parse("HLA-DQA10102-DQB10314", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10314") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10315():
    result = parse("HLA-DQA10102-DQB10315", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10315") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10316():
    result = parse("HLA-DQA10102-DQB10316", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10316") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10317():
    result = parse("HLA-DQA10102-DQB10317", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10317") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10318():
    result = parse("HLA-DQA10102-DQB10318", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10318") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10319():
    result = parse("HLA-DQA10102-DQB10319", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10319") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10320():
    result = parse("HLA-DQA10102-DQB10320", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10320") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10321():
    result = parse("HLA-DQA10102-DQB10321", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10321") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10322():
    result = parse("HLA-DQA10102-DQB10322", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10322") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10323():
    result = parse("HLA-DQA10102-DQB10323", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10323") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10324():
    result = parse("HLA-DQA10102-DQB10324", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10324") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10325():
    result = parse("HLA-DQA10102-DQB10325", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10325") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10326():
    result = parse("HLA-DQA10102-DQB10326", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10326") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10327():
    result = parse("HLA-DQA10102-DQB10327", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10327") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10328():
    result = parse("HLA-DQA10102-DQB10328", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10328") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10329():
    result = parse("HLA-DQA10102-DQB10329", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10329") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10330():
    result = parse("HLA-DQA10102-DQB10330", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10330") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10331():
    result = parse("HLA-DQA10102-DQB10331", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10331") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10332():
    result = parse("HLA-DQA10102-DQB10332", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10332") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10333():
    result = parse("HLA-DQA10102-DQB10333", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10333") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10334():
    result = parse("HLA-DQA10102-DQB10334", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10334") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10335():
    result = parse("HLA-DQA10102-DQB10335", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10335") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10336():
    result = parse("HLA-DQA10102-DQB10336", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10336") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10337():
    result = parse("HLA-DQA10102-DQB10337", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10337") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10338():
    result = parse("HLA-DQA10102-DQB10338", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10338") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10401():
    result = parse("HLA-DQA10102-DQB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10401") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10402():
    result = parse("HLA-DQA10102-DQB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10402") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10403():
    result = parse("HLA-DQA10102-DQB10403", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10403") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10404():
    result = parse("HLA-DQA10102-DQB10404", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10404") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10405():
    result = parse("HLA-DQA10102-DQB10405", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10405") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10406():
    result = parse("HLA-DQA10102-DQB10406", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10406") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10407():
    result = parse("HLA-DQA10102-DQB10407", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10407") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10408():
    result = parse("HLA-DQA10102-DQB10408", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10408") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10501():
    result = parse("HLA-DQA10102-DQB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10501") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10502():
    result = parse("HLA-DQA10102-DQB10502", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10502") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10503():
    result = parse("HLA-DQA10102-DQB10503", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10503") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10505():
    result = parse("HLA-DQA10102-DQB10505", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10505") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10506():
    result = parse("HLA-DQA10102-DQB10506", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10506") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10507():
    result = parse("HLA-DQA10102-DQB10507", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10507") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10508():
    result = parse("HLA-DQA10102-DQB10508", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10508") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10509():
    result = parse("HLA-DQA10102-DQB10509", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10509") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10510():
    result = parse("HLA-DQA10102-DQB10510", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10510") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10511():
    result = parse("HLA-DQA10102-DQB10511", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10511") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10512():
    result = parse("HLA-DQA10102-DQB10512", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10512") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10513():
    result = parse("HLA-DQA10102-DQB10513", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10513") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10514():
    result = parse("HLA-DQA10102-DQB10514", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10514") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10601():
    result = parse("HLA-DQA10102-DQB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10601") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10602():
    result = parse("HLA-DQA10102-DQB10602", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10602") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10603():
    result = parse("HLA-DQA10102-DQB10603", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10603") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10604():
    result = parse("HLA-DQA10102-DQB10604", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10604") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10607():
    result = parse("HLA-DQA10102-DQB10607", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10607") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10608():
    result = parse("HLA-DQA10102-DQB10608", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10608") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10609():
    result = parse("HLA-DQA10102-DQB10609", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10609") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10610():
    result = parse("HLA-DQA10102-DQB10610", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10610") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10611():
    result = parse("HLA-DQA10102-DQB10611", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10611") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10612():
    result = parse("HLA-DQA10102-DQB10612", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10612") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10614():
    result = parse("HLA-DQA10102-DQB10614", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10614") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10615():
    result = parse("HLA-DQA10102-DQB10615", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10615") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10616():
    result = parse("HLA-DQA10102-DQB10616", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10616") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10617():
    result = parse("HLA-DQA10102-DQB10617", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10617") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10618():
    result = parse("HLA-DQA10102-DQB10618", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10618") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10619():
    result = parse("HLA-DQA10102-DQB10619", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10619") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10621():
    result = parse("HLA-DQA10102-DQB10621", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10621") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10622():
    result = parse("HLA-DQA10102-DQB10622", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10622") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10623():
    result = parse("HLA-DQA10102-DQB10623", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10623") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10624():
    result = parse("HLA-DQA10102-DQB10624", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10624") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10625():
    result = parse("HLA-DQA10102-DQB10625", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10625") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10627():
    result = parse("HLA-DQA10102-DQB10627", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10627") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10628():
    result = parse("HLA-DQA10102-DQB10628", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10628") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10629():
    result = parse("HLA-DQA10102-DQB10629", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10629") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10630():
    result = parse("HLA-DQA10102-DQB10630", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10630") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10631():
    result = parse("HLA-DQA10102-DQB10631", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10631") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10632():
    result = parse("HLA-DQA10102-DQB10632", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10632") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10633():
    result = parse("HLA-DQA10102-DQB10633", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10633") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10634():
    result = parse("HLA-DQA10102-DQB10634", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10634") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10635():
    result = parse("HLA-DQA10102-DQB10635", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10635") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10636():
    result = parse("HLA-DQA10102-DQB10636", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10636") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10637():
    result = parse("HLA-DQA10102-DQB10637", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10637") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10638():
    result = parse("HLA-DQA10102-DQB10638", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10638") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10639():
    result = parse("HLA-DQA10102-DQB10639", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10639") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10640():
    result = parse("HLA-DQA10102-DQB10640", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10640") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10641():
    result = parse("HLA-DQA10102-DQB10641", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10641") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10642():
    result = parse("HLA-DQA10102-DQB10642", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10642") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10643():
    result = parse("HLA-DQA10102-DQB10643", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10643") to be Pair but got {result}'
    )


def test_HLA_DQA10102_DQB10644():
    result = parse("HLA-DQA10102-DQB10644", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10102-DQB10644") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10201():
    result = parse("HLA-DQA10103-DQB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10201") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10202():
    result = parse("HLA-DQA10103-DQB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10202") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10203():
    result = parse("HLA-DQA10103-DQB10203", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10203") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10204():
    result = parse("HLA-DQA10103-DQB10204", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10204") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10205():
    result = parse("HLA-DQA10103-DQB10205", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10205") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10206():
    result = parse("HLA-DQA10103-DQB10206", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10206") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10301():
    result = parse("HLA-DQA10103-DQB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10301") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10302():
    result = parse("HLA-DQA10103-DQB10302", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10302") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10303():
    result = parse("HLA-DQA10103-DQB10303", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10303") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10304():
    result = parse("HLA-DQA10103-DQB10304", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10304") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10305():
    result = parse("HLA-DQA10103-DQB10305", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10305") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10306():
    result = parse("HLA-DQA10103-DQB10306", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10306") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10307():
    result = parse("HLA-DQA10103-DQB10307", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10307") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10308():
    result = parse("HLA-DQA10103-DQB10308", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10308") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10309():
    result = parse("HLA-DQA10103-DQB10309", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10309") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10310():
    result = parse("HLA-DQA10103-DQB10310", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10310") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10311():
    result = parse("HLA-DQA10103-DQB10311", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10311") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10312():
    result = parse("HLA-DQA10103-DQB10312", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10312") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10313():
    result = parse("HLA-DQA10103-DQB10313", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10313") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10314():
    result = parse("HLA-DQA10103-DQB10314", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10314") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10315():
    result = parse("HLA-DQA10103-DQB10315", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10315") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10316():
    result = parse("HLA-DQA10103-DQB10316", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10316") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10317():
    result = parse("HLA-DQA10103-DQB10317", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10317") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10318():
    result = parse("HLA-DQA10103-DQB10318", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10318") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10319():
    result = parse("HLA-DQA10103-DQB10319", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10319") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10320():
    result = parse("HLA-DQA10103-DQB10320", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10320") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10321():
    result = parse("HLA-DQA10103-DQB10321", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10321") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10322():
    result = parse("HLA-DQA10103-DQB10322", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10322") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10323():
    result = parse("HLA-DQA10103-DQB10323", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10323") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10324():
    result = parse("HLA-DQA10103-DQB10324", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10324") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10325():
    result = parse("HLA-DQA10103-DQB10325", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10325") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10326():
    result = parse("HLA-DQA10103-DQB10326", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10326") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10327():
    result = parse("HLA-DQA10103-DQB10327", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10327") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10328():
    result = parse("HLA-DQA10103-DQB10328", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10328") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10329():
    result = parse("HLA-DQA10103-DQB10329", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10329") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10330():
    result = parse("HLA-DQA10103-DQB10330", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10330") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10331():
    result = parse("HLA-DQA10103-DQB10331", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10331") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10332():
    result = parse("HLA-DQA10103-DQB10332", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10332") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10333():
    result = parse("HLA-DQA10103-DQB10333", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10333") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10334():
    result = parse("HLA-DQA10103-DQB10334", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10334") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10335():
    result = parse("HLA-DQA10103-DQB10335", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10335") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10336():
    result = parse("HLA-DQA10103-DQB10336", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10336") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10337():
    result = parse("HLA-DQA10103-DQB10337", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10337") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10338():
    result = parse("HLA-DQA10103-DQB10338", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10338") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10401():
    result = parse("HLA-DQA10103-DQB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10401") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10402():
    result = parse("HLA-DQA10103-DQB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10402") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10403():
    result = parse("HLA-DQA10103-DQB10403", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10403") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10404():
    result = parse("HLA-DQA10103-DQB10404", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10404") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10405():
    result = parse("HLA-DQA10103-DQB10405", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10405") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10406():
    result = parse("HLA-DQA10103-DQB10406", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10406") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10407():
    result = parse("HLA-DQA10103-DQB10407", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10407") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10408():
    result = parse("HLA-DQA10103-DQB10408", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10408") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10501():
    result = parse("HLA-DQA10103-DQB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10501") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10502():
    result = parse("HLA-DQA10103-DQB10502", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10502") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10503():
    result = parse("HLA-DQA10103-DQB10503", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10503") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10505():
    result = parse("HLA-DQA10103-DQB10505", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10505") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10506():
    result = parse("HLA-DQA10103-DQB10506", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10506") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10507():
    result = parse("HLA-DQA10103-DQB10507", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10507") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10508():
    result = parse("HLA-DQA10103-DQB10508", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10508") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10509():
    result = parse("HLA-DQA10103-DQB10509", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10509") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10510():
    result = parse("HLA-DQA10103-DQB10510", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10510") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10511():
    result = parse("HLA-DQA10103-DQB10511", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10511") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10512():
    result = parse("HLA-DQA10103-DQB10512", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10512") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10513():
    result = parse("HLA-DQA10103-DQB10513", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10513") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10514():
    result = parse("HLA-DQA10103-DQB10514", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10514") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10601():
    result = parse("HLA-DQA10103-DQB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10601") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10602():
    result = parse("HLA-DQA10103-DQB10602", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10602") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10603():
    result = parse("HLA-DQA10103-DQB10603", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10603") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10604():
    result = parse("HLA-DQA10103-DQB10604", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10604") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10607():
    result = parse("HLA-DQA10103-DQB10607", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10607") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10608():
    result = parse("HLA-DQA10103-DQB10608", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10608") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10609():
    result = parse("HLA-DQA10103-DQB10609", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10609") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10610():
    result = parse("HLA-DQA10103-DQB10610", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10610") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10611():
    result = parse("HLA-DQA10103-DQB10611", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10611") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10612():
    result = parse("HLA-DQA10103-DQB10612", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10612") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10614():
    result = parse("HLA-DQA10103-DQB10614", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10614") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10615():
    result = parse("HLA-DQA10103-DQB10615", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10615") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10616():
    result = parse("HLA-DQA10103-DQB10616", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10616") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10617():
    result = parse("HLA-DQA10103-DQB10617", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10617") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10618():
    result = parse("HLA-DQA10103-DQB10618", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10618") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10619():
    result = parse("HLA-DQA10103-DQB10619", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10619") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10621():
    result = parse("HLA-DQA10103-DQB10621", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10621") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10622():
    result = parse("HLA-DQA10103-DQB10622", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10622") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10623():
    result = parse("HLA-DQA10103-DQB10623", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10623") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10624():
    result = parse("HLA-DQA10103-DQB10624", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10624") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10625():
    result = parse("HLA-DQA10103-DQB10625", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10625") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10627():
    result = parse("HLA-DQA10103-DQB10627", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10627") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10628():
    result = parse("HLA-DQA10103-DQB10628", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10628") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10629():
    result = parse("HLA-DQA10103-DQB10629", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10629") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10630():
    result = parse("HLA-DQA10103-DQB10630", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10630") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10631():
    result = parse("HLA-DQA10103-DQB10631", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10631") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10632():
    result = parse("HLA-DQA10103-DQB10632", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10632") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10633():
    result = parse("HLA-DQA10103-DQB10633", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10633") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10634():
    result = parse("HLA-DQA10103-DQB10634", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10634") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10635():
    result = parse("HLA-DQA10103-DQB10635", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10635") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10636():
    result = parse("HLA-DQA10103-DQB10636", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10636") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10637():
    result = parse("HLA-DQA10103-DQB10637", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10637") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10638():
    result = parse("HLA-DQA10103-DQB10638", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10638") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10639():
    result = parse("HLA-DQA10103-DQB10639", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10639") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10640():
    result = parse("HLA-DQA10103-DQB10640", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10640") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10641():
    result = parse("HLA-DQA10103-DQB10641", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10641") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10642():
    result = parse("HLA-DQA10103-DQB10642", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10642") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10643():
    result = parse("HLA-DQA10103-DQB10643", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10643") to be Pair but got {result}'
    )


def test_HLA_DQA10103_DQB10644():
    result = parse("HLA-DQA10103-DQB10644", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10103-DQB10644") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10201():
    result = parse("HLA-DQA10104-DQB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10201") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10202():
    result = parse("HLA-DQA10104-DQB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10202") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10203():
    result = parse("HLA-DQA10104-DQB10203", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10203") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10204():
    result = parse("HLA-DQA10104-DQB10204", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10204") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10205():
    result = parse("HLA-DQA10104-DQB10205", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10205") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10206():
    result = parse("HLA-DQA10104-DQB10206", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10206") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10301():
    result = parse("HLA-DQA10104-DQB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10301") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10302():
    result = parse("HLA-DQA10104-DQB10302", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10302") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10303():
    result = parse("HLA-DQA10104-DQB10303", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10303") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10304():
    result = parse("HLA-DQA10104-DQB10304", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10304") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10305():
    result = parse("HLA-DQA10104-DQB10305", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10305") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10306():
    result = parse("HLA-DQA10104-DQB10306", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10306") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10307():
    result = parse("HLA-DQA10104-DQB10307", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10307") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10308():
    result = parse("HLA-DQA10104-DQB10308", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10308") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10309():
    result = parse("HLA-DQA10104-DQB10309", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10309") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10310():
    result = parse("HLA-DQA10104-DQB10310", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10310") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10311():
    result = parse("HLA-DQA10104-DQB10311", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10311") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10312():
    result = parse("HLA-DQA10104-DQB10312", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10312") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10313():
    result = parse("HLA-DQA10104-DQB10313", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10313") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10314():
    result = parse("HLA-DQA10104-DQB10314", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10314") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10315():
    result = parse("HLA-DQA10104-DQB10315", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10315") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10316():
    result = parse("HLA-DQA10104-DQB10316", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10316") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10317():
    result = parse("HLA-DQA10104-DQB10317", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10317") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10318():
    result = parse("HLA-DQA10104-DQB10318", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10318") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10319():
    result = parse("HLA-DQA10104-DQB10319", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10319") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10320():
    result = parse("HLA-DQA10104-DQB10320", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10320") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10321():
    result = parse("HLA-DQA10104-DQB10321", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10321") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10322():
    result = parse("HLA-DQA10104-DQB10322", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10322") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10323():
    result = parse("HLA-DQA10104-DQB10323", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10323") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10324():
    result = parse("HLA-DQA10104-DQB10324", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10324") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10325():
    result = parse("HLA-DQA10104-DQB10325", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10325") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10326():
    result = parse("HLA-DQA10104-DQB10326", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10326") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10327():
    result = parse("HLA-DQA10104-DQB10327", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10327") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10328():
    result = parse("HLA-DQA10104-DQB10328", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10328") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10329():
    result = parse("HLA-DQA10104-DQB10329", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10329") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10330():
    result = parse("HLA-DQA10104-DQB10330", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10330") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10331():
    result = parse("HLA-DQA10104-DQB10331", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10331") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10332():
    result = parse("HLA-DQA10104-DQB10332", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10332") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10333():
    result = parse("HLA-DQA10104-DQB10333", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10333") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10334():
    result = parse("HLA-DQA10104-DQB10334", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10334") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10335():
    result = parse("HLA-DQA10104-DQB10335", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10335") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10336():
    result = parse("HLA-DQA10104-DQB10336", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10336") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10337():
    result = parse("HLA-DQA10104-DQB10337", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10337") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10338():
    result = parse("HLA-DQA10104-DQB10338", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10338") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10401():
    result = parse("HLA-DQA10104-DQB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10401") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10402():
    result = parse("HLA-DQA10104-DQB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10402") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10403():
    result = parse("HLA-DQA10104-DQB10403", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10403") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10404():
    result = parse("HLA-DQA10104-DQB10404", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10404") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10405():
    result = parse("HLA-DQA10104-DQB10405", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10405") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10406():
    result = parse("HLA-DQA10104-DQB10406", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10406") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10407():
    result = parse("HLA-DQA10104-DQB10407", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10407") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10408():
    result = parse("HLA-DQA10104-DQB10408", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10408") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10501():
    result = parse("HLA-DQA10104-DQB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10501") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10502():
    result = parse("HLA-DQA10104-DQB10502", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10502") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10503():
    result = parse("HLA-DQA10104-DQB10503", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10503") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10505():
    result = parse("HLA-DQA10104-DQB10505", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10505") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10506():
    result = parse("HLA-DQA10104-DQB10506", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10506") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10507():
    result = parse("HLA-DQA10104-DQB10507", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10507") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10508():
    result = parse("HLA-DQA10104-DQB10508", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10508") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10509():
    result = parse("HLA-DQA10104-DQB10509", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10509") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10510():
    result = parse("HLA-DQA10104-DQB10510", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10510") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10511():
    result = parse("HLA-DQA10104-DQB10511", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10511") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10512():
    result = parse("HLA-DQA10104-DQB10512", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10512") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10513():
    result = parse("HLA-DQA10104-DQB10513", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10513") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10514():
    result = parse("HLA-DQA10104-DQB10514", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10514") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10601():
    result = parse("HLA-DQA10104-DQB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10601") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10602():
    result = parse("HLA-DQA10104-DQB10602", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10602") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10603():
    result = parse("HLA-DQA10104-DQB10603", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10603") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10604():
    result = parse("HLA-DQA10104-DQB10604", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10604") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10607():
    result = parse("HLA-DQA10104-DQB10607", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10607") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10608():
    result = parse("HLA-DQA10104-DQB10608", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10608") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10609():
    result = parse("HLA-DQA10104-DQB10609", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10609") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10610():
    result = parse("HLA-DQA10104-DQB10610", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10610") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10611():
    result = parse("HLA-DQA10104-DQB10611", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10611") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10612():
    result = parse("HLA-DQA10104-DQB10612", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10612") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10614():
    result = parse("HLA-DQA10104-DQB10614", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10614") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10615():
    result = parse("HLA-DQA10104-DQB10615", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10615") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10616():
    result = parse("HLA-DQA10104-DQB10616", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10616") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10617():
    result = parse("HLA-DQA10104-DQB10617", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10617") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10618():
    result = parse("HLA-DQA10104-DQB10618", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10618") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10619():
    result = parse("HLA-DQA10104-DQB10619", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10619") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10621():
    result = parse("HLA-DQA10104-DQB10621", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10621") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10622():
    result = parse("HLA-DQA10104-DQB10622", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10622") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10623():
    result = parse("HLA-DQA10104-DQB10623", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10623") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10624():
    result = parse("HLA-DQA10104-DQB10624", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10624") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10625():
    result = parse("HLA-DQA10104-DQB10625", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10625") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10627():
    result = parse("HLA-DQA10104-DQB10627", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10627") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10628():
    result = parse("HLA-DQA10104-DQB10628", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10628") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10629():
    result = parse("HLA-DQA10104-DQB10629", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10629") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10630():
    result = parse("HLA-DQA10104-DQB10630", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10630") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10631():
    result = parse("HLA-DQA10104-DQB10631", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10631") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10632():
    result = parse("HLA-DQA10104-DQB10632", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10632") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10633():
    result = parse("HLA-DQA10104-DQB10633", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10633") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10634():
    result = parse("HLA-DQA10104-DQB10634", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10634") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10635():
    result = parse("HLA-DQA10104-DQB10635", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10635") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10636():
    result = parse("HLA-DQA10104-DQB10636", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10636") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10637():
    result = parse("HLA-DQA10104-DQB10637", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10637") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10638():
    result = parse("HLA-DQA10104-DQB10638", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10638") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10639():
    result = parse("HLA-DQA10104-DQB10639", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10639") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10640():
    result = parse("HLA-DQA10104-DQB10640", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10640") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10641():
    result = parse("HLA-DQA10104-DQB10641", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10641") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10642():
    result = parse("HLA-DQA10104-DQB10642", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10642") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10643():
    result = parse("HLA-DQA10104-DQB10643", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10643") to be Pair but got {result}'
    )


def test_HLA_DQA10104_DQB10644():
    result = parse("HLA-DQA10104-DQB10644", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10104-DQB10644") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10201():
    result = parse("HLA-DQA10105-DQB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10201") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10202():
    result = parse("HLA-DQA10105-DQB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10202") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10203():
    result = parse("HLA-DQA10105-DQB10203", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10203") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10204():
    result = parse("HLA-DQA10105-DQB10204", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10204") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10205():
    result = parse("HLA-DQA10105-DQB10205", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10205") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10206():
    result = parse("HLA-DQA10105-DQB10206", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10206") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10301():
    result = parse("HLA-DQA10105-DQB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10301") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10302():
    result = parse("HLA-DQA10105-DQB10302", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10302") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10303():
    result = parse("HLA-DQA10105-DQB10303", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10303") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10304():
    result = parse("HLA-DQA10105-DQB10304", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10304") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10305():
    result = parse("HLA-DQA10105-DQB10305", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10305") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10306():
    result = parse("HLA-DQA10105-DQB10306", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10306") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10307():
    result = parse("HLA-DQA10105-DQB10307", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10307") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10308():
    result = parse("HLA-DQA10105-DQB10308", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10308") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10309():
    result = parse("HLA-DQA10105-DQB10309", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10309") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10310():
    result = parse("HLA-DQA10105-DQB10310", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10310") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10311():
    result = parse("HLA-DQA10105-DQB10311", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10311") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10312():
    result = parse("HLA-DQA10105-DQB10312", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10312") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10313():
    result = parse("HLA-DQA10105-DQB10313", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10313") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10314():
    result = parse("HLA-DQA10105-DQB10314", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10314") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10315():
    result = parse("HLA-DQA10105-DQB10315", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10315") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10316():
    result = parse("HLA-DQA10105-DQB10316", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10316") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10317():
    result = parse("HLA-DQA10105-DQB10317", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10317") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10318():
    result = parse("HLA-DQA10105-DQB10318", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10318") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10319():
    result = parse("HLA-DQA10105-DQB10319", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10319") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10320():
    result = parse("HLA-DQA10105-DQB10320", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10320") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10321():
    result = parse("HLA-DQA10105-DQB10321", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10321") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10322():
    result = parse("HLA-DQA10105-DQB10322", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10322") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10323():
    result = parse("HLA-DQA10105-DQB10323", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10323") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10324():
    result = parse("HLA-DQA10105-DQB10324", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10324") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10325():
    result = parse("HLA-DQA10105-DQB10325", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10325") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10326():
    result = parse("HLA-DQA10105-DQB10326", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10326") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10327():
    result = parse("HLA-DQA10105-DQB10327", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10327") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10328():
    result = parse("HLA-DQA10105-DQB10328", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10328") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10329():
    result = parse("HLA-DQA10105-DQB10329", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10329") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10330():
    result = parse("HLA-DQA10105-DQB10330", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10330") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10331():
    result = parse("HLA-DQA10105-DQB10331", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10331") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10332():
    result = parse("HLA-DQA10105-DQB10332", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10332") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10333():
    result = parse("HLA-DQA10105-DQB10333", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10333") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10334():
    result = parse("HLA-DQA10105-DQB10334", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10334") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10335():
    result = parse("HLA-DQA10105-DQB10335", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10335") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10336():
    result = parse("HLA-DQA10105-DQB10336", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10336") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10337():
    result = parse("HLA-DQA10105-DQB10337", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10337") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10338():
    result = parse("HLA-DQA10105-DQB10338", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10338") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10401():
    result = parse("HLA-DQA10105-DQB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10401") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10402():
    result = parse("HLA-DQA10105-DQB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10402") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10403():
    result = parse("HLA-DQA10105-DQB10403", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10403") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10404():
    result = parse("HLA-DQA10105-DQB10404", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10404") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10405():
    result = parse("HLA-DQA10105-DQB10405", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10405") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10406():
    result = parse("HLA-DQA10105-DQB10406", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10406") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10407():
    result = parse("HLA-DQA10105-DQB10407", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10407") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10408():
    result = parse("HLA-DQA10105-DQB10408", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10408") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10501():
    result = parse("HLA-DQA10105-DQB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10501") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10502():
    result = parse("HLA-DQA10105-DQB10502", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10502") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10503():
    result = parse("HLA-DQA10105-DQB10503", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10503") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10505():
    result = parse("HLA-DQA10105-DQB10505", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10505") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10506():
    result = parse("HLA-DQA10105-DQB10506", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10506") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10507():
    result = parse("HLA-DQA10105-DQB10507", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10507") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10508():
    result = parse("HLA-DQA10105-DQB10508", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10508") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10509():
    result = parse("HLA-DQA10105-DQB10509", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10509") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10510():
    result = parse("HLA-DQA10105-DQB10510", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10510") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10511():
    result = parse("HLA-DQA10105-DQB10511", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10511") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10512():
    result = parse("HLA-DQA10105-DQB10512", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10512") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10513():
    result = parse("HLA-DQA10105-DQB10513", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10513") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10514():
    result = parse("HLA-DQA10105-DQB10514", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10514") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10601():
    result = parse("HLA-DQA10105-DQB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10601") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10602():
    result = parse("HLA-DQA10105-DQB10602", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10602") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10603():
    result = parse("HLA-DQA10105-DQB10603", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10603") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10604():
    result = parse("HLA-DQA10105-DQB10604", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10604") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10607():
    result = parse("HLA-DQA10105-DQB10607", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10607") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10608():
    result = parse("HLA-DQA10105-DQB10608", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10608") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10609():
    result = parse("HLA-DQA10105-DQB10609", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10609") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10610():
    result = parse("HLA-DQA10105-DQB10610", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10610") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10611():
    result = parse("HLA-DQA10105-DQB10611", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10611") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10612():
    result = parse("HLA-DQA10105-DQB10612", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10612") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10614():
    result = parse("HLA-DQA10105-DQB10614", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10614") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10615():
    result = parse("HLA-DQA10105-DQB10615", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10615") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10616():
    result = parse("HLA-DQA10105-DQB10616", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10616") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10617():
    result = parse("HLA-DQA10105-DQB10617", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10617") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10618():
    result = parse("HLA-DQA10105-DQB10618", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10618") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10619():
    result = parse("HLA-DQA10105-DQB10619", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10619") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10621():
    result = parse("HLA-DQA10105-DQB10621", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10621") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10622():
    result = parse("HLA-DQA10105-DQB10622", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10622") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10623():
    result = parse("HLA-DQA10105-DQB10623", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10623") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10624():
    result = parse("HLA-DQA10105-DQB10624", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10624") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10625():
    result = parse("HLA-DQA10105-DQB10625", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10625") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10627():
    result = parse("HLA-DQA10105-DQB10627", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10627") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10628():
    result = parse("HLA-DQA10105-DQB10628", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10628") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10629():
    result = parse("HLA-DQA10105-DQB10629", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10629") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10630():
    result = parse("HLA-DQA10105-DQB10630", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10630") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10631():
    result = parse("HLA-DQA10105-DQB10631", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10631") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10632():
    result = parse("HLA-DQA10105-DQB10632", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10632") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10633():
    result = parse("HLA-DQA10105-DQB10633", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10633") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10634():
    result = parse("HLA-DQA10105-DQB10634", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10634") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10635():
    result = parse("HLA-DQA10105-DQB10635", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10635") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10636():
    result = parse("HLA-DQA10105-DQB10636", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10636") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10637():
    result = parse("HLA-DQA10105-DQB10637", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10637") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10638():
    result = parse("HLA-DQA10105-DQB10638", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10638") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10639():
    result = parse("HLA-DQA10105-DQB10639", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10639") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10640():
    result = parse("HLA-DQA10105-DQB10640", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10640") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10641():
    result = parse("HLA-DQA10105-DQB10641", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10641") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10642():
    result = parse("HLA-DQA10105-DQB10642", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10642") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10643():
    result = parse("HLA-DQA10105-DQB10643", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10643") to be Pair but got {result}'
    )


def test_HLA_DQA10105_DQB10644():
    result = parse("HLA-DQA10105-DQB10644", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10105-DQB10644") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10201():
    result = parse("HLA-DQA10106-DQB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10201") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10202():
    result = parse("HLA-DQA10106-DQB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10202") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10203():
    result = parse("HLA-DQA10106-DQB10203", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10203") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10204():
    result = parse("HLA-DQA10106-DQB10204", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10204") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10205():
    result = parse("HLA-DQA10106-DQB10205", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10205") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10206():
    result = parse("HLA-DQA10106-DQB10206", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10206") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10301():
    result = parse("HLA-DQA10106-DQB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10301") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10302():
    result = parse("HLA-DQA10106-DQB10302", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10302") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10303():
    result = parse("HLA-DQA10106-DQB10303", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10303") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10304():
    result = parse("HLA-DQA10106-DQB10304", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10304") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10305():
    result = parse("HLA-DQA10106-DQB10305", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10305") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10306():
    result = parse("HLA-DQA10106-DQB10306", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10306") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10307():
    result = parse("HLA-DQA10106-DQB10307", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10307") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10308():
    result = parse("HLA-DQA10106-DQB10308", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10308") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10309():
    result = parse("HLA-DQA10106-DQB10309", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10309") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10310():
    result = parse("HLA-DQA10106-DQB10310", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10310") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10311():
    result = parse("HLA-DQA10106-DQB10311", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10311") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10312():
    result = parse("HLA-DQA10106-DQB10312", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10312") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10313():
    result = parse("HLA-DQA10106-DQB10313", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10313") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10314():
    result = parse("HLA-DQA10106-DQB10314", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10314") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10315():
    result = parse("HLA-DQA10106-DQB10315", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10315") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10316():
    result = parse("HLA-DQA10106-DQB10316", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10316") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10317():
    result = parse("HLA-DQA10106-DQB10317", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10317") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10318():
    result = parse("HLA-DQA10106-DQB10318", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10318") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10319():
    result = parse("HLA-DQA10106-DQB10319", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10319") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10320():
    result = parse("HLA-DQA10106-DQB10320", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10320") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10321():
    result = parse("HLA-DQA10106-DQB10321", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10321") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10322():
    result = parse("HLA-DQA10106-DQB10322", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10322") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10323():
    result = parse("HLA-DQA10106-DQB10323", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10323") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10324():
    result = parse("HLA-DQA10106-DQB10324", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10324") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10325():
    result = parse("HLA-DQA10106-DQB10325", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10325") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10326():
    result = parse("HLA-DQA10106-DQB10326", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10326") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10327():
    result = parse("HLA-DQA10106-DQB10327", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10327") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10328():
    result = parse("HLA-DQA10106-DQB10328", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10328") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10329():
    result = parse("HLA-DQA10106-DQB10329", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10329") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10330():
    result = parse("HLA-DQA10106-DQB10330", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10330") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10331():
    result = parse("HLA-DQA10106-DQB10331", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10331") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10332():
    result = parse("HLA-DQA10106-DQB10332", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10332") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10333():
    result = parse("HLA-DQA10106-DQB10333", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10333") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10334():
    result = parse("HLA-DQA10106-DQB10334", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10334") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10335():
    result = parse("HLA-DQA10106-DQB10335", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10335") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10336():
    result = parse("HLA-DQA10106-DQB10336", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10336") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10337():
    result = parse("HLA-DQA10106-DQB10337", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10337") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10338():
    result = parse("HLA-DQA10106-DQB10338", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10338") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10401():
    result = parse("HLA-DQA10106-DQB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10401") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10402():
    result = parse("HLA-DQA10106-DQB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10402") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10403():
    result = parse("HLA-DQA10106-DQB10403", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10403") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10404():
    result = parse("HLA-DQA10106-DQB10404", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10404") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10405():
    result = parse("HLA-DQA10106-DQB10405", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10405") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10406():
    result = parse("HLA-DQA10106-DQB10406", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10406") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10407():
    result = parse("HLA-DQA10106-DQB10407", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10407") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10408():
    result = parse("HLA-DQA10106-DQB10408", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10408") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10501():
    result = parse("HLA-DQA10106-DQB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10501") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10502():
    result = parse("HLA-DQA10106-DQB10502", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10502") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10503():
    result = parse("HLA-DQA10106-DQB10503", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10503") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10505():
    result = parse("HLA-DQA10106-DQB10505", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10505") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10506():
    result = parse("HLA-DQA10106-DQB10506", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10506") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10507():
    result = parse("HLA-DQA10106-DQB10507", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10507") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10508():
    result = parse("HLA-DQA10106-DQB10508", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10508") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10509():
    result = parse("HLA-DQA10106-DQB10509", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10509") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10510():
    result = parse("HLA-DQA10106-DQB10510", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10510") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10511():
    result = parse("HLA-DQA10106-DQB10511", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10511") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10512():
    result = parse("HLA-DQA10106-DQB10512", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10512") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10513():
    result = parse("HLA-DQA10106-DQB10513", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10513") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10514():
    result = parse("HLA-DQA10106-DQB10514", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10514") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10601():
    result = parse("HLA-DQA10106-DQB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10601") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10602():
    result = parse("HLA-DQA10106-DQB10602", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10602") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10603():
    result = parse("HLA-DQA10106-DQB10603", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10603") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10604():
    result = parse("HLA-DQA10106-DQB10604", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10604") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10607():
    result = parse("HLA-DQA10106-DQB10607", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10607") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10608():
    result = parse("HLA-DQA10106-DQB10608", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10608") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10609():
    result = parse("HLA-DQA10106-DQB10609", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10609") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10610():
    result = parse("HLA-DQA10106-DQB10610", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10610") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10611():
    result = parse("HLA-DQA10106-DQB10611", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10611") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10612():
    result = parse("HLA-DQA10106-DQB10612", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10612") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10614():
    result = parse("HLA-DQA10106-DQB10614", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10614") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10615():
    result = parse("HLA-DQA10106-DQB10615", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10615") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10616():
    result = parse("HLA-DQA10106-DQB10616", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10616") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10617():
    result = parse("HLA-DQA10106-DQB10617", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10617") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10618():
    result = parse("HLA-DQA10106-DQB10618", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10618") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10619():
    result = parse("HLA-DQA10106-DQB10619", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10619") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10621():
    result = parse("HLA-DQA10106-DQB10621", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10621") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10622():
    result = parse("HLA-DQA10106-DQB10622", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10622") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10623():
    result = parse("HLA-DQA10106-DQB10623", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10623") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10624():
    result = parse("HLA-DQA10106-DQB10624", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10624") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10625():
    result = parse("HLA-DQA10106-DQB10625", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10625") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10627():
    result = parse("HLA-DQA10106-DQB10627", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10627") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10628():
    result = parse("HLA-DQA10106-DQB10628", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10628") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10629():
    result = parse("HLA-DQA10106-DQB10629", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10629") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10630():
    result = parse("HLA-DQA10106-DQB10630", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10630") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10631():
    result = parse("HLA-DQA10106-DQB10631", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10631") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10632():
    result = parse("HLA-DQA10106-DQB10632", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10632") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10633():
    result = parse("HLA-DQA10106-DQB10633", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10633") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10634():
    result = parse("HLA-DQA10106-DQB10634", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10634") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10635():
    result = parse("HLA-DQA10106-DQB10635", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10635") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10636():
    result = parse("HLA-DQA10106-DQB10636", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10636") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10637():
    result = parse("HLA-DQA10106-DQB10637", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10637") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10638():
    result = parse("HLA-DQA10106-DQB10638", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10638") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10639():
    result = parse("HLA-DQA10106-DQB10639", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10639") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10640():
    result = parse("HLA-DQA10106-DQB10640", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10640") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10641():
    result = parse("HLA-DQA10106-DQB10641", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10641") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10642():
    result = parse("HLA-DQA10106-DQB10642", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10642") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10643():
    result = parse("HLA-DQA10106-DQB10643", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10643") to be Pair but got {result}'
    )


def test_HLA_DQA10106_DQB10644():
    result = parse("HLA-DQA10106-DQB10644", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10106-DQB10644") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10201():
    result = parse("HLA-DQA10107-DQB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10201") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10202():
    result = parse("HLA-DQA10107-DQB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10202") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10203():
    result = parse("HLA-DQA10107-DQB10203", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10203") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10204():
    result = parse("HLA-DQA10107-DQB10204", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10204") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10205():
    result = parse("HLA-DQA10107-DQB10205", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10205") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10206():
    result = parse("HLA-DQA10107-DQB10206", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10206") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10301():
    result = parse("HLA-DQA10107-DQB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10301") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10302():
    result = parse("HLA-DQA10107-DQB10302", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10302") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10303():
    result = parse("HLA-DQA10107-DQB10303", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10303") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10304():
    result = parse("HLA-DQA10107-DQB10304", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10304") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10305():
    result = parse("HLA-DQA10107-DQB10305", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10305") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10306():
    result = parse("HLA-DQA10107-DQB10306", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10306") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10307():
    result = parse("HLA-DQA10107-DQB10307", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10307") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10308():
    result = parse("HLA-DQA10107-DQB10308", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10308") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10309():
    result = parse("HLA-DQA10107-DQB10309", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10309") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10310():
    result = parse("HLA-DQA10107-DQB10310", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10310") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10311():
    result = parse("HLA-DQA10107-DQB10311", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10311") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10312():
    result = parse("HLA-DQA10107-DQB10312", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10312") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10313():
    result = parse("HLA-DQA10107-DQB10313", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10313") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10314():
    result = parse("HLA-DQA10107-DQB10314", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10314") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10315():
    result = parse("HLA-DQA10107-DQB10315", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10315") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10316():
    result = parse("HLA-DQA10107-DQB10316", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10316") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10317():
    result = parse("HLA-DQA10107-DQB10317", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10317") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10318():
    result = parse("HLA-DQA10107-DQB10318", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10318") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10319():
    result = parse("HLA-DQA10107-DQB10319", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10319") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10320():
    result = parse("HLA-DQA10107-DQB10320", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10320") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10321():
    result = parse("HLA-DQA10107-DQB10321", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10321") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10322():
    result = parse("HLA-DQA10107-DQB10322", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10322") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10323():
    result = parse("HLA-DQA10107-DQB10323", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10323") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10324():
    result = parse("HLA-DQA10107-DQB10324", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10324") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10325():
    result = parse("HLA-DQA10107-DQB10325", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10325") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10326():
    result = parse("HLA-DQA10107-DQB10326", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10326") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10327():
    result = parse("HLA-DQA10107-DQB10327", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10327") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10328():
    result = parse("HLA-DQA10107-DQB10328", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10328") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10329():
    result = parse("HLA-DQA10107-DQB10329", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10329") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10330():
    result = parse("HLA-DQA10107-DQB10330", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10330") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10331():
    result = parse("HLA-DQA10107-DQB10331", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10331") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10332():
    result = parse("HLA-DQA10107-DQB10332", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10332") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10333():
    result = parse("HLA-DQA10107-DQB10333", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10333") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10334():
    result = parse("HLA-DQA10107-DQB10334", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10334") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10335():
    result = parse("HLA-DQA10107-DQB10335", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10335") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10336():
    result = parse("HLA-DQA10107-DQB10336", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10336") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10337():
    result = parse("HLA-DQA10107-DQB10337", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10337") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10338():
    result = parse("HLA-DQA10107-DQB10338", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10338") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10401():
    result = parse("HLA-DQA10107-DQB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10401") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10402():
    result = parse("HLA-DQA10107-DQB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10402") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10403():
    result = parse("HLA-DQA10107-DQB10403", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10403") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10404():
    result = parse("HLA-DQA10107-DQB10404", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10404") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10405():
    result = parse("HLA-DQA10107-DQB10405", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10405") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10406():
    result = parse("HLA-DQA10107-DQB10406", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10406") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10407():
    result = parse("HLA-DQA10107-DQB10407", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10407") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10408():
    result = parse("HLA-DQA10107-DQB10408", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10408") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10501():
    result = parse("HLA-DQA10107-DQB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10501") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10502():
    result = parse("HLA-DQA10107-DQB10502", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10502") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10503():
    result = parse("HLA-DQA10107-DQB10503", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10503") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10505():
    result = parse("HLA-DQA10107-DQB10505", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10505") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10506():
    result = parse("HLA-DQA10107-DQB10506", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10506") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10507():
    result = parse("HLA-DQA10107-DQB10507", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10507") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10508():
    result = parse("HLA-DQA10107-DQB10508", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10508") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10509():
    result = parse("HLA-DQA10107-DQB10509", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10509") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10510():
    result = parse("HLA-DQA10107-DQB10510", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10510") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10511():
    result = parse("HLA-DQA10107-DQB10511", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10511") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10512():
    result = parse("HLA-DQA10107-DQB10512", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10512") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10513():
    result = parse("HLA-DQA10107-DQB10513", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10513") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10514():
    result = parse("HLA-DQA10107-DQB10514", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10514") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10601():
    result = parse("HLA-DQA10107-DQB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10601") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10602():
    result = parse("HLA-DQA10107-DQB10602", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10602") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10603():
    result = parse("HLA-DQA10107-DQB10603", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10603") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10604():
    result = parse("HLA-DQA10107-DQB10604", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10604") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10607():
    result = parse("HLA-DQA10107-DQB10607", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10607") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10608():
    result = parse("HLA-DQA10107-DQB10608", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10608") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10609():
    result = parse("HLA-DQA10107-DQB10609", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10609") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10610():
    result = parse("HLA-DQA10107-DQB10610", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10610") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10611():
    result = parse("HLA-DQA10107-DQB10611", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10611") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10612():
    result = parse("HLA-DQA10107-DQB10612", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10612") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10614():
    result = parse("HLA-DQA10107-DQB10614", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10614") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10615():
    result = parse("HLA-DQA10107-DQB10615", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10615") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10616():
    result = parse("HLA-DQA10107-DQB10616", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10616") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10617():
    result = parse("HLA-DQA10107-DQB10617", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10617") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10618():
    result = parse("HLA-DQA10107-DQB10618", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10618") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10619():
    result = parse("HLA-DQA10107-DQB10619", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10619") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10621():
    result = parse("HLA-DQA10107-DQB10621", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10621") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10622():
    result = parse("HLA-DQA10107-DQB10622", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10622") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10623():
    result = parse("HLA-DQA10107-DQB10623", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10623") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10624():
    result = parse("HLA-DQA10107-DQB10624", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10624") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10625():
    result = parse("HLA-DQA10107-DQB10625", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10625") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10627():
    result = parse("HLA-DQA10107-DQB10627", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10627") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10628():
    result = parse("HLA-DQA10107-DQB10628", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10628") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10629():
    result = parse("HLA-DQA10107-DQB10629", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10629") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10630():
    result = parse("HLA-DQA10107-DQB10630", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10630") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10631():
    result = parse("HLA-DQA10107-DQB10631", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10631") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10632():
    result = parse("HLA-DQA10107-DQB10632", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10632") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10633():
    result = parse("HLA-DQA10107-DQB10633", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10633") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10634():
    result = parse("HLA-DQA10107-DQB10634", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10634") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10635():
    result = parse("HLA-DQA10107-DQB10635", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10635") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10636():
    result = parse("HLA-DQA10107-DQB10636", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10636") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10637():
    result = parse("HLA-DQA10107-DQB10637", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10637") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10638():
    result = parse("HLA-DQA10107-DQB10638", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10638") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10639():
    result = parse("HLA-DQA10107-DQB10639", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10639") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10640():
    result = parse("HLA-DQA10107-DQB10640", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10640") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10641():
    result = parse("HLA-DQA10107-DQB10641", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10641") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10642():
    result = parse("HLA-DQA10107-DQB10642", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10642") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10643():
    result = parse("HLA-DQA10107-DQB10643", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10643") to be Pair but got {result}'
    )


def test_HLA_DQA10107_DQB10644():
    result = parse("HLA-DQA10107-DQB10644", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10107-DQB10644") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10201():
    result = parse("HLA-DQA10108-DQB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10201") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10202():
    result = parse("HLA-DQA10108-DQB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10202") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10203():
    result = parse("HLA-DQA10108-DQB10203", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10203") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10204():
    result = parse("HLA-DQA10108-DQB10204", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10204") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10205():
    result = parse("HLA-DQA10108-DQB10205", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10205") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10206():
    result = parse("HLA-DQA10108-DQB10206", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10206") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10301():
    result = parse("HLA-DQA10108-DQB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10301") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10302():
    result = parse("HLA-DQA10108-DQB10302", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10302") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10303():
    result = parse("HLA-DQA10108-DQB10303", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10303") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10304():
    result = parse("HLA-DQA10108-DQB10304", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10304") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10305():
    result = parse("HLA-DQA10108-DQB10305", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10305") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10306():
    result = parse("HLA-DQA10108-DQB10306", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10306") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10307():
    result = parse("HLA-DQA10108-DQB10307", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10307") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10308():
    result = parse("HLA-DQA10108-DQB10308", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10308") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10309():
    result = parse("HLA-DQA10108-DQB10309", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10309") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10310():
    result = parse("HLA-DQA10108-DQB10310", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10310") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10311():
    result = parse("HLA-DQA10108-DQB10311", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10311") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10312():
    result = parse("HLA-DQA10108-DQB10312", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10312") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10313():
    result = parse("HLA-DQA10108-DQB10313", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10313") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10314():
    result = parse("HLA-DQA10108-DQB10314", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10314") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10315():
    result = parse("HLA-DQA10108-DQB10315", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10315") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10316():
    result = parse("HLA-DQA10108-DQB10316", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10316") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10317():
    result = parse("HLA-DQA10108-DQB10317", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10317") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10318():
    result = parse("HLA-DQA10108-DQB10318", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10318") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10319():
    result = parse("HLA-DQA10108-DQB10319", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10319") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10320():
    result = parse("HLA-DQA10108-DQB10320", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10320") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10321():
    result = parse("HLA-DQA10108-DQB10321", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10321") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10322():
    result = parse("HLA-DQA10108-DQB10322", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10322") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10323():
    result = parse("HLA-DQA10108-DQB10323", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10323") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10324():
    result = parse("HLA-DQA10108-DQB10324", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10324") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10325():
    result = parse("HLA-DQA10108-DQB10325", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10325") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10326():
    result = parse("HLA-DQA10108-DQB10326", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10326") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10327():
    result = parse("HLA-DQA10108-DQB10327", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10327") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10328():
    result = parse("HLA-DQA10108-DQB10328", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10328") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10329():
    result = parse("HLA-DQA10108-DQB10329", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10329") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10330():
    result = parse("HLA-DQA10108-DQB10330", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10330") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10331():
    result = parse("HLA-DQA10108-DQB10331", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10331") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10332():
    result = parse("HLA-DQA10108-DQB10332", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10332") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10333():
    result = parse("HLA-DQA10108-DQB10333", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10333") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10334():
    result = parse("HLA-DQA10108-DQB10334", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10334") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10335():
    result = parse("HLA-DQA10108-DQB10335", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10335") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10336():
    result = parse("HLA-DQA10108-DQB10336", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10336") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10337():
    result = parse("HLA-DQA10108-DQB10337", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10337") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10338():
    result = parse("HLA-DQA10108-DQB10338", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10338") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10401():
    result = parse("HLA-DQA10108-DQB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10401") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10402():
    result = parse("HLA-DQA10108-DQB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10402") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10403():
    result = parse("HLA-DQA10108-DQB10403", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10403") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10404():
    result = parse("HLA-DQA10108-DQB10404", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10404") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10405():
    result = parse("HLA-DQA10108-DQB10405", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10405") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10406():
    result = parse("HLA-DQA10108-DQB10406", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10406") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10407():
    result = parse("HLA-DQA10108-DQB10407", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10407") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10408():
    result = parse("HLA-DQA10108-DQB10408", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10408") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10501():
    result = parse("HLA-DQA10108-DQB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10501") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10502():
    result = parse("HLA-DQA10108-DQB10502", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10502") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10503():
    result = parse("HLA-DQA10108-DQB10503", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10503") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10505():
    result = parse("HLA-DQA10108-DQB10505", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10505") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10506():
    result = parse("HLA-DQA10108-DQB10506", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10506") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10507():
    result = parse("HLA-DQA10108-DQB10507", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10507") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10508():
    result = parse("HLA-DQA10108-DQB10508", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10508") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10509():
    result = parse("HLA-DQA10108-DQB10509", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10509") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10510():
    result = parse("HLA-DQA10108-DQB10510", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10510") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10511():
    result = parse("HLA-DQA10108-DQB10511", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10511") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10512():
    result = parse("HLA-DQA10108-DQB10512", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10512") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10513():
    result = parse("HLA-DQA10108-DQB10513", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10513") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10514():
    result = parse("HLA-DQA10108-DQB10514", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10514") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10601():
    result = parse("HLA-DQA10108-DQB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10601") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10602():
    result = parse("HLA-DQA10108-DQB10602", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10602") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10603():
    result = parse("HLA-DQA10108-DQB10603", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10603") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10604():
    result = parse("HLA-DQA10108-DQB10604", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10604") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10607():
    result = parse("HLA-DQA10108-DQB10607", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10607") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10608():
    result = parse("HLA-DQA10108-DQB10608", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10608") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10609():
    result = parse("HLA-DQA10108-DQB10609", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10609") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10610():
    result = parse("HLA-DQA10108-DQB10610", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10610") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10611():
    result = parse("HLA-DQA10108-DQB10611", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10611") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10612():
    result = parse("HLA-DQA10108-DQB10612", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10612") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10614():
    result = parse("HLA-DQA10108-DQB10614", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10614") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10615():
    result = parse("HLA-DQA10108-DQB10615", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10615") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10616():
    result = parse("HLA-DQA10108-DQB10616", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10616") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10617():
    result = parse("HLA-DQA10108-DQB10617", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10617") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10618():
    result = parse("HLA-DQA10108-DQB10618", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10618") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10619():
    result = parse("HLA-DQA10108-DQB10619", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10619") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10621():
    result = parse("HLA-DQA10108-DQB10621", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10621") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10622():
    result = parse("HLA-DQA10108-DQB10622", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10622") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10623():
    result = parse("HLA-DQA10108-DQB10623", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10623") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10624():
    result = parse("HLA-DQA10108-DQB10624", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10624") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10625():
    result = parse("HLA-DQA10108-DQB10625", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10625") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10627():
    result = parse("HLA-DQA10108-DQB10627", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10627") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10628():
    result = parse("HLA-DQA10108-DQB10628", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10628") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10629():
    result = parse("HLA-DQA10108-DQB10629", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10629") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10630():
    result = parse("HLA-DQA10108-DQB10630", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10630") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10631():
    result = parse("HLA-DQA10108-DQB10631", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10631") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10632():
    result = parse("HLA-DQA10108-DQB10632", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10632") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10633():
    result = parse("HLA-DQA10108-DQB10633", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10633") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10634():
    result = parse("HLA-DQA10108-DQB10634", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10634") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10635():
    result = parse("HLA-DQA10108-DQB10635", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10635") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10636():
    result = parse("HLA-DQA10108-DQB10636", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10636") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10637():
    result = parse("HLA-DQA10108-DQB10637", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10637") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10638():
    result = parse("HLA-DQA10108-DQB10638", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10638") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10639():
    result = parse("HLA-DQA10108-DQB10639", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10639") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10640():
    result = parse("HLA-DQA10108-DQB10640", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10640") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10641():
    result = parse("HLA-DQA10108-DQB10641", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10641") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10642():
    result = parse("HLA-DQA10108-DQB10642", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10642") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10643():
    result = parse("HLA-DQA10108-DQB10643", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10643") to be Pair but got {result}'
    )


def test_HLA_DQA10108_DQB10644():
    result = parse("HLA-DQA10108-DQB10644", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10108-DQB10644") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10201():
    result = parse("HLA-DQA10109-DQB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10201") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10202():
    result = parse("HLA-DQA10109-DQB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10202") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10203():
    result = parse("HLA-DQA10109-DQB10203", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10203") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10204():
    result = parse("HLA-DQA10109-DQB10204", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10204") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10205():
    result = parse("HLA-DQA10109-DQB10205", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10205") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10206():
    result = parse("HLA-DQA10109-DQB10206", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10206") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10301():
    result = parse("HLA-DQA10109-DQB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10301") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10302():
    result = parse("HLA-DQA10109-DQB10302", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10302") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10303():
    result = parse("HLA-DQA10109-DQB10303", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10303") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10304():
    result = parse("HLA-DQA10109-DQB10304", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10304") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10305():
    result = parse("HLA-DQA10109-DQB10305", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10305") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10306():
    result = parse("HLA-DQA10109-DQB10306", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10306") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10307():
    result = parse("HLA-DQA10109-DQB10307", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10307") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10308():
    result = parse("HLA-DQA10109-DQB10308", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10308") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10309():
    result = parse("HLA-DQA10109-DQB10309", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10309") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10310():
    result = parse("HLA-DQA10109-DQB10310", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10310") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10311():
    result = parse("HLA-DQA10109-DQB10311", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10311") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10312():
    result = parse("HLA-DQA10109-DQB10312", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10312") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10313():
    result = parse("HLA-DQA10109-DQB10313", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10313") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10314():
    result = parse("HLA-DQA10109-DQB10314", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10314") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10315():
    result = parse("HLA-DQA10109-DQB10315", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10315") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10316():
    result = parse("HLA-DQA10109-DQB10316", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10316") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10317():
    result = parse("HLA-DQA10109-DQB10317", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10317") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10318():
    result = parse("HLA-DQA10109-DQB10318", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10318") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10319():
    result = parse("HLA-DQA10109-DQB10319", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10319") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10320():
    result = parse("HLA-DQA10109-DQB10320", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10320") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10321():
    result = parse("HLA-DQA10109-DQB10321", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10321") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10322():
    result = parse("HLA-DQA10109-DQB10322", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10322") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10323():
    result = parse("HLA-DQA10109-DQB10323", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10323") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10324():
    result = parse("HLA-DQA10109-DQB10324", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10324") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10325():
    result = parse("HLA-DQA10109-DQB10325", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10325") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10326():
    result = parse("HLA-DQA10109-DQB10326", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10326") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10327():
    result = parse("HLA-DQA10109-DQB10327", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10327") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10328():
    result = parse("HLA-DQA10109-DQB10328", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10328") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10329():
    result = parse("HLA-DQA10109-DQB10329", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10329") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10330():
    result = parse("HLA-DQA10109-DQB10330", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10330") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10331():
    result = parse("HLA-DQA10109-DQB10331", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10331") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10332():
    result = parse("HLA-DQA10109-DQB10332", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10332") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10333():
    result = parse("HLA-DQA10109-DQB10333", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10333") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10334():
    result = parse("HLA-DQA10109-DQB10334", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10334") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10335():
    result = parse("HLA-DQA10109-DQB10335", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10335") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10336():
    result = parse("HLA-DQA10109-DQB10336", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10336") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10337():
    result = parse("HLA-DQA10109-DQB10337", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10337") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10338():
    result = parse("HLA-DQA10109-DQB10338", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10338") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10401():
    result = parse("HLA-DQA10109-DQB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10401") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10402():
    result = parse("HLA-DQA10109-DQB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10402") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10403():
    result = parse("HLA-DQA10109-DQB10403", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10403") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10404():
    result = parse("HLA-DQA10109-DQB10404", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10404") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10405():
    result = parse("HLA-DQA10109-DQB10405", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10405") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10406():
    result = parse("HLA-DQA10109-DQB10406", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10406") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10407():
    result = parse("HLA-DQA10109-DQB10407", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10407") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10408():
    result = parse("HLA-DQA10109-DQB10408", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10408") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10501():
    result = parse("HLA-DQA10109-DQB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10501") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10502():
    result = parse("HLA-DQA10109-DQB10502", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10502") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10503():
    result = parse("HLA-DQA10109-DQB10503", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10503") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10505():
    result = parse("HLA-DQA10109-DQB10505", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10505") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10506():
    result = parse("HLA-DQA10109-DQB10506", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10506") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10507():
    result = parse("HLA-DQA10109-DQB10507", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10507") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10508():
    result = parse("HLA-DQA10109-DQB10508", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10508") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10509():
    result = parse("HLA-DQA10109-DQB10509", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10509") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10510():
    result = parse("HLA-DQA10109-DQB10510", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10510") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10511():
    result = parse("HLA-DQA10109-DQB10511", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10511") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10512():
    result = parse("HLA-DQA10109-DQB10512", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10512") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10513():
    result = parse("HLA-DQA10109-DQB10513", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10513") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10514():
    result = parse("HLA-DQA10109-DQB10514", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10514") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10601():
    result = parse("HLA-DQA10109-DQB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10601") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10602():
    result = parse("HLA-DQA10109-DQB10602", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10602") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10603():
    result = parse("HLA-DQA10109-DQB10603", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10603") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10604():
    result = parse("HLA-DQA10109-DQB10604", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10604") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10607():
    result = parse("HLA-DQA10109-DQB10607", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10607") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10608():
    result = parse("HLA-DQA10109-DQB10608", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10608") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10609():
    result = parse("HLA-DQA10109-DQB10609", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10609") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10610():
    result = parse("HLA-DQA10109-DQB10610", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10610") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10611():
    result = parse("HLA-DQA10109-DQB10611", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10611") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10612():
    result = parse("HLA-DQA10109-DQB10612", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10612") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10614():
    result = parse("HLA-DQA10109-DQB10614", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10614") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10615():
    result = parse("HLA-DQA10109-DQB10615", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10615") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10616():
    result = parse("HLA-DQA10109-DQB10616", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10616") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10617():
    result = parse("HLA-DQA10109-DQB10617", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10617") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10618():
    result = parse("HLA-DQA10109-DQB10618", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10618") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10619():
    result = parse("HLA-DQA10109-DQB10619", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10619") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10621():
    result = parse("HLA-DQA10109-DQB10621", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10621") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10622():
    result = parse("HLA-DQA10109-DQB10622", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10622") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10623():
    result = parse("HLA-DQA10109-DQB10623", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10623") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10624():
    result = parse("HLA-DQA10109-DQB10624", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10624") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10625():
    result = parse("HLA-DQA10109-DQB10625", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10625") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10627():
    result = parse("HLA-DQA10109-DQB10627", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10627") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10628():
    result = parse("HLA-DQA10109-DQB10628", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10628") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10629():
    result = parse("HLA-DQA10109-DQB10629", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10629") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10630():
    result = parse("HLA-DQA10109-DQB10630", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10630") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10631():
    result = parse("HLA-DQA10109-DQB10631", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10631") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10632():
    result = parse("HLA-DQA10109-DQB10632", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10632") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10633():
    result = parse("HLA-DQA10109-DQB10633", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10633") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10634():
    result = parse("HLA-DQA10109-DQB10634", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10634") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10635():
    result = parse("HLA-DQA10109-DQB10635", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10635") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10636():
    result = parse("HLA-DQA10109-DQB10636", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10636") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10637():
    result = parse("HLA-DQA10109-DQB10637", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10637") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10638():
    result = parse("HLA-DQA10109-DQB10638", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10638") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10639():
    result = parse("HLA-DQA10109-DQB10639", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10639") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10640():
    result = parse("HLA-DQA10109-DQB10640", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10640") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10641():
    result = parse("HLA-DQA10109-DQB10641", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10641") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10642():
    result = parse("HLA-DQA10109-DQB10642", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10642") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10643():
    result = parse("HLA-DQA10109-DQB10643", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10643") to be Pair but got {result}'
    )


def test_HLA_DQA10109_DQB10644():
    result = parse("HLA-DQA10109-DQB10644", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10109-DQB10644") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10201():
    result = parse("HLA-DQA10201-DQB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10201") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10202():
    result = parse("HLA-DQA10201-DQB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10202") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10203():
    result = parse("HLA-DQA10201-DQB10203", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10203") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10204():
    result = parse("HLA-DQA10201-DQB10204", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10204") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10205():
    result = parse("HLA-DQA10201-DQB10205", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10205") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10206():
    result = parse("HLA-DQA10201-DQB10206", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10206") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10301():
    result = parse("HLA-DQA10201-DQB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10301") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10302():
    result = parse("HLA-DQA10201-DQB10302", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10302") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10303():
    result = parse("HLA-DQA10201-DQB10303", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10303") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10304():
    result = parse("HLA-DQA10201-DQB10304", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10304") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10305():
    result = parse("HLA-DQA10201-DQB10305", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10305") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10306():
    result = parse("HLA-DQA10201-DQB10306", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10306") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10307():
    result = parse("HLA-DQA10201-DQB10307", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10307") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10308():
    result = parse("HLA-DQA10201-DQB10308", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10308") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10309():
    result = parse("HLA-DQA10201-DQB10309", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10309") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10310():
    result = parse("HLA-DQA10201-DQB10310", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10310") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10311():
    result = parse("HLA-DQA10201-DQB10311", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10311") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10312():
    result = parse("HLA-DQA10201-DQB10312", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10312") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10313():
    result = parse("HLA-DQA10201-DQB10313", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10313") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10314():
    result = parse("HLA-DQA10201-DQB10314", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10314") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10315():
    result = parse("HLA-DQA10201-DQB10315", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10315") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10316():
    result = parse("HLA-DQA10201-DQB10316", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10316") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10317():
    result = parse("HLA-DQA10201-DQB10317", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10317") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10318():
    result = parse("HLA-DQA10201-DQB10318", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10318") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10319():
    result = parse("HLA-DQA10201-DQB10319", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10319") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10320():
    result = parse("HLA-DQA10201-DQB10320", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10320") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10321():
    result = parse("HLA-DQA10201-DQB10321", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10321") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10322():
    result = parse("HLA-DQA10201-DQB10322", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10322") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10323():
    result = parse("HLA-DQA10201-DQB10323", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10323") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10324():
    result = parse("HLA-DQA10201-DQB10324", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10324") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10325():
    result = parse("HLA-DQA10201-DQB10325", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10325") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10326():
    result = parse("HLA-DQA10201-DQB10326", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10326") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10327():
    result = parse("HLA-DQA10201-DQB10327", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10327") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10328():
    result = parse("HLA-DQA10201-DQB10328", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10328") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10329():
    result = parse("HLA-DQA10201-DQB10329", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10329") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10330():
    result = parse("HLA-DQA10201-DQB10330", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10330") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10331():
    result = parse("HLA-DQA10201-DQB10331", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10331") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10332():
    result = parse("HLA-DQA10201-DQB10332", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10332") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10333():
    result = parse("HLA-DQA10201-DQB10333", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10333") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10334():
    result = parse("HLA-DQA10201-DQB10334", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10334") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10335():
    result = parse("HLA-DQA10201-DQB10335", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10335") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10336():
    result = parse("HLA-DQA10201-DQB10336", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10336") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10337():
    result = parse("HLA-DQA10201-DQB10337", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10337") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10338():
    result = parse("HLA-DQA10201-DQB10338", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10338") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10401():
    result = parse("HLA-DQA10201-DQB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10401") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10402():
    result = parse("HLA-DQA10201-DQB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10402") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10403():
    result = parse("HLA-DQA10201-DQB10403", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10403") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10404():
    result = parse("HLA-DQA10201-DQB10404", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10404") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10405():
    result = parse("HLA-DQA10201-DQB10405", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10405") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10406():
    result = parse("HLA-DQA10201-DQB10406", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10406") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10407():
    result = parse("HLA-DQA10201-DQB10407", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10407") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10408():
    result = parse("HLA-DQA10201-DQB10408", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10408") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10501():
    result = parse("HLA-DQA10201-DQB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10501") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10502():
    result = parse("HLA-DQA10201-DQB10502", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10502") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10503():
    result = parse("HLA-DQA10201-DQB10503", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10503") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10505():
    result = parse("HLA-DQA10201-DQB10505", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10505") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10506():
    result = parse("HLA-DQA10201-DQB10506", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10506") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10507():
    result = parse("HLA-DQA10201-DQB10507", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10507") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10508():
    result = parse("HLA-DQA10201-DQB10508", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10508") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10509():
    result = parse("HLA-DQA10201-DQB10509", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10509") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10510():
    result = parse("HLA-DQA10201-DQB10510", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10510") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10511():
    result = parse("HLA-DQA10201-DQB10511", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10511") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10512():
    result = parse("HLA-DQA10201-DQB10512", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10512") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10513():
    result = parse("HLA-DQA10201-DQB10513", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10513") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10514():
    result = parse("HLA-DQA10201-DQB10514", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10514") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10601():
    result = parse("HLA-DQA10201-DQB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10601") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10602():
    result = parse("HLA-DQA10201-DQB10602", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10602") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10603():
    result = parse("HLA-DQA10201-DQB10603", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10603") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10604():
    result = parse("HLA-DQA10201-DQB10604", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10604") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10607():
    result = parse("HLA-DQA10201-DQB10607", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10607") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10608():
    result = parse("HLA-DQA10201-DQB10608", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10608") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10609():
    result = parse("HLA-DQA10201-DQB10609", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10609") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10610():
    result = parse("HLA-DQA10201-DQB10610", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10610") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10611():
    result = parse("HLA-DQA10201-DQB10611", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10611") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10612():
    result = parse("HLA-DQA10201-DQB10612", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10612") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10614():
    result = parse("HLA-DQA10201-DQB10614", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10614") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10615():
    result = parse("HLA-DQA10201-DQB10615", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10615") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10616():
    result = parse("HLA-DQA10201-DQB10616", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10616") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10617():
    result = parse("HLA-DQA10201-DQB10617", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10617") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10618():
    result = parse("HLA-DQA10201-DQB10618", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10618") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10619():
    result = parse("HLA-DQA10201-DQB10619", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10619") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10621():
    result = parse("HLA-DQA10201-DQB10621", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10621") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10622():
    result = parse("HLA-DQA10201-DQB10622", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10622") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10623():
    result = parse("HLA-DQA10201-DQB10623", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10623") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10624():
    result = parse("HLA-DQA10201-DQB10624", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10624") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10625():
    result = parse("HLA-DQA10201-DQB10625", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10625") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10627():
    result = parse("HLA-DQA10201-DQB10627", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10627") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10628():
    result = parse("HLA-DQA10201-DQB10628", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10628") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10629():
    result = parse("HLA-DQA10201-DQB10629", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10629") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10630():
    result = parse("HLA-DQA10201-DQB10630", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10630") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10631():
    result = parse("HLA-DQA10201-DQB10631", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10631") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10632():
    result = parse("HLA-DQA10201-DQB10632", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10632") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10633():
    result = parse("HLA-DQA10201-DQB10633", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10633") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10634():
    result = parse("HLA-DQA10201-DQB10634", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10634") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10635():
    result = parse("HLA-DQA10201-DQB10635", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10635") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10636():
    result = parse("HLA-DQA10201-DQB10636", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10636") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10637():
    result = parse("HLA-DQA10201-DQB10637", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10637") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10638():
    result = parse("HLA-DQA10201-DQB10638", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10638") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10639():
    result = parse("HLA-DQA10201-DQB10639", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10639") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10640():
    result = parse("HLA-DQA10201-DQB10640", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10640") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10641():
    result = parse("HLA-DQA10201-DQB10641", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10641") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10642():
    result = parse("HLA-DQA10201-DQB10642", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10642") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10643():
    result = parse("HLA-DQA10201-DQB10643", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10643") to be Pair but got {result}'
    )


def test_HLA_DQA10201_DQB10644():
    result = parse("HLA-DQA10201-DQB10644", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10201-DQB10644") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10201():
    result = parse("HLA-DQA10301-DQB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10201") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10202():
    result = parse("HLA-DQA10301-DQB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10202") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10203():
    result = parse("HLA-DQA10301-DQB10203", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10203") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10204():
    result = parse("HLA-DQA10301-DQB10204", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10204") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10205():
    result = parse("HLA-DQA10301-DQB10205", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10205") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10206():
    result = parse("HLA-DQA10301-DQB10206", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10206") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10301():
    result = parse("HLA-DQA10301-DQB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10301") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10302():
    result = parse("HLA-DQA10301-DQB10302", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10302") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10303():
    result = parse("HLA-DQA10301-DQB10303", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10303") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10304():
    result = parse("HLA-DQA10301-DQB10304", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10304") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10305():
    result = parse("HLA-DQA10301-DQB10305", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10305") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10306():
    result = parse("HLA-DQA10301-DQB10306", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10306") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10307():
    result = parse("HLA-DQA10301-DQB10307", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10307") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10308():
    result = parse("HLA-DQA10301-DQB10308", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10308") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10309():
    result = parse("HLA-DQA10301-DQB10309", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10309") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10310():
    result = parse("HLA-DQA10301-DQB10310", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10310") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10311():
    result = parse("HLA-DQA10301-DQB10311", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10311") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10312():
    result = parse("HLA-DQA10301-DQB10312", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10312") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10313():
    result = parse("HLA-DQA10301-DQB10313", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10313") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10314():
    result = parse("HLA-DQA10301-DQB10314", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10314") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10315():
    result = parse("HLA-DQA10301-DQB10315", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10315") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10316():
    result = parse("HLA-DQA10301-DQB10316", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10316") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10317():
    result = parse("HLA-DQA10301-DQB10317", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10317") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10318():
    result = parse("HLA-DQA10301-DQB10318", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10318") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10319():
    result = parse("HLA-DQA10301-DQB10319", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10319") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10320():
    result = parse("HLA-DQA10301-DQB10320", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10320") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10321():
    result = parse("HLA-DQA10301-DQB10321", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10321") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10322():
    result = parse("HLA-DQA10301-DQB10322", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10322") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10323():
    result = parse("HLA-DQA10301-DQB10323", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10323") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10324():
    result = parse("HLA-DQA10301-DQB10324", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10324") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10325():
    result = parse("HLA-DQA10301-DQB10325", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10325") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10326():
    result = parse("HLA-DQA10301-DQB10326", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10326") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10327():
    result = parse("HLA-DQA10301-DQB10327", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10327") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10328():
    result = parse("HLA-DQA10301-DQB10328", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10328") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10329():
    result = parse("HLA-DQA10301-DQB10329", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10329") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10330():
    result = parse("HLA-DQA10301-DQB10330", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10330") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10331():
    result = parse("HLA-DQA10301-DQB10331", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10331") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10332():
    result = parse("HLA-DQA10301-DQB10332", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10332") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10333():
    result = parse("HLA-DQA10301-DQB10333", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10333") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10334():
    result = parse("HLA-DQA10301-DQB10334", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10334") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10335():
    result = parse("HLA-DQA10301-DQB10335", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10335") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10336():
    result = parse("HLA-DQA10301-DQB10336", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10336") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10337():
    result = parse("HLA-DQA10301-DQB10337", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10337") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10338():
    result = parse("HLA-DQA10301-DQB10338", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10338") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10401():
    result = parse("HLA-DQA10301-DQB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10401") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10402():
    result = parse("HLA-DQA10301-DQB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10402") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10403():
    result = parse("HLA-DQA10301-DQB10403", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10403") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10404():
    result = parse("HLA-DQA10301-DQB10404", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10404") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10405():
    result = parse("HLA-DQA10301-DQB10405", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10405") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10406():
    result = parse("HLA-DQA10301-DQB10406", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10406") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10407():
    result = parse("HLA-DQA10301-DQB10407", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10407") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10408():
    result = parse("HLA-DQA10301-DQB10408", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10408") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10501():
    result = parse("HLA-DQA10301-DQB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10501") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10502():
    result = parse("HLA-DQA10301-DQB10502", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10502") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10503():
    result = parse("HLA-DQA10301-DQB10503", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10503") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10505():
    result = parse("HLA-DQA10301-DQB10505", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10505") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10506():
    result = parse("HLA-DQA10301-DQB10506", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10506") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10507():
    result = parse("HLA-DQA10301-DQB10507", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10507") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10508():
    result = parse("HLA-DQA10301-DQB10508", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10508") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10509():
    result = parse("HLA-DQA10301-DQB10509", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10509") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10510():
    result = parse("HLA-DQA10301-DQB10510", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10510") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10511():
    result = parse("HLA-DQA10301-DQB10511", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10511") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10512():
    result = parse("HLA-DQA10301-DQB10512", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10512") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10513():
    result = parse("HLA-DQA10301-DQB10513", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10513") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10514():
    result = parse("HLA-DQA10301-DQB10514", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10514") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10601():
    result = parse("HLA-DQA10301-DQB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10601") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10602():
    result = parse("HLA-DQA10301-DQB10602", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10602") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10603():
    result = parse("HLA-DQA10301-DQB10603", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10603") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10604():
    result = parse("HLA-DQA10301-DQB10604", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10604") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10607():
    result = parse("HLA-DQA10301-DQB10607", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10607") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10608():
    result = parse("HLA-DQA10301-DQB10608", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10608") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10609():
    result = parse("HLA-DQA10301-DQB10609", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10609") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10610():
    result = parse("HLA-DQA10301-DQB10610", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10610") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10611():
    result = parse("HLA-DQA10301-DQB10611", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10611") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10612():
    result = parse("HLA-DQA10301-DQB10612", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10612") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10614():
    result = parse("HLA-DQA10301-DQB10614", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10614") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10615():
    result = parse("HLA-DQA10301-DQB10615", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10615") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10616():
    result = parse("HLA-DQA10301-DQB10616", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10616") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10617():
    result = parse("HLA-DQA10301-DQB10617", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10617") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10618():
    result = parse("HLA-DQA10301-DQB10618", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10618") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10619():
    result = parse("HLA-DQA10301-DQB10619", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10619") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10621():
    result = parse("HLA-DQA10301-DQB10621", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10621") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10622():
    result = parse("HLA-DQA10301-DQB10622", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10622") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10623():
    result = parse("HLA-DQA10301-DQB10623", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10623") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10624():
    result = parse("HLA-DQA10301-DQB10624", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10624") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10625():
    result = parse("HLA-DQA10301-DQB10625", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10625") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10627():
    result = parse("HLA-DQA10301-DQB10627", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10627") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10628():
    result = parse("HLA-DQA10301-DQB10628", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10628") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10629():
    result = parse("HLA-DQA10301-DQB10629", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10629") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10630():
    result = parse("HLA-DQA10301-DQB10630", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10630") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10631():
    result = parse("HLA-DQA10301-DQB10631", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10631") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10632():
    result = parse("HLA-DQA10301-DQB10632", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10632") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10633():
    result = parse("HLA-DQA10301-DQB10633", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10633") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10634():
    result = parse("HLA-DQA10301-DQB10634", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10634") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10635():
    result = parse("HLA-DQA10301-DQB10635", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10635") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10636():
    result = parse("HLA-DQA10301-DQB10636", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10636") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10637():
    result = parse("HLA-DQA10301-DQB10637", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10637") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10638():
    result = parse("HLA-DQA10301-DQB10638", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10638") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10639():
    result = parse("HLA-DQA10301-DQB10639", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10639") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10640():
    result = parse("HLA-DQA10301-DQB10640", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10640") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10641():
    result = parse("HLA-DQA10301-DQB10641", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10641") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10642():
    result = parse("HLA-DQA10301-DQB10642", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10642") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10643():
    result = parse("HLA-DQA10301-DQB10643", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10643") to be Pair but got {result}'
    )


def test_HLA_DQA10301_DQB10644():
    result = parse("HLA-DQA10301-DQB10644", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10301-DQB10644") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10201():
    result = parse("HLA-DQA10302-DQB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10201") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10202():
    result = parse("HLA-DQA10302-DQB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10202") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10203():
    result = parse("HLA-DQA10302-DQB10203", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10203") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10204():
    result = parse("HLA-DQA10302-DQB10204", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10204") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10205():
    result = parse("HLA-DQA10302-DQB10205", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10205") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10206():
    result = parse("HLA-DQA10302-DQB10206", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10206") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10301():
    result = parse("HLA-DQA10302-DQB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10301") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10302():
    result = parse("HLA-DQA10302-DQB10302", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10302") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10303():
    result = parse("HLA-DQA10302-DQB10303", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10303") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10304():
    result = parse("HLA-DQA10302-DQB10304", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10304") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10305():
    result = parse("HLA-DQA10302-DQB10305", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10305") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10306():
    result = parse("HLA-DQA10302-DQB10306", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10306") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10307():
    result = parse("HLA-DQA10302-DQB10307", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10307") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10308():
    result = parse("HLA-DQA10302-DQB10308", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10308") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10309():
    result = parse("HLA-DQA10302-DQB10309", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10309") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10310():
    result = parse("HLA-DQA10302-DQB10310", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10310") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10311():
    result = parse("HLA-DQA10302-DQB10311", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10311") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10312():
    result = parse("HLA-DQA10302-DQB10312", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10312") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10313():
    result = parse("HLA-DQA10302-DQB10313", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10313") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10314():
    result = parse("HLA-DQA10302-DQB10314", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10314") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10315():
    result = parse("HLA-DQA10302-DQB10315", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10315") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10316():
    result = parse("HLA-DQA10302-DQB10316", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10316") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10317():
    result = parse("HLA-DQA10302-DQB10317", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10317") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10318():
    result = parse("HLA-DQA10302-DQB10318", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10318") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10319():
    result = parse("HLA-DQA10302-DQB10319", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10319") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10320():
    result = parse("HLA-DQA10302-DQB10320", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10320") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10321():
    result = parse("HLA-DQA10302-DQB10321", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10321") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10322():
    result = parse("HLA-DQA10302-DQB10322", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10322") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10323():
    result = parse("HLA-DQA10302-DQB10323", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10323") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10324():
    result = parse("HLA-DQA10302-DQB10324", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10324") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10325():
    result = parse("HLA-DQA10302-DQB10325", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10325") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10326():
    result = parse("HLA-DQA10302-DQB10326", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10326") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10327():
    result = parse("HLA-DQA10302-DQB10327", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10327") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10328():
    result = parse("HLA-DQA10302-DQB10328", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10328") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10329():
    result = parse("HLA-DQA10302-DQB10329", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10329") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10330():
    result = parse("HLA-DQA10302-DQB10330", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10330") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10331():
    result = parse("HLA-DQA10302-DQB10331", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10331") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10332():
    result = parse("HLA-DQA10302-DQB10332", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10332") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10333():
    result = parse("HLA-DQA10302-DQB10333", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10333") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10334():
    result = parse("HLA-DQA10302-DQB10334", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10334") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10335():
    result = parse("HLA-DQA10302-DQB10335", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10335") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10336():
    result = parse("HLA-DQA10302-DQB10336", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10336") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10337():
    result = parse("HLA-DQA10302-DQB10337", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10337") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10338():
    result = parse("HLA-DQA10302-DQB10338", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10338") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10401():
    result = parse("HLA-DQA10302-DQB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10401") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10402():
    result = parse("HLA-DQA10302-DQB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10402") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10403():
    result = parse("HLA-DQA10302-DQB10403", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10403") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10404():
    result = parse("HLA-DQA10302-DQB10404", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10404") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10405():
    result = parse("HLA-DQA10302-DQB10405", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10405") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10406():
    result = parse("HLA-DQA10302-DQB10406", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10406") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10407():
    result = parse("HLA-DQA10302-DQB10407", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10407") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10408():
    result = parse("HLA-DQA10302-DQB10408", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10408") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10501():
    result = parse("HLA-DQA10302-DQB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10501") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10502():
    result = parse("HLA-DQA10302-DQB10502", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10502") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10503():
    result = parse("HLA-DQA10302-DQB10503", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10503") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10505():
    result = parse("HLA-DQA10302-DQB10505", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10505") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10506():
    result = parse("HLA-DQA10302-DQB10506", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10506") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10507():
    result = parse("HLA-DQA10302-DQB10507", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10507") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10508():
    result = parse("HLA-DQA10302-DQB10508", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10508") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10509():
    result = parse("HLA-DQA10302-DQB10509", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10509") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10510():
    result = parse("HLA-DQA10302-DQB10510", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10510") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10511():
    result = parse("HLA-DQA10302-DQB10511", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10511") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10512():
    result = parse("HLA-DQA10302-DQB10512", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10512") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10513():
    result = parse("HLA-DQA10302-DQB10513", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10513") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10514():
    result = parse("HLA-DQA10302-DQB10514", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10514") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10601():
    result = parse("HLA-DQA10302-DQB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10601") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10602():
    result = parse("HLA-DQA10302-DQB10602", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10602") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10603():
    result = parse("HLA-DQA10302-DQB10603", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10603") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10604():
    result = parse("HLA-DQA10302-DQB10604", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10604") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10607():
    result = parse("HLA-DQA10302-DQB10607", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10607") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10608():
    result = parse("HLA-DQA10302-DQB10608", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10608") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10609():
    result = parse("HLA-DQA10302-DQB10609", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10609") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10610():
    result = parse("HLA-DQA10302-DQB10610", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10610") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10611():
    result = parse("HLA-DQA10302-DQB10611", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10611") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10612():
    result = parse("HLA-DQA10302-DQB10612", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10612") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10614():
    result = parse("HLA-DQA10302-DQB10614", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10614") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10615():
    result = parse("HLA-DQA10302-DQB10615", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10615") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10616():
    result = parse("HLA-DQA10302-DQB10616", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10616") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10617():
    result = parse("HLA-DQA10302-DQB10617", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10617") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10618():
    result = parse("HLA-DQA10302-DQB10618", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10618") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10619():
    result = parse("HLA-DQA10302-DQB10619", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10619") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10621():
    result = parse("HLA-DQA10302-DQB10621", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10621") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10622():
    result = parse("HLA-DQA10302-DQB10622", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10622") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10623():
    result = parse("HLA-DQA10302-DQB10623", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10623") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10624():
    result = parse("HLA-DQA10302-DQB10624", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10624") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10625():
    result = parse("HLA-DQA10302-DQB10625", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10625") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10627():
    result = parse("HLA-DQA10302-DQB10627", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10627") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10628():
    result = parse("HLA-DQA10302-DQB10628", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10628") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10629():
    result = parse("HLA-DQA10302-DQB10629", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10629") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10630():
    result = parse("HLA-DQA10302-DQB10630", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10630") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10631():
    result = parse("HLA-DQA10302-DQB10631", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10631") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10632():
    result = parse("HLA-DQA10302-DQB10632", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10632") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10633():
    result = parse("HLA-DQA10302-DQB10633", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10633") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10634():
    result = parse("HLA-DQA10302-DQB10634", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10634") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10635():
    result = parse("HLA-DQA10302-DQB10635", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10635") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10636():
    result = parse("HLA-DQA10302-DQB10636", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10636") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10637():
    result = parse("HLA-DQA10302-DQB10637", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10637") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10638():
    result = parse("HLA-DQA10302-DQB10638", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10638") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10639():
    result = parse("HLA-DQA10302-DQB10639", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10639") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10640():
    result = parse("HLA-DQA10302-DQB10640", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10640") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10641():
    result = parse("HLA-DQA10302-DQB10641", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10641") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10642():
    result = parse("HLA-DQA10302-DQB10642", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10642") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10643():
    result = parse("HLA-DQA10302-DQB10643", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10643") to be Pair but got {result}'
    )


def test_HLA_DQA10302_DQB10644():
    result = parse("HLA-DQA10302-DQB10644", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10302-DQB10644") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10201():
    result = parse("HLA-DQA10303-DQB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10201") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10202():
    result = parse("HLA-DQA10303-DQB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10202") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10203():
    result = parse("HLA-DQA10303-DQB10203", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10203") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10204():
    result = parse("HLA-DQA10303-DQB10204", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10204") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10205():
    result = parse("HLA-DQA10303-DQB10205", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10205") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10206():
    result = parse("HLA-DQA10303-DQB10206", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10206") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10301():
    result = parse("HLA-DQA10303-DQB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10301") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10302():
    result = parse("HLA-DQA10303-DQB10302", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10302") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10303():
    result = parse("HLA-DQA10303-DQB10303", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10303") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10304():
    result = parse("HLA-DQA10303-DQB10304", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10304") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10305():
    result = parse("HLA-DQA10303-DQB10305", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10305") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10306():
    result = parse("HLA-DQA10303-DQB10306", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10306") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10307():
    result = parse("HLA-DQA10303-DQB10307", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10307") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10308():
    result = parse("HLA-DQA10303-DQB10308", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10308") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10309():
    result = parse("HLA-DQA10303-DQB10309", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10309") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10310():
    result = parse("HLA-DQA10303-DQB10310", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10310") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10311():
    result = parse("HLA-DQA10303-DQB10311", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10311") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10312():
    result = parse("HLA-DQA10303-DQB10312", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10312") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10313():
    result = parse("HLA-DQA10303-DQB10313", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10313") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10314():
    result = parse("HLA-DQA10303-DQB10314", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10314") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10315():
    result = parse("HLA-DQA10303-DQB10315", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10315") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10316():
    result = parse("HLA-DQA10303-DQB10316", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10316") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10317():
    result = parse("HLA-DQA10303-DQB10317", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10317") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10318():
    result = parse("HLA-DQA10303-DQB10318", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10318") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10319():
    result = parse("HLA-DQA10303-DQB10319", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10319") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10320():
    result = parse("HLA-DQA10303-DQB10320", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10320") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10321():
    result = parse("HLA-DQA10303-DQB10321", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10321") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10322():
    result = parse("HLA-DQA10303-DQB10322", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10322") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10323():
    result = parse("HLA-DQA10303-DQB10323", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10323") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10324():
    result = parse("HLA-DQA10303-DQB10324", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10324") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10325():
    result = parse("HLA-DQA10303-DQB10325", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10325") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10326():
    result = parse("HLA-DQA10303-DQB10326", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10326") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10327():
    result = parse("HLA-DQA10303-DQB10327", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10327") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10328():
    result = parse("HLA-DQA10303-DQB10328", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10328") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10329():
    result = parse("HLA-DQA10303-DQB10329", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10329") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10330():
    result = parse("HLA-DQA10303-DQB10330", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10330") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10331():
    result = parse("HLA-DQA10303-DQB10331", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10331") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10332():
    result = parse("HLA-DQA10303-DQB10332", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10332") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10333():
    result = parse("HLA-DQA10303-DQB10333", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10333") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10334():
    result = parse("HLA-DQA10303-DQB10334", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10334") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10335():
    result = parse("HLA-DQA10303-DQB10335", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10335") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10336():
    result = parse("HLA-DQA10303-DQB10336", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10336") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10337():
    result = parse("HLA-DQA10303-DQB10337", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10337") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10338():
    result = parse("HLA-DQA10303-DQB10338", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10338") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10401():
    result = parse("HLA-DQA10303-DQB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10401") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10402():
    result = parse("HLA-DQA10303-DQB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10402") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10403():
    result = parse("HLA-DQA10303-DQB10403", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10403") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10404():
    result = parse("HLA-DQA10303-DQB10404", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10404") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10405():
    result = parse("HLA-DQA10303-DQB10405", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10405") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10406():
    result = parse("HLA-DQA10303-DQB10406", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10406") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10407():
    result = parse("HLA-DQA10303-DQB10407", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10407") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10408():
    result = parse("HLA-DQA10303-DQB10408", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10408") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10501():
    result = parse("HLA-DQA10303-DQB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10501") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10502():
    result = parse("HLA-DQA10303-DQB10502", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10502") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10503():
    result = parse("HLA-DQA10303-DQB10503", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10503") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10505():
    result = parse("HLA-DQA10303-DQB10505", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10505") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10506():
    result = parse("HLA-DQA10303-DQB10506", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10506") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10507():
    result = parse("HLA-DQA10303-DQB10507", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10507") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10508():
    result = parse("HLA-DQA10303-DQB10508", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10508") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10509():
    result = parse("HLA-DQA10303-DQB10509", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10509") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10510():
    result = parse("HLA-DQA10303-DQB10510", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10510") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10511():
    result = parse("HLA-DQA10303-DQB10511", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10511") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10512():
    result = parse("HLA-DQA10303-DQB10512", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10512") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10513():
    result = parse("HLA-DQA10303-DQB10513", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10513") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10514():
    result = parse("HLA-DQA10303-DQB10514", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10514") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10601():
    result = parse("HLA-DQA10303-DQB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10601") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10602():
    result = parse("HLA-DQA10303-DQB10602", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10602") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10603():
    result = parse("HLA-DQA10303-DQB10603", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10603") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10604():
    result = parse("HLA-DQA10303-DQB10604", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10604") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10607():
    result = parse("HLA-DQA10303-DQB10607", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10607") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10608():
    result = parse("HLA-DQA10303-DQB10608", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10608") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10609():
    result = parse("HLA-DQA10303-DQB10609", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10609") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10610():
    result = parse("HLA-DQA10303-DQB10610", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10610") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10611():
    result = parse("HLA-DQA10303-DQB10611", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10611") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10612():
    result = parse("HLA-DQA10303-DQB10612", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10612") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10614():
    result = parse("HLA-DQA10303-DQB10614", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10614") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10615():
    result = parse("HLA-DQA10303-DQB10615", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10615") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10616():
    result = parse("HLA-DQA10303-DQB10616", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10616") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10617():
    result = parse("HLA-DQA10303-DQB10617", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10617") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10618():
    result = parse("HLA-DQA10303-DQB10618", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10618") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10619():
    result = parse("HLA-DQA10303-DQB10619", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10619") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10621():
    result = parse("HLA-DQA10303-DQB10621", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10621") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10622():
    result = parse("HLA-DQA10303-DQB10622", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10622") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10623():
    result = parse("HLA-DQA10303-DQB10623", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10623") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10624():
    result = parse("HLA-DQA10303-DQB10624", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10624") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10625():
    result = parse("HLA-DQA10303-DQB10625", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10625") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10627():
    result = parse("HLA-DQA10303-DQB10627", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10627") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10628():
    result = parse("HLA-DQA10303-DQB10628", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10628") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10629():
    result = parse("HLA-DQA10303-DQB10629", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10629") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10630():
    result = parse("HLA-DQA10303-DQB10630", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10630") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10631():
    result = parse("HLA-DQA10303-DQB10631", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10631") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10632():
    result = parse("HLA-DQA10303-DQB10632", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10632") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10633():
    result = parse("HLA-DQA10303-DQB10633", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10633") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10634():
    result = parse("HLA-DQA10303-DQB10634", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10634") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10635():
    result = parse("HLA-DQA10303-DQB10635", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10635") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10636():
    result = parse("HLA-DQA10303-DQB10636", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10636") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10637():
    result = parse("HLA-DQA10303-DQB10637", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10637") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10638():
    result = parse("HLA-DQA10303-DQB10638", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10638") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10639():
    result = parse("HLA-DQA10303-DQB10639", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10639") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10640():
    result = parse("HLA-DQA10303-DQB10640", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10640") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10641():
    result = parse("HLA-DQA10303-DQB10641", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10641") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10642():
    result = parse("HLA-DQA10303-DQB10642", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10642") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10643():
    result = parse("HLA-DQA10303-DQB10643", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10643") to be Pair but got {result}'
    )


def test_HLA_DQA10303_DQB10644():
    result = parse("HLA-DQA10303-DQB10644", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10303-DQB10644") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10201():
    result = parse("HLA-DQA10401-DQB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10201") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10202():
    result = parse("HLA-DQA10401-DQB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10202") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10203():
    result = parse("HLA-DQA10401-DQB10203", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10203") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10204():
    result = parse("HLA-DQA10401-DQB10204", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10204") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10205():
    result = parse("HLA-DQA10401-DQB10205", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10205") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10206():
    result = parse("HLA-DQA10401-DQB10206", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10206") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10301():
    result = parse("HLA-DQA10401-DQB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10301") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10302():
    result = parse("HLA-DQA10401-DQB10302", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10302") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10303():
    result = parse("HLA-DQA10401-DQB10303", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10303") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10304():
    result = parse("HLA-DQA10401-DQB10304", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10304") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10305():
    result = parse("HLA-DQA10401-DQB10305", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10305") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10306():
    result = parse("HLA-DQA10401-DQB10306", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10306") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10307():
    result = parse("HLA-DQA10401-DQB10307", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10307") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10308():
    result = parse("HLA-DQA10401-DQB10308", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10308") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10309():
    result = parse("HLA-DQA10401-DQB10309", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10309") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10310():
    result = parse("HLA-DQA10401-DQB10310", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10310") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10311():
    result = parse("HLA-DQA10401-DQB10311", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10311") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10312():
    result = parse("HLA-DQA10401-DQB10312", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10312") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10313():
    result = parse("HLA-DQA10401-DQB10313", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10313") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10314():
    result = parse("HLA-DQA10401-DQB10314", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10314") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10315():
    result = parse("HLA-DQA10401-DQB10315", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10315") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10316():
    result = parse("HLA-DQA10401-DQB10316", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10316") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10317():
    result = parse("HLA-DQA10401-DQB10317", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10317") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10318():
    result = parse("HLA-DQA10401-DQB10318", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10318") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10319():
    result = parse("HLA-DQA10401-DQB10319", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10319") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10320():
    result = parse("HLA-DQA10401-DQB10320", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10320") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10321():
    result = parse("HLA-DQA10401-DQB10321", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10321") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10322():
    result = parse("HLA-DQA10401-DQB10322", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10322") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10323():
    result = parse("HLA-DQA10401-DQB10323", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10323") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10324():
    result = parse("HLA-DQA10401-DQB10324", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10324") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10325():
    result = parse("HLA-DQA10401-DQB10325", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10325") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10326():
    result = parse("HLA-DQA10401-DQB10326", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10326") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10327():
    result = parse("HLA-DQA10401-DQB10327", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10327") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10328():
    result = parse("HLA-DQA10401-DQB10328", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10328") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10329():
    result = parse("HLA-DQA10401-DQB10329", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10329") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10330():
    result = parse("HLA-DQA10401-DQB10330", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10330") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10331():
    result = parse("HLA-DQA10401-DQB10331", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10331") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10332():
    result = parse("HLA-DQA10401-DQB10332", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10332") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10333():
    result = parse("HLA-DQA10401-DQB10333", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10333") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10334():
    result = parse("HLA-DQA10401-DQB10334", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10334") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10335():
    result = parse("HLA-DQA10401-DQB10335", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10335") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10336():
    result = parse("HLA-DQA10401-DQB10336", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10336") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10337():
    result = parse("HLA-DQA10401-DQB10337", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10337") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10338():
    result = parse("HLA-DQA10401-DQB10338", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10338") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10401():
    result = parse("HLA-DQA10401-DQB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10401") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10402():
    result = parse("HLA-DQA10401-DQB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10402") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10403():
    result = parse("HLA-DQA10401-DQB10403", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10403") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10404():
    result = parse("HLA-DQA10401-DQB10404", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10404") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10405():
    result = parse("HLA-DQA10401-DQB10405", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10405") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10406():
    result = parse("HLA-DQA10401-DQB10406", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10406") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10407():
    result = parse("HLA-DQA10401-DQB10407", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10407") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10408():
    result = parse("HLA-DQA10401-DQB10408", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10408") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10501():
    result = parse("HLA-DQA10401-DQB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10501") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10502():
    result = parse("HLA-DQA10401-DQB10502", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10502") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10503():
    result = parse("HLA-DQA10401-DQB10503", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10503") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10505():
    result = parse("HLA-DQA10401-DQB10505", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10505") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10506():
    result = parse("HLA-DQA10401-DQB10506", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10506") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10507():
    result = parse("HLA-DQA10401-DQB10507", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10507") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10508():
    result = parse("HLA-DQA10401-DQB10508", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10508") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10509():
    result = parse("HLA-DQA10401-DQB10509", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10509") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10510():
    result = parse("HLA-DQA10401-DQB10510", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10510") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10511():
    result = parse("HLA-DQA10401-DQB10511", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10511") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10512():
    result = parse("HLA-DQA10401-DQB10512", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10512") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10513():
    result = parse("HLA-DQA10401-DQB10513", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10513") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10514():
    result = parse("HLA-DQA10401-DQB10514", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10514") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10601():
    result = parse("HLA-DQA10401-DQB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10601") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10602():
    result = parse("HLA-DQA10401-DQB10602", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10602") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10603():
    result = parse("HLA-DQA10401-DQB10603", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10603") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10604():
    result = parse("HLA-DQA10401-DQB10604", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10604") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10607():
    result = parse("HLA-DQA10401-DQB10607", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10607") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10608():
    result = parse("HLA-DQA10401-DQB10608", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10608") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10609():
    result = parse("HLA-DQA10401-DQB10609", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10609") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10610():
    result = parse("HLA-DQA10401-DQB10610", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10610") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10611():
    result = parse("HLA-DQA10401-DQB10611", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10611") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10612():
    result = parse("HLA-DQA10401-DQB10612", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10612") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10614():
    result = parse("HLA-DQA10401-DQB10614", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10614") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10615():
    result = parse("HLA-DQA10401-DQB10615", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10615") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10616():
    result = parse("HLA-DQA10401-DQB10616", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10616") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10617():
    result = parse("HLA-DQA10401-DQB10617", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10617") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10618():
    result = parse("HLA-DQA10401-DQB10618", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10618") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10619():
    result = parse("HLA-DQA10401-DQB10619", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10619") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10621():
    result = parse("HLA-DQA10401-DQB10621", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10621") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10622():
    result = parse("HLA-DQA10401-DQB10622", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10622") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10623():
    result = parse("HLA-DQA10401-DQB10623", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10623") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10624():
    result = parse("HLA-DQA10401-DQB10624", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10624") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10625():
    result = parse("HLA-DQA10401-DQB10625", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10625") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10627():
    result = parse("HLA-DQA10401-DQB10627", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10627") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10628():
    result = parse("HLA-DQA10401-DQB10628", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10628") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10629():
    result = parse("HLA-DQA10401-DQB10629", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10629") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10630():
    result = parse("HLA-DQA10401-DQB10630", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10630") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10631():
    result = parse("HLA-DQA10401-DQB10631", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10631") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10632():
    result = parse("HLA-DQA10401-DQB10632", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10632") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10633():
    result = parse("HLA-DQA10401-DQB10633", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10633") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10634():
    result = parse("HLA-DQA10401-DQB10634", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10634") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10635():
    result = parse("HLA-DQA10401-DQB10635", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10635") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10636():
    result = parse("HLA-DQA10401-DQB10636", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10636") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10637():
    result = parse("HLA-DQA10401-DQB10637", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10637") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10638():
    result = parse("HLA-DQA10401-DQB10638", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10638") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10639():
    result = parse("HLA-DQA10401-DQB10639", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10639") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10640():
    result = parse("HLA-DQA10401-DQB10640", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10640") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10641():
    result = parse("HLA-DQA10401-DQB10641", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10641") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10642():
    result = parse("HLA-DQA10401-DQB10642", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10642") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10643():
    result = parse("HLA-DQA10401-DQB10643", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10643") to be Pair but got {result}'
    )


def test_HLA_DQA10401_DQB10644():
    result = parse("HLA-DQA10401-DQB10644", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10401-DQB10644") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10201():
    result = parse("HLA-DQA10402-DQB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10201") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10202():
    result = parse("HLA-DQA10402-DQB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10202") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10203():
    result = parse("HLA-DQA10402-DQB10203", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10203") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10204():
    result = parse("HLA-DQA10402-DQB10204", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10204") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10205():
    result = parse("HLA-DQA10402-DQB10205", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10205") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10206():
    result = parse("HLA-DQA10402-DQB10206", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10206") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10301():
    result = parse("HLA-DQA10402-DQB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10301") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10302():
    result = parse("HLA-DQA10402-DQB10302", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10302") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10303():
    result = parse("HLA-DQA10402-DQB10303", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10303") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10304():
    result = parse("HLA-DQA10402-DQB10304", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10304") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10305():
    result = parse("HLA-DQA10402-DQB10305", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10305") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10306():
    result = parse("HLA-DQA10402-DQB10306", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10306") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10307():
    result = parse("HLA-DQA10402-DQB10307", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10307") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10308():
    result = parse("HLA-DQA10402-DQB10308", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10308") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10309():
    result = parse("HLA-DQA10402-DQB10309", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10309") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10310():
    result = parse("HLA-DQA10402-DQB10310", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10310") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10311():
    result = parse("HLA-DQA10402-DQB10311", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10311") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10312():
    result = parse("HLA-DQA10402-DQB10312", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10312") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10313():
    result = parse("HLA-DQA10402-DQB10313", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10313") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10314():
    result = parse("HLA-DQA10402-DQB10314", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10314") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10315():
    result = parse("HLA-DQA10402-DQB10315", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10315") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10316():
    result = parse("HLA-DQA10402-DQB10316", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10316") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10317():
    result = parse("HLA-DQA10402-DQB10317", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10317") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10318():
    result = parse("HLA-DQA10402-DQB10318", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10318") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10319():
    result = parse("HLA-DQA10402-DQB10319", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10319") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10320():
    result = parse("HLA-DQA10402-DQB10320", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10320") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10321():
    result = parse("HLA-DQA10402-DQB10321", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10321") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10322():
    result = parse("HLA-DQA10402-DQB10322", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10322") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10323():
    result = parse("HLA-DQA10402-DQB10323", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10323") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10324():
    result = parse("HLA-DQA10402-DQB10324", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10324") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10325():
    result = parse("HLA-DQA10402-DQB10325", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10325") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10326():
    result = parse("HLA-DQA10402-DQB10326", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10326") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10327():
    result = parse("HLA-DQA10402-DQB10327", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10327") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10328():
    result = parse("HLA-DQA10402-DQB10328", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10328") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10329():
    result = parse("HLA-DQA10402-DQB10329", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10329") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10330():
    result = parse("HLA-DQA10402-DQB10330", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10330") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10331():
    result = parse("HLA-DQA10402-DQB10331", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10331") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10332():
    result = parse("HLA-DQA10402-DQB10332", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10332") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10333():
    result = parse("HLA-DQA10402-DQB10333", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10333") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10334():
    result = parse("HLA-DQA10402-DQB10334", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10334") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10335():
    result = parse("HLA-DQA10402-DQB10335", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10335") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10336():
    result = parse("HLA-DQA10402-DQB10336", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10336") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10337():
    result = parse("HLA-DQA10402-DQB10337", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10337") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10338():
    result = parse("HLA-DQA10402-DQB10338", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10338") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10401():
    result = parse("HLA-DQA10402-DQB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10401") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10402():
    result = parse("HLA-DQA10402-DQB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10402") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10403():
    result = parse("HLA-DQA10402-DQB10403", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10403") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10404():
    result = parse("HLA-DQA10402-DQB10404", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10404") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10405():
    result = parse("HLA-DQA10402-DQB10405", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10405") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10406():
    result = parse("HLA-DQA10402-DQB10406", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10406") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10407():
    result = parse("HLA-DQA10402-DQB10407", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10407") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10408():
    result = parse("HLA-DQA10402-DQB10408", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10408") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10501():
    result = parse("HLA-DQA10402-DQB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10501") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10502():
    result = parse("HLA-DQA10402-DQB10502", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10502") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10503():
    result = parse("HLA-DQA10402-DQB10503", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10503") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10505():
    result = parse("HLA-DQA10402-DQB10505", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10505") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10506():
    result = parse("HLA-DQA10402-DQB10506", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10506") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10507():
    result = parse("HLA-DQA10402-DQB10507", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10507") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10508():
    result = parse("HLA-DQA10402-DQB10508", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10508") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10509():
    result = parse("HLA-DQA10402-DQB10509", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10509") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10510():
    result = parse("HLA-DQA10402-DQB10510", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10510") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10511():
    result = parse("HLA-DQA10402-DQB10511", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10511") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10512():
    result = parse("HLA-DQA10402-DQB10512", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10512") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10513():
    result = parse("HLA-DQA10402-DQB10513", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10513") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10514():
    result = parse("HLA-DQA10402-DQB10514", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10514") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10601():
    result = parse("HLA-DQA10402-DQB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10601") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10602():
    result = parse("HLA-DQA10402-DQB10602", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10602") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10603():
    result = parse("HLA-DQA10402-DQB10603", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10603") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10604():
    result = parse("HLA-DQA10402-DQB10604", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10604") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10607():
    result = parse("HLA-DQA10402-DQB10607", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10607") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10608():
    result = parse("HLA-DQA10402-DQB10608", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10608") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10609():
    result = parse("HLA-DQA10402-DQB10609", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10609") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10610():
    result = parse("HLA-DQA10402-DQB10610", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10610") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10611():
    result = parse("HLA-DQA10402-DQB10611", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10611") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10612():
    result = parse("HLA-DQA10402-DQB10612", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10612") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10614():
    result = parse("HLA-DQA10402-DQB10614", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10614") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10615():
    result = parse("HLA-DQA10402-DQB10615", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10615") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10616():
    result = parse("HLA-DQA10402-DQB10616", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10616") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10617():
    result = parse("HLA-DQA10402-DQB10617", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10617") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10618():
    result = parse("HLA-DQA10402-DQB10618", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10618") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10619():
    result = parse("HLA-DQA10402-DQB10619", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10619") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10621():
    result = parse("HLA-DQA10402-DQB10621", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10621") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10622():
    result = parse("HLA-DQA10402-DQB10622", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10622") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10623():
    result = parse("HLA-DQA10402-DQB10623", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10623") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10624():
    result = parse("HLA-DQA10402-DQB10624", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10624") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10625():
    result = parse("HLA-DQA10402-DQB10625", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10625") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10627():
    result = parse("HLA-DQA10402-DQB10627", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10627") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10628():
    result = parse("HLA-DQA10402-DQB10628", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10628") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10629():
    result = parse("HLA-DQA10402-DQB10629", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10629") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10630():
    result = parse("HLA-DQA10402-DQB10630", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10630") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10631():
    result = parse("HLA-DQA10402-DQB10631", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10631") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10632():
    result = parse("HLA-DQA10402-DQB10632", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10632") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10633():
    result = parse("HLA-DQA10402-DQB10633", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10633") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10634():
    result = parse("HLA-DQA10402-DQB10634", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10634") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10635():
    result = parse("HLA-DQA10402-DQB10635", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10635") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10636():
    result = parse("HLA-DQA10402-DQB10636", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10636") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10637():
    result = parse("HLA-DQA10402-DQB10637", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10637") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10638():
    result = parse("HLA-DQA10402-DQB10638", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10638") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10639():
    result = parse("HLA-DQA10402-DQB10639", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10639") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10640():
    result = parse("HLA-DQA10402-DQB10640", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10640") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10641():
    result = parse("HLA-DQA10402-DQB10641", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10641") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10642():
    result = parse("HLA-DQA10402-DQB10642", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10642") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10643():
    result = parse("HLA-DQA10402-DQB10643", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10643") to be Pair but got {result}'
    )


def test_HLA_DQA10402_DQB10644():
    result = parse("HLA-DQA10402-DQB10644", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10402-DQB10644") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10201():
    result = parse("HLA-DQA10404-DQB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10201") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10202():
    result = parse("HLA-DQA10404-DQB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10202") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10203():
    result = parse("HLA-DQA10404-DQB10203", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10203") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10204():
    result = parse("HLA-DQA10404-DQB10204", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10204") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10205():
    result = parse("HLA-DQA10404-DQB10205", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10205") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10206():
    result = parse("HLA-DQA10404-DQB10206", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10206") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10301():
    result = parse("HLA-DQA10404-DQB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10301") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10302():
    result = parse("HLA-DQA10404-DQB10302", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10302") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10303():
    result = parse("HLA-DQA10404-DQB10303", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10303") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10304():
    result = parse("HLA-DQA10404-DQB10304", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10304") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10305():
    result = parse("HLA-DQA10404-DQB10305", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10305") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10306():
    result = parse("HLA-DQA10404-DQB10306", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10306") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10307():
    result = parse("HLA-DQA10404-DQB10307", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10307") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10308():
    result = parse("HLA-DQA10404-DQB10308", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10308") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10309():
    result = parse("HLA-DQA10404-DQB10309", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10309") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10310():
    result = parse("HLA-DQA10404-DQB10310", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10310") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10311():
    result = parse("HLA-DQA10404-DQB10311", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10311") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10312():
    result = parse("HLA-DQA10404-DQB10312", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10312") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10313():
    result = parse("HLA-DQA10404-DQB10313", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10313") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10314():
    result = parse("HLA-DQA10404-DQB10314", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10314") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10315():
    result = parse("HLA-DQA10404-DQB10315", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10315") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10316():
    result = parse("HLA-DQA10404-DQB10316", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10316") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10317():
    result = parse("HLA-DQA10404-DQB10317", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10317") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10318():
    result = parse("HLA-DQA10404-DQB10318", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10318") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10319():
    result = parse("HLA-DQA10404-DQB10319", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10319") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10320():
    result = parse("HLA-DQA10404-DQB10320", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10320") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10321():
    result = parse("HLA-DQA10404-DQB10321", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10321") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10322():
    result = parse("HLA-DQA10404-DQB10322", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10322") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10323():
    result = parse("HLA-DQA10404-DQB10323", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10323") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10324():
    result = parse("HLA-DQA10404-DQB10324", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10324") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10325():
    result = parse("HLA-DQA10404-DQB10325", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10325") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10326():
    result = parse("HLA-DQA10404-DQB10326", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10326") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10327():
    result = parse("HLA-DQA10404-DQB10327", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10327") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10328():
    result = parse("HLA-DQA10404-DQB10328", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10328") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10329():
    result = parse("HLA-DQA10404-DQB10329", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10329") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10330():
    result = parse("HLA-DQA10404-DQB10330", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10330") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10331():
    result = parse("HLA-DQA10404-DQB10331", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10331") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10332():
    result = parse("HLA-DQA10404-DQB10332", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10332") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10333():
    result = parse("HLA-DQA10404-DQB10333", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10333") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10334():
    result = parse("HLA-DQA10404-DQB10334", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10334") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10335():
    result = parse("HLA-DQA10404-DQB10335", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10335") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10336():
    result = parse("HLA-DQA10404-DQB10336", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10336") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10337():
    result = parse("HLA-DQA10404-DQB10337", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10337") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10338():
    result = parse("HLA-DQA10404-DQB10338", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10338") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10401():
    result = parse("HLA-DQA10404-DQB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10401") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10402():
    result = parse("HLA-DQA10404-DQB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10402") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10403():
    result = parse("HLA-DQA10404-DQB10403", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10403") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10404():
    result = parse("HLA-DQA10404-DQB10404", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10404") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10405():
    result = parse("HLA-DQA10404-DQB10405", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10405") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10406():
    result = parse("HLA-DQA10404-DQB10406", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10406") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10407():
    result = parse("HLA-DQA10404-DQB10407", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10407") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10408():
    result = parse("HLA-DQA10404-DQB10408", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10408") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10501():
    result = parse("HLA-DQA10404-DQB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10501") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10502():
    result = parse("HLA-DQA10404-DQB10502", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10502") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10503():
    result = parse("HLA-DQA10404-DQB10503", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10503") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10505():
    result = parse("HLA-DQA10404-DQB10505", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10505") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10506():
    result = parse("HLA-DQA10404-DQB10506", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10506") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10507():
    result = parse("HLA-DQA10404-DQB10507", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10507") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10508():
    result = parse("HLA-DQA10404-DQB10508", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10508") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10509():
    result = parse("HLA-DQA10404-DQB10509", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10509") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10510():
    result = parse("HLA-DQA10404-DQB10510", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10510") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10511():
    result = parse("HLA-DQA10404-DQB10511", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10511") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10512():
    result = parse("HLA-DQA10404-DQB10512", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10512") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10513():
    result = parse("HLA-DQA10404-DQB10513", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10513") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10514():
    result = parse("HLA-DQA10404-DQB10514", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10514") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10601():
    result = parse("HLA-DQA10404-DQB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10601") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10602():
    result = parse("HLA-DQA10404-DQB10602", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10602") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10603():
    result = parse("HLA-DQA10404-DQB10603", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10603") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10604():
    result = parse("HLA-DQA10404-DQB10604", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10604") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10607():
    result = parse("HLA-DQA10404-DQB10607", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10607") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10608():
    result = parse("HLA-DQA10404-DQB10608", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10608") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10609():
    result = parse("HLA-DQA10404-DQB10609", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10609") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10610():
    result = parse("HLA-DQA10404-DQB10610", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10610") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10611():
    result = parse("HLA-DQA10404-DQB10611", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10611") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10612():
    result = parse("HLA-DQA10404-DQB10612", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10612") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10614():
    result = parse("HLA-DQA10404-DQB10614", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10614") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10615():
    result = parse("HLA-DQA10404-DQB10615", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10615") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10616():
    result = parse("HLA-DQA10404-DQB10616", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10616") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10617():
    result = parse("HLA-DQA10404-DQB10617", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10617") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10618():
    result = parse("HLA-DQA10404-DQB10618", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10618") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10619():
    result = parse("HLA-DQA10404-DQB10619", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10619") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10621():
    result = parse("HLA-DQA10404-DQB10621", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10621") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10622():
    result = parse("HLA-DQA10404-DQB10622", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10622") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10623():
    result = parse("HLA-DQA10404-DQB10623", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10623") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10624():
    result = parse("HLA-DQA10404-DQB10624", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10624") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10625():
    result = parse("HLA-DQA10404-DQB10625", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10625") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10627():
    result = parse("HLA-DQA10404-DQB10627", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10627") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10628():
    result = parse("HLA-DQA10404-DQB10628", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10628") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10629():
    result = parse("HLA-DQA10404-DQB10629", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10629") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10630():
    result = parse("HLA-DQA10404-DQB10630", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10630") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10631():
    result = parse("HLA-DQA10404-DQB10631", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10631") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10632():
    result = parse("HLA-DQA10404-DQB10632", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10632") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10633():
    result = parse("HLA-DQA10404-DQB10633", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10633") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10634():
    result = parse("HLA-DQA10404-DQB10634", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10634") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10635():
    result = parse("HLA-DQA10404-DQB10635", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10635") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10636():
    result = parse("HLA-DQA10404-DQB10636", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10636") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10637():
    result = parse("HLA-DQA10404-DQB10637", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10637") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10638():
    result = parse("HLA-DQA10404-DQB10638", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10638") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10639():
    result = parse("HLA-DQA10404-DQB10639", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10639") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10640():
    result = parse("HLA-DQA10404-DQB10640", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10640") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10641():
    result = parse("HLA-DQA10404-DQB10641", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10641") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10642():
    result = parse("HLA-DQA10404-DQB10642", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10642") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10643():
    result = parse("HLA-DQA10404-DQB10643", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10643") to be Pair but got {result}'
    )


def test_HLA_DQA10404_DQB10644():
    result = parse("HLA-DQA10404-DQB10644", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10404-DQB10644") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10201():
    result = parse("HLA-DQA10501-DQB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10201") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10202():
    result = parse("HLA-DQA10501-DQB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10202") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10203():
    result = parse("HLA-DQA10501-DQB10203", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10203") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10204():
    result = parse("HLA-DQA10501-DQB10204", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10204") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10205():
    result = parse("HLA-DQA10501-DQB10205", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10205") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10206():
    result = parse("HLA-DQA10501-DQB10206", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10206") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10301():
    result = parse("HLA-DQA10501-DQB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10301") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10302():
    result = parse("HLA-DQA10501-DQB10302", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10302") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10303():
    result = parse("HLA-DQA10501-DQB10303", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10303") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10304():
    result = parse("HLA-DQA10501-DQB10304", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10304") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10305():
    result = parse("HLA-DQA10501-DQB10305", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10305") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10306():
    result = parse("HLA-DQA10501-DQB10306", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10306") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10307():
    result = parse("HLA-DQA10501-DQB10307", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10307") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10308():
    result = parse("HLA-DQA10501-DQB10308", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10308") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10309():
    result = parse("HLA-DQA10501-DQB10309", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10309") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10310():
    result = parse("HLA-DQA10501-DQB10310", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10310") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10311():
    result = parse("HLA-DQA10501-DQB10311", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10311") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10312():
    result = parse("HLA-DQA10501-DQB10312", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10312") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10313():
    result = parse("HLA-DQA10501-DQB10313", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10313") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10314():
    result = parse("HLA-DQA10501-DQB10314", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10314") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10315():
    result = parse("HLA-DQA10501-DQB10315", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10315") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10316():
    result = parse("HLA-DQA10501-DQB10316", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10316") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10317():
    result = parse("HLA-DQA10501-DQB10317", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10317") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10318():
    result = parse("HLA-DQA10501-DQB10318", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10318") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10319():
    result = parse("HLA-DQA10501-DQB10319", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10319") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10320():
    result = parse("HLA-DQA10501-DQB10320", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10320") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10321():
    result = parse("HLA-DQA10501-DQB10321", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10321") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10322():
    result = parse("HLA-DQA10501-DQB10322", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10322") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10323():
    result = parse("HLA-DQA10501-DQB10323", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10323") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10324():
    result = parse("HLA-DQA10501-DQB10324", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10324") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10325():
    result = parse("HLA-DQA10501-DQB10325", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10325") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10326():
    result = parse("HLA-DQA10501-DQB10326", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10326") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10327():
    result = parse("HLA-DQA10501-DQB10327", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10327") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10328():
    result = parse("HLA-DQA10501-DQB10328", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10328") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10329():
    result = parse("HLA-DQA10501-DQB10329", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10329") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10330():
    result = parse("HLA-DQA10501-DQB10330", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10330") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10331():
    result = parse("HLA-DQA10501-DQB10331", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10331") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10332():
    result = parse("HLA-DQA10501-DQB10332", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10332") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10333():
    result = parse("HLA-DQA10501-DQB10333", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10333") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10334():
    result = parse("HLA-DQA10501-DQB10334", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10334") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10335():
    result = parse("HLA-DQA10501-DQB10335", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10335") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10336():
    result = parse("HLA-DQA10501-DQB10336", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10336") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10337():
    result = parse("HLA-DQA10501-DQB10337", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10337") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10338():
    result = parse("HLA-DQA10501-DQB10338", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10338") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10401():
    result = parse("HLA-DQA10501-DQB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10401") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10402():
    result = parse("HLA-DQA10501-DQB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10402") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10403():
    result = parse("HLA-DQA10501-DQB10403", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10403") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10404():
    result = parse("HLA-DQA10501-DQB10404", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10404") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10405():
    result = parse("HLA-DQA10501-DQB10405", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10405") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10406():
    result = parse("HLA-DQA10501-DQB10406", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10406") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10407():
    result = parse("HLA-DQA10501-DQB10407", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10407") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10408():
    result = parse("HLA-DQA10501-DQB10408", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10408") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10501():
    result = parse("HLA-DQA10501-DQB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10501") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10502():
    result = parse("HLA-DQA10501-DQB10502", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10502") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10503():
    result = parse("HLA-DQA10501-DQB10503", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10503") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10505():
    result = parse("HLA-DQA10501-DQB10505", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10505") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10506():
    result = parse("HLA-DQA10501-DQB10506", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10506") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10507():
    result = parse("HLA-DQA10501-DQB10507", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10507") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10508():
    result = parse("HLA-DQA10501-DQB10508", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10508") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10509():
    result = parse("HLA-DQA10501-DQB10509", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10509") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10510():
    result = parse("HLA-DQA10501-DQB10510", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10510") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10511():
    result = parse("HLA-DQA10501-DQB10511", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10511") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10512():
    result = parse("HLA-DQA10501-DQB10512", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10512") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10513():
    result = parse("HLA-DQA10501-DQB10513", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10513") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10514():
    result = parse("HLA-DQA10501-DQB10514", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10514") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10601():
    result = parse("HLA-DQA10501-DQB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10601") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10602():
    result = parse("HLA-DQA10501-DQB10602", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10602") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10603():
    result = parse("HLA-DQA10501-DQB10603", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10603") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10604():
    result = parse("HLA-DQA10501-DQB10604", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10604") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10607():
    result = parse("HLA-DQA10501-DQB10607", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10607") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10608():
    result = parse("HLA-DQA10501-DQB10608", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10608") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10609():
    result = parse("HLA-DQA10501-DQB10609", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10609") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10610():
    result = parse("HLA-DQA10501-DQB10610", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10610") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10611():
    result = parse("HLA-DQA10501-DQB10611", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10611") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10612():
    result = parse("HLA-DQA10501-DQB10612", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10612") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10614():
    result = parse("HLA-DQA10501-DQB10614", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10614") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10615():
    result = parse("HLA-DQA10501-DQB10615", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10615") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10616():
    result = parse("HLA-DQA10501-DQB10616", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10616") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10617():
    result = parse("HLA-DQA10501-DQB10617", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10617") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10618():
    result = parse("HLA-DQA10501-DQB10618", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10618") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10619():
    result = parse("HLA-DQA10501-DQB10619", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10619") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10621():
    result = parse("HLA-DQA10501-DQB10621", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10621") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10622():
    result = parse("HLA-DQA10501-DQB10622", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10622") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10623():
    result = parse("HLA-DQA10501-DQB10623", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10623") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10624():
    result = parse("HLA-DQA10501-DQB10624", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10624") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10625():
    result = parse("HLA-DQA10501-DQB10625", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10625") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10627():
    result = parse("HLA-DQA10501-DQB10627", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10627") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10628():
    result = parse("HLA-DQA10501-DQB10628", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10628") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10629():
    result = parse("HLA-DQA10501-DQB10629", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10629") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10630():
    result = parse("HLA-DQA10501-DQB10630", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10630") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10631():
    result = parse("HLA-DQA10501-DQB10631", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10631") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10632():
    result = parse("HLA-DQA10501-DQB10632", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10632") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10633():
    result = parse("HLA-DQA10501-DQB10633", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10633") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10634():
    result = parse("HLA-DQA10501-DQB10634", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10634") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10635():
    result = parse("HLA-DQA10501-DQB10635", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10635") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10636():
    result = parse("HLA-DQA10501-DQB10636", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10636") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10637():
    result = parse("HLA-DQA10501-DQB10637", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10637") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10638():
    result = parse("HLA-DQA10501-DQB10638", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10638") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10639():
    result = parse("HLA-DQA10501-DQB10639", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10639") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10640():
    result = parse("HLA-DQA10501-DQB10640", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10640") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10641():
    result = parse("HLA-DQA10501-DQB10641", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10641") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10642():
    result = parse("HLA-DQA10501-DQB10642", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10642") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10643():
    result = parse("HLA-DQA10501-DQB10643", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10643") to be Pair but got {result}'
    )


def test_HLA_DQA10501_DQB10644():
    result = parse("HLA-DQA10501-DQB10644", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10501-DQB10644") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10201():
    result = parse("HLA-DQA10503-DQB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10201") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10202():
    result = parse("HLA-DQA10503-DQB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10202") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10203():
    result = parse("HLA-DQA10503-DQB10203", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10203") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10204():
    result = parse("HLA-DQA10503-DQB10204", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10204") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10205():
    result = parse("HLA-DQA10503-DQB10205", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10205") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10206():
    result = parse("HLA-DQA10503-DQB10206", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10206") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10301():
    result = parse("HLA-DQA10503-DQB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10301") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10302():
    result = parse("HLA-DQA10503-DQB10302", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10302") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10303():
    result = parse("HLA-DQA10503-DQB10303", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10303") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10304():
    result = parse("HLA-DQA10503-DQB10304", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10304") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10305():
    result = parse("HLA-DQA10503-DQB10305", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10305") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10306():
    result = parse("HLA-DQA10503-DQB10306", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10306") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10307():
    result = parse("HLA-DQA10503-DQB10307", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10307") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10308():
    result = parse("HLA-DQA10503-DQB10308", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10308") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10309():
    result = parse("HLA-DQA10503-DQB10309", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10309") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10310():
    result = parse("HLA-DQA10503-DQB10310", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10310") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10311():
    result = parse("HLA-DQA10503-DQB10311", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10311") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10312():
    result = parse("HLA-DQA10503-DQB10312", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10312") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10313():
    result = parse("HLA-DQA10503-DQB10313", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10313") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10314():
    result = parse("HLA-DQA10503-DQB10314", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10314") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10315():
    result = parse("HLA-DQA10503-DQB10315", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10315") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10316():
    result = parse("HLA-DQA10503-DQB10316", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10316") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10317():
    result = parse("HLA-DQA10503-DQB10317", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10317") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10318():
    result = parse("HLA-DQA10503-DQB10318", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10318") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10319():
    result = parse("HLA-DQA10503-DQB10319", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10319") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10320():
    result = parse("HLA-DQA10503-DQB10320", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10320") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10321():
    result = parse("HLA-DQA10503-DQB10321", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10321") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10322():
    result = parse("HLA-DQA10503-DQB10322", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10322") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10323():
    result = parse("HLA-DQA10503-DQB10323", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10323") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10324():
    result = parse("HLA-DQA10503-DQB10324", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10324") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10325():
    result = parse("HLA-DQA10503-DQB10325", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10325") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10326():
    result = parse("HLA-DQA10503-DQB10326", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10326") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10327():
    result = parse("HLA-DQA10503-DQB10327", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10327") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10328():
    result = parse("HLA-DQA10503-DQB10328", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10328") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10329():
    result = parse("HLA-DQA10503-DQB10329", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10329") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10330():
    result = parse("HLA-DQA10503-DQB10330", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10330") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10331():
    result = parse("HLA-DQA10503-DQB10331", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10331") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10332():
    result = parse("HLA-DQA10503-DQB10332", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10332") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10333():
    result = parse("HLA-DQA10503-DQB10333", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10333") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10334():
    result = parse("HLA-DQA10503-DQB10334", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10334") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10335():
    result = parse("HLA-DQA10503-DQB10335", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10335") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10336():
    result = parse("HLA-DQA10503-DQB10336", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10336") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10337():
    result = parse("HLA-DQA10503-DQB10337", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10337") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10338():
    result = parse("HLA-DQA10503-DQB10338", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10338") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10401():
    result = parse("HLA-DQA10503-DQB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10401") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10402():
    result = parse("HLA-DQA10503-DQB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10402") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10403():
    result = parse("HLA-DQA10503-DQB10403", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10403") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10404():
    result = parse("HLA-DQA10503-DQB10404", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10404") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10405():
    result = parse("HLA-DQA10503-DQB10405", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10405") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10406():
    result = parse("HLA-DQA10503-DQB10406", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10406") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10407():
    result = parse("HLA-DQA10503-DQB10407", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10407") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10408():
    result = parse("HLA-DQA10503-DQB10408", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10408") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10501():
    result = parse("HLA-DQA10503-DQB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10501") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10502():
    result = parse("HLA-DQA10503-DQB10502", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10502") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10503():
    result = parse("HLA-DQA10503-DQB10503", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10503") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10505():
    result = parse("HLA-DQA10503-DQB10505", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10505") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10506():
    result = parse("HLA-DQA10503-DQB10506", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10506") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10507():
    result = parse("HLA-DQA10503-DQB10507", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10507") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10508():
    result = parse("HLA-DQA10503-DQB10508", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10508") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10509():
    result = parse("HLA-DQA10503-DQB10509", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10509") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10510():
    result = parse("HLA-DQA10503-DQB10510", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10510") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10511():
    result = parse("HLA-DQA10503-DQB10511", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10511") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10512():
    result = parse("HLA-DQA10503-DQB10512", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10512") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10513():
    result = parse("HLA-DQA10503-DQB10513", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10513") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10514():
    result = parse("HLA-DQA10503-DQB10514", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10514") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10601():
    result = parse("HLA-DQA10503-DQB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10601") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10602():
    result = parse("HLA-DQA10503-DQB10602", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10602") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10603():
    result = parse("HLA-DQA10503-DQB10603", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10603") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10604():
    result = parse("HLA-DQA10503-DQB10604", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10604") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10607():
    result = parse("HLA-DQA10503-DQB10607", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10607") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10608():
    result = parse("HLA-DQA10503-DQB10608", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10608") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10609():
    result = parse("HLA-DQA10503-DQB10609", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10609") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10610():
    result = parse("HLA-DQA10503-DQB10610", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10610") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10611():
    result = parse("HLA-DQA10503-DQB10611", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10611") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10612():
    result = parse("HLA-DQA10503-DQB10612", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10612") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10614():
    result = parse("HLA-DQA10503-DQB10614", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10614") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10615():
    result = parse("HLA-DQA10503-DQB10615", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10615") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10616():
    result = parse("HLA-DQA10503-DQB10616", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10616") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10617():
    result = parse("HLA-DQA10503-DQB10617", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10617") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10618():
    result = parse("HLA-DQA10503-DQB10618", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10618") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10619():
    result = parse("HLA-DQA10503-DQB10619", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10619") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10621():
    result = parse("HLA-DQA10503-DQB10621", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10621") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10622():
    result = parse("HLA-DQA10503-DQB10622", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10622") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10623():
    result = parse("HLA-DQA10503-DQB10623", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10623") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10624():
    result = parse("HLA-DQA10503-DQB10624", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10624") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10625():
    result = parse("HLA-DQA10503-DQB10625", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10625") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10627():
    result = parse("HLA-DQA10503-DQB10627", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10627") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10628():
    result = parse("HLA-DQA10503-DQB10628", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10628") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10629():
    result = parse("HLA-DQA10503-DQB10629", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10629") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10630():
    result = parse("HLA-DQA10503-DQB10630", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10630") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10631():
    result = parse("HLA-DQA10503-DQB10631", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10631") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10632():
    result = parse("HLA-DQA10503-DQB10632", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10632") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10633():
    result = parse("HLA-DQA10503-DQB10633", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10633") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10634():
    result = parse("HLA-DQA10503-DQB10634", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10634") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10635():
    result = parse("HLA-DQA10503-DQB10635", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10635") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10636():
    result = parse("HLA-DQA10503-DQB10636", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10636") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10637():
    result = parse("HLA-DQA10503-DQB10637", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10637") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10638():
    result = parse("HLA-DQA10503-DQB10638", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10638") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10639():
    result = parse("HLA-DQA10503-DQB10639", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10639") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10640():
    result = parse("HLA-DQA10503-DQB10640", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10640") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10641():
    result = parse("HLA-DQA10503-DQB10641", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10641") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10642():
    result = parse("HLA-DQA10503-DQB10642", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10642") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10643():
    result = parse("HLA-DQA10503-DQB10643", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10643") to be Pair but got {result}'
    )


def test_HLA_DQA10503_DQB10644():
    result = parse("HLA-DQA10503-DQB10644", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10503-DQB10644") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10201():
    result = parse("HLA-DQA10504-DQB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10201") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10202():
    result = parse("HLA-DQA10504-DQB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10202") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10203():
    result = parse("HLA-DQA10504-DQB10203", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10203") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10204():
    result = parse("HLA-DQA10504-DQB10204", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10204") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10205():
    result = parse("HLA-DQA10504-DQB10205", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10205") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10206():
    result = parse("HLA-DQA10504-DQB10206", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10206") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10301():
    result = parse("HLA-DQA10504-DQB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10301") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10302():
    result = parse("HLA-DQA10504-DQB10302", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10302") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10303():
    result = parse("HLA-DQA10504-DQB10303", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10303") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10304():
    result = parse("HLA-DQA10504-DQB10304", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10304") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10305():
    result = parse("HLA-DQA10504-DQB10305", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10305") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10306():
    result = parse("HLA-DQA10504-DQB10306", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10306") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10307():
    result = parse("HLA-DQA10504-DQB10307", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10307") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10308():
    result = parse("HLA-DQA10504-DQB10308", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10308") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10309():
    result = parse("HLA-DQA10504-DQB10309", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10309") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10310():
    result = parse("HLA-DQA10504-DQB10310", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10310") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10311():
    result = parse("HLA-DQA10504-DQB10311", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10311") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10312():
    result = parse("HLA-DQA10504-DQB10312", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10312") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10313():
    result = parse("HLA-DQA10504-DQB10313", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10313") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10314():
    result = parse("HLA-DQA10504-DQB10314", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10314") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10315():
    result = parse("HLA-DQA10504-DQB10315", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10315") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10316():
    result = parse("HLA-DQA10504-DQB10316", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10316") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10317():
    result = parse("HLA-DQA10504-DQB10317", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10317") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10318():
    result = parse("HLA-DQA10504-DQB10318", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10318") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10319():
    result = parse("HLA-DQA10504-DQB10319", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10319") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10320():
    result = parse("HLA-DQA10504-DQB10320", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10320") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10321():
    result = parse("HLA-DQA10504-DQB10321", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10321") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10322():
    result = parse("HLA-DQA10504-DQB10322", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10322") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10323():
    result = parse("HLA-DQA10504-DQB10323", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10323") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10324():
    result = parse("HLA-DQA10504-DQB10324", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10324") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10325():
    result = parse("HLA-DQA10504-DQB10325", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10325") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10326():
    result = parse("HLA-DQA10504-DQB10326", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10326") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10327():
    result = parse("HLA-DQA10504-DQB10327", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10327") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10328():
    result = parse("HLA-DQA10504-DQB10328", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10328") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10329():
    result = parse("HLA-DQA10504-DQB10329", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10329") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10330():
    result = parse("HLA-DQA10504-DQB10330", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10330") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10331():
    result = parse("HLA-DQA10504-DQB10331", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10331") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10332():
    result = parse("HLA-DQA10504-DQB10332", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10332") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10333():
    result = parse("HLA-DQA10504-DQB10333", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10333") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10334():
    result = parse("HLA-DQA10504-DQB10334", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10334") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10335():
    result = parse("HLA-DQA10504-DQB10335", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10335") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10336():
    result = parse("HLA-DQA10504-DQB10336", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10336") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10337():
    result = parse("HLA-DQA10504-DQB10337", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10337") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10338():
    result = parse("HLA-DQA10504-DQB10338", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10338") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10401():
    result = parse("HLA-DQA10504-DQB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10401") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10402():
    result = parse("HLA-DQA10504-DQB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10402") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10403():
    result = parse("HLA-DQA10504-DQB10403", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10403") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10404():
    result = parse("HLA-DQA10504-DQB10404", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10404") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10405():
    result = parse("HLA-DQA10504-DQB10405", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10405") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10406():
    result = parse("HLA-DQA10504-DQB10406", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10406") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10407():
    result = parse("HLA-DQA10504-DQB10407", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10407") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10408():
    result = parse("HLA-DQA10504-DQB10408", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10408") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10501():
    result = parse("HLA-DQA10504-DQB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10501") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10502():
    result = parse("HLA-DQA10504-DQB10502", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10502") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10503():
    result = parse("HLA-DQA10504-DQB10503", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10503") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10505():
    result = parse("HLA-DQA10504-DQB10505", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10505") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10506():
    result = parse("HLA-DQA10504-DQB10506", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10506") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10507():
    result = parse("HLA-DQA10504-DQB10507", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10507") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10508():
    result = parse("HLA-DQA10504-DQB10508", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10508") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10509():
    result = parse("HLA-DQA10504-DQB10509", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10509") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10510():
    result = parse("HLA-DQA10504-DQB10510", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10510") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10511():
    result = parse("HLA-DQA10504-DQB10511", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10511") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10512():
    result = parse("HLA-DQA10504-DQB10512", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10512") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10513():
    result = parse("HLA-DQA10504-DQB10513", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10513") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10514():
    result = parse("HLA-DQA10504-DQB10514", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10514") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10601():
    result = parse("HLA-DQA10504-DQB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10601") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10602():
    result = parse("HLA-DQA10504-DQB10602", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10602") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10603():
    result = parse("HLA-DQA10504-DQB10603", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10603") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10604():
    result = parse("HLA-DQA10504-DQB10604", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10604") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10607():
    result = parse("HLA-DQA10504-DQB10607", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10607") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10608():
    result = parse("HLA-DQA10504-DQB10608", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10608") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10609():
    result = parse("HLA-DQA10504-DQB10609", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10609") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10610():
    result = parse("HLA-DQA10504-DQB10610", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10610") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10611():
    result = parse("HLA-DQA10504-DQB10611", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10611") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10612():
    result = parse("HLA-DQA10504-DQB10612", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10612") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10614():
    result = parse("HLA-DQA10504-DQB10614", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10614") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10615():
    result = parse("HLA-DQA10504-DQB10615", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10615") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10616():
    result = parse("HLA-DQA10504-DQB10616", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10616") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10617():
    result = parse("HLA-DQA10504-DQB10617", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10617") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10618():
    result = parse("HLA-DQA10504-DQB10618", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10618") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10619():
    result = parse("HLA-DQA10504-DQB10619", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10619") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10621():
    result = parse("HLA-DQA10504-DQB10621", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10621") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10622():
    result = parse("HLA-DQA10504-DQB10622", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10622") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10623():
    result = parse("HLA-DQA10504-DQB10623", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10623") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10624():
    result = parse("HLA-DQA10504-DQB10624", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10624") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10625():
    result = parse("HLA-DQA10504-DQB10625", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10625") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10627():
    result = parse("HLA-DQA10504-DQB10627", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10627") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10628():
    result = parse("HLA-DQA10504-DQB10628", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10628") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10629():
    result = parse("HLA-DQA10504-DQB10629", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10629") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10630():
    result = parse("HLA-DQA10504-DQB10630", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10630") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10631():
    result = parse("HLA-DQA10504-DQB10631", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10631") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10632():
    result = parse("HLA-DQA10504-DQB10632", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10632") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10633():
    result = parse("HLA-DQA10504-DQB10633", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10633") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10634():
    result = parse("HLA-DQA10504-DQB10634", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10634") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10635():
    result = parse("HLA-DQA10504-DQB10635", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10635") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10636():
    result = parse("HLA-DQA10504-DQB10636", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10636") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10637():
    result = parse("HLA-DQA10504-DQB10637", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10637") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10638():
    result = parse("HLA-DQA10504-DQB10638", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10638") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10639():
    result = parse("HLA-DQA10504-DQB10639", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10639") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10640():
    result = parse("HLA-DQA10504-DQB10640", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10640") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10641():
    result = parse("HLA-DQA10504-DQB10641", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10641") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10642():
    result = parse("HLA-DQA10504-DQB10642", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10642") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10643():
    result = parse("HLA-DQA10504-DQB10643", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10643") to be Pair but got {result}'
    )


def test_HLA_DQA10504_DQB10644():
    result = parse("HLA-DQA10504-DQB10644", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10504-DQB10644") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10201():
    result = parse("HLA-DQA10505-DQB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10201") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10202():
    result = parse("HLA-DQA10505-DQB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10202") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10203():
    result = parse("HLA-DQA10505-DQB10203", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10203") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10204():
    result = parse("HLA-DQA10505-DQB10204", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10204") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10205():
    result = parse("HLA-DQA10505-DQB10205", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10205") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10206():
    result = parse("HLA-DQA10505-DQB10206", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10206") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10301():
    result = parse("HLA-DQA10505-DQB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10301") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10302():
    result = parse("HLA-DQA10505-DQB10302", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10302") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10303():
    result = parse("HLA-DQA10505-DQB10303", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10303") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10304():
    result = parse("HLA-DQA10505-DQB10304", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10304") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10305():
    result = parse("HLA-DQA10505-DQB10305", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10305") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10306():
    result = parse("HLA-DQA10505-DQB10306", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10306") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10307():
    result = parse("HLA-DQA10505-DQB10307", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10307") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10308():
    result = parse("HLA-DQA10505-DQB10308", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10308") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10309():
    result = parse("HLA-DQA10505-DQB10309", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10309") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10310():
    result = parse("HLA-DQA10505-DQB10310", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10310") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10311():
    result = parse("HLA-DQA10505-DQB10311", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10311") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10312():
    result = parse("HLA-DQA10505-DQB10312", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10312") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10313():
    result = parse("HLA-DQA10505-DQB10313", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10313") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10314():
    result = parse("HLA-DQA10505-DQB10314", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10314") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10315():
    result = parse("HLA-DQA10505-DQB10315", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10315") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10316():
    result = parse("HLA-DQA10505-DQB10316", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10316") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10317():
    result = parse("HLA-DQA10505-DQB10317", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10317") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10318():
    result = parse("HLA-DQA10505-DQB10318", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10318") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10319():
    result = parse("HLA-DQA10505-DQB10319", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10319") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10320():
    result = parse("HLA-DQA10505-DQB10320", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10320") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10321():
    result = parse("HLA-DQA10505-DQB10321", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10321") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10322():
    result = parse("HLA-DQA10505-DQB10322", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10322") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10323():
    result = parse("HLA-DQA10505-DQB10323", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10323") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10324():
    result = parse("HLA-DQA10505-DQB10324", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10324") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10325():
    result = parse("HLA-DQA10505-DQB10325", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10325") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10326():
    result = parse("HLA-DQA10505-DQB10326", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10326") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10327():
    result = parse("HLA-DQA10505-DQB10327", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10327") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10328():
    result = parse("HLA-DQA10505-DQB10328", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10328") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10329():
    result = parse("HLA-DQA10505-DQB10329", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10329") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10330():
    result = parse("HLA-DQA10505-DQB10330", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10330") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10331():
    result = parse("HLA-DQA10505-DQB10331", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10331") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10332():
    result = parse("HLA-DQA10505-DQB10332", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10332") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10333():
    result = parse("HLA-DQA10505-DQB10333", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10333") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10334():
    result = parse("HLA-DQA10505-DQB10334", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10334") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10335():
    result = parse("HLA-DQA10505-DQB10335", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10335") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10336():
    result = parse("HLA-DQA10505-DQB10336", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10336") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10337():
    result = parse("HLA-DQA10505-DQB10337", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10337") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10338():
    result = parse("HLA-DQA10505-DQB10338", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10338") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10401():
    result = parse("HLA-DQA10505-DQB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10401") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10402():
    result = parse("HLA-DQA10505-DQB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10402") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10403():
    result = parse("HLA-DQA10505-DQB10403", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10403") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10404():
    result = parse("HLA-DQA10505-DQB10404", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10404") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10405():
    result = parse("HLA-DQA10505-DQB10405", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10405") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10406():
    result = parse("HLA-DQA10505-DQB10406", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10406") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10407():
    result = parse("HLA-DQA10505-DQB10407", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10407") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10408():
    result = parse("HLA-DQA10505-DQB10408", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10408") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10501():
    result = parse("HLA-DQA10505-DQB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10501") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10502():
    result = parse("HLA-DQA10505-DQB10502", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10502") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10503():
    result = parse("HLA-DQA10505-DQB10503", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10503") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10505():
    result = parse("HLA-DQA10505-DQB10505", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10505") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10506():
    result = parse("HLA-DQA10505-DQB10506", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10506") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10507():
    result = parse("HLA-DQA10505-DQB10507", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10507") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10508():
    result = parse("HLA-DQA10505-DQB10508", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10508") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10509():
    result = parse("HLA-DQA10505-DQB10509", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10509") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10510():
    result = parse("HLA-DQA10505-DQB10510", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10510") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10511():
    result = parse("HLA-DQA10505-DQB10511", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10511") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10512():
    result = parse("HLA-DQA10505-DQB10512", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10512") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10513():
    result = parse("HLA-DQA10505-DQB10513", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10513") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10514():
    result = parse("HLA-DQA10505-DQB10514", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10514") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10601():
    result = parse("HLA-DQA10505-DQB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10601") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10602():
    result = parse("HLA-DQA10505-DQB10602", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10602") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10603():
    result = parse("HLA-DQA10505-DQB10603", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10603") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10604():
    result = parse("HLA-DQA10505-DQB10604", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10604") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10607():
    result = parse("HLA-DQA10505-DQB10607", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10607") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10608():
    result = parse("HLA-DQA10505-DQB10608", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10608") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10609():
    result = parse("HLA-DQA10505-DQB10609", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10609") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10610():
    result = parse("HLA-DQA10505-DQB10610", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10610") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10611():
    result = parse("HLA-DQA10505-DQB10611", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10611") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10612():
    result = parse("HLA-DQA10505-DQB10612", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10612") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10614():
    result = parse("HLA-DQA10505-DQB10614", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10614") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10615():
    result = parse("HLA-DQA10505-DQB10615", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10615") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10616():
    result = parse("HLA-DQA10505-DQB10616", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10616") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10617():
    result = parse("HLA-DQA10505-DQB10617", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10617") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10618():
    result = parse("HLA-DQA10505-DQB10618", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10618") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10619():
    result = parse("HLA-DQA10505-DQB10619", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10619") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10621():
    result = parse("HLA-DQA10505-DQB10621", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10621") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10622():
    result = parse("HLA-DQA10505-DQB10622", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10622") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10623():
    result = parse("HLA-DQA10505-DQB10623", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10623") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10624():
    result = parse("HLA-DQA10505-DQB10624", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10624") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10625():
    result = parse("HLA-DQA10505-DQB10625", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10625") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10627():
    result = parse("HLA-DQA10505-DQB10627", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10627") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10628():
    result = parse("HLA-DQA10505-DQB10628", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10628") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10629():
    result = parse("HLA-DQA10505-DQB10629", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10629") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10630():
    result = parse("HLA-DQA10505-DQB10630", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10630") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10631():
    result = parse("HLA-DQA10505-DQB10631", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10631") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10632():
    result = parse("HLA-DQA10505-DQB10632", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10632") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10633():
    result = parse("HLA-DQA10505-DQB10633", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10633") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10634():
    result = parse("HLA-DQA10505-DQB10634", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10634") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10635():
    result = parse("HLA-DQA10505-DQB10635", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10635") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10636():
    result = parse("HLA-DQA10505-DQB10636", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10636") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10637():
    result = parse("HLA-DQA10505-DQB10637", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10637") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10638():
    result = parse("HLA-DQA10505-DQB10638", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10638") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10639():
    result = parse("HLA-DQA10505-DQB10639", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10639") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10640():
    result = parse("HLA-DQA10505-DQB10640", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10640") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10641():
    result = parse("HLA-DQA10505-DQB10641", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10641") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10642():
    result = parse("HLA-DQA10505-DQB10642", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10642") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10643():
    result = parse("HLA-DQA10505-DQB10643", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10643") to be Pair but got {result}'
    )


def test_HLA_DQA10505_DQB10644():
    result = parse("HLA-DQA10505-DQB10644", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10505-DQB10644") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10201():
    result = parse("HLA-DQA10506-DQB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10201") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10202():
    result = parse("HLA-DQA10506-DQB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10202") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10203():
    result = parse("HLA-DQA10506-DQB10203", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10203") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10204():
    result = parse("HLA-DQA10506-DQB10204", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10204") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10205():
    result = parse("HLA-DQA10506-DQB10205", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10205") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10206():
    result = parse("HLA-DQA10506-DQB10206", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10206") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10301():
    result = parse("HLA-DQA10506-DQB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10301") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10302():
    result = parse("HLA-DQA10506-DQB10302", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10302") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10303():
    result = parse("HLA-DQA10506-DQB10303", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10303") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10304():
    result = parse("HLA-DQA10506-DQB10304", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10304") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10305():
    result = parse("HLA-DQA10506-DQB10305", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10305") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10306():
    result = parse("HLA-DQA10506-DQB10306", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10306") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10307():
    result = parse("HLA-DQA10506-DQB10307", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10307") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10308():
    result = parse("HLA-DQA10506-DQB10308", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10308") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10309():
    result = parse("HLA-DQA10506-DQB10309", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10309") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10310():
    result = parse("HLA-DQA10506-DQB10310", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10310") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10311():
    result = parse("HLA-DQA10506-DQB10311", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10311") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10312():
    result = parse("HLA-DQA10506-DQB10312", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10312") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10313():
    result = parse("HLA-DQA10506-DQB10313", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10313") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10314():
    result = parse("HLA-DQA10506-DQB10314", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10314") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10315():
    result = parse("HLA-DQA10506-DQB10315", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10315") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10316():
    result = parse("HLA-DQA10506-DQB10316", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10316") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10317():
    result = parse("HLA-DQA10506-DQB10317", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10317") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10318():
    result = parse("HLA-DQA10506-DQB10318", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10318") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10319():
    result = parse("HLA-DQA10506-DQB10319", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10319") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10320():
    result = parse("HLA-DQA10506-DQB10320", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10320") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10321():
    result = parse("HLA-DQA10506-DQB10321", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10321") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10322():
    result = parse("HLA-DQA10506-DQB10322", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10322") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10323():
    result = parse("HLA-DQA10506-DQB10323", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10323") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10324():
    result = parse("HLA-DQA10506-DQB10324", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10324") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10325():
    result = parse("HLA-DQA10506-DQB10325", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10325") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10326():
    result = parse("HLA-DQA10506-DQB10326", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10326") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10327():
    result = parse("HLA-DQA10506-DQB10327", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10327") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10328():
    result = parse("HLA-DQA10506-DQB10328", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10328") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10329():
    result = parse("HLA-DQA10506-DQB10329", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10329") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10330():
    result = parse("HLA-DQA10506-DQB10330", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10330") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10331():
    result = parse("HLA-DQA10506-DQB10331", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10331") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10332():
    result = parse("HLA-DQA10506-DQB10332", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10332") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10333():
    result = parse("HLA-DQA10506-DQB10333", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10333") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10334():
    result = parse("HLA-DQA10506-DQB10334", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10334") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10335():
    result = parse("HLA-DQA10506-DQB10335", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10335") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10336():
    result = parse("HLA-DQA10506-DQB10336", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10336") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10337():
    result = parse("HLA-DQA10506-DQB10337", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10337") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10338():
    result = parse("HLA-DQA10506-DQB10338", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10338") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10401():
    result = parse("HLA-DQA10506-DQB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10401") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10402():
    result = parse("HLA-DQA10506-DQB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10402") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10403():
    result = parse("HLA-DQA10506-DQB10403", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10403") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10404():
    result = parse("HLA-DQA10506-DQB10404", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10404") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10405():
    result = parse("HLA-DQA10506-DQB10405", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10405") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10406():
    result = parse("HLA-DQA10506-DQB10406", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10406") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10407():
    result = parse("HLA-DQA10506-DQB10407", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10407") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10408():
    result = parse("HLA-DQA10506-DQB10408", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10408") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10501():
    result = parse("HLA-DQA10506-DQB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10501") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10502():
    result = parse("HLA-DQA10506-DQB10502", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10502") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10503():
    result = parse("HLA-DQA10506-DQB10503", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10503") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10505():
    result = parse("HLA-DQA10506-DQB10505", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10505") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10506():
    result = parse("HLA-DQA10506-DQB10506", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10506") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10507():
    result = parse("HLA-DQA10506-DQB10507", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10507") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10508():
    result = parse("HLA-DQA10506-DQB10508", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10508") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10509():
    result = parse("HLA-DQA10506-DQB10509", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10509") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10510():
    result = parse("HLA-DQA10506-DQB10510", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10510") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10511():
    result = parse("HLA-DQA10506-DQB10511", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10511") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10512():
    result = parse("HLA-DQA10506-DQB10512", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10512") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10513():
    result = parse("HLA-DQA10506-DQB10513", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10513") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10514():
    result = parse("HLA-DQA10506-DQB10514", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10514") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10601():
    result = parse("HLA-DQA10506-DQB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10601") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10602():
    result = parse("HLA-DQA10506-DQB10602", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10602") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10603():
    result = parse("HLA-DQA10506-DQB10603", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10603") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10604():
    result = parse("HLA-DQA10506-DQB10604", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10604") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10607():
    result = parse("HLA-DQA10506-DQB10607", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10607") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10608():
    result = parse("HLA-DQA10506-DQB10608", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10608") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10609():
    result = parse("HLA-DQA10506-DQB10609", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10609") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10610():
    result = parse("HLA-DQA10506-DQB10610", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10610") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10611():
    result = parse("HLA-DQA10506-DQB10611", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10611") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10612():
    result = parse("HLA-DQA10506-DQB10612", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10612") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10614():
    result = parse("HLA-DQA10506-DQB10614", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10614") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10615():
    result = parse("HLA-DQA10506-DQB10615", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10615") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10616():
    result = parse("HLA-DQA10506-DQB10616", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10616") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10617():
    result = parse("HLA-DQA10506-DQB10617", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10617") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10618():
    result = parse("HLA-DQA10506-DQB10618", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10618") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10619():
    result = parse("HLA-DQA10506-DQB10619", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10619") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10621():
    result = parse("HLA-DQA10506-DQB10621", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10621") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10622():
    result = parse("HLA-DQA10506-DQB10622", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10622") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10623():
    result = parse("HLA-DQA10506-DQB10623", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10623") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10624():
    result = parse("HLA-DQA10506-DQB10624", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10624") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10625():
    result = parse("HLA-DQA10506-DQB10625", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10625") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10627():
    result = parse("HLA-DQA10506-DQB10627", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10627") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10628():
    result = parse("HLA-DQA10506-DQB10628", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10628") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10629():
    result = parse("HLA-DQA10506-DQB10629", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10629") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10630():
    result = parse("HLA-DQA10506-DQB10630", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10630") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10631():
    result = parse("HLA-DQA10506-DQB10631", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10631") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10632():
    result = parse("HLA-DQA10506-DQB10632", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10632") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10633():
    result = parse("HLA-DQA10506-DQB10633", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10633") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10634():
    result = parse("HLA-DQA10506-DQB10634", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10634") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10635():
    result = parse("HLA-DQA10506-DQB10635", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10635") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10636():
    result = parse("HLA-DQA10506-DQB10636", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10636") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10637():
    result = parse("HLA-DQA10506-DQB10637", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10637") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10638():
    result = parse("HLA-DQA10506-DQB10638", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10638") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10639():
    result = parse("HLA-DQA10506-DQB10639", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10639") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10640():
    result = parse("HLA-DQA10506-DQB10640", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10640") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10641():
    result = parse("HLA-DQA10506-DQB10641", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10641") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10642():
    result = parse("HLA-DQA10506-DQB10642", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10642") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10643():
    result = parse("HLA-DQA10506-DQB10643", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10643") to be Pair but got {result}'
    )


def test_HLA_DQA10506_DQB10644():
    result = parse("HLA-DQA10506-DQB10644", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10506-DQB10644") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10201():
    result = parse("HLA-DQA10507-DQB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10201") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10202():
    result = parse("HLA-DQA10507-DQB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10202") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10203():
    result = parse("HLA-DQA10507-DQB10203", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10203") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10204():
    result = parse("HLA-DQA10507-DQB10204", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10204") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10205():
    result = parse("HLA-DQA10507-DQB10205", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10205") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10206():
    result = parse("HLA-DQA10507-DQB10206", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10206") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10301():
    result = parse("HLA-DQA10507-DQB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10301") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10302():
    result = parse("HLA-DQA10507-DQB10302", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10302") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10303():
    result = parse("HLA-DQA10507-DQB10303", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10303") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10304():
    result = parse("HLA-DQA10507-DQB10304", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10304") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10305():
    result = parse("HLA-DQA10507-DQB10305", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10305") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10306():
    result = parse("HLA-DQA10507-DQB10306", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10306") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10307():
    result = parse("HLA-DQA10507-DQB10307", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10307") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10308():
    result = parse("HLA-DQA10507-DQB10308", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10308") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10309():
    result = parse("HLA-DQA10507-DQB10309", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10309") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10310():
    result = parse("HLA-DQA10507-DQB10310", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10310") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10311():
    result = parse("HLA-DQA10507-DQB10311", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10311") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10312():
    result = parse("HLA-DQA10507-DQB10312", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10312") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10313():
    result = parse("HLA-DQA10507-DQB10313", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10313") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10314():
    result = parse("HLA-DQA10507-DQB10314", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10314") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10315():
    result = parse("HLA-DQA10507-DQB10315", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10315") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10316():
    result = parse("HLA-DQA10507-DQB10316", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10316") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10317():
    result = parse("HLA-DQA10507-DQB10317", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10317") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10318():
    result = parse("HLA-DQA10507-DQB10318", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10318") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10319():
    result = parse("HLA-DQA10507-DQB10319", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10319") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10320():
    result = parse("HLA-DQA10507-DQB10320", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10320") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10321():
    result = parse("HLA-DQA10507-DQB10321", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10321") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10322():
    result = parse("HLA-DQA10507-DQB10322", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10322") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10323():
    result = parse("HLA-DQA10507-DQB10323", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10323") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10324():
    result = parse("HLA-DQA10507-DQB10324", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10324") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10325():
    result = parse("HLA-DQA10507-DQB10325", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10325") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10326():
    result = parse("HLA-DQA10507-DQB10326", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10326") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10327():
    result = parse("HLA-DQA10507-DQB10327", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10327") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10328():
    result = parse("HLA-DQA10507-DQB10328", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10328") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10329():
    result = parse("HLA-DQA10507-DQB10329", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10329") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10330():
    result = parse("HLA-DQA10507-DQB10330", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10330") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10331():
    result = parse("HLA-DQA10507-DQB10331", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10331") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10332():
    result = parse("HLA-DQA10507-DQB10332", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10332") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10333():
    result = parse("HLA-DQA10507-DQB10333", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10333") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10334():
    result = parse("HLA-DQA10507-DQB10334", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10334") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10335():
    result = parse("HLA-DQA10507-DQB10335", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10335") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10336():
    result = parse("HLA-DQA10507-DQB10336", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10336") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10337():
    result = parse("HLA-DQA10507-DQB10337", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10337") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10338():
    result = parse("HLA-DQA10507-DQB10338", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10338") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10401():
    result = parse("HLA-DQA10507-DQB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10401") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10402():
    result = parse("HLA-DQA10507-DQB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10402") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10403():
    result = parse("HLA-DQA10507-DQB10403", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10403") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10404():
    result = parse("HLA-DQA10507-DQB10404", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10404") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10405():
    result = parse("HLA-DQA10507-DQB10405", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10405") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10406():
    result = parse("HLA-DQA10507-DQB10406", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10406") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10407():
    result = parse("HLA-DQA10507-DQB10407", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10407") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10408():
    result = parse("HLA-DQA10507-DQB10408", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10408") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10501():
    result = parse("HLA-DQA10507-DQB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10501") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10502():
    result = parse("HLA-DQA10507-DQB10502", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10502") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10503():
    result = parse("HLA-DQA10507-DQB10503", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10503") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10505():
    result = parse("HLA-DQA10507-DQB10505", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10505") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10506():
    result = parse("HLA-DQA10507-DQB10506", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10506") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10507():
    result = parse("HLA-DQA10507-DQB10507", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10507") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10508():
    result = parse("HLA-DQA10507-DQB10508", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10508") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10509():
    result = parse("HLA-DQA10507-DQB10509", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10509") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10510():
    result = parse("HLA-DQA10507-DQB10510", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10510") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10511():
    result = parse("HLA-DQA10507-DQB10511", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10511") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10512():
    result = parse("HLA-DQA10507-DQB10512", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10512") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10513():
    result = parse("HLA-DQA10507-DQB10513", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10513") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10514():
    result = parse("HLA-DQA10507-DQB10514", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10514") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10601():
    result = parse("HLA-DQA10507-DQB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10601") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10602():
    result = parse("HLA-DQA10507-DQB10602", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10602") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10603():
    result = parse("HLA-DQA10507-DQB10603", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10603") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10604():
    result = parse("HLA-DQA10507-DQB10604", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10604") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10607():
    result = parse("HLA-DQA10507-DQB10607", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10607") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10608():
    result = parse("HLA-DQA10507-DQB10608", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10608") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10609():
    result = parse("HLA-DQA10507-DQB10609", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10609") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10610():
    result = parse("HLA-DQA10507-DQB10610", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10610") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10611():
    result = parse("HLA-DQA10507-DQB10611", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10611") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10612():
    result = parse("HLA-DQA10507-DQB10612", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10612") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10614():
    result = parse("HLA-DQA10507-DQB10614", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10614") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10615():
    result = parse("HLA-DQA10507-DQB10615", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10615") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10616():
    result = parse("HLA-DQA10507-DQB10616", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10616") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10617():
    result = parse("HLA-DQA10507-DQB10617", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10617") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10618():
    result = parse("HLA-DQA10507-DQB10618", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10618") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10619():
    result = parse("HLA-DQA10507-DQB10619", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10619") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10621():
    result = parse("HLA-DQA10507-DQB10621", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10621") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10622():
    result = parse("HLA-DQA10507-DQB10622", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10622") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10623():
    result = parse("HLA-DQA10507-DQB10623", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10623") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10624():
    result = parse("HLA-DQA10507-DQB10624", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10624") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10625():
    result = parse("HLA-DQA10507-DQB10625", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10625") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10627():
    result = parse("HLA-DQA10507-DQB10627", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10627") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10628():
    result = parse("HLA-DQA10507-DQB10628", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10628") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10629():
    result = parse("HLA-DQA10507-DQB10629", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10629") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10630():
    result = parse("HLA-DQA10507-DQB10630", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10630") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10631():
    result = parse("HLA-DQA10507-DQB10631", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10631") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10632():
    result = parse("HLA-DQA10507-DQB10632", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10632") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10633():
    result = parse("HLA-DQA10507-DQB10633", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10633") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10634():
    result = parse("HLA-DQA10507-DQB10634", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10634") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10635():
    result = parse("HLA-DQA10507-DQB10635", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10635") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10636():
    result = parse("HLA-DQA10507-DQB10636", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10636") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10637():
    result = parse("HLA-DQA10507-DQB10637", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10637") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10638():
    result = parse("HLA-DQA10507-DQB10638", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10638") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10639():
    result = parse("HLA-DQA10507-DQB10639", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10639") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10640():
    result = parse("HLA-DQA10507-DQB10640", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10640") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10641():
    result = parse("HLA-DQA10507-DQB10641", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10641") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10642():
    result = parse("HLA-DQA10507-DQB10642", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10642") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10643():
    result = parse("HLA-DQA10507-DQB10643", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10643") to be Pair but got {result}'
    )


def test_HLA_DQA10507_DQB10644():
    result = parse("HLA-DQA10507-DQB10644", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10507-DQB10644") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10201():
    result = parse("HLA-DQA10508-DQB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10201") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10202():
    result = parse("HLA-DQA10508-DQB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10202") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10203():
    result = parse("HLA-DQA10508-DQB10203", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10203") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10204():
    result = parse("HLA-DQA10508-DQB10204", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10204") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10205():
    result = parse("HLA-DQA10508-DQB10205", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10205") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10206():
    result = parse("HLA-DQA10508-DQB10206", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10206") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10301():
    result = parse("HLA-DQA10508-DQB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10301") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10302():
    result = parse("HLA-DQA10508-DQB10302", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10302") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10303():
    result = parse("HLA-DQA10508-DQB10303", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10303") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10304():
    result = parse("HLA-DQA10508-DQB10304", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10304") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10305():
    result = parse("HLA-DQA10508-DQB10305", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10305") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10306():
    result = parse("HLA-DQA10508-DQB10306", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10306") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10307():
    result = parse("HLA-DQA10508-DQB10307", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10307") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10308():
    result = parse("HLA-DQA10508-DQB10308", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10308") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10309():
    result = parse("HLA-DQA10508-DQB10309", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10309") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10310():
    result = parse("HLA-DQA10508-DQB10310", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10310") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10311():
    result = parse("HLA-DQA10508-DQB10311", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10311") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10312():
    result = parse("HLA-DQA10508-DQB10312", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10312") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10313():
    result = parse("HLA-DQA10508-DQB10313", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10313") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10314():
    result = parse("HLA-DQA10508-DQB10314", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10314") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10315():
    result = parse("HLA-DQA10508-DQB10315", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10315") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10316():
    result = parse("HLA-DQA10508-DQB10316", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10316") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10317():
    result = parse("HLA-DQA10508-DQB10317", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10317") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10318():
    result = parse("HLA-DQA10508-DQB10318", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10318") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10319():
    result = parse("HLA-DQA10508-DQB10319", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10319") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10320():
    result = parse("HLA-DQA10508-DQB10320", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10320") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10321():
    result = parse("HLA-DQA10508-DQB10321", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10321") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10322():
    result = parse("HLA-DQA10508-DQB10322", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10322") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10323():
    result = parse("HLA-DQA10508-DQB10323", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10323") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10324():
    result = parse("HLA-DQA10508-DQB10324", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10324") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10325():
    result = parse("HLA-DQA10508-DQB10325", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10325") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10326():
    result = parse("HLA-DQA10508-DQB10326", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10326") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10327():
    result = parse("HLA-DQA10508-DQB10327", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10327") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10328():
    result = parse("HLA-DQA10508-DQB10328", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10328") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10329():
    result = parse("HLA-DQA10508-DQB10329", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10329") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10330():
    result = parse("HLA-DQA10508-DQB10330", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10330") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10331():
    result = parse("HLA-DQA10508-DQB10331", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10331") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10332():
    result = parse("HLA-DQA10508-DQB10332", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10332") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10333():
    result = parse("HLA-DQA10508-DQB10333", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10333") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10334():
    result = parse("HLA-DQA10508-DQB10334", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10334") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10335():
    result = parse("HLA-DQA10508-DQB10335", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10335") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10336():
    result = parse("HLA-DQA10508-DQB10336", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10336") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10337():
    result = parse("HLA-DQA10508-DQB10337", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10337") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10338():
    result = parse("HLA-DQA10508-DQB10338", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10338") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10401():
    result = parse("HLA-DQA10508-DQB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10401") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10402():
    result = parse("HLA-DQA10508-DQB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10402") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10403():
    result = parse("HLA-DQA10508-DQB10403", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10403") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10404():
    result = parse("HLA-DQA10508-DQB10404", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10404") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10405():
    result = parse("HLA-DQA10508-DQB10405", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10405") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10406():
    result = parse("HLA-DQA10508-DQB10406", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10406") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10407():
    result = parse("HLA-DQA10508-DQB10407", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10407") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10408():
    result = parse("HLA-DQA10508-DQB10408", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10408") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10501():
    result = parse("HLA-DQA10508-DQB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10501") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10502():
    result = parse("HLA-DQA10508-DQB10502", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10502") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10503():
    result = parse("HLA-DQA10508-DQB10503", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10503") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10505():
    result = parse("HLA-DQA10508-DQB10505", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10505") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10506():
    result = parse("HLA-DQA10508-DQB10506", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10506") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10507():
    result = parse("HLA-DQA10508-DQB10507", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10507") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10508():
    result = parse("HLA-DQA10508-DQB10508", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10508") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10509():
    result = parse("HLA-DQA10508-DQB10509", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10509") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10510():
    result = parse("HLA-DQA10508-DQB10510", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10510") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10511():
    result = parse("HLA-DQA10508-DQB10511", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10511") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10512():
    result = parse("HLA-DQA10508-DQB10512", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10512") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10513():
    result = parse("HLA-DQA10508-DQB10513", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10513") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10514():
    result = parse("HLA-DQA10508-DQB10514", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10514") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10601():
    result = parse("HLA-DQA10508-DQB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10601") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10602():
    result = parse("HLA-DQA10508-DQB10602", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10602") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10603():
    result = parse("HLA-DQA10508-DQB10603", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10603") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10604():
    result = parse("HLA-DQA10508-DQB10604", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10604") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10607():
    result = parse("HLA-DQA10508-DQB10607", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10607") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10608():
    result = parse("HLA-DQA10508-DQB10608", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10608") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10609():
    result = parse("HLA-DQA10508-DQB10609", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10609") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10610():
    result = parse("HLA-DQA10508-DQB10610", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10610") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10611():
    result = parse("HLA-DQA10508-DQB10611", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10611") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10612():
    result = parse("HLA-DQA10508-DQB10612", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10612") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10614():
    result = parse("HLA-DQA10508-DQB10614", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10614") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10615():
    result = parse("HLA-DQA10508-DQB10615", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10615") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10616():
    result = parse("HLA-DQA10508-DQB10616", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10616") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10617():
    result = parse("HLA-DQA10508-DQB10617", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10617") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10618():
    result = parse("HLA-DQA10508-DQB10618", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10618") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10619():
    result = parse("HLA-DQA10508-DQB10619", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10619") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10621():
    result = parse("HLA-DQA10508-DQB10621", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10621") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10622():
    result = parse("HLA-DQA10508-DQB10622", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10622") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10623():
    result = parse("HLA-DQA10508-DQB10623", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10623") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10624():
    result = parse("HLA-DQA10508-DQB10624", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10624") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10625():
    result = parse("HLA-DQA10508-DQB10625", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10625") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10627():
    result = parse("HLA-DQA10508-DQB10627", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10627") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10628():
    result = parse("HLA-DQA10508-DQB10628", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10628") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10629():
    result = parse("HLA-DQA10508-DQB10629", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10629") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10630():
    result = parse("HLA-DQA10508-DQB10630", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10630") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10631():
    result = parse("HLA-DQA10508-DQB10631", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10631") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10632():
    result = parse("HLA-DQA10508-DQB10632", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10632") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10633():
    result = parse("HLA-DQA10508-DQB10633", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10633") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10634():
    result = parse("HLA-DQA10508-DQB10634", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10634") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10635():
    result = parse("HLA-DQA10508-DQB10635", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10635") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10636():
    result = parse("HLA-DQA10508-DQB10636", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10636") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10637():
    result = parse("HLA-DQA10508-DQB10637", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10637") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10638():
    result = parse("HLA-DQA10508-DQB10638", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10638") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10639():
    result = parse("HLA-DQA10508-DQB10639", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10639") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10640():
    result = parse("HLA-DQA10508-DQB10640", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10640") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10641():
    result = parse("HLA-DQA10508-DQB10641", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10641") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10642():
    result = parse("HLA-DQA10508-DQB10642", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10642") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10643():
    result = parse("HLA-DQA10508-DQB10643", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10643") to be Pair but got {result}'
    )


def test_HLA_DQA10508_DQB10644():
    result = parse("HLA-DQA10508-DQB10644", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10508-DQB10644") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10201():
    result = parse("HLA-DQA10509-DQB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10201") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10202():
    result = parse("HLA-DQA10509-DQB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10202") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10203():
    result = parse("HLA-DQA10509-DQB10203", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10203") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10204():
    result = parse("HLA-DQA10509-DQB10204", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10204") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10205():
    result = parse("HLA-DQA10509-DQB10205", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10205") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10206():
    result = parse("HLA-DQA10509-DQB10206", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10206") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10301():
    result = parse("HLA-DQA10509-DQB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10301") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10302():
    result = parse("HLA-DQA10509-DQB10302", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10302") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10303():
    result = parse("HLA-DQA10509-DQB10303", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10303") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10304():
    result = parse("HLA-DQA10509-DQB10304", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10304") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10305():
    result = parse("HLA-DQA10509-DQB10305", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10305") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10306():
    result = parse("HLA-DQA10509-DQB10306", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10306") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10307():
    result = parse("HLA-DQA10509-DQB10307", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10307") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10308():
    result = parse("HLA-DQA10509-DQB10308", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10308") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10309():
    result = parse("HLA-DQA10509-DQB10309", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10309") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10310():
    result = parse("HLA-DQA10509-DQB10310", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10310") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10311():
    result = parse("HLA-DQA10509-DQB10311", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10311") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10312():
    result = parse("HLA-DQA10509-DQB10312", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10312") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10313():
    result = parse("HLA-DQA10509-DQB10313", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10313") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10314():
    result = parse("HLA-DQA10509-DQB10314", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10314") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10315():
    result = parse("HLA-DQA10509-DQB10315", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10315") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10316():
    result = parse("HLA-DQA10509-DQB10316", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10316") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10317():
    result = parse("HLA-DQA10509-DQB10317", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10317") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10318():
    result = parse("HLA-DQA10509-DQB10318", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10318") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10319():
    result = parse("HLA-DQA10509-DQB10319", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10319") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10320():
    result = parse("HLA-DQA10509-DQB10320", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10320") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10321():
    result = parse("HLA-DQA10509-DQB10321", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10321") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10322():
    result = parse("HLA-DQA10509-DQB10322", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10322") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10323():
    result = parse("HLA-DQA10509-DQB10323", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10323") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10324():
    result = parse("HLA-DQA10509-DQB10324", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10324") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10325():
    result = parse("HLA-DQA10509-DQB10325", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10325") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10326():
    result = parse("HLA-DQA10509-DQB10326", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10326") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10327():
    result = parse("HLA-DQA10509-DQB10327", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10327") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10328():
    result = parse("HLA-DQA10509-DQB10328", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10328") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10329():
    result = parse("HLA-DQA10509-DQB10329", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10329") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10330():
    result = parse("HLA-DQA10509-DQB10330", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10330") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10331():
    result = parse("HLA-DQA10509-DQB10331", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10331") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10332():
    result = parse("HLA-DQA10509-DQB10332", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10332") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10333():
    result = parse("HLA-DQA10509-DQB10333", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10333") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10334():
    result = parse("HLA-DQA10509-DQB10334", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10334") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10335():
    result = parse("HLA-DQA10509-DQB10335", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10335") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10336():
    result = parse("HLA-DQA10509-DQB10336", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10336") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10337():
    result = parse("HLA-DQA10509-DQB10337", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10337") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10338():
    result = parse("HLA-DQA10509-DQB10338", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10338") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10401():
    result = parse("HLA-DQA10509-DQB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10401") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10402():
    result = parse("HLA-DQA10509-DQB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10402") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10403():
    result = parse("HLA-DQA10509-DQB10403", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10403") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10404():
    result = parse("HLA-DQA10509-DQB10404", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10404") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10405():
    result = parse("HLA-DQA10509-DQB10405", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10405") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10406():
    result = parse("HLA-DQA10509-DQB10406", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10406") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10407():
    result = parse("HLA-DQA10509-DQB10407", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10407") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10408():
    result = parse("HLA-DQA10509-DQB10408", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10408") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10501():
    result = parse("HLA-DQA10509-DQB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10501") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10502():
    result = parse("HLA-DQA10509-DQB10502", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10502") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10503():
    result = parse("HLA-DQA10509-DQB10503", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10503") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10505():
    result = parse("HLA-DQA10509-DQB10505", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10505") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10506():
    result = parse("HLA-DQA10509-DQB10506", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10506") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10507():
    result = parse("HLA-DQA10509-DQB10507", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10507") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10508():
    result = parse("HLA-DQA10509-DQB10508", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10508") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10509():
    result = parse("HLA-DQA10509-DQB10509", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10509") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10510():
    result = parse("HLA-DQA10509-DQB10510", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10510") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10511():
    result = parse("HLA-DQA10509-DQB10511", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10511") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10512():
    result = parse("HLA-DQA10509-DQB10512", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10512") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10513():
    result = parse("HLA-DQA10509-DQB10513", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10513") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10514():
    result = parse("HLA-DQA10509-DQB10514", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10514") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10601():
    result = parse("HLA-DQA10509-DQB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10601") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10602():
    result = parse("HLA-DQA10509-DQB10602", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10602") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10603():
    result = parse("HLA-DQA10509-DQB10603", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10603") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10604():
    result = parse("HLA-DQA10509-DQB10604", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10604") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10607():
    result = parse("HLA-DQA10509-DQB10607", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10607") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10608():
    result = parse("HLA-DQA10509-DQB10608", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10608") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10609():
    result = parse("HLA-DQA10509-DQB10609", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10609") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10610():
    result = parse("HLA-DQA10509-DQB10610", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10610") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10611():
    result = parse("HLA-DQA10509-DQB10611", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10611") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10612():
    result = parse("HLA-DQA10509-DQB10612", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10612") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10614():
    result = parse("HLA-DQA10509-DQB10614", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10614") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10615():
    result = parse("HLA-DQA10509-DQB10615", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10615") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10616():
    result = parse("HLA-DQA10509-DQB10616", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10616") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10617():
    result = parse("HLA-DQA10509-DQB10617", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10617") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10618():
    result = parse("HLA-DQA10509-DQB10618", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10618") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10619():
    result = parse("HLA-DQA10509-DQB10619", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10619") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10621():
    result = parse("HLA-DQA10509-DQB10621", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10621") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10622():
    result = parse("HLA-DQA10509-DQB10622", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10622") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10623():
    result = parse("HLA-DQA10509-DQB10623", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10623") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10624():
    result = parse("HLA-DQA10509-DQB10624", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10624") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10625():
    result = parse("HLA-DQA10509-DQB10625", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10625") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10627():
    result = parse("HLA-DQA10509-DQB10627", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10627") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10628():
    result = parse("HLA-DQA10509-DQB10628", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10628") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10629():
    result = parse("HLA-DQA10509-DQB10629", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10629") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10630():
    result = parse("HLA-DQA10509-DQB10630", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10630") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10631():
    result = parse("HLA-DQA10509-DQB10631", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10631") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10632():
    result = parse("HLA-DQA10509-DQB10632", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10632") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10633():
    result = parse("HLA-DQA10509-DQB10633", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10633") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10634():
    result = parse("HLA-DQA10509-DQB10634", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10634") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10635():
    result = parse("HLA-DQA10509-DQB10635", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10635") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10636():
    result = parse("HLA-DQA10509-DQB10636", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10636") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10637():
    result = parse("HLA-DQA10509-DQB10637", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10637") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10638():
    result = parse("HLA-DQA10509-DQB10638", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10638") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10639():
    result = parse("HLA-DQA10509-DQB10639", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10639") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10640():
    result = parse("HLA-DQA10509-DQB10640", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10640") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10641():
    result = parse("HLA-DQA10509-DQB10641", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10641") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10642():
    result = parse("HLA-DQA10509-DQB10642", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10642") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10643():
    result = parse("HLA-DQA10509-DQB10643", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10643") to be Pair but got {result}'
    )


def test_HLA_DQA10509_DQB10644():
    result = parse("HLA-DQA10509-DQB10644", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10509-DQB10644") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10201():
    result = parse("HLA-DQA10510-DQB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10201") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10202():
    result = parse("HLA-DQA10510-DQB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10202") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10203():
    result = parse("HLA-DQA10510-DQB10203", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10203") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10204():
    result = parse("HLA-DQA10510-DQB10204", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10204") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10205():
    result = parse("HLA-DQA10510-DQB10205", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10205") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10206():
    result = parse("HLA-DQA10510-DQB10206", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10206") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10301():
    result = parse("HLA-DQA10510-DQB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10301") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10302():
    result = parse("HLA-DQA10510-DQB10302", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10302") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10303():
    result = parse("HLA-DQA10510-DQB10303", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10303") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10304():
    result = parse("HLA-DQA10510-DQB10304", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10304") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10305():
    result = parse("HLA-DQA10510-DQB10305", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10305") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10306():
    result = parse("HLA-DQA10510-DQB10306", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10306") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10307():
    result = parse("HLA-DQA10510-DQB10307", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10307") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10308():
    result = parse("HLA-DQA10510-DQB10308", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10308") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10309():
    result = parse("HLA-DQA10510-DQB10309", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10309") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10310():
    result = parse("HLA-DQA10510-DQB10310", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10310") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10311():
    result = parse("HLA-DQA10510-DQB10311", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10311") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10312():
    result = parse("HLA-DQA10510-DQB10312", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10312") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10313():
    result = parse("HLA-DQA10510-DQB10313", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10313") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10314():
    result = parse("HLA-DQA10510-DQB10314", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10314") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10315():
    result = parse("HLA-DQA10510-DQB10315", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10315") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10316():
    result = parse("HLA-DQA10510-DQB10316", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10316") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10317():
    result = parse("HLA-DQA10510-DQB10317", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10317") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10318():
    result = parse("HLA-DQA10510-DQB10318", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10318") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10319():
    result = parse("HLA-DQA10510-DQB10319", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10319") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10320():
    result = parse("HLA-DQA10510-DQB10320", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10320") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10321():
    result = parse("HLA-DQA10510-DQB10321", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10321") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10322():
    result = parse("HLA-DQA10510-DQB10322", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10322") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10323():
    result = parse("HLA-DQA10510-DQB10323", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10323") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10324():
    result = parse("HLA-DQA10510-DQB10324", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10324") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10325():
    result = parse("HLA-DQA10510-DQB10325", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10325") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10326():
    result = parse("HLA-DQA10510-DQB10326", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10326") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10327():
    result = parse("HLA-DQA10510-DQB10327", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10327") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10328():
    result = parse("HLA-DQA10510-DQB10328", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10328") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10329():
    result = parse("HLA-DQA10510-DQB10329", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10329") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10330():
    result = parse("HLA-DQA10510-DQB10330", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10330") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10331():
    result = parse("HLA-DQA10510-DQB10331", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10331") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10332():
    result = parse("HLA-DQA10510-DQB10332", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10332") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10333():
    result = parse("HLA-DQA10510-DQB10333", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10333") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10334():
    result = parse("HLA-DQA10510-DQB10334", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10334") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10335():
    result = parse("HLA-DQA10510-DQB10335", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10335") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10336():
    result = parse("HLA-DQA10510-DQB10336", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10336") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10337():
    result = parse("HLA-DQA10510-DQB10337", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10337") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10338():
    result = parse("HLA-DQA10510-DQB10338", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10338") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10401():
    result = parse("HLA-DQA10510-DQB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10401") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10402():
    result = parse("HLA-DQA10510-DQB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10402") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10403():
    result = parse("HLA-DQA10510-DQB10403", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10403") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10404():
    result = parse("HLA-DQA10510-DQB10404", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10404") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10405():
    result = parse("HLA-DQA10510-DQB10405", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10405") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10406():
    result = parse("HLA-DQA10510-DQB10406", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10406") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10407():
    result = parse("HLA-DQA10510-DQB10407", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10407") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10408():
    result = parse("HLA-DQA10510-DQB10408", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10408") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10501():
    result = parse("HLA-DQA10510-DQB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10501") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10502():
    result = parse("HLA-DQA10510-DQB10502", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10502") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10503():
    result = parse("HLA-DQA10510-DQB10503", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10503") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10505():
    result = parse("HLA-DQA10510-DQB10505", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10505") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10506():
    result = parse("HLA-DQA10510-DQB10506", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10506") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10507():
    result = parse("HLA-DQA10510-DQB10507", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10507") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10508():
    result = parse("HLA-DQA10510-DQB10508", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10508") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10509():
    result = parse("HLA-DQA10510-DQB10509", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10509") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10510():
    result = parse("HLA-DQA10510-DQB10510", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10510") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10511():
    result = parse("HLA-DQA10510-DQB10511", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10511") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10512():
    result = parse("HLA-DQA10510-DQB10512", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10512") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10513():
    result = parse("HLA-DQA10510-DQB10513", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10513") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10514():
    result = parse("HLA-DQA10510-DQB10514", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10514") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10601():
    result = parse("HLA-DQA10510-DQB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10601") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10602():
    result = parse("HLA-DQA10510-DQB10602", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10602") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10603():
    result = parse("HLA-DQA10510-DQB10603", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10603") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10604():
    result = parse("HLA-DQA10510-DQB10604", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10604") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10607():
    result = parse("HLA-DQA10510-DQB10607", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10607") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10608():
    result = parse("HLA-DQA10510-DQB10608", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10608") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10609():
    result = parse("HLA-DQA10510-DQB10609", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10609") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10610():
    result = parse("HLA-DQA10510-DQB10610", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10610") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10611():
    result = parse("HLA-DQA10510-DQB10611", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10611") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10612():
    result = parse("HLA-DQA10510-DQB10612", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10612") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10614():
    result = parse("HLA-DQA10510-DQB10614", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10614") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10615():
    result = parse("HLA-DQA10510-DQB10615", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10615") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10616():
    result = parse("HLA-DQA10510-DQB10616", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10616") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10617():
    result = parse("HLA-DQA10510-DQB10617", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10617") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10618():
    result = parse("HLA-DQA10510-DQB10618", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10618") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10619():
    result = parse("HLA-DQA10510-DQB10619", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10619") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10621():
    result = parse("HLA-DQA10510-DQB10621", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10621") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10622():
    result = parse("HLA-DQA10510-DQB10622", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10622") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10623():
    result = parse("HLA-DQA10510-DQB10623", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10623") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10624():
    result = parse("HLA-DQA10510-DQB10624", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10624") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10625():
    result = parse("HLA-DQA10510-DQB10625", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10625") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10627():
    result = parse("HLA-DQA10510-DQB10627", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10627") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10628():
    result = parse("HLA-DQA10510-DQB10628", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10628") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10629():
    result = parse("HLA-DQA10510-DQB10629", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10629") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10630():
    result = parse("HLA-DQA10510-DQB10630", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10630") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10631():
    result = parse("HLA-DQA10510-DQB10631", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10631") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10632():
    result = parse("HLA-DQA10510-DQB10632", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10632") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10633():
    result = parse("HLA-DQA10510-DQB10633", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10633") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10634():
    result = parse("HLA-DQA10510-DQB10634", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10634") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10635():
    result = parse("HLA-DQA10510-DQB10635", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10635") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10636():
    result = parse("HLA-DQA10510-DQB10636", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10636") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10637():
    result = parse("HLA-DQA10510-DQB10637", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10637") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10638():
    result = parse("HLA-DQA10510-DQB10638", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10638") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10639():
    result = parse("HLA-DQA10510-DQB10639", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10639") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10640():
    result = parse("HLA-DQA10510-DQB10640", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10640") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10641():
    result = parse("HLA-DQA10510-DQB10641", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10641") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10642():
    result = parse("HLA-DQA10510-DQB10642", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10642") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10643():
    result = parse("HLA-DQA10510-DQB10643", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10643") to be Pair but got {result}'
    )


def test_HLA_DQA10510_DQB10644():
    result = parse("HLA-DQA10510-DQB10644", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10510-DQB10644") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10201():
    result = parse("HLA-DQA10511-DQB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10201") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10202():
    result = parse("HLA-DQA10511-DQB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10202") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10203():
    result = parse("HLA-DQA10511-DQB10203", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10203") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10204():
    result = parse("HLA-DQA10511-DQB10204", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10204") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10205():
    result = parse("HLA-DQA10511-DQB10205", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10205") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10206():
    result = parse("HLA-DQA10511-DQB10206", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10206") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10301():
    result = parse("HLA-DQA10511-DQB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10301") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10302():
    result = parse("HLA-DQA10511-DQB10302", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10302") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10303():
    result = parse("HLA-DQA10511-DQB10303", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10303") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10304():
    result = parse("HLA-DQA10511-DQB10304", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10304") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10305():
    result = parse("HLA-DQA10511-DQB10305", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10305") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10306():
    result = parse("HLA-DQA10511-DQB10306", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10306") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10307():
    result = parse("HLA-DQA10511-DQB10307", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10307") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10308():
    result = parse("HLA-DQA10511-DQB10308", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10308") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10309():
    result = parse("HLA-DQA10511-DQB10309", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10309") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10310():
    result = parse("HLA-DQA10511-DQB10310", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10310") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10311():
    result = parse("HLA-DQA10511-DQB10311", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10311") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10312():
    result = parse("HLA-DQA10511-DQB10312", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10312") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10313():
    result = parse("HLA-DQA10511-DQB10313", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10313") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10314():
    result = parse("HLA-DQA10511-DQB10314", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10314") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10315():
    result = parse("HLA-DQA10511-DQB10315", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10315") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10316():
    result = parse("HLA-DQA10511-DQB10316", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10316") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10317():
    result = parse("HLA-DQA10511-DQB10317", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10317") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10318():
    result = parse("HLA-DQA10511-DQB10318", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10318") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10319():
    result = parse("HLA-DQA10511-DQB10319", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10319") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10320():
    result = parse("HLA-DQA10511-DQB10320", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10320") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10321():
    result = parse("HLA-DQA10511-DQB10321", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10321") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10322():
    result = parse("HLA-DQA10511-DQB10322", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10322") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10323():
    result = parse("HLA-DQA10511-DQB10323", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10323") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10324():
    result = parse("HLA-DQA10511-DQB10324", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10324") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10325():
    result = parse("HLA-DQA10511-DQB10325", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10325") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10326():
    result = parse("HLA-DQA10511-DQB10326", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10326") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10327():
    result = parse("HLA-DQA10511-DQB10327", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10327") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10328():
    result = parse("HLA-DQA10511-DQB10328", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10328") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10329():
    result = parse("HLA-DQA10511-DQB10329", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10329") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10330():
    result = parse("HLA-DQA10511-DQB10330", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10330") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10331():
    result = parse("HLA-DQA10511-DQB10331", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10331") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10332():
    result = parse("HLA-DQA10511-DQB10332", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10332") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10333():
    result = parse("HLA-DQA10511-DQB10333", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10333") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10334():
    result = parse("HLA-DQA10511-DQB10334", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10334") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10335():
    result = parse("HLA-DQA10511-DQB10335", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10335") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10336():
    result = parse("HLA-DQA10511-DQB10336", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10336") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10337():
    result = parse("HLA-DQA10511-DQB10337", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10337") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10338():
    result = parse("HLA-DQA10511-DQB10338", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10338") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10401():
    result = parse("HLA-DQA10511-DQB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10401") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10402():
    result = parse("HLA-DQA10511-DQB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10402") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10403():
    result = parse("HLA-DQA10511-DQB10403", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10403") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10404():
    result = parse("HLA-DQA10511-DQB10404", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10404") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10405():
    result = parse("HLA-DQA10511-DQB10405", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10405") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10406():
    result = parse("HLA-DQA10511-DQB10406", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10406") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10407():
    result = parse("HLA-DQA10511-DQB10407", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10407") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10408():
    result = parse("HLA-DQA10511-DQB10408", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10408") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10501():
    result = parse("HLA-DQA10511-DQB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10501") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10502():
    result = parse("HLA-DQA10511-DQB10502", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10502") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10503():
    result = parse("HLA-DQA10511-DQB10503", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10503") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10505():
    result = parse("HLA-DQA10511-DQB10505", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10505") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10506():
    result = parse("HLA-DQA10511-DQB10506", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10506") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10507():
    result = parse("HLA-DQA10511-DQB10507", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10507") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10508():
    result = parse("HLA-DQA10511-DQB10508", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10508") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10509():
    result = parse("HLA-DQA10511-DQB10509", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10509") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10510():
    result = parse("HLA-DQA10511-DQB10510", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10510") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10511():
    result = parse("HLA-DQA10511-DQB10511", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10511") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10512():
    result = parse("HLA-DQA10511-DQB10512", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10512") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10513():
    result = parse("HLA-DQA10511-DQB10513", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10513") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10514():
    result = parse("HLA-DQA10511-DQB10514", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10514") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10601():
    result = parse("HLA-DQA10511-DQB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10601") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10602():
    result = parse("HLA-DQA10511-DQB10602", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10602") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10603():
    result = parse("HLA-DQA10511-DQB10603", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10603") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10604():
    result = parse("HLA-DQA10511-DQB10604", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10604") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10607():
    result = parse("HLA-DQA10511-DQB10607", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10607") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10608():
    result = parse("HLA-DQA10511-DQB10608", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10608") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10609():
    result = parse("HLA-DQA10511-DQB10609", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10609") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10610():
    result = parse("HLA-DQA10511-DQB10610", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10610") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10611():
    result = parse("HLA-DQA10511-DQB10611", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10611") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10612():
    result = parse("HLA-DQA10511-DQB10612", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10612") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10614():
    result = parse("HLA-DQA10511-DQB10614", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10614") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10615():
    result = parse("HLA-DQA10511-DQB10615", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10615") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10616():
    result = parse("HLA-DQA10511-DQB10616", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10616") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10617():
    result = parse("HLA-DQA10511-DQB10617", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10617") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10618():
    result = parse("HLA-DQA10511-DQB10618", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10618") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10619():
    result = parse("HLA-DQA10511-DQB10619", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10619") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10621():
    result = parse("HLA-DQA10511-DQB10621", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10621") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10622():
    result = parse("HLA-DQA10511-DQB10622", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10622") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10623():
    result = parse("HLA-DQA10511-DQB10623", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10623") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10624():
    result = parse("HLA-DQA10511-DQB10624", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10624") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10625():
    result = parse("HLA-DQA10511-DQB10625", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10625") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10627():
    result = parse("HLA-DQA10511-DQB10627", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10627") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10628():
    result = parse("HLA-DQA10511-DQB10628", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10628") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10629():
    result = parse("HLA-DQA10511-DQB10629", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10629") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10630():
    result = parse("HLA-DQA10511-DQB10630", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10630") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10631():
    result = parse("HLA-DQA10511-DQB10631", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10631") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10632():
    result = parse("HLA-DQA10511-DQB10632", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10632") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10633():
    result = parse("HLA-DQA10511-DQB10633", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10633") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10634():
    result = parse("HLA-DQA10511-DQB10634", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10634") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10635():
    result = parse("HLA-DQA10511-DQB10635", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10635") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10636():
    result = parse("HLA-DQA10511-DQB10636", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10636") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10637():
    result = parse("HLA-DQA10511-DQB10637", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10637") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10638():
    result = parse("HLA-DQA10511-DQB10638", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10638") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10639():
    result = parse("HLA-DQA10511-DQB10639", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10639") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10640():
    result = parse("HLA-DQA10511-DQB10640", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10640") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10641():
    result = parse("HLA-DQA10511-DQB10641", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10641") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10642():
    result = parse("HLA-DQA10511-DQB10642", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10642") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10643():
    result = parse("HLA-DQA10511-DQB10643", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10643") to be Pair but got {result}'
    )


def test_HLA_DQA10511_DQB10644():
    result = parse("HLA-DQA10511-DQB10644", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10511-DQB10644") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10201():
    result = parse("HLA-DQA10601-DQB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10201") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10202():
    result = parse("HLA-DQA10601-DQB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10202") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10203():
    result = parse("HLA-DQA10601-DQB10203", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10203") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10204():
    result = parse("HLA-DQA10601-DQB10204", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10204") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10205():
    result = parse("HLA-DQA10601-DQB10205", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10205") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10206():
    result = parse("HLA-DQA10601-DQB10206", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10206") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10301():
    result = parse("HLA-DQA10601-DQB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10301") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10302():
    result = parse("HLA-DQA10601-DQB10302", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10302") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10303():
    result = parse("HLA-DQA10601-DQB10303", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10303") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10304():
    result = parse("HLA-DQA10601-DQB10304", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10304") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10305():
    result = parse("HLA-DQA10601-DQB10305", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10305") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10306():
    result = parse("HLA-DQA10601-DQB10306", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10306") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10307():
    result = parse("HLA-DQA10601-DQB10307", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10307") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10308():
    result = parse("HLA-DQA10601-DQB10308", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10308") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10309():
    result = parse("HLA-DQA10601-DQB10309", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10309") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10310():
    result = parse("HLA-DQA10601-DQB10310", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10310") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10311():
    result = parse("HLA-DQA10601-DQB10311", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10311") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10312():
    result = parse("HLA-DQA10601-DQB10312", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10312") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10313():
    result = parse("HLA-DQA10601-DQB10313", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10313") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10314():
    result = parse("HLA-DQA10601-DQB10314", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10314") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10315():
    result = parse("HLA-DQA10601-DQB10315", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10315") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10316():
    result = parse("HLA-DQA10601-DQB10316", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10316") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10317():
    result = parse("HLA-DQA10601-DQB10317", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10317") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10318():
    result = parse("HLA-DQA10601-DQB10318", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10318") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10319():
    result = parse("HLA-DQA10601-DQB10319", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10319") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10320():
    result = parse("HLA-DQA10601-DQB10320", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10320") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10321():
    result = parse("HLA-DQA10601-DQB10321", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10321") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10322():
    result = parse("HLA-DQA10601-DQB10322", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10322") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10323():
    result = parse("HLA-DQA10601-DQB10323", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10323") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10324():
    result = parse("HLA-DQA10601-DQB10324", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10324") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10325():
    result = parse("HLA-DQA10601-DQB10325", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10325") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10326():
    result = parse("HLA-DQA10601-DQB10326", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10326") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10327():
    result = parse("HLA-DQA10601-DQB10327", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10327") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10328():
    result = parse("HLA-DQA10601-DQB10328", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10328") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10329():
    result = parse("HLA-DQA10601-DQB10329", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10329") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10330():
    result = parse("HLA-DQA10601-DQB10330", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10330") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10331():
    result = parse("HLA-DQA10601-DQB10331", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10331") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10332():
    result = parse("HLA-DQA10601-DQB10332", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10332") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10333():
    result = parse("HLA-DQA10601-DQB10333", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10333") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10334():
    result = parse("HLA-DQA10601-DQB10334", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10334") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10335():
    result = parse("HLA-DQA10601-DQB10335", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10335") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10336():
    result = parse("HLA-DQA10601-DQB10336", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10336") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10337():
    result = parse("HLA-DQA10601-DQB10337", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10337") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10338():
    result = parse("HLA-DQA10601-DQB10338", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10338") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10401():
    result = parse("HLA-DQA10601-DQB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10401") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10402():
    result = parse("HLA-DQA10601-DQB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10402") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10403():
    result = parse("HLA-DQA10601-DQB10403", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10403") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10404():
    result = parse("HLA-DQA10601-DQB10404", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10404") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10405():
    result = parse("HLA-DQA10601-DQB10405", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10405") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10406():
    result = parse("HLA-DQA10601-DQB10406", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10406") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10407():
    result = parse("HLA-DQA10601-DQB10407", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10407") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10408():
    result = parse("HLA-DQA10601-DQB10408", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10408") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10501():
    result = parse("HLA-DQA10601-DQB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10501") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10502():
    result = parse("HLA-DQA10601-DQB10502", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10502") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10503():
    result = parse("HLA-DQA10601-DQB10503", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10503") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10505():
    result = parse("HLA-DQA10601-DQB10505", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10505") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10506():
    result = parse("HLA-DQA10601-DQB10506", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10506") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10507():
    result = parse("HLA-DQA10601-DQB10507", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10507") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10508():
    result = parse("HLA-DQA10601-DQB10508", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10508") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10509():
    result = parse("HLA-DQA10601-DQB10509", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10509") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10510():
    result = parse("HLA-DQA10601-DQB10510", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10510") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10511():
    result = parse("HLA-DQA10601-DQB10511", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10511") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10512():
    result = parse("HLA-DQA10601-DQB10512", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10512") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10513():
    result = parse("HLA-DQA10601-DQB10513", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10513") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10514():
    result = parse("HLA-DQA10601-DQB10514", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10514") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10601():
    result = parse("HLA-DQA10601-DQB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10601") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10602():
    result = parse("HLA-DQA10601-DQB10602", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10602") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10603():
    result = parse("HLA-DQA10601-DQB10603", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10603") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10604():
    result = parse("HLA-DQA10601-DQB10604", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10604") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10607():
    result = parse("HLA-DQA10601-DQB10607", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10607") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10608():
    result = parse("HLA-DQA10601-DQB10608", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10608") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10609():
    result = parse("HLA-DQA10601-DQB10609", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10609") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10610():
    result = parse("HLA-DQA10601-DQB10610", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10610") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10611():
    result = parse("HLA-DQA10601-DQB10611", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10611") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10612():
    result = parse("HLA-DQA10601-DQB10612", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10612") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10614():
    result = parse("HLA-DQA10601-DQB10614", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10614") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10615():
    result = parse("HLA-DQA10601-DQB10615", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10615") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10616():
    result = parse("HLA-DQA10601-DQB10616", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10616") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10617():
    result = parse("HLA-DQA10601-DQB10617", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10617") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10618():
    result = parse("HLA-DQA10601-DQB10618", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10618") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10619():
    result = parse("HLA-DQA10601-DQB10619", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10619") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10621():
    result = parse("HLA-DQA10601-DQB10621", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10621") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10622():
    result = parse("HLA-DQA10601-DQB10622", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10622") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10623():
    result = parse("HLA-DQA10601-DQB10623", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10623") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10624():
    result = parse("HLA-DQA10601-DQB10624", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10624") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10625():
    result = parse("HLA-DQA10601-DQB10625", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10625") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10627():
    result = parse("HLA-DQA10601-DQB10627", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10627") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10628():
    result = parse("HLA-DQA10601-DQB10628", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10628") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10629():
    result = parse("HLA-DQA10601-DQB10629", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10629") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10630():
    result = parse("HLA-DQA10601-DQB10630", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10630") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10631():
    result = parse("HLA-DQA10601-DQB10631", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10631") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10632():
    result = parse("HLA-DQA10601-DQB10632", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10632") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10633():
    result = parse("HLA-DQA10601-DQB10633", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10633") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10634():
    result = parse("HLA-DQA10601-DQB10634", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10634") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10635():
    result = parse("HLA-DQA10601-DQB10635", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10635") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10636():
    result = parse("HLA-DQA10601-DQB10636", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10636") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10637():
    result = parse("HLA-DQA10601-DQB10637", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10637") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10638():
    result = parse("HLA-DQA10601-DQB10638", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10638") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10639():
    result = parse("HLA-DQA10601-DQB10639", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10639") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10640():
    result = parse("HLA-DQA10601-DQB10640", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10640") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10641():
    result = parse("HLA-DQA10601-DQB10641", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10641") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10642():
    result = parse("HLA-DQA10601-DQB10642", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10642") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10643():
    result = parse("HLA-DQA10601-DQB10643", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10643") to be Pair but got {result}'
    )


def test_HLA_DQA10601_DQB10644():
    result = parse("HLA-DQA10601-DQB10644", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10601-DQB10644") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10201():
    result = parse("HLA-DQA10602-DQB10201", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10201") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10202():
    result = parse("HLA-DQA10602-DQB10202", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10202") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10203():
    result = parse("HLA-DQA10602-DQB10203", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10203") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10204():
    result = parse("HLA-DQA10602-DQB10204", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10204") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10205():
    result = parse("HLA-DQA10602-DQB10205", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10205") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10206():
    result = parse("HLA-DQA10602-DQB10206", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10206") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10301():
    result = parse("HLA-DQA10602-DQB10301", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10301") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10302():
    result = parse("HLA-DQA10602-DQB10302", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10302") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10303():
    result = parse("HLA-DQA10602-DQB10303", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10303") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10304():
    result = parse("HLA-DQA10602-DQB10304", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10304") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10305():
    result = parse("HLA-DQA10602-DQB10305", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10305") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10306():
    result = parse("HLA-DQA10602-DQB10306", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10306") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10307():
    result = parse("HLA-DQA10602-DQB10307", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10307") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10308():
    result = parse("HLA-DQA10602-DQB10308", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10308") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10309():
    result = parse("HLA-DQA10602-DQB10309", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10309") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10310():
    result = parse("HLA-DQA10602-DQB10310", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10310") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10311():
    result = parse("HLA-DQA10602-DQB10311", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10311") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10312():
    result = parse("HLA-DQA10602-DQB10312", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10312") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10313():
    result = parse("HLA-DQA10602-DQB10313", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10313") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10314():
    result = parse("HLA-DQA10602-DQB10314", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10314") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10315():
    result = parse("HLA-DQA10602-DQB10315", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10315") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10316():
    result = parse("HLA-DQA10602-DQB10316", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10316") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10317():
    result = parse("HLA-DQA10602-DQB10317", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10317") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10318():
    result = parse("HLA-DQA10602-DQB10318", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10318") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10319():
    result = parse("HLA-DQA10602-DQB10319", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10319") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10320():
    result = parse("HLA-DQA10602-DQB10320", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10320") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10321():
    result = parse("HLA-DQA10602-DQB10321", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10321") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10322():
    result = parse("HLA-DQA10602-DQB10322", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10322") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10323():
    result = parse("HLA-DQA10602-DQB10323", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10323") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10324():
    result = parse("HLA-DQA10602-DQB10324", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10324") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10325():
    result = parse("HLA-DQA10602-DQB10325", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10325") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10326():
    result = parse("HLA-DQA10602-DQB10326", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10326") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10327():
    result = parse("HLA-DQA10602-DQB10327", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10327") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10328():
    result = parse("HLA-DQA10602-DQB10328", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10328") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10329():
    result = parse("HLA-DQA10602-DQB10329", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10329") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10330():
    result = parse("HLA-DQA10602-DQB10330", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10330") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10331():
    result = parse("HLA-DQA10602-DQB10331", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10331") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10332():
    result = parse("HLA-DQA10602-DQB10332", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10332") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10333():
    result = parse("HLA-DQA10602-DQB10333", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10333") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10334():
    result = parse("HLA-DQA10602-DQB10334", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10334") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10335():
    result = parse("HLA-DQA10602-DQB10335", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10335") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10336():
    result = parse("HLA-DQA10602-DQB10336", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10336") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10337():
    result = parse("HLA-DQA10602-DQB10337", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10337") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10338():
    result = parse("HLA-DQA10602-DQB10338", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10338") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10401():
    result = parse("HLA-DQA10602-DQB10401", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10401") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10402():
    result = parse("HLA-DQA10602-DQB10402", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10402") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10403():
    result = parse("HLA-DQA10602-DQB10403", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10403") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10404():
    result = parse("HLA-DQA10602-DQB10404", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10404") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10405():
    result = parse("HLA-DQA10602-DQB10405", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10405") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10406():
    result = parse("HLA-DQA10602-DQB10406", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10406") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10407():
    result = parse("HLA-DQA10602-DQB10407", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10407") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10408():
    result = parse("HLA-DQA10602-DQB10408", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10408") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10501():
    result = parse("HLA-DQA10602-DQB10501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10501") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10502():
    result = parse("HLA-DQA10602-DQB10502", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10502") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10503():
    result = parse("HLA-DQA10602-DQB10503", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10503") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10505():
    result = parse("HLA-DQA10602-DQB10505", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10505") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10506():
    result = parse("HLA-DQA10602-DQB10506", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10506") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10507():
    result = parse("HLA-DQA10602-DQB10507", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10507") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10508():
    result = parse("HLA-DQA10602-DQB10508", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10508") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10509():
    result = parse("HLA-DQA10602-DQB10509", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10509") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10510():
    result = parse("HLA-DQA10602-DQB10510", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10510") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10511():
    result = parse("HLA-DQA10602-DQB10511", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10511") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10512():
    result = parse("HLA-DQA10602-DQB10512", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10512") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10513():
    result = parse("HLA-DQA10602-DQB10513", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10513") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10514():
    result = parse("HLA-DQA10602-DQB10514", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10514") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10601():
    result = parse("HLA-DQA10602-DQB10601", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10601") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10602():
    result = parse("HLA-DQA10602-DQB10602", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10602") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10603():
    result = parse("HLA-DQA10602-DQB10603", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10603") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10604():
    result = parse("HLA-DQA10602-DQB10604", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10604") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10607():
    result = parse("HLA-DQA10602-DQB10607", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10607") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10608():
    result = parse("HLA-DQA10602-DQB10608", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10608") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10609():
    result = parse("HLA-DQA10602-DQB10609", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10609") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10610():
    result = parse("HLA-DQA10602-DQB10610", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10610") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10611():
    result = parse("HLA-DQA10602-DQB10611", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10611") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10612():
    result = parse("HLA-DQA10602-DQB10612", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10612") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10614():
    result = parse("HLA-DQA10602-DQB10614", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10614") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10615():
    result = parse("HLA-DQA10602-DQB10615", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10615") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10616():
    result = parse("HLA-DQA10602-DQB10616", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10616") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10617():
    result = parse("HLA-DQA10602-DQB10617", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10617") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10618():
    result = parse("HLA-DQA10602-DQB10618", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10618") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10619():
    result = parse("HLA-DQA10602-DQB10619", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10619") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10621():
    result = parse("HLA-DQA10602-DQB10621", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10621") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10622():
    result = parse("HLA-DQA10602-DQB10622", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10622") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10623():
    result = parse("HLA-DQA10602-DQB10623", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10623") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10624():
    result = parse("HLA-DQA10602-DQB10624", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10624") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10625():
    result = parse("HLA-DQA10602-DQB10625", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10625") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10627():
    result = parse("HLA-DQA10602-DQB10627", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10627") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10628():
    result = parse("HLA-DQA10602-DQB10628", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10628") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10629():
    result = parse("HLA-DQA10602-DQB10629", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10629") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10630():
    result = parse("HLA-DQA10602-DQB10630", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10630") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10631():
    result = parse("HLA-DQA10602-DQB10631", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10631") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10632():
    result = parse("HLA-DQA10602-DQB10632", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10632") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10633():
    result = parse("HLA-DQA10602-DQB10633", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10633") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10634():
    result = parse("HLA-DQA10602-DQB10634", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10634") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10635():
    result = parse("HLA-DQA10602-DQB10635", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10635") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10636():
    result = parse("HLA-DQA10602-DQB10636", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10636") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10637():
    result = parse("HLA-DQA10602-DQB10637", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10637") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10638():
    result = parse("HLA-DQA10602-DQB10638", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10638") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10639():
    result = parse("HLA-DQA10602-DQB10639", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10639") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10640():
    result = parse("HLA-DQA10602-DQB10640", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10640") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10641():
    result = parse("HLA-DQA10602-DQB10641", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10641") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10642():
    result = parse("HLA-DQA10602-DQB10642", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10642") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10643():
    result = parse("HLA-DQA10602-DQB10643", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10643") to be Pair but got {result}'
    )


def test_HLA_DQA10602_DQB10644():
    result = parse("HLA-DQA10602-DQB10644", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("HLA-DQA10602-DQB10644") to be Pair but got {result}'
    )


def test_BoLA_DRA_DRB30101():
    result = parse("BoLA-DRA-DRB30101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("BoLA-DRA-DRB30101") to be Pair but got {result}'
    )


def test_BoLA_DRA_DRB31101():
    result = parse("BoLA-DRA-DRB31101", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("BoLA-DRA-DRB31101") to be Pair but got {result}'
    )


def test_BoLA_DRA_DRB31501():
    result = parse("BoLA-DRA-DRB31501", infer_class2_pairing=True)
    assert result.__class__ is Pair, (
        f'Expected parse("BoLA-DRA-DRB31501") to be Pair but got {result}'
    )
